/*
 * x11-calc-10.c - RPN (Reverse Polish) calculator simulator.
 *
 * Copyright(C) 2021   MT
 *
 * Model specific functions.
 *
 * This  program is free software: you can redistribute it and/or modify it
 * under  the terms of the GNU General Public License as published  by  the
 * Free  Software Foundation, either version 3 of the License, or (at  your
 * option) any later version.
 *
 * This  program  is distributed in the hope that it will  be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without even   the   implied   warranty   of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You  should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 10 Oct 21         - Initial version - MT
 * 03 Jan 21         - Changed debug() macro so that debug code is executed
 *                     when DEBUG is defined (doesn't need to be true) - MT
 * 31 Jan 22         - Added ROM - MT
 * 12 Mar 22         - Added the label state property - MT
 * 22 May 22         - Fixed shortcut key for SST - MT
 * 18 Mar 24         - Embedded firmware - MT
 *
 * TO DO :           -
 */

#define NAME           "x11-calc-10c"
#define BUILD          "0006"
#define DATE           "18 Mar 24"
#define AUTHOR         "MT"

#include <stdarg.h>    /* strlen(), etc. */
#include <stdio.h>     /* fprintf(), etc. */
#include <stdlib.h>    /* getenv(), etc. */

#include <X11/Xlib.h>  /* XOpenDisplay(), etc. */
#include <X11/Xutil.h> /* XSizeHints etc. */

#include "x11-calc-font.h"
#include "x11-calc-button.h"
#include "x11-calc-switch.h"
#include "x11-calc-label.h"
#include "x11-calc-colour.h"

#include "x11-calc-cpu.h"

#include "x11-calc.h"

#include "gcc-debug.h"

oregister o_mem[MEMORY_SIZE];

int i_rom[ROM_SIZE];

void v_init_labels(olabel *h_label[]) {
   int i_height = h_small_font->ascent + h_small_font->descent;
   h_label[0] = h_label_create(001, "CLEAR" , h_alternate_font, KBD_LEFT + 2 * (KEY_WIDTH + KEY_GAP),
      KBD_TOP + KEY_HEIGHT +  2 * (KBD_ROW - i_height) + h_small_font->descent,
      2 * (KEY_WIDTH + KEY_GAP) + KEY_WIDTH, i_height, YELLOW, BACKGROUND, -1);
}

void v_init_buttons(obutton *h_button[]) {
   int i_left, i_top, i_count;

   /* Define top row of keys. */
   i_top = KBD_TOP + KEY_HEIGHT;
   i_left = KBD_LEFT;
   i_count = 0;
   h_button[i_count++] = h_button_create(00023, 000, "/\xaf", "x\xb2", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00063, 000, "eX", "ln", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00163, 000, "10x", "log", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00303, 000, "yX", "-HMS", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00203, 000, "1/x", "-H", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00202, 'c', "CHS", "\x1c", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00302, '7', "7", "FIX", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00162, '8', "8", "SCI", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00062, '9', "9", "ENG", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00022, '/', "\xf7", "X\x1a\x59", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define second row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00020, 000, "%", "-R", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00060, 000, "GTO", "-P", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00160, 000, "SIN", "SIN\xaf\xb9", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00300, 000, "COS", "COS\xaf\xb9", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00200, 000, "TAN", "TAN\xaf\xb9", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00207, 'e', "EEX", "n!", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00307, '4', "4", "DEG", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00167, '5', "5", "RAD", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00067, '6', "6", "GRD", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00027, '*', "\xd7", "X=0", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define third row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00021, 000, "R/S", "PSE", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00061, ' ', "SST", "BST", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00161, 000, "Rv", "PRGM", "", "", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00301, 000, "X-Y", "REG", "", "", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00201, 033, "CLx", "PREFIX", "", "", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00204, 015, "ENTER", "LSTx", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT + KBD_ROW, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00304, '1', "1", "x,r", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00164, '2', "2", "y,r", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00064, '3', "3", "L.R", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00024, '-', "-", "-RAD", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);


   /* Define fourth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00030, 000, "ON", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, True, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00070, 'f', "f", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, YELLOW, BACKGROUND, YELLOW, YELLOW);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00170, 000, "P/R", "MEM", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00310, 000, "STO", "INT", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00210, 000, "RCL", "FRAC", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00305, '0', "0", "x", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00165, '.', ".", "s", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00065, 000, "E+", "E-", "", "",  h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00025, '+', "+", "-DEG", "", "",  h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
}

int i_rom[ROM_SIZE] = {
   0x0107, 0x004e, 0x0270, 0x0238, 0x02ee, 0x013f, 0x01e5, 0x0000,
   0x004e, 0x02e0, 0x006e, 0x0014, 0x006b, 0x00a1, 0x0000, 0x013b,
   0x00dc, 0x00e1, 0x00bc, 0x00dd, 0x00d9, 0x00b9, 0x0393, 0x00d6,
   0x002c, 0x0220, 0x0330, 0x005a, 0x01bc, 0x0170, 0x0071, 0x001a,
   0x01e5, 0x0000, 0x02b9, 0x0000, 0x0366, 0x003f, 0x011d, 0x001e,
   0x02b9, 0x0000, 0x0366, 0x0360, 0x02e0, 0x0143, 0x0248, 0x0083,
   0x00ff, 0x015c, 0x0150, 0x00e8, 0x0120, 0x00f3, 0x01b3, 0x011d,
   0x0085, 0x006d, 0x0018, 0x00b0, 0x03e8, 0x00ae, 0x0244, 0x00a0,
   0x03a9, 0x0014, 0x00d5, 0x0018, 0x00d4, 0x0013, 0x0204, 0x0070,
   0x020c, 0x011d, 0x000c, 0x020c, 0x02ad, 0x0007, 0x035c, 0x0006,
   0x0079, 0x0008, 0x004c, 0x021f, 0x018c, 0x00f5, 0x000c, 0x0344,
   0x0260, 0x004e, 0x0270, 0x026e, 0x0228, 0x0060, 0x0000, 0x004e,
   0x0270, 0x0078, 0x00ee, 0x0158, 0x0071, 0x0018, 0x017c, 0x00de,
   0x01d8, 0x00ee, 0x005e, 0x03e0, 0x00b0, 0x038c, 0x01e7, 0x0283,
   0x00e6, 0x00b5, 0x0154, 0x00e7, 0x0121, 0x0111, 0x02c3, 0x011e,
   0x00a5, 0x0260, 0x00a0, 0x0101, 0x000c, 0x03cc, 0x0360, 0x02c3,
   0x00e4, 0x00c9, 0x00e9, 0x00de, 0x00e0, 0x019c, 0x024b, 0x00ea,
   0x010a, 0x023b, 0x0384, 0x02f8, 0x038c, 0x009b, 0x03c6, 0x0276,
   0x03c6, 0x038d, 0x000c, 0x0222, 0x0102, 0x02d0, 0x039c, 0x00a2,
   0x0362, 0x03c7, 0x025c, 0x0102, 0x004e, 0x00a2, 0x0179, 0x0038,
   0x031c, 0x004a, 0x02e8, 0x02a5, 0x0006, 0x0194, 0x0139, 0x001b,
   0x038c, 0x030f, 0x0260, 0x01a9, 0x0010, 0x024b, 0x004e, 0x0220,
   0x003c, 0x0106, 0x0130, 0x0018, 0x03e0, 0x0194, 0x02af, 0x019c,
   0x015b, 0x0254, 0x00c7, 0x01cb, 0x0254, 0x0097, 0x01bb, 0x0000,
   0x00e5, 0x00e2, 0x0158, 0x00df, 0x0122, 0x0123, 0x021b, 0x011f,
   0x0105, 0x0194, 0x00cb, 0x038c, 0x0131, 0x001a, 0x02fb, 0x0166,
   0x0166, 0x0166, 0x03e6, 0x03e6, 0x005c, 0x038b, 0x0254, 0x03cf,
   0x00fb, 0x0254, 0x03bf, 0x00db, 0x0166, 0x0166, 0x0166, 0x0166,
   0x0166, 0x0166, 0x0166, 0x0166, 0x0166, 0x0166, 0x0166, 0x0166,
   0x0166, 0x0166, 0x0166, 0x0194, 0x0023, 0x031c, 0x02d0, 0x00fb,
   0x031c, 0x0290, 0x00e3, 0x0166, 0x0166, 0x0166, 0x0166, 0x0194,
   0x0027, 0x031c, 0x0310, 0x009b, 0x031c, 0x0350, 0x0083, 0x0194,
   0x00af, 0x031c, 0x0084, 0x03e6, 0x028b, 0x0194, 0x0087, 0x025c,
   0x0006, 0x03cb, 0x0194, 0x008f, 0x00dc, 0x03db, 0x031c, 0x0102,
   0x01f3, 0x0314, 0x02cb, 0x0088, 0x0383, 0x0166, 0x0166, 0x0314,
   0x0023, 0x0342, 0x037d, 0x0006, 0x0166, 0x0166, 0x0166, 0x0166,
   0x0166, 0x0166, 0x0166, 0x0054, 0x0063, 0x0130, 0x00d8, 0x0206,
   0x01f6, 0x01f6, 0x0156, 0x0386, 0x0386, 0x0206, 0x0146, 0x00f3,
   0x0194, 0x002b, 0x0130, 0x00c5, 0x0146, 0x00cb, 0x0314, 0x0053,
   0x0342, 0x001f, 0x0166, 0x0243, 0x01a2, 0x008c, 0x016d, 0x0017,
   0x0073, 0x0154, 0x0013, 0x019c, 0x0166, 0x03e6, 0x0214, 0x0013,
   0x035c, 0x03dc, 0x01a6, 0x02d4, 0x03eb, 0x0084, 0x02f1, 0x0006,
   0x0194, 0x0223, 0x029c, 0x020b, 0x0194, 0x020b, 0x011c, 0x03e3,
   0x0194, 0x021b, 0x015c, 0x03c3, 0x0194, 0x012b, 0x02f8, 0x031c,
   0x0106, 0x02ea, 0x0067, 0x0386, 0x00a2, 0x0222, 0x03ca, 0x0053,
   0x01a9, 0x0010, 0x00e9, 0x000c, 0x01b1, 0x0002, 0x0262, 0x004b,
   0x0226, 0x0190, 0x02e8, 0x038c, 0x03a3, 0x03c9, 0x0014, 0x033b,
   0x0106, 0x0110, 0x0310, 0x0366, 0x001b, 0x00a6, 0x03a3, 0x031c,
   0x004a, 0x038b, 0x038c, 0x00c7, 0x0348, 0x02f8, 0x031c, 0x02ea,
   0x001f, 0x02fd, 0x001c, 0x01a9, 0x0010, 0x00e9, 0x000c, 0x0001,
   0x0018, 0x01d8, 0x00ae, 0x034c, 0x0113, 0x0355, 0x001c, 0x0198,
   0x0335, 0x0014, 0x00f3, 0x0355, 0x001c, 0x03c9, 0x0014, 0x03e3,
   0x0260, 0x020c, 0x002f, 0x0208, 0x034c, 0x0027, 0x02fb, 0x0355,
   0x001c, 0x0204, 0x0213, 0x02ed, 0x001c, 0x00cc, 0x0281, 0x0003,
   0x03cc, 0x002b, 0x00a1, 0x0000, 0x028c, 0x03a3, 0x0331, 0x0014,
   0x02dd, 0x001c, 0x01e5, 0x0012, 0x038c, 0x03eb, 0x008e, 0x02ed,
   0x001c, 0x00cc, 0x00df, 0x02e8, 0x0331, 0x0014, 0x00cc, 0x0013,
   0x004e, 0x031c, 0x006e, 0x00ee, 0x002b, 0x03ee, 0x03ee, 0x03dc,
   0x03dc, 0x0276, 0x03db, 0x006a, 0x0314, 0x0027, 0x03d4, 0x03d4,
   0x006a, 0x00ee, 0x02f0, 0x02a9, 0x0002, 0x0276, 0x032b, 0x005c,
   0x0231, 0x001e, 0x0013, 0x0033, 0x0073, 0x00c3, 0x0083, 0x0082,
   0x00c2, 0x0072, 0x0032, 0x0012, 0x0010, 0x0030, 0x0070, 0x00c0,
   0x0080, 0x0087, 0x00c7, 0x0077, 0x0037, 0x0017, 0x0011, 0x0031,
   0x0071, 0x00c1, 0x0081, 0x0084, 0x00c4, 0x0074, 0x0034, 0x0014,
   0x0018, 0x0038, 0x0078, 0x00c8, 0x0088, 0x0084, 0x00c5, 0x0075,
   0x0035, 0x0015, 0x00b5, 0x0030, 0x001b, 0x00ad, 0x0030, 0x00d5,
   0x0018, 0x02f0, 0x035c, 0x03e0, 0x008c, 0x03a0, 0x00be, 0x02be,
   0x00be, 0x03e0, 0x035c, 0x0048, 0x001b, 0x010e, 0x0044, 0x0260,
   0x0184, 0x003d, 0x000c, 0x004e, 0x0270, 0x00e0, 0x00ae, 0x0068,
   0x00b5, 0x000c, 0x02d6, 0x001b, 0x02dc, 0x0210, 0x027c, 0x00b1,
   0x000c, 0x02d6, 0x001b, 0x019c, 0x0090, 0x013c, 0x03d9, 0x003c,
   0x0078, 0x033c, 0x0068, 0x00dc, 0x0222, 0x003f, 0x010c, 0x002b,
   0x021c, 0x0276, 0x0017, 0x02d0, 0x00c1, 0x000c, 0x02d6, 0x001b,
   0x011c, 0x0210, 0x00ad, 0x000c, 0x02d6, 0x001b, 0x015c, 0x0090,
   0x007c, 0x00b1, 0x000c, 0x02d6, 0x001b, 0x001c, 0x0210, 0x023c,
   0x014e, 0x00ae, 0x0035, 0x000c, 0x000e, 0x00b5, 0x000c, 0x02d6,
   0x001b, 0x019c, 0x0090, 0x00ad, 0x000c, 0x02d6, 0x001b, 0x035c,
   0x0210, 0x013c, 0x00b1, 0x000c, 0x02d6, 0x001b, 0x035c, 0x0210,
   0x02fc, 0x00b1, 0x000c, 0x02d6, 0x001b, 0x00dc, 0x0090, 0x037c,
   0x03d9, 0x003c, 0x00b5, 0x000c, 0x02d6, 0x0013, 0x0090, 0x00bc,
   0x03d9, 0x003c, 0x00ae, 0x0065, 0x000c, 0x0078, 0x007c, 0x0068,
   0x018c, 0x0023, 0x004c, 0x000d, 0x000f, 0x01a0, 0x0078, 0x011e,
   0x017e, 0x036d, 0x000b, 0x02a0, 0x02be, 0x0260, 0x000e, 0x02fc,
   0x039c, 0x0102, 0x004e, 0x0130, 0x0002, 0x030c, 0x001b, 0x0130,
   0x0003, 0x01a2, 0x0097, 0x01a2, 0x00e7, 0x01a2, 0x011f, 0x01a2,
   0x007f, 0x01a2, 0x00cf, 0x01a2, 0x010f, 0x01a2, 0x006f, 0x01a2,
   0x00bf, 0x01a2, 0x0107, 0x005b, 0x027c, 0x0089, 0x000c, 0x007c,
   0x014e, 0x0081, 0x000c, 0x017c, 0x0089, 0x000c, 0x023c, 0x00a3,
   0x01bc, 0x0089, 0x000c, 0x023c, 0x014e, 0x0081, 0x000c, 0x013c,
   0x005b, 0x00fc, 0x014e, 0x0081, 0x000c, 0x027c, 0x03d9, 0x003c,
   0x008d, 0x000c, 0x033c, 0x014e, 0x019c, 0x00b0, 0x02fe, 0x0023,
   0x0110, 0x019c, 0x0142, 0x02b8, 0x0370, 0x02a8, 0x006e, 0x002d,
   0x000c, 0x004e, 0x00a0, 0x0194, 0x0023, 0x0130, 0x0004, 0x033c,
   0x00e0, 0x0059, 0x000c, 0x0071, 0x0018, 0x00fc, 0x005a, 0x0046,
   0x0270, 0x01fe, 0x01fe, 0x003b, 0x021c, 0x0050, 0x02fe, 0x001b,
   0x031c, 0x0110, 0x005e, 0x038c, 0x001b, 0x005c, 0x0110, 0x0029,
   0x000c, 0x0069, 0x000c, 0x0078, 0x00ee, 0x00a0, 0x02e0, 0x0320,
   0x0071, 0x001a, 0x010e, 0x0278, 0x0370, 0x0268, 0x0063, 0x004c,
   0x0360, 0x03c8, 0x03cc, 0x0360, 0x0188, 0x015b, 0x010e, 0x02b8,
   0x0370, 0x02a8, 0x018c, 0x03a3, 0x03cc, 0x03a0, 0x0048, 0x03e0,
   0x006e, 0x0013, 0x014e, 0x004e, 0x0130, 0x0002, 0x030c, 0x0360,
   0x0130, 0x0003, 0x03e0, 0x017c, 0x014e, 0x0078, 0x033c, 0x0068,
   0x005a, 0x005c, 0x00d0, 0x03d0, 0x02fc, 0x0330, 0x00f6, 0x005a,
   0x0056, 0x03e0, 0x0384, 0x0079, 0x0008, 0x03c8, 0x03cc, 0x03f7,
   0x0130, 0x0004, 0x03c8, 0x03cc, 0x0266, 0x03eb, 0x03e0, 0x00b0,
   0x00ee, 0x028c, 0x0360, 0x0084, 0x0104, 0x039c, 0x0098, 0x031c,
   0x02e2, 0x0033, 0x0108, 0x0262, 0x02e2, 0x0013, 0x0088, 0x02a0,
   0x0006, 0x039c, 0x00a2, 0x00ce, 0x0066, 0x010c, 0x00ef, 0x0356,
   0x00af, 0x0130, 0x0010, 0x0306, 0x00b3, 0x0126, 0x0306, 0x001f,
   0x0266, 0x0106, 0x02dd, 0x000c, 0x02f6, 0x0013, 0x03dc, 0x02f9,
   0x000c, 0x001e, 0x0356, 0x00d7, 0x01eb, 0x0066, 0x0086, 0x0166,
   0x0146, 0x038f, 0x0108, 0x0066, 0x02dd, 0x000c, 0x02f9, 0x000c,
   0x008c, 0x00a7, 0x02f6, 0x0023, 0x02a0, 0x0286, 0x0276, 0x00a6,
   0x009c, 0x03ea, 0x03ea, 0x03ea, 0x0143, 0x02fe, 0x001f, 0x02fa,
   0x0353, 0x038e, 0x0226, 0x03f3, 0x00fb, 0x00e6, 0x0176, 0x01a6,
   0x0130, 0x0030, 0x01c6, 0x03fb, 0x0146, 0x03c6, 0x01c6, 0x03fb,
   0x0146, 0x00c6, 0x035c, 0x0013, 0x01a2, 0x01a6, 0x02e7, 0x017e,
   0x02a0, 0x0266, 0x03d4, 0x0260, 0x0162, 0x03bb, 0x03bb, 0x017e,
   0x01a6, 0x0346, 0x03ef, 0x0260, 0x0006, 0x0084, 0x03e0, 0x00b0,
   0x005e, 0x035c, 0x03d4, 0x01a6, 0x03f3, 0x03e0, 0x000e, 0x010a,
   0x015a, 0x0013, 0x017e, 0x000a, 0x00be, 0x00ba, 0x02fe, 0x0093,
   0x010c, 0x00bb, 0x0226, 0x02f6, 0x004b, 0x0276, 0x02f6, 0x002f,
   0x00b0, 0x010e, 0x001e, 0x005b, 0x0236, 0x00a6, 0x03ce, 0x00a6,
   0x0006, 0x011e, 0x011a, 0x0260, 0x01aa, 0x0106, 0x02a0, 0x03e0,
   0x0226, 0x03d4, 0x039b, 0x039c, 0x0260, 0x000e, 0x0270, 0x00ae,
   0x02f0, 0x00ae, 0x03e0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0253,
   0x01f8, 0x0088, 0x016c, 0x01ac, 0x009c, 0x01b4, 0x01f4, 0x00a8,
   0x01fc, 0x01bc, 0x0044, 0x0004, 0x01c4, 0x007c, 0x0174, 0x0000,
   0x01bb, 0x0048, 0x0237, 0x0026, 0x01e7, 0x0016, 0x000c, 0x0012,
   0x01ab, 0x0013, 0x02ad, 0x0023, 0x02ae, 0x0024, 0x02af, 0x0025,
   0x0004, 0x0035, 0x0225, 0x0034, 0x0006, 0x0031, 0x0000, 0x0036,
   0x0253, 0x0014, 0x0008, 0x0015, 0x0283, 0x0011, 0x000a, 0x0021,
   0x0398, 0x0148, 0x03c8, 0x0126, 0x022d, 0x0116, 0x010a, 0x0112,
   0x01b3, 0x0113, 0x02ed, 0x0123, 0x02ec, 0x0124, 0x02ee, 0x0125,
   0x0230, 0x0033, 0x000f, 0x0134, 0x0003, 0x0131, 0x0000, 0x0136,
   0x00c0, 0x0114, 0x00c1, 0x0115, 0x009f, 0x0111, 0x02d1, 0x0121,
   0x00a1, 0x0020, 0x0027, 0x0030, 0x019a, 0x0010, 0x0029, 0x0040,
   0x01e4, 0x0049, 0x0219, 0x01f0, 0x011a, 0x01f1, 0x011b, 0x01f2,
   0x0114, 0x01f3, 0x023a, 0x01f4, 0x023e, 0x01f5, 0x0242, 0x01f6,
   0x0093, 0x0145, 0x0096, 0x0144, 0x02cd, 0x0122, 0x0225, 0x0016,
   0x024e, 0x0120, 0x016a, 0x0130, 0x0247, 0x0110, 0x0174, 0x0140,
   0x01e3, 0x0149, 0x0388, 0x00ae, 0x01d8, 0x02c4, 0x0071, 0x0018,
   0x0331, 0x0014, 0x02dd, 0x001c, 0x004e, 0x027a, 0x018c, 0x025d,
   0x0017, 0x0260, 0x0016, 0x0071, 0x0018, 0x004e, 0x027a, 0x025c,
   0x0110, 0x0110, 0x031c, 0x0290, 0x0306, 0x002d, 0x0017, 0x01c6,
   0x0130, 0x0036, 0x0306, 0x0183, 0x008e, 0x004e, 0x009c, 0x0210,
   0x0130, 0x0018, 0x0306, 0x001f, 0x009c, 0x0310, 0x011a, 0x004e,
   0x021c, 0x0110, 0x00ca, 0x01ea, 0x038c, 0x020f, 0x01bc, 0x0330,
   0x0106, 0x004e, 0x0130, 0x0039, 0x01bc, 0x0170, 0x005a, 0x00a6,
   0x01bc, 0x021a, 0x0170, 0x0130, 0x0003, 0x006e, 0x0306, 0x001f,
   0x03a9, 0x0014, 0x00b0, 0x02a0, 0x03e0, 0x03e6, 0x01c5, 0x0018,
   0x0038, 0x00ae, 0x03c3, 0x031c, 0x0130, 0x0038, 0x01ca, 0x0130,
   0x000a, 0x01ca, 0x003b, 0x014a, 0x038c, 0x00ab, 0x015c, 0x0110,
   0x0043, 0x01ca, 0x00db, 0x014a, 0x038c, 0x004b, 0x015c, 0x00d0,
   0x003c, 0x0130, 0x00f0, 0x0206, 0x0161, 0x0016, 0x02d5, 0x0010,
   0x02be, 0x001f, 0x02d5, 0x0010, 0x00ad, 0x0030, 0x00d5, 0x0018,
   0x00d4, 0x00df, 0x02f0, 0x009d, 0x0016, 0x01ca, 0x0063, 0x014a,
   0x038c, 0x0023, 0x015c, 0x0090, 0x0323, 0x02d5, 0x0010, 0x02a1,
   0x0030, 0x036b, 0x038c, 0x0023, 0x015c, 0x0050, 0x02d3, 0x02d5,
   0x0010, 0x0279, 0x0034, 0x031b, 0x031c, 0x0231, 0x001e, 0x038c,
   0x03ed, 0x0026, 0x004e, 0x026e, 0x00cf, 0x011c, 0x0090, 0x03d0,
   0x01d0, 0x003c, 0x009b, 0x00a6, 0x0106, 0x0162, 0x038f, 0x0162,
   0x0033, 0x038c, 0x039f, 0x021c, 0x0010, 0x0173, 0x0162, 0x009b,
   0x038c, 0x0043, 0x011c, 0x0150, 0x00bc, 0x031c, 0x00a2, 0x037c,
   0x01cb, 0x01c5, 0x0018, 0x0038, 0x00f0, 0x02a9, 0x001c, 0x00b0,
   0x00f9, 0x0002, 0x0162, 0x006b, 0x038c, 0x037f, 0x01c5, 0x0018,
   0x00b0, 0x0244, 0x00d5, 0x0018, 0x00d4, 0x023f, 0x02f0, 0x038b,
   0x0162, 0x0083, 0x038c, 0x0033, 0x011c, 0x0090, 0x03d0, 0x0210,
   0x024b, 0x021c, 0x0050, 0x0058, 0x01b1, 0x0002, 0x021c, 0x0090,
   0x03db, 0x0162, 0x0043, 0x038c, 0x03d3, 0x011c, 0x0090, 0x03d0,
   0x0250, 0x037b, 0x038c, 0x003b, 0x005c, 0x0090, 0x0090, 0x03d0,
   0x01bc, 0x01f3, 0x00a6, 0x0130, 0x0007, 0x00e6, 0x031c, 0x02f8,
   0x004a, 0x02a0, 0x01a6, 0x0023, 0x0204, 0x02e8, 0x02f3, 0x020c,
   0x001b, 0x01a6, 0x03df, 0x01a6, 0x001b, 0x0150, 0x0023, 0x01a6,
   0x0023, 0x0190, 0x0310, 0x0393, 0x039c, 0x0310, 0x031c, 0x0260,
   0x0266, 0x02a0, 0x018a, 0x03e3, 0x012a, 0x03e6, 0x00a2, 0x0106,
   0x03e6, 0x03e6, 0x0260, 0x00b6, 0x0316, 0x037d, 0x0006, 0x00b6,
   0x02eb, 0x0226, 0x01bc, 0x0330, 0x029c, 0x0116, 0x02fc, 0x005a,
   0x027a, 0x037c, 0x00a6, 0x02f6, 0x001b, 0x0110, 0x0090, 0x010e,
   0x0046, 0x039c, 0x01d0, 0x00ee, 0x02f8, 0x0006, 0x031c, 0x02ea,
   0x00e3, 0x039c, 0x0222, 0x0222, 0x0222, 0x0222, 0x0043, 0x03c6,
   0x0102, 0x0110, 0x039c, 0x01c2, 0x0046, 0x007b, 0x031c, 0x00a2,
   0x0386, 0x0166, 0x039c, 0x0023, 0x02a0, 0x0126, 0x0260, 0x0222,
   0x03e3, 0x02a0, 0x0166, 0x0166, 0x00a6, 0x003c, 0x02dc, 0x03d0,
   0x00dc, 0x00aa, 0x02d0, 0x010e, 0x0222, 0x0360, 0x0260, 0x029c,
   0x0222, 0x0360, 0x01be, 0x03e0, 0x02f8, 0x00a6, 0x031c, 0x03e6,
   0x038a, 0x00a6, 0x0188, 0x02e6, 0x003b, 0x0184, 0x0266, 0x0262,
   0x0016, 0x00b6, 0x0270, 0x00aa, 0x0038, 0x03e0, 0x0260, 0x028c,
   0x0360, 0x02a9, 0x001c, 0x0288, 0x001a, 0x001e, 0x01ba, 0x004e,
   0x0104, 0x03e0, 0x0044, 0x0084, 0x0144, 0x0284, 0x00c4, 0x0184,
   0x02c4, 0x03bb, 0x01a9, 0x0010, 0x0079, 0x0008, 0x035c, 0x0130,
   0x0128, 0x03c8, 0x03cc, 0x0155, 0x0002, 0x0266, 0x03db, 0x03e0,
   0x004e, 0x0270, 0x025c, 0x00d0, 0x0210, 0x00d0, 0x0210, 0x001c,
   0x0310, 0x0050, 0x0310, 0x02a8, 0x004e, 0x035c, 0x0210, 0x00d0,
   0x0210, 0x02d0, 0x0310, 0x021c, 0x0210, 0x0268, 0x0030, 0x002b,
   0x0130, 0x00f0, 0x0023, 0x010e, 0x0130, 0x00fb, 0x0270, 0x0038,
   0x03e0, 0x03e9, 0x003c, 0x02dc, 0x00ce, 0x01d8, 0x006e, 0x00ce,
   0x02f6, 0x0360, 0x0226, 0x02e6, 0x003b, 0x0266, 0x03ee, 0x001e,
   0x03d4, 0x034e, 0x03cf, 0x0266, 0x03e0, 0x02fa, 0x0017, 0x004e,
   0x02a0, 0x035c, 0x02f6, 0x0033, 0x0266, 0x0236, 0x0276, 0x001b,
   0x0226, 0x03e0, 0x01f6, 0x001b, 0x004e, 0x002b, 0x004a, 0x026a,
   0x0056, 0x03d4, 0x03d4, 0x03e0, 0x00b0, 0x00eb, 0x004e, 0x021c,
   0x0290, 0x025c, 0x0222, 0x0222, 0x010e, 0x01d0, 0x00ee, 0x02f8,
   0x01d6, 0x02a0, 0x013a, 0x0260, 0x01b6, 0x03e3, 0x02a0, 0x005a,
   0x02fc, 0x021a, 0x035c, 0x0350, 0x02d0, 0x011c, 0x03d0, 0x03d0,
   0x0290, 0x02d0, 0x02dc, 0x03d0, 0x010e, 0x00ed, 0x000c, 0x001d,
   0x0032, 0x03e6, 0x02f8, 0x0316, 0x0027, 0x009c, 0x0231, 0x001e,
   0x00a6, 0x023c, 0x021c, 0x0010, 0x03d0, 0x0270, 0x03e0, 0x004e,
   0x0270, 0x00b0, 0x0068, 0x0001, 0x0018, 0x0044, 0x0341, 0x0018,
   0x0011, 0x001c, 0x00ae, 0x00f0, 0x0198, 0x036e, 0x01df, 0x01a0,
   0x021c, 0x0310, 0x0106, 0x0226, 0x00e6, 0x0130, 0x0010, 0x027c,
   0x00ba, 0x0023, 0x023a, 0x037a, 0x0033, 0x0330, 0x0146, 0x03db,
   0x0126, 0x03cb, 0x0186, 0x0346, 0x0107, 0x0048, 0x0341, 0x0018,
   0x006e, 0x00b0, 0x01ce, 0x004e, 0x0130, 0x0086, 0x02a6, 0x036e,
   0x00cf, 0x0015, 0x001c, 0x010e, 0x0198, 0x036e, 0x009f, 0x004e,
   0x0270, 0x0078, 0x0070, 0x004e, 0x026e, 0x0268, 0x02a8, 0x03cc,
   0x03a0, 0x0084, 0x00a1, 0x0002, 0x004e, 0x0226, 0x0226, 0x023c,
   0x0023, 0x004e, 0x03e3, 0x004e, 0x025c, 0x00f0, 0x0231, 0x001e,
   0x01a0, 0x0015, 0x001c, 0x00f0, 0x00f0, 0x01d8, 0x01d8, 0x00d8,
   0x00d8, 0x03d8, 0x03d8, 0x00ee, 0x0011, 0x001c, 0x01ce, 0x034e,
   0x035f, 0x0158, 0x004e, 0x0130, 0x0001, 0x0270, 0x00ee, 0x0038,
   0x014e, 0x00ae, 0x004c, 0x00b7, 0x012e, 0x00ae, 0x01d8, 0x02f0,
   0x004e, 0x0038, 0x01d8, 0x02f0, 0x0130, 0x00f0, 0x00ae, 0x00ee,
   0x0366, 0x03a0, 0x006e, 0x0266, 0x02e6, 0x0347, 0x0266, 0x0056,
   0x032b, 0x018e, 0x0000, 0x0353, 0x006e, 0x02dc, 0x0150, 0x02d4,
   0x03f3, 0x004c, 0x03a0, 0x01ee, 0x03e0, 0x004e, 0x0066, 0x02a0,
   0x0226, 0x0260, 0x01a6, 0x03e3, 0x003c, 0x0331, 0x001a, 0x01a0,
   0x0270, 0x031c, 0x0110, 0x019c, 0x0050, 0x0320, 0x0013, 0x0278,
   0x01ee, 0x0268, 0x02a8, 0x0086, 0x00f5, 0x000c, 0x004e, 0x005c,
   0x0090, 0x026e, 0x031f, 0x03cc, 0x03eb, 0x0130, 0x01e2, 0x0206,
   0x005a, 0x01bc, 0x0330, 0x0106, 0x0220, 0x003c, 0x0056, 0x0366,
   0x02af, 0x006e, 0x0166, 0x0130, 0x0028, 0x0306, 0x030f, 0x004e,
   0x026e, 0x011c, 0x0050, 0x0010, 0x0075, 0x0008, 0x0143, 0x0384,
   0x0071, 0x0018, 0x011a, 0x0179, 0x0038, 0x037a, 0x0167, 0x00f5,
   0x000c, 0x02b9, 0x0000, 0x0130, 0x0012, 0x0366, 0x020b, 0x0084,
   0x0130, 0x0017, 0x0366, 0x006b, 0x0130, 0x0075, 0x0366, 0x00a3,
   0x0130, 0x0014, 0x0366, 0x00bb, 0x0226, 0x0366, 0x0097, 0x0088,
   0x00f5, 0x000c, 0x01fd, 0x0018, 0x008c, 0x03ef, 0x001c, 0x02e0,
   0x0320, 0x0155, 0x0002, 0x030c, 0x001f, 0x0308, 0x0013, 0x0304,
   0x0229, 0x0002, 0x0304, 0x039c, 0x0130, 0x0004, 0x0058, 0x0130,
   0x00f0, 0x0165, 0x0038, 0x02e8, 0x01a0, 0x0070, 0x026e, 0x011c,
   0x0350, 0x0290, 0x03d0, 0x0053, 0x004e, 0x0204, 0x0260, 0x026e,
   0x03d4, 0x0236, 0x02d4, 0x03eb, 0x011c, 0x0390, 0x0290, 0x0290,
   0x0310, 0x0290, 0x01bc, 0x02dc, 0x03d0, 0x010e, 0x00a0, 0x001c,
   0x0141, 0x0002, 0x00d5, 0x0018, 0x010e, 0x024c, 0x02b5, 0x001c,
   0x00ae, 0x002b, 0x024c, 0x0360, 0x0013, 0x00b0, 0x0158, 0x0378,
   0x03a8, 0x0338, 0x0368, 0x0198, 0x0328, 0x03e0, 0x023c, 0x01b6,
   0x03f3, 0x00a6, 0x03e0, 0x0260, 0x00c4, 0x0071, 0x0018, 0x031c,
   0x026a, 0x0043, 0x0150, 0x0310, 0x001b, 0x0222, 0x0226, 0x02e8,
   0x03e0, 0x0106, 0x0142, 0x0142, 0x03cb, 0x03e6, 0x03e6, 0x01d6,
   0x0356, 0x0017, 0x00c8, 0x0042, 0x039b, 0x02ed, 0x001c, 0x00cc,
   0x03a0, 0x004a, 0x036b, 0x02be, 0x00b5, 0x0031, 0x004e, 0x0270,
   0x00ce, 0x00be, 0x011e, 0x0068, 0x0071, 0x0018, 0x017c, 0x00a6,
   0x0106, 0x013c, 0x02e8, 0x03e0, 0x004e, 0x0270, 0x0078, 0x00ee,
   0x007e, 0x00de, 0x003e, 0x0068, 0x0071, 0x0018, 0x017c, 0x00a6,
   0x038b, 0x01d5, 0x0028, 0x02b9, 0x001c, 0x00ae, 0x03e0, 0x0000,
   0x02b9, 0x001c, 0x00b9, 0x0002, 0x004e, 0x03eb, 0x0281, 0x0006,
   0x0231, 0x0036, 0x0291, 0x0032, 0x03e9, 0x003c, 0x0284, 0x0104,
   0x035e, 0x0013, 0x0108, 0x001e, 0x001a, 0x006e, 0x00ce, 0x01e6,
   0x0073, 0x00ce, 0x035e, 0x007f, 0x02dc, 0x03d4, 0x0094, 0x019d,
   0x0023, 0x0226, 0x03db, 0x02b1, 0x0020, 0x00d3, 0x0275, 0x0020,
   0x015c, 0x0033, 0x006e, 0x0166, 0x03ae, 0x0333, 0x023a, 0x018e,
   0x03f3, 0x012e, 0x03ee, 0x0266, 0x00ab, 0x009c, 0x02e2, 0x002b,
   0x0262, 0x02e2, 0x00a7, 0x0222, 0x035c, 0x0053, 0x0222, 0x018e,
   0x03f3, 0x012e, 0x0154, 0x012f, 0x03ee, 0x0266, 0x03d4, 0x00ee,
   0x02db, 0x00ae, 0x03fa, 0x00ae, 0x02e2, 0x0313, 0x004e, 0x035c,
   0x026a, 0x010e, 0x021c, 0x0050, 0x010c, 0x0013, 0x02a6, 0x006e,
   0x010e, 0x004c, 0x003b, 0x0379, 0x001c, 0x0089, 0x0030, 0x03b1,
   0x001c, 0x028c, 0x001b, 0x02be, 0x011e, 0x0231, 0x0032, 0x00ee,
   0x004c, 0x002b, 0x0341, 0x0034, 0x00ae, 0x006e, 0x02dc, 0x0190,
   0x009c, 0x02fa, 0x00e3, 0x03dc, 0x02e2, 0x002b, 0x0262, 0x008e,
   0x0158, 0x007b, 0x0226, 0x038e, 0x027e, 0x03a3, 0x0046, 0x003c,
   0x0162, 0x006e, 0x010e, 0x010c, 0x0239, 0x0035, 0x029b, 0x03ae,
   0x027e, 0x03f3, 0x012e, 0x017e, 0x0198, 0x033b, 0x006e, 0x005a,
   0x005e, 0x010e, 0x010c, 0x01f1, 0x0035, 0x004c, 0x001b, 0x0379,
   0x001c, 0x0081, 0x0030, 0x0233, 0x00ee, 0x035c, 0x0090, 0x00d0,
   0x0010, 0x0090, 0x0150, 0x0210, 0x0150, 0x0010, 0x0250, 0x0090,
   0x0250, 0x0250, 0x0110, 0x010b, 0x004e, 0x0354, 0x0097, 0x027a,
   0x0110, 0x023a, 0x00d4, 0x00df, 0x0254, 0x0137, 0x0114, 0x017f,
   0x0294, 0x01bf, 0x0154, 0x01e7, 0x039c, 0x00d0, 0x015c, 0x006b,
   0x0190, 0x0250, 0x00d0, 0x0050, 0x0110, 0x01d0, 0x0050, 0x0210,
   0x0010, 0x0150, 0x0190, 0x035c, 0x00ee, 0x03e0, 0x00d0, 0x0050,
   0x0010, 0x0050, 0x01d0, 0x0250, 0x0210, 0x0010, 0x0110, 0x00d0,
   0x00d0, 0x019c, 0x0393, 0x011c, 0x00d0, 0x00d0, 0x0010, 0x0210,
   0x0150, 0x00d0, 0x0130, 0x0168, 0x00dc, 0x033b, 0x015c, 0x00d0,
   0x00d0, 0x00d0, 0x0010, 0x0210, 0x00d0, 0x0150, 0x025c, 0x02eb,
   0x005c, 0x00d0, 0x00d0, 0x0130, 0x0331, 0x011c, 0x02b3, 0x0130,
   0x0333, 0x029c, 0x0293, 0x03e9, 0x003c, 0x0148, 0x02da, 0x0077,
   0x017d, 0x0000, 0x02fa, 0x007b, 0x0198, 0x02fe, 0x0067, 0x002e,
   0x0231, 0x0032, 0x03e9, 0x003c, 0x0144, 0x0104, 0x003e, 0x035e,
   0x0017, 0x02da, 0x021d, 0x002a, 0x00a6, 0x0106, 0x02e6, 0x007b,
   0x0146, 0x001b, 0x02a6, 0x0108, 0x000e, 0x005e, 0x005a, 0x035c,
   0x018a, 0x0262, 0x0222, 0x008e, 0x0158, 0x00f3, 0x035c, 0x00ce,
   0x0262, 0x00ae, 0x034e, 0x0219, 0x0026, 0x0342, 0x0027, 0x0266,
   0x03ee, 0x03e3, 0x01d8, 0x02bd, 0x0034, 0x035c, 0x004e, 0x00a6,
   0x010e, 0x006e, 0x002b, 0x0154, 0x01f7, 0x03d4, 0x023e, 0x0226,
   0x03db, 0x0313, 0x038e, 0x027e, 0x03f3, 0x0198, 0x012e, 0x01be,
   0x02d3, 0x023e, 0x006e, 0x03ee, 0x03d4, 0x0094, 0x039b, 0x00ae,
   0x008e, 0x03ea, 0x03ea, 0x03ea, 0x00ae, 0x039c, 0x01d0, 0x0286,
   0x02c6, 0x01e3, 0x015c, 0x038e, 0x00ee, 0x02b1, 0x0020, 0x0271,
   0x0024, 0x02fa, 0x00e3, 0x02d4, 0x03bb, 0x002e, 0x039c, 0x0082,
   0x012e, 0x038e, 0x0271, 0x0020, 0x010c, 0x0037, 0x006e, 0x018e,
   0x006e, 0x012e, 0x006e, 0x001c, 0x0271, 0x0024, 0x02fa, 0x003b,
   0x038e, 0x03db, 0x00ee, 0x00db, 0x038e, 0x0023, 0x035e, 0x03ef,
   0x0266, 0x005e, 0x010c, 0x001b, 0x02be, 0x0000, 0x01d5, 0x0030,
   0x014c, 0x00cb, 0x017d, 0x0000, 0x02b1, 0x0030, 0x0198, 0x02fe,
   0x003d, 0x0022, 0x01a6, 0x00ee, 0x03db, 0x038e, 0x0341, 0x0034,
   0x006e, 0x015c, 0x021b, 0x012e, 0x0262, 0x03f3, 0x0042, 0x0226,
   0x03dc, 0x03e0, 0x008c, 0x03a0, 0x004e, 0x01d8, 0x0275, 0x0020,
   0x00ee, 0x0289, 0x0036, 0x000e, 0x0275, 0x0020, 0x0284, 0x00b0,
   0x02a9, 0x0030, 0x02e3, 0x0029, 0x0024, 0x004e, 0x0158, 0x0275,
   0x0020, 0x00ee, 0x037b, 0x0148, 0x028c, 0x018f, 0x0006, 0x020c,
   0x0017, 0x0320, 0x00b0, 0x0379, 0x0014, 0x001c, 0x0162, 0x0023,
   0x03ea, 0x03dc, 0x03e3, 0x01a2, 0x0014, 0x010f, 0x02d4, 0x0027,
   0x014c, 0x0017, 0x017e, 0x008e, 0x03d4, 0x03d4, 0x01aa, 0x00ee,
   0x023c, 0x00dc, 0x03ca, 0x01bc, 0x00ae, 0x00ee, 0x035c, 0x011e,
   0x02a0, 0x035a, 0x0097, 0x000e, 0x00ae, 0x006e, 0x005b, 0x028c,
   0x001f, 0x02be, 0x01c7, 0x010c, 0x01e7, 0x02fa, 0x012d, 0x0002,
   0x02be, 0x0244, 0x00f0, 0x03db, 0x0342, 0x037f, 0x01a6, 0x03fa,
   0x03e3, 0x0026, 0x00c3, 0x03e6, 0x028c, 0x0213, 0x010c, 0x03f3,
   0x005c, 0x00b0, 0x03ea, 0x008e, 0x02a0, 0x009c, 0x038a, 0x038a,
   0x038a, 0x0086, 0x0006, 0x031c, 0x02d6, 0x002b, 0x018a, 0x0353,
   0x008a, 0x0006, 0x00ae, 0x02fc, 0x00ae, 0x0126, 0x001c, 0x035e,
   0x002f, 0x01a6, 0x03ee, 0x038a, 0x03db, 0x00a6, 0x006e, 0x00d5,
   0x0018, 0x0354, 0x00f9, 0x0002, 0x026b, 0x03e5, 0x001c, 0x03db,
   0x009c, 0x00a2, 0x02a2, 0x00a2, 0x02bb, 0x02a9, 0x001c, 0x0361,
   0x003c, 0x01ee, 0x023a, 0x0046, 0x0373, 0x0284, 0x0248, 0x028c,
   0x007f, 0x0379, 0x0014, 0x002e, 0x035c, 0x0222, 0x0102, 0x009c,
   0x006a, 0x0108, 0x035a, 0x030f, 0x0104, 0x006a, 0x02f3, 0x02fa,
   0x036b, 0x00ee, 0x02dc, 0x01d0, 0x00ee, 0x033e, 0x02b3, 0x010c,
   0x02a7, 0x002e, 0x036b, 0x03e9, 0x003c, 0x0379, 0x001c, 0x0338,
   0x010e, 0x00b0, 0x035e, 0x00b3, 0x0006, 0x00ba, 0x02f6, 0x002b,
   0x013b, 0x02e6, 0x012b, 0x0266, 0x03ee, 0x035a, 0x03df, 0x02e6,
   0x004f, 0x00be, 0x011e, 0x01fe, 0x01fe, 0x021e, 0x02fe, 0x0013,
   0x0288, 0x0338, 0x005e, 0x03ed, 0x0020, 0x00ee, 0x0338, 0x010e,
   0x0378, 0x0328, 0x03b8, 0x0368, 0x00ee, 0x03e0, 0x035e, 0x0033,
   0x021c, 0x0231, 0x001e, 0x03e9, 0x003c, 0x035e, 0x001b, 0x039c,
   0x03cb, 0x003e, 0x00ce, 0x006e, 0x01ee, 0x01ee, 0x020e, 0x00ee,
   0x005a, 0x010e, 0x01ee, 0x01e6, 0x0013, 0x02ba, 0x014e, 0x039c,
   0x0342, 0x0017, 0x03ae, 0x038e, 0x004e, 0x006e, 0x02dc, 0x0150,
   0x03ce, 0x0053, 0x0222, 0x01ce, 0x03f3, 0x014e, 0x03ee, 0x0394,
   0x01e9, 0x0033, 0x03d4, 0x03ca, 0x03bb, 0x00c8, 0x0188, 0x037d,
   0x003c, 0x0361, 0x003a, 0x00b0, 0x02fa, 0x012b, 0x02fe, 0x0023,
   0x0288, 0x00c8, 0x005e, 0x027d, 0x0030, 0x0379, 0x001c, 0x0338,
   0x010e, 0x02a1, 0x0030, 0x017d, 0x0000, 0x00bd, 0x0030, 0x0215,
   0x0028, 0x03e5, 0x001c, 0x00ae, 0x00b0, 0x005e, 0x0279, 0x0034,
   0x02fa, 0x0117, 0x000e, 0x0103, 0x00cc, 0x001f, 0x00c8, 0x03e0,
   0x00c4, 0x03e0, 0x01d5, 0x0028, 0x00ae, 0x0288, 0x02fe, 0x0013,
   0x0148, 0x005e, 0x02b9, 0x001c, 0x02fa, 0x03a0, 0x000e, 0x01a1,
   0x003a, 0x0351, 0x0028, 0x03db, 0x00c8, 0x0188, 0x02c8, 0x037d,
   0x003c, 0x03e9, 0x003c, 0x02fe, 0x004b, 0x0148, 0x02cc, 0x0033,
   0x00cc, 0x0023, 0x00c4, 0x0288, 0x0144, 0x035c, 0x00a6, 0x0106,
   0x01e6, 0x013f, 0x0346, 0x0087, 0x00ce, 0x02ce, 0x0303, 0x035c,
   0x0262, 0x02ee, 0x004f, 0x018c, 0x02ef, 0x01d1, 0x002c, 0x000e,
   0x01a6, 0x00ae, 0x02ab, 0x018c, 0x021d, 0x002b, 0x0239, 0x0034,
   0x0351, 0x0028, 0x006e, 0x00ce, 0x035c, 0x005a, 0x005e, 0x0226,
   0x02e6, 0x010b, 0x023e, 0x03d4, 0x0154, 0x03d3, 0x00ee, 0x035b,
   0x018c, 0x00c3, 0x0379, 0x001c, 0x0081, 0x0030, 0x03b1, 0x001c,
   0x0089, 0x0030, 0x0271, 0x0030, 0x001e, 0x0215, 0x0028, 0x00b0,
   0x005e, 0x0158, 0x0046, 0x0249, 0x0034, 0x00a6, 0x0106, 0x01e6,
   0x02b3, 0x02cb, 0x01d8, 0x004e, 0x023e, 0x03ce, 0x006b, 0x00ae,
   0x01d8, 0x0222, 0x011e, 0x01d8, 0x03ae, 0x03ae, 0x01be, 0x03eb,
   0x001e, 0x012e, 0x00ae, 0x008e, 0x01ce, 0x0393, 0x01d8, 0x023e,
   0x01d8, 0x006e, 0x03ee, 0x03d4, 0x0154, 0x03b3, 0x00ee, 0x02d5,
   0x0034, 0x006e, 0x01d8, 0x0046, 0x029c, 0x00ee, 0x0245, 0x0038,
   0x00ee, 0x0013, 0x012e, 0x0262, 0x03f3, 0x038e, 0x0042, 0x02fa,
   0x0195, 0x003a, 0x03dc, 0x0393, 0x035c, 0x004e, 0x01d0, 0x0210,
   0x0150, 0x00d0, 0x0250, 0x0210, 0x0050, 0x0190, 0x00d0, 0x00d0,
   0x0250, 0x01d0, 0x0150, 0x035c, 0x03e0, 0x03ca, 0x020a, 0x010a,
   0x03ca, 0x01ea, 0x01ea, 0x024a, 0x008c, 0x0033, 0x000e, 0x0106,
   0x020e, 0x0046, 0x03e0, 0x014a, 0x03ca, 0x02ea, 0x03ef, 0x03e0,
   0x03b5, 0x003c, 0x02e0, 0x0061, 0x0018, 0x03e9, 0x003c, 0x0089,
   0x0030, 0x0379, 0x001c, 0x004c, 0x03d1, 0x0030, 0x004c, 0x03e9,
   0x0031, 0x017d, 0x0000, 0x0331, 0x0034, 0x004e, 0x0270, 0x01f9,
   0x0028, 0x004c, 0x0037, 0x02a8, 0x02bc, 0x0268, 0x0048, 0x0323,
   0x006d, 0x0018, 0x00ae, 0x0289, 0x001c, 0x004e, 0x0270, 0x02b8,
   0x010e, 0x0278, 0x02bc, 0x0106, 0x0001, 0x0018, 0x00cd, 0x003a,
   0x02fe, 0x006f, 0x02f6, 0x005f, 0x010e, 0x008e, 0x001c, 0x03ee,
   0x038a, 0x035c, 0x034a, 0x002b, 0x01a6, 0x03c3, 0x021d, 0x002a,
   0x0166, 0x0306, 0x001b, 0x0236, 0x03e0, 0x004e, 0x0222, 0x03ce,
   0x023e, 0x00ee, 0x02c2, 0x001b, 0x03aa, 0x0226, 0x000e, 0x01c2,
   0x0023, 0x03ee, 0x012e, 0x03fb, 0x01de, 0x0033, 0x038a, 0x016e,
   0x0226, 0x012e, 0x03fb, 0x006a, 0x0262, 0x036b, 0x027e, 0x035b,
   0x03ee, 0x0086, 0x005a, 0x005e, 0x012a, 0x014e, 0x00ba, 0x03e0,
   0x03f8, 0x0091, 0x0016, 0x011d, 0x000c, 0x0069, 0x0008, 0x021c,
   0x0210, 0x0266, 0x03fb, 0x0001, 0x0018, 0x01b1, 0x0002, 0x0260,
   0x004e, 0x03e8, 0x02f8, 0x03c6, 0x0276, 0x03c6, 0x039c, 0x0262,
   0x0151, 0x0038, 0x004e, 0x0070, 0x0328, 0x0368, 0x03a8, 0x0373,
   0x004e, 0x001b, 0x004e, 0x02be, 0x035c, 0x0050, 0x003b, 0x02be,
   0x0000, 0x01d5, 0x0028, 0x002e, 0x007a, 0x0158, 0x0046, 0x003e,
   0x005e, 0x01d8, 0x031c, 0x03d4, 0x0176, 0x0236, 0x0354, 0x03e3,
   0x00ee, 0x02ee, 0x016b, 0x01d8, 0x006e, 0x02ee, 0x014b, 0x0326,
   0x0087, 0x01d8, 0x006e, 0x0326, 0x03df, 0x00ae, 0x01d8, 0x030e,
   0x0023, 0x01d8, 0x00ae, 0x002b, 0x01d8, 0x00ae, 0x01d8, 0x006e,
   0x019e, 0x035e, 0x005b, 0x028e, 0x011e, 0x0326, 0x003b, 0x01d8,
   0x02fc, 0x01d8, 0x006e, 0x01a6, 0x006e, 0x0326, 0x004b, 0x0166,
   0x03ce, 0x00be, 0x011e, 0x03d4, 0x02d4, 0x03c3, 0x004e, 0x00ae,
   0x0198, 0x00ee, 0x012e, 0x0276, 0x0276, 0x0276, 0x00ae, 0x0158,
   0x02fe, 0x001b, 0x0166, 0x03ce, 0x00ae, 0x035c, 0x034a, 0x00bf,
   0x00ee, 0x00ae, 0x035c, 0x010e, 0x01e6, 0x006b, 0x023a, 0x005b,
   0x00c6, 0x0226, 0x0222, 0x00de, 0x006e, 0x02fa, 0x0360, 0x004e,
   0x001e, 0x03e0, 0x00c6, 0x03c3, 0x006e, 0x0363, 0x0342, 0x034f,
   0x0266, 0x03ea, 0x03e3, 0x0085, 0x0018, 0x0303, 0x0085, 0x0018,
   0x0198, 0x03d4, 0x004a, 0x02fb, 0x017d, 0x0000, 0x0073, 0x010e,
   0x0043, 0x01d5, 0x0028, 0x002b, 0x00ae, 0x0338, 0x0266, 0x0266,
   0x002e, 0x007a, 0x0158, 0x0046, 0x003e, 0x005e, 0x01d8, 0x0206,
   0x025e, 0x0013, 0x029e, 0x000e, 0x01d8, 0x02dc, 0x03dc, 0x038e,
   0x0013, 0x012e, 0x0262, 0x03f3, 0x0354, 0x03cb, 0x0198, 0x0133,
   0x0088, 0x02fa, 0x03a0, 0x010e, 0x008e, 0x0226, 0x0226, 0x0106,
   0x035c, 0x0146, 0x0047, 0x03d4, 0x0394, 0x001b, 0x00ce, 0x03e0,
   0x0266, 0x03d3, 0x004e, 0x00da, 0x008c, 0x0093, 0x03dc, 0x02d4,
   0x0023, 0x021d, 0x002c, 0x002b, 0x03dc, 0x021d, 0x002c, 0x03d4,
   0x03d4, 0x021d, 0x002c, 0x010e, 0x00ce, 0x01b9, 0x0032, 0x000e,
   0x0215, 0x002c, 0x03dc, 0x02d4, 0x0017, 0x03dc, 0x0215, 0x002c,
   0x03ee, 0x014e, 0x00ee, 0x0393, 0x0078, 0x0311, 0x0034, 0x00b8,
   0x00b5, 0x0032, 0x00f8, 0x0311, 0x0034, 0x0138, 0x03d3, 0x0078,
   0x010e, 0x00f8, 0x0315, 0x0034, 0x0178, 0x039b, 0x03d1, 0x0030,
   0x0379, 0x001c, 0x03fd, 0x0030, 0x017d, 0x0000, 0x0331, 0x0034,
   0x0291, 0x001c, 0x000e, 0x0113, 0x03b5, 0x003c, 0x0019, 0x0034,
   0x00f9, 0x0002, 0x0048, 0x03b5, 0x003c, 0x03d1, 0x0030, 0x0379,
   0x001c, 0x03e9, 0x0030, 0x0271, 0x0030, 0x01f9, 0x0028, 0x0379,
   0x001c, 0x03fd, 0x0030, 0x017d, 0x0000, 0x0331, 0x0034, 0x00d5,
   0x0018, 0x02b9, 0x001c, 0x00b0, 0x010e, 0x0061, 0x0018, 0x02a1,
   0x0030, 0x00f8, 0x004c, 0x0017, 0x0078, 0x036d, 0x001c, 0x004c,
   0x03d1, 0x0031, 0x004c, 0x03fd, 0x0030, 0x0271, 0x0030, 0x0379,
   0x001c, 0x004c, 0x002f, 0x03d1, 0x0030, 0x00f8, 0x0023, 0x03fd,
   0x0030, 0x0078, 0x02a9, 0x0030, 0x017d, 0x0000, 0x00bd, 0x0030,
   0x0379, 0x001c, 0x004c, 0x03fd, 0x0031, 0x004c, 0x03d1, 0x0030,
   0x0061, 0x0018, 0x02a9, 0x0030, 0x02fa, 0x0201, 0x002a, 0x017d,
   0x0000, 0x014b, 0x000e, 0x0361, 0x003c, 0x00ee, 0x00b0, 0x02a9,
   0x0030, 0x00d5, 0x0038, 0x016b, 0x010e, 0x00d5, 0x0038, 0x02a1,
   0x0030, 0x0361, 0x003c, 0x013b, 0x02be, 0x006e, 0x008e, 0x0158,
   0x038e, 0x034e, 0x0027, 0x0198, 0x010e, 0x03e0, 0x0226, 0x03cb,
   0x035c, 0x0162, 0x006e, 0x0123, 0x03e9, 0x003c, 0x004e, 0x0158,
   0x035c, 0x0050, 0x00ee, 0x00ae, 0x01d8, 0x00ae, 0x0063, 0x0158,
   0x0046, 0x03cb, 0x02fa, 0x004b, 0x01d5, 0x0028, 0x002e, 0x007a,
   0x0158, 0x0046, 0x003e, 0x02fa, 0x021d, 0x002a, 0x01d8, 0x0246,
   0x025e, 0x0013, 0x029e, 0x01d8, 0x005e, 0x00ae, 0x006e, 0x032e,
   0x002b, 0x01d8, 0x03ee, 0x0266, 0x01d8, 0x035c, 0x004e, 0x0013,
   0x0222, 0x018e, 0x03f3, 0x012e, 0x03ee, 0x03d4, 0x02d4, 0x03d3,
   0x00ae, 0x0198, 0x01e1, 0x0032, 0x010e, 0x02be, 0x02a1, 0x0031,
   0x0061, 0x0018, 0x0158, 0x0046, 0x02fa, 0x0201, 0x002a, 0x029b,
   0x0158, 0x008e, 0x00ee, 0x01ee, 0x01ee, 0x020e, 0x006e, 0x03ce,
   0x02ee, 0x0027, 0x0198, 0x00ae, 0x03e0, 0x0166, 0x03cb, 0x028e,
   0x01d8, 0x0226, 0x024b, 0x0088, 0x03b5, 0x003c, 0x00b0, 0x03e8,
   0x010e, 0x00f8, 0x004c, 0x0017, 0x0078, 0x0051, 0x0008, 0x0035,
   0x0008, 0x03f8, 0x027d, 0x0030, 0x0138, 0x004c, 0x0017, 0x00b8,
   0x0051, 0x0008, 0x0029, 0x0008, 0x0338, 0x010e, 0x00b0, 0x03e8,
   0x02f8, 0x00ae, 0x004c, 0x001f, 0x0048, 0x0313, 0x010e, 0x00b0,
   0x02a1, 0x0030, 0x0051, 0x0008, 0x0178, 0x0029, 0x0008, 0x000e,
   0x0162, 0x0051, 0x0008, 0x0061, 0x0018, 0x0035, 0x0008, 0x00b9,
   0x0002, 0x03b5, 0x003c, 0x0061, 0x0018, 0x010e, 0x00f8, 0x00ae,
   0x02fa, 0x0201, 0x002a, 0x0279, 0x0034, 0x0289, 0x001c, 0x0061,
   0x0018, 0x010e, 0x0078, 0x00ae, 0x0279, 0x0034, 0x00f9, 0x0002,
   0x01d5, 0x0028, 0x03a8, 0x00ae, 0x03d3, 0x004e, 0x035c, 0x0226,
   0x0250, 0x03e0, 0x02f8, 0x025c, 0x0042, 0x0043, 0x02f8, 0x025c,
   0x0110, 0x0023, 0x02f8, 0x025c, 0x0150, 0x02e8, 0x0063, 0x02be,
   0x010e, 0x0338, 0x00ad, 0x0030, 0x02fe, 0x002b, 0x02fa, 0x001b,
   0x0355, 0x001c, 0x01b1, 0x0002, 0x038d, 0x000c, 0x0262, 0x03eb,
   0x03e0, 0x038d, 0x000c, 0x0222, 0x03eb, 0x004e, 0x009c, 0x0350,
   0x0210, 0x0150, 0x0290, 0x03e0, 0x03dc, 0x0266, 0x0354, 0x03eb,
   0x005e, 0x01d5, 0x0030, 0x00cc, 0x003b, 0x02be, 0x00be, 0x0361,
   0x003c, 0x00bd, 0x0030, 0x028c, 0x002b, 0x0361, 0x003c, 0x00bd,
   0x0030, 0x004c, 0x0077, 0x0166, 0x0166, 0x0000, 0x01e5, 0x0034,
   0x008c, 0x003f, 0x004e, 0x035c, 0x0266, 0x0250, 0x02a9, 0x0030,
   0x014c, 0x0013, 0x02be, 0x02cc, 0x0360, 0x0144, 0x0284, 0x0291,
   0x003e, 0x004e, 0x026e, 0x005e, 0x0354, 0x006f, 0x0194, 0x00e7,
   0x00d4, 0x011f, 0x0254, 0x0147, 0x0114, 0x015f, 0x039c, 0x01d0,
   0x029c, 0x03e0, 0x00dc, 0x0190, 0x0190, 0x0210, 0x0190, 0x0150,
   0x0090, 0x0110, 0x0250, 0x0130, 0x0116, 0x035c, 0x03e0, 0x0190,
   0x0394, 0x03f3, 0x036b, 0x011c, 0x02bd, 0x0038, 0x039c, 0x0150,
   0x005c, 0x0210, 0x019c, 0x03e0, 0x015c, 0x02bd, 0x0038, 0x039c,
   0x0250, 0x00dc, 0x03e0, 0x005c, 0x02bd, 0x0038, 0x025c, 0x03e0,
   0x021c, 0x02bd, 0x0038, 0x011c, 0x03e0, 0x037d, 0x003c, 0x02cd,
   0x002a, 0x037d, 0x003c, 0x02c8, 0x0188, 0x01d5, 0x0028, 0x00ae,
   0x000e, 0x002e, 0x00ba, 0x02fe, 0x0043, 0x0288, 0x018c, 0x001b,
   0x00cc, 0x0013, 0x0148, 0x005e, 0x00ee, 0x004c, 0x00c1, 0x003f,
   0x008c, 0x002b, 0x00ae, 0x010e, 0x03ce, 0x01ce, 0x004e, 0x035c,
   0x0110, 0x0150, 0x00ee, 0x0266, 0x02f6, 0x002f, 0x0266, 0x001b,
   0x0226, 0x038e, 0x00ee, 0x0158, 0x01ee, 0x01ee, 0x01ee, 0x03ce,
   0x00ee, 0x02f6, 0x009f, 0x018e, 0x03fb, 0x012e, 0x03ee, 0x0266,
   0x03db, 0x004e, 0x00ee, 0x0198, 0x01ee, 0x004c, 0x001b, 0x038e,
   0x03ce, 0x00ee, 0x018e, 0x005b, 0x012e, 0x00ee, 0x0198, 0x00ee,
   0x004c, 0x010b, 0x02e6, 0x00f7, 0x03ee, 0x00eb, 0x00cc, 0x0047,
   0x00c8, 0x014c, 0x001f, 0x0148, 0x0373, 0x0144, 0x0363, 0x00c4,
   0x018c, 0x03c3, 0x028c, 0x001b, 0x0284, 0x032b, 0x0288, 0x031b,
   0x01d1, 0x002c, 0x024b, 0x006e, 0x018e, 0x0000, 0x0351, 0x0028,
   0x003b, 0x0226, 0x02f6, 0x0027, 0x018e, 0x03b3, 0x012e, 0x0266,
   0x0000, 0x01d5, 0x0030, 0x004c, 0x005f, 0x0198, 0x01ee, 0x0266,
   0x0000, 0x0281, 0x0034, 0x0361, 0x003c, 0x02b1, 0x0030, 0x01d8,
   0x00ae, 0x010e, 0x0226, 0x003b, 0x006e, 0x03ee, 0x003b, 0x03d4,
   0x0154, 0x01b7, 0x0226, 0x03e3, 0x006e, 0x004e, 0x00ee, 0x0245,
   0x0038, 0x00ee, 0x0013, 0x023e, 0x018e, 0x03f3, 0x012e, 0x03d4,
   0x03ce, 0x03ee, 0x0154, 0x039b, 0x01d8, 0x038e, 0x038e, 0x004e,
   0x035c, 0x0050, 0x01d8, 0x039c, 0x0190, 0x0190, 0x005b, 0x038a,
   0x038a, 0x01be, 0x03eb, 0x001e, 0x01d8, 0x00ae, 0x024e, 0x012e,
   0x01d8, 0x008e, 0x011e, 0x0262, 0x03ab, 0x00ae, 0x03fa, 0x00ae,
   0x02fa, 0x0123, 0x027e, 0x0266, 0x001e, 0x038e, 0x039b, 0x0198,
   0x02cc, 0x0167, 0x00cc, 0x0153, 0x0239, 0x0034, 0x013b, 0x00b0,
   0x0158, 0x0046, 0x0249, 0x0034, 0x02b9, 0x001c, 0x0271, 0x0030,
   0x00cc, 0x001b, 0x03e5, 0x001c, 0x00d5, 0x0018, 0x028c, 0x001b,
   0x02be, 0x0000, 0x03e5, 0x001c, 0x00fb, 0x005e, 0x01d8, 0x00ae,
   0x0198, 0x01ae, 0x02cc, 0x001f, 0x00cc, 0x001f, 0x0286, 0x006e,
   0x02da, 0x00b3, 0x01d8, 0x02bd, 0x0034, 0x018c, 0x006b, 0x0379,
   0x001c, 0x0271, 0x0030, 0x0081, 0x0030, 0x0215, 0x0028, 0x02cc,
   0x027f, 0x0239, 0x0034, 0x014c, 0x03a0, 0x02be, 0x03e0, 0x004e,
   0x035c, 0x027a, 0x0236, 0x010e, 0x008e, 0x018c, 0x03a0, 0x0333,
   0x004e, 0x01d8, 0x01d1, 0x002c, 0x01ee, 0x03ce, 0x03e0, 0x02f8,
   0x0144, 0x0284, 0x0260, 0x025c, 0x01e2, 0x01e2, 0x002b, 0x02e2,
   0x0017, 0x0048, 0x0088, 0x02c9, 0x0012, 0x02f8, 0x0116, 0x021c,
   0x0190, 0x0316, 0x03cb, 0x001c, 0x0231, 0x001e, 0x01ee, 0x01ee,
   0x014e, 0x03e0, 0x002e, 0x00fa, 0x00da, 0x010e, 0x03e0, 0x0000
};
