/*
 * x11-calc-29.c - RPN (Reverse Polish) calculator simulator.
 *
 * Copyright(C) 2018   MT
 *
 * Model specific functions.
 *
 * This  program is free software: you can redistribute it and/or modify it
 * under  the terms of the GNU General Public License as published  by  the
 * Free  Software Foundation, either version 3 of the License, or (at  your
 * option) any later version.
 *
 * This  program  is distributed in the hope that it will  be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without even   the   implied   warranty   of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You  should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 09 Mar 14         - Initial version - MT
 * 10 Mar 14         - Changed indexes to BCD hex values - MT
 * 10 Dec 18         - Alternate  function key now LIGHT_BLUE, allowing  it
 *                     to be a different colour to the alternate text - MT
 * 16 Oct 21         - Added ROM contents and key codes - MT
 * 04 Nov 21         - Allows size of the window to be changed by modifying
 *                     the value of SCALE at compile time - MT
 * 22 Nov 21         - Fixed function key colour - MT
 * 23 Nov 21         - Added the alternate function text - MT
 * 06 Dec 21         - Changed green to a slightly lighter colour to try to
 *                     improve the appearance of the black text - MT
 *                   - Label text colour now explicitly defined - MT
 * 03 Jan 21         - Changed debug() macro so that debug code is executed
 *                     when DEBUG is defined (doesn't need to be true) - MT
 * 11 Jan 22         - Removed ROM_BANKS - MT
 * 23 Jan 22         - Changed the colour of the numeric keys - MT
 * 12 Feb 22         - Updated layout and separated the initialisation code
 *                     for buttons and switches into two functions - MT
 * 21 Oct 23         - Updated switch parameters to accomodate a 3 position
 *                     switch - MT
 *
 */

#define NAME           "x11-calc-27"
#define BUILD          "0014"
#define DATE           "21 Oct 23"
#define AUTHOR         "MT"

#include <stdarg.h>    /* strlen(), etc. */
#include <stdio.h>     /* fprintf(), etc. */
#include <stdlib.h>    /* getenv(), etc. */

#include <X11/Xlib.h>  /* XOpenDisplay(), etc. */
#include <X11/Xutil.h> /* XSizeHints etc. */

#include "x11-calc-font.h"
#include "x11-calc-button.h"
#include "x11-calc-switch.h"
#include "x11-calc-label.h"
#include "x11-calc-colour.h"

#include "x11-calc-cpu.h"

#include "x11-calc.h"

#include "gcc-debug.h"

oregister o_mem[MEMORY_SIZE];

void v_init_switches(oswitch *h_switch[]) /* Define the switches. */
{
   h_switch[0] = h_switch_create(00000, "OFF", "", "ON ", h_alternate_font, KBD_LEFT, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
   h_switch[1] = NULL;
}

void v_init_buttons(obutton *h_button[]) {
   int i_left, i_top;

   /* Define top row of keys. */
   i_top = KBD_TOP + 2* (SWITCH_HEIGHT + 1); /* Assumes the function label and switch text use the same font */
   i_left = KBD_LEFT;
   h_button[0] = h_button_create(00263, 000, " y ", "FIX", "", "LR", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[1] = h_button_create(00262, 000, " x ", "SCI", "", " s ", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[2] = h_button_create(00261, 000, " % ", "ENG", "", "d%", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[3] = h_button_create(00260, 'f', "f", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, YELLOW, BACKGROUND, YELLOW, YELLOW);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[4] = h_button_create(00264, 'g', "g", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, BACKGROUND, BLACK, BLACK);

   /* Define second row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[5] = h_button_create(00103, 000, "X-Y", "n", "", "r", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[6] = h_button_create(00102, 000, "R", "i", "", "VAR", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[7] = h_button_create(00101, 000, "STO", "PMT", "", "N.D", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[8] = h_button_create(00100, 000, "RCL", "PV", "", "NPV", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[9] = h_button_create(00104, 000, "yX", "FV", "", "IRR", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);

   /* Define third row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[10] = h_button_create(00323, 015, "ENTER", "PREFIX", "", "RESET", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, 2 * KEY_WIDTH + KEY_GAP, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += 2 * (KEY_WIDTH + KEY_GAP);
   h_button[11] = h_button_create(00321, 'c', "CHS", "E", "", "DEG", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[12] = h_button_create(00320, 'e', "EEX", "REG", "", "RAD", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[13] = h_button_create(00324, 033, "CLX", "STK", "", "GRD", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);

   /* Define fourth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[14] = h_button_create(00143, '-', "-", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[15] = h_button_create(00142, '7', "7", "LN", "", "eX", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[16] = h_button_create(00141, '8', "8", "LOG", "", "10x", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[17] = h_button_create(00140, '9', "9", "-R", "", "-P", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);

   /* Define fifth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[18] = h_button_create(00243, '+', "+", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[19] = h_button_create(00242, '4', "4", "SIN", "", "SIN-\xb9", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[20] = h_button_create(00241, '5', "5", "COS", "", "COS-\xb9", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[21] = h_button_create(00240, '6', "6", "TAN", "", "TAN-\xb9", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);

   /* Define sixth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[22] = h_button_create(00163, '*', "\xd7", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[23] = h_button_create(00162, '1', "1", "H.MS+", "", "H.MS-", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[24] = h_button_create(00161, '2', "2", "V\xaf", "", "x\xb2", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[25] = h_button_create(00160, '3', "3", "n!", "", "1/x", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);

   /* Define bottom row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[26] = h_button_create(00223, '/', "\xf7", "", "", "", h_large_font, h_small_font, h_alternate_font,i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[27] = h_button_create(00222, '0', "0", "-H.MS", "", "-H", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[28] = h_button_create(00221, '.', ".", "LASTx", "", "\x1c", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[29] = h_button_create(00220, 000, "E+", "E-", "", "%E", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, BLACK, LIGHT_GRAY);
}

int i_rom[ROM_SIZE] = {
   00310, 00204, 00672, 00672, 01710, 01160, 01260, 00610,
   00432, 01247, 00745, 00004, 00724, 00201, 01124, 00201,
   01314, 01414, 01777, 01224, 00127, 00110, 01504, 01327,
   01324, 00252, 01010, 00110, 01410, 01750, 01020, 00745,
   00110, 01204, 01304, 01007, 00745, 01010, 01310, 00232,
   01143, 00104, 00110, 01504, 01773, 01262, 00262, 01134,
   00655, 01007, 00745, 00151, 01040, 00745, 00155, 00464,
   01117, 00216, 01074, 01352, 00076, 01206, 00216, 01020,
   00177, 01357, 01133, 00223, 00745, 00640, 00745, 00724,
   00201, 01134, 00052, 01366, 00051, 00774, 01302, 00153,
   00110, 01145, 00006, 00410, 00510, 00704, 01007, 00110,
   00004, 00133, 00440, 00372, 01470, 01175, 01674, 01373,
   00656, 00656, 01177, 00141, 00564, 00375, 01237, 00745,
   01310, 00104, 01243, 01244, 00125, 00620, 00473, 00656,
   00656, 00656, 01773, 01004, 00141, 00240, 00745, 00155,
   01040, 01524, 01722, 01624, 01775, 01020, 00514, 00534,
   00576, 00210, 01714, 00374, 00620, 00554, 00204, 01724,
   00202, 01760, 01734, 00212, 00310, 00420, 00006, 00020,
   00733, 00053, 01777, 00604, 00141, 00440, 00745, 01110,
   01237, 00174, 00342, 00230, 00174, 00342, 01020, 00656,
   00656, 00656, 00677, 00404, 00141, 00564, 00401, 00114,
   00110, 00140, 01234, 00256, 01214, 00304, 01404, 01007,
   00117, 00327, 00313, 01343, 00110, 01604, 01005, 00240,
   00745, 00155, 01040, 00745, 00110, 00213, 00024, 01546,
   00710, 01542, 00315, 00412, 01156, 01156, 01156, 01352,
   00327, 00610, 00756, 00130, 00610, 00332, 01360, 01237,
   00433, 01703, 01020, 00637, 00745, 00432, 00647, 00274,
   01342, 00334, 00605, 00605, 01374, 01342, 00340, 00605,
   01674, 01342, 00344, 00675, 00174, 01342, 00350, 00705,
   01174, 01342, 00354, 00656, 00716, 00372, 00155, 00540,
   01410, 00745, 01366, 00201, 00734, 00055, 01124, 00055,
   00174, 00202, 01242, 00202, 00364, 01373, 00656, 01624,
   00322, 00724, 00443, 01324, 01514, 01424, 00322, 00124,
   00414, 01124, 00423, 01310, 00114, 01104, 01655, 00036,
   01126, 00012, 01112, 01074, 00706, 00720, 01144, 00474,
   00642, 00357, 00123, 00304, 00552, 00633, 00432, 01020,
   00002, 01106, 00040, 01124, 00442, 01074, 00706, 01174,
   00706, 00174, 01646, 01646, 01410, 00341, 01074, 01506,
   00645, 00341, 01761, 00213, 00774, 00356, 01075, 00763,
   00040, 01075, 00733, 01102, 00620, 00344, 00440, 00024,
   00504, 00244, 00504, 01726, 00232, 00272, 00620, 01146,
   01526, 00717, 00232, 01524, 00120, 00213, 01522, 00710,
   01203, 01116, 01116, 01116, 01512, 00771, 00723, 01302,
   00532, 00453, 00656, 00620, 00537, 01410, 01352, 00545,
   01156, 00752, 01152, 00157, 00756, 01020, 00774, 00406,
   01146, 00412, 01020, 00710, 00216, 01512, 00471, 00674,
   01075, 00256, 00341, 00012, 01516, 00521, 00256, 00341,
   00064, 01145, 01761, 00510, 00110, 00040, 00774, 01410,
   00372, 01242, 00620, 00054, 00601, 00372, 00213, 01356,
   00465, 00744, 00703, 01726, 01156, 00620, 01037, 00620,
   00344, 00626, 01356, 00626, 01156, 01077, 00432, 00206,
   00246, 00532, 00006, 00510, 01532, 00516, 01524, 00703,
   00420, 01106, 01410, 00262, 01020, 00510, 00616, 00565,
   00334, 00461, 01566, 00655, 00432, 00565, 00410, 00510,
   01655, 00266, 00016, 01610, 00024, 00705, 00234, 00553,
   00116, 01352, 00607, 01504, 01646, 00620, 00756, 01356,
   00464, 00354, 00674, 00004, 01277, 00174, 01131, 00733,
   00234, 00757, 00024, 00757, 00620, 01726, 01723, 01410,
   00774, 01502, 00527, 01116, 00726, 01507, 00072, 00032,
   00114, 01274, 01730, 01630, 01230, 01230, 01430, 01230,
   00310, 01730, 01354, 00741, 00232, 01134, 00574, 01350,
   01450, 01650, 00763, 00036, 00072, 00662, 00340, 00756,
   01152, 01352, 00766, 00752, 01672, 01203, 00510, 00272,
   00733, 01156, 01726, 00707, 00174, 00706, 00706, 01020,
   00223, 00253, 00727, 00163, 01407, 01407, 01407, 00740,
   00740, 01210, 01375, 01366, 01244, 01362, 01307, 01423,
   00217, 00257, 00357, 00377, 01473, 01467, 01477, 01117,
   01113, 01375, 01364, 00217, 01461, 00272, 01770, 00464,
   01133, 01364, 01357, 00404, 00372, 00715, 01127, 01240,
   00564, 00267, 01262, 00372, 00715, 01010, 01310, 00132,
   00715, 01010, 00371, 00404, 00223, 01311, 00032, 00226,
   00745, 01555, 00243, 00325, 01127, 00000, 00440, 00774,
   01311, 01552, 00726, 00272, 00172, 00736, 01506, 01115,
   00656, 01416, 01122, 00752, 01127, 01116, 00423, 00164,
   01533, 00000, 00432, 00742, 01772, 00762, 00372, 01302,
   01133, 01706, 00756, 00032, 01602, 00607, 00732, 00472,
   00577, 01622, 00643, 01646, 00672, 00756, 00472, 00633,
   00106, 01142, 00537, 01162, 00537, 00732, 00156, 00436,
   00532, 00236, 01127, 00364, 00767, 00272, 00564, 00065,
   01127, 00172, 00372, 00572, 00572, 00632, 00372, 00436,
   00272, 00556, 01023, 01166, 00556, 00616, 01474, 01542,
   01212, 01732, 01772, 00216, 00432, 00132, 01274, 00530,
   01772, 01163, 00604, 00664, 00271, 00340, 00742, 01632,
   01133, 00532, 00732, 00620, 01746, 01354, 01227, 00402,
   00232, 00372, 01020, 00000, 00752, 00222, 01532, 01312,
   00132, 01010, 00372, 01310, 00372, 00564, 01261, 01264,
   00013, 00000, 01566, 01265, 00432, 01562, 00726, 01020,
   00716, 01534, 01274, 00652, 00064, 00155, 00220, 00764,
   01647, 01504, 00652, 00220, 00704, 01204, 00422, 00564,
   00605, 00022, 01264, 00173, 00440, 01204, 00604, 01375,
   01524, 01047, 01364, 00243, 00432, 00624, 00132, 01172,
   00412, 00422, 01127, 00564, 01627, 00756, 01162, 01567,
   00422, 00410, 00232, 01132, 00510, 01224, 01351, 01216,
   00132, 01332, 01324, 00564, 00431, 00022, 00634, 01041,
   00172, 01074, 00442, 01757, 00732, 00676, 01763, 00662,
   01672, 00172, 00756, 00732, 00236, 00564, 01261, 00764,
   01435, 01534, 01440, 00372, 00132, 01770, 00232, 00564,
   00615, 00232, 00410, 00616, 01310, 00510, 00232, 00764,
   00011, 01010, 01310, 01770, 00216, 00016, 01672, 00410,
   00564, 00131, 00564, 00265, 01364, 01467, 00000, 01137,
   00372, 00132, 00510, 00232, 01056, 00016, 01672, 00564,
   00431, 00422, 01364, 01357, 01156, 01027, 00432, 00326,
   00434, 01726, 00720, 01154, 01467, 00651, 00353, 00720,
   00651, 00620, 00620, 00651, 00272, 00332, 01613, 00000,
   00737, 00553, 01353, 01333, 00372, 01670, 00656, 01174,
   01367, 01725, 00752, 01643, 00216, 01160, 00216, 01424,
   01745, 01234, 00316, 01655, 00070, 00627, 00000, 00000,
   00000, 00000, 00040, 01364, 00111, 00572, 00572, 01772,
   00766, 00416, 01020, 00756, 00756, 00040, 00332, 00517,
   01746, 00606, 00246, 01746, 00546, 00546, 01046, 00434,
   01651, 00032, 00256, 00632, 00416, 01020, 01040, 00372,
   01570, 00064, 00701, 00174, 01367, 01326, 01610, 00774,
   00316, 00756, 00756, 01552, 01656, 00620, 01354, 01454,
   00332, 01020, 00272, 00432, 00450, 00550, 00650, 01223,
   00733, 01467, 01655, 00555, 00627, 01260, 00627, 01552,
   01640, 00024, 01642, 00432, 01172, 01574, 00746, 01156,
   01164, 00543, 01164, 00277, 00750, 01050, 01150, 00232,
   00627, 00506, 01746, 01546, 01651, 01020, 01312, 01610,
   00273, 01637, 00447, 01725, 00204, 01643, 00372, 01270,
   00274, 01367, 00372, 01370, 01374, 00040, 01174, 01506,
   00451, 00064, 01007, 00656, 00656, 00432, 00310, 01350,
   01134, 01644, 01450, 01650, 01237, 01655, 01770, 00627,
   01127, 01053, 00020, 00627, 00010, 00627, 00032, 00641,
   00720, 01144, 01734, 00720, 00641, 00732, 00532, 00372,
   00564, 01305, 00564, 01363, 00540, 00464, 01767, 01725,
   01710, 00610, 00627, 00124, 01756, 01310, 01020, 00662,
   00122, 00774, 00642, 00142, 01020, 00110, 01404, 00064,
   01005, 00214, 00610, 00412, 01020, 00110, 01410, 00020,
   00064, 00151, 01362, 00005, 01104, 00272, 01355, 01465,
   00572, 00575, 01262, 00764, 01725, 00410, 00364, 00555,
   00572, 00264, 00325, 00272, 01465, 00232, 00575, 00510,
   01355, 01310, 01650, 01661, 00230, 00330, 00130, 00630,
   00430, 00130, 01130, 00232, 01770, 01134, 00050, 01262,
   01355, 01465, 00375, 01465, 00232, 00575, 01550, 00771,
   00330, 00330, 00030, 00230, 00730, 00430, 00430, 00330,
   00272, 01570, 01355, 00765, 01030, 00427, 00540, 00540,
   00607, 00003, 01073, 01040, 01040, 01262, 00230, 00130,
   00230, 00530, 00530, 01130, 01030, 01645, 01355, 00765,
   00730, 01030, 00130, 00430, 00730, 00730, 01130, 00430,
   01645, 01355, 01143, 01534, 00260, 00432, 01453, 00564,
   00113, 01750, 01070, 00272, 01465, 00375, 01050, 01262,
   00410, 01370, 00272, 01701, 00575, 00510, 00664, 01575,
   01770, 01355, 01170, 00375, 01150, 01570, 00371, 00240,
   01750, 00272, 00570, 01753, 00000, 00410, 00432, 00774,
   00130, 01020, 00330, 01645, 01355, 01670, 01355, 01134,
   00214, 01465, 00232, 00371, 01064, 00603, 00704, 01040,
   00743, 00340, 00000, 01210, 01355, 01701, 00575, 00737,
   00410, 01661, 00330, 00530, 00630, 00530, 00630, 00330,
   00730, 01030, 00230, 01262, 01645, 01355, 00410, 01661,
   00330, 00130, 01130, 00330, 01030, 00130, 00530, 01013,
   01340, 01723, 01077, 01064, 00107, 00624, 00301, 00132,
   00564, 00411, 01340, 00564, 00067, 00610, 00774, 00402,
   01020, 01534, 00260, 00372, 00132, 01770, 00564, 00075,
   00764, 00021, 01310, 01770, 01340, 00540, 01365, 01533,
   01473, 01365, 01643, 01607, 01365, 00742, 00742, 01643,
   00334, 00300, 00232, 00072, 01274, 01730, 00030, 01330,
   00140, 00610, 00774, 00342, 00426, 00342, 01474, 00402,
   00340, 00272, 00510, 00540, 00432, 00774, 01156, 01020,
   01465, 00756, 00756, 01020, 01750, 01210, 00232, 00371,
   01210, 00232, 00575, 00364, 00617, 01410, 01750, 00232,
   01160, 00070, 00434, 00535, 00401, 00324, 00646, 00561,
   01360, 01770, 00464, 01541, 01233, 00072, 00126, 01105,
   01305, 00267, 01366, 00725, 00605, 00267, 00132, 00651,
   00510, 01307, 00232, 00222, 00665, 01305, 00426, 00664,
   00243, 00272, 01471, 00401, 00664, 00271, 01334, 00451,
   01262, 00272, 00510, 00232, 01227, 00774, 00072, 00156,
   00446, 00327, 01646, 00756, 00642, 00226, 00272, 01020,
   01625, 00605, 00522, 01122, 00416, 00664, 00363, 01262,
   00761, 00267, 00032, 00662, 01672, 01216, 00426, 00774,
   00453, 00742, 01032, 00447, 00472, 00732, 00620, 00354,
   00526, 00356, 00416, 01136, 00453, 01274, 01154, 00512,
   00032, 00232, 00222, 01533, 00140, 01034, 00630, 00065,
   00027, 00072, 00366, 01062, 00633, 01222, 01056, 00016,
   00022, 00433, 01474, 01133, 00472, 01142, 00663, 00244,
   00566, 00720, 01672, 00667, 00756, 01672, 01020, 00761,
   00265, 00561, 01360, 01020, 00774, 00072, 00652, 00652,
   00752, 00752, 01416, 00605, 00232, 00226, 01366, 00611,
   00232, 00366, 01416, 00730, 01732, 00656, 01332, 00730,
   01053, 00616, 01174, 01062, 01133, 01222, 00032, 00667,
   00324, 00633, 00232, 00634, 00667, 00111, 00027, 01670,
   00272, 01370, 01566, 00676, 01470, 00111, 00040, 00000,
   00000, 01304, 01570, 01203, 00410, 00332, 00651, 00510,
   00556, 01522, 00564, 01020, 00704, 01625, 00363, 00375,
   00027, 00434, 00674, 01262, 01625, 00267, 01470, 00111,
   01761, 00065, 01471, 01324, 00713, 00401, 01140, 01105,
   00426, 00764, 01743, 00232, 00375, 01433, 00432, 00762,
   01772, 01020, 00656, 00620, 00153, 00140, 00356, 01627,
   01152, 01152, 00016, 01622, 01522, 00740, 00472, 01307,
   01466, 00744, 01262, 00132, 01032, 00774, 01506, 00764,
   00416, 01020, 00000, 00000, 00761, 00265, 01570, 01020,
   01164, 00123, 00662, 01156, 01502, 00751, 00706, 01713,
   00000, 00000, 00000, 00000, 01370, 01156, 01156, 01020,
   01356, 01043, 01172, 00372, 00066, 01675, 00232, 01072,
   01312, 01013, 01072, 00232, 00372, 01352, 01020, 01272,
   00206, 00620, 00732, 00554, 01021, 00774, 01502, 00722,
   00726, 00540, 00472, 01142, 00153, 01562, 01154, 00244,
   01000, 00432, 01305, 01665, 00022, 00734, 01050, 01162,
   01224, 01303, 00624, 01307, 00540, 01371, 00774, 00414,
   00714, 01366, 01315, 01562, 01174, 01356, 01330, 00756,
   00032, 01626, 01356, 00664, 01646, 00162, 01274, 00620,
   01122, 00377, 00122, 00162, 00436, 00467, 01355, 00271,
   01010, 00064, 01237, 01672, 00742, 00122, 00172, 00420,
   00522, 00610, 00222, 00732, 01672, 01162, 00523, 01410,
   00610, 00472, 00732, 01122, 00457, 00262, 01122, 00522,
   00623, 00132, 00732, 00673, 00544, 01141, 00762, 00620,
   00132, 00122, 00732, 00467, 01162, 00720, 00372, 00764,
   00675, 01672, 00372, 00157, 01516, 01205, 01523, 01522,
   01324, 00232, 00432, 01020, 01234, 00725, 00232, 00510,
   00232, 00172, 01512, 01324, 00656, 01116, 00736, 01526,
   01164, 01516, 01223, 00222, 00262, 00562, 00562, 00622,
   01362, 01065, 00404, 00422, 00327, 00072, 00166, 00022,
   01516, 01252, 01562, 01266, 00420, 00662, 01410, 00132,
   00662, 01672, 00132, 00222, 00416, 00564, 00431, 00420,
   00564, 00353, 00656, 01732, 00662, 00620, 00344, 01325,
   01143, 00720, 01156, 00254, 01261, 01020, 00122, 01672,
   00704, 00432, 00467, 00064, 00155, 01210, 00604, 01204,
   00410, 00232, 01020, 00132, 00232, 00510, 00540, 00372,
   01675, 00372, 00564, 00431, 00263, 01234, 00725, 00232,
   00510, 00232, 01526, 01167, 00540, 00032, 00226, 00217,
   00272, 01102, 01526, 00470, 00432, 00032, 00243, 01371,
   00774, 00272, 00656, 01512, 01225, 00032, 00642, 00564,
   00761, 00261, 00273, 00267, 01577, 00564, 01627, 00432,
   00774, 00230, 00330, 00030, 00230, 00530, 01030, 00530,
   00030, 01130, 00230, 01130, 01130, 00430, 00774, 01020,
   00000, 00000, 00564, 00265, 00724, 01533, 00563, 00000,
   00623, 00265, 00627, 00372, 00675, 00372, 01305, 01254,
   01414, 01274, 00730, 00222, 00372, 00147, 00172, 01162,
   00223, 01646, 00232, 00736, 00232, 01122, 00133, 00132,
   00642, 00564, 01347, 01646, 01122, 00217, 00022, 00472,
   00642, 00133, 01646, 00642, 00147, 00232, 00545, 00414,
   00372, 00432, 00232, 00564, 01437, 00756, 01672, 01352,
   01743, 01522, 01465, 01216, 01352, 01516, 00426, 00032,
   00556, 00503, 00406, 01562, 01511, 01172, 00412, 00424,
   01512, 00422, 01014, 00272, 01020, 01672, 01156, 00467,
   00416, 01362, 01526, 00132, 01032, 01256, 00436, 01020,
   00000, 00664, 01677, 01262, 00140, 00756, 01032, 00567,
   00472, 01166, 00633, 00507, 01725, 00040, 00232, 00716,
   00232, 00732, 01034, 01536, 01552, 01502, 00573, 00432,
   00244, 01671, 01172, 00430, 00772, 00422, 01772, 01544,
   01603, 00444, 01620, 00144, 01633, 01644, 01644, 00644,
   01653, 00720, 01020, 01574, 00330, 00130, 00030, 00130,
   00730, 01130, 01030, 00030, 00430, 00330, 00474, 01020,
   00274, 00330, 00330, 00030, 01030, 00530, 00330, 00130,
   00730, 00674, 01020, 01674, 00330, 00330, 00330, 00030,
   01030, 00430, 01574, 01020, 01174, 00330, 00330, 00330,
   00330, 00374, 01020, 01074, 00330, 00330, 00274, 01020,
   00762, 01032, 01303, 00472, 00732, 01776, 00372, 00620,
   01020, 00474, 00630, 01130, 00330, 00130, 00430, 00730,
   00130, 01030, 00030, 00530, 00630, 00774, 01020, 00072,
   00356, 00774, 00332, 00556, 01573, 00332, 01264, 01571,
   00642, 01523, 00720, 01503, 00564, 01305, 00072, 00264,
   00747, 00620, 01354, 01737, 00332, 01533, 00332, 01156,
   01547, 00332, 01503, 00232, 00706, 00706, 00706, 00232,
   00573, 00372, 00710, 00774, 01342, 01763, 01142, 01142,
   01713, 01404, 01604, 00372, 01020, 00032, 00414, 00226,
   00372, 00545, 00372, 01004, 00335, 01024, 01413, 01020,
   01424, 00266, 01670, 00624, 00275, 00101, 01524, 00136,
   01550, 00424, 00014, 01310, 01504, 00257, 00770, 00227,
   01140, 01750, 01010, 01765, 01305, 00410, 00634, 00033,
   01070, 00163, 00040, 00670, 01445, 00272, 01524, 00016,
   00470, 01415, 01372, 00430, 00742, 01305, 00510, 00365,
   01624, 00000, 01650, 01765, 01534, 00315, 01170, 00123,
   00410, 01435, 00410, 01617, 00000, 00405, 00470, 00101,
   01310, 01765, 00470, 00101, 00623, 00440, 00440, 00670,
   01020, 00770, 01773, 00000, 01317, 01461, 01350, 01570,
   00210, 01114, 01366, 00430, 01262, 01650, 01711, 00416,
   00410, 00432, 01450, 01750, 01370, 00272, 01470, 01305,
   01670, 01517, 01524, 00077, 01070, 01020, 00424, 00155,
   00432, 01550, 01650, 00232, 00340, 00470, 00272, 01461,
   01741, 00464, 01541, 00064, 00647, 00410, 01570, 00272,
   01770, 01305, 00510, 00371, 00603, 01262, 00540, 00151,
   00404, 00410, 01504, 01765, 00510, 01741, 00510, 00272,
   01305, 00551, 01735, 01534, 00145, 01210, 00510, 00232,
   00410, 00510, 01305, 01170, 01735, 01514, 00405, 00763,
   01750, 01010, 00405, 01305, 00470, 00101, 00551, 00232,
   00365, 00422, 00410, 00470, 00272, 01461, 00365, 00510,
   00232, 00101, 00724, 00245, 01755, 01524, 00144, 01310,
   01504, 01765, 01117, 00422, 01755, 01570, 00232, 00101,
   00603, 00564, 00067, 01750, 01404, 00117, 01550, 00405,
   01414, 00604, 00123, 00404, 00117, 01305, 01566, 00253,
   01461, 00232, 00603, 01552, 00430, 01366, 00430, 00774,
   01142, 01562, 00430, 01020, 00440, 00770, 01305, 00410,
   01170, 01604, 00167, 00371, 01450, 01370, 00272, 01670,
   01305, 01770, 01160, 00070, 01124, 00343, 01562, 00060,
   01366, 00060, 01104, 00371, 01650, 01711, 01746, 00620,
   01354, 00346, 00272, 01770, 01056, 01356, 00600, 01056,
   00756, 00517, 01270, 01415, 01356, 00377, 01443, 00232,
   00424, 00165, 00733, 00264, 00327, 00570, 00272, 01020,
   01331, 01655, 01461, 00237, 00616, 01353, 01107, 00143,
   01304, 01404, 00003, 01427, 00540, 01173, 01240, 00143,
   00143, 00540, 00143, 00277, 00220, 00403, 01153, 00143,
   00164, 01533, 00143, 01663, 01603, 00003, 00340, 00213,
   00043, 01304, 01331, 01262, 01655, 01461, 00232, 00371,
   01366, 00730, 01415, 01324, 00637, 00105, 01513, 01270,
   00272, 01461, 00232, 00105, 00034, 00520, 01262, 00410,
   01170, 00272, 00022, 00513, 01670, 01567, 00540, 00540,
   01270, 01262, 01050, 01670, 01262, 01525, 00105, 01150,
   01461, 00474, 00230, 00061, 01070, 01445, 00232, 01717,
   01765, 00105, 00510, 01651, 01461, 00371, 00034, 00702,
   01350, 00762, 00774, 01142, 01372, 00702, 01070, 01262,
   01655, 00750, 00210, 01070, 00061, 01370, 00061, 00410,
   01370, 00272, 01461, 00375, 00510, 00232, 00105, 00770,
   00375, 01461, 00371, 00410, 01170, 00272, 01370, 00061,
   01461, 00371, 00770, 00375, 00510, 01366, 00622, 01057,
   01370, 01525, 00061, 00410, 00272, 01670, 00061, 00510,
   00371, 01670, 00232, 00105, 00432, 01474, 00630, 01512,
   00404, 01370, 00061, 01366, 00672, 01370, 00375, 01124,
   00106, 00543, 01270, 01050, 01570, 00427, 00540, 00232,
   00105, 01434, 00715, 01670, 01473, 01461, 00375, 00410,
   01070, 00272, 01170, 00371, 00375, 00510, 00105, 00756,
   00756, 00756, 01552, 01555, 01070, 01637, 01415, 00272,
   01270, 01020, 01461, 00375, 01370, 00061, 01134, 00702,
   01461, 00371, 00340, 00564, 01763, 01771, 00105, 01645,
   01677, 01366, 00430, 01020, 00440, 01570, 00061, 01340,
   01270, 00272, 01470, 01473, 01670, 00272, 01470, 01020,
   01334, 00720, 01424, 00474, 01570, 01335, 00105, 01477,
   01331, 01262, 01655, 01217, 01461, 00272, 01170, 00105,
   00543, 00640, 00640, 00640, 01331, 01655, 01467, 00410,
   01415, 00564, 00207, 00105, 01352, 00744, 00375, 01070,
   00004, 01512, 00460, 00272, 01227, 00410, 01670, 00272,
   01570, 01020, 00764, 01435, 00132, 00232, 01770, 00564,
   00075, 01010, 01310, 00510, 00257, 00000, 00000, 00564,
   01247, 00172, 01332, 01137, 01102, 01532, 01217, 00432,
   00634, 01131, 01541, 00577, 00264, 01243, 00164, 00565,
   00334, 01034, 01572, 01050, 01010, 01770, 01310, 00432,
   00032, 00072, 00266, 01362, 01064, 00404, 01534, 01065,
   01234, 01065, 01214, 00704, 00414, 00774, 01352, 01214,
   01534, 01072, 00634, 01227, 01575, 00432, 00172, 00372,
   01672, 00642, 01206, 00473, 00132, 00232, 01615, 00410,
   00232, 00564, 00135, 01156, 00264, 00745, 00372, 00132,
   01770, 00232, 00564, 00615, 00022, 01552, 01227, 00132,
   01117, 01364, 00111, 00232, 00432, 00664, 01311, 00372,
   01364, 00111, 00572, 01772, 00372, 01234, 01160, 01601,
   00372, 00232, 01072, 00232, 00372, 00432, 01615, 00022,
   00734, 01164, 01601, 00472, 00422, 01424, 01202, 00756,
   00756, 00564, 00431, 00022, 01624, 01202, 00172, 01732,
   01032, 01615, 00564, 01345, 01524, 01212, 01010, 01310,
   00232, 00422, 00064, 01237, 01356, 01021, 00132, 00624,
   00430, 01534, 01223, 00564, 00411, 00022, 01541, 00774,
   00410, 00510, 00436, 00756, 01356, 01244, 00762, 00620,
   00654, 01233, 00510, 00577, 00410, 00432, 00762, 01772,
   01327, 00232, 00410, 00742, 00262, 00410, 01732, 01732,
   01122, 01273, 00022, 00472, 00232, 00172, 01632, 01247,
   00410, 00762, 00410, 00132, 00732, 00620, 00654, 01265,
   00372, 00564, 00431, 01427, 01646, 01122, 01423, 00022,
   00416, 00410, 00274, 00372, 01621, 00372, 01503, 00472,
   01142, 01477, 01672, 00402, 01366, 01135, 00720, 01457,
   01224, 01334, 01204, 01020, 01214, 01020, 01672, 00756,
   01556, 01336, 01020, 00340, 00432, 01172, 00422, 00244,
   01365, 01444, 01406, 01544, 01414, 00444, 01774, 00144,
   01551, 01474, 00730, 00274, 01020, 00674, 00630, 00630,
   01030, 00630, 00530, 00230, 00430, 01130, 00130, 00130,
   00630, 00207, 00630, 01344, 01362, 00013, 00374, 00011,
   00174, 01030, 00474, 01020, 01374, 00011, 01474, 01130,
   00674, 01020, 00774, 00432, 00730, 01030, 00530, 00330,
   01130, 01030, 00130, 00630, 00330, 00330, 01130, 00730,
   00530, 00774, 01020, 01504, 00604, 01204, 01010, 00232,
   01566, 01453, 00432, 00032, 00072, 00226, 01362, 01465,
   00704, 01224, 01464, 00404, 00422, 00372, 01424, 01665,
   01634, 01476, 00232, 00272, 01772, 01632, 01115, 00372,
   01156, 01552, 01507, 01156, 00437, 00756, 01672, 00372,
   00410, 00510, 00572, 00572, 00572, 01772, 00372, 01552,
   01540, 00764, 00335, 00432, 00372, 00510, 00572, 00732,
   01434, 01534, 01672, 01772, 00372, 01032, 01513, 00472,
   00372, 00510, 00372, 01434, 01570, 01556, 01567, 00732,
   00743, 00574, 00011, 00374, 01020, 01070, 00564, 00111,
   01164, 01373, 00132, 01032, 01264, 01541, 00767, 00756,
   01552, 01577, 01032, 00713, 00472, 00564, 01625, 00022,
   01424, 01614, 00372, 00510, 00372, 00564, 00431, 00022,
   00410, 00111, 00564, 00131, 01156, 00410, 00510, 00756,
   01157, 00732, 01167, 00432, 00774, 00430, 00530, 00207,
   00620, 00644, 01676, 00756, 01143, 00432, 00372, 01264,
   01621, 00372, 00764, 01305, 00654, 01637, 00372, 00410,
   01672, 01672, 00432, 00774, 00130, 00410, 01274, 00630,
   01663, 01343, 00704, 00567, 00440, 00111, 00443, 00000,
   00432, 00032, 00642, 00564, 01345, 01503, 00774, 00510,
   01224, 01664, 01534, 01673, 00372, 01770, 00764, 00021,
   01310, 01770, 00132, 00564, 00075, 00434, 01720, 01262,
   00064, 01237, 01234, 01733, 01214, 00424, 01731, 00404,
   00567, 00414, 00567, 01204, 00634, 01725, 00734, 01662,
   00714, 00567, 01646, 01646, 01122, 01613, 00022, 00410,
   00232, 01072, 00472, 00410, 00172, 00262, 01142, 01623,
   00232, 00726, 00232, 01366, 01771, 01162, 00022, 01672,
   01663, 00264, 01573, 00000, 00174, 00011, 01574, 01020
};
