/*
 * x11-calc-33c.c - RPN (Reverse Polish) calculator simulator.
 *
 * Copyright(C) 2018   MT
 *
 * Model specific functions.
 *
 * This  program is free software: you can redistribute it and/or modify it
 * under  the terms of the GNU General Public License as published  by  the
 * Free  Software Foundation, either version 3 of the License, or (at  your
 * option) any later version.
 *
 * This  program  is distributed in the hope that it will  be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without even   the   implied   warranty   of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You  should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 13 Jun 13         - Initial version - MT
 * 10 Mar 14         - Changed indexes to BCD hex values - MT
 * 10 Dec 18         - Alternate  function key now LIGHT_BLUE, allowing  it
 *                     to be a different color to the alternate text - MT
 * 31 Aug 20         - Made  version(), about(), and error() model specific
 *                     so that the name reflects the model number - MT
 *                   - Modified version() to display a leading zero in  the
 *                     date instead of a space - MT
 * 26 Sep 21         - Replaced BCD hex key codes with octal values - MT
 *                   - Added shortcut key definitions - MT
 * 18 Oct 21         - Added key codes and ROM contents - MT
 * 20 Oct 21         - Assigned space bar to single step - MT
 * 02 Nov 21         - Allows size of the window to be changed by modifying
 *                     the value of SCALE at compile time - MT
 * 23 Nov 21         - Added the alternate function text - MT
 * 06 Dec 21         - Label text colour now explicitly defined - MT
 * 03 Jan 21         - Changed debug() macro so that debug code is executed
 *                     when DEBUG is defined (doesn't need to be true) - MT
 * 11 Jan 22         - Removed ROM_BANKS - MT
 * 12 Feb 22         - Updated layout and separated the initialisation code
 *                     for buttons and switches into two functions - MT
 * 21 Oct 23         - Updated switch parameters to accomodate a 3 position
 *                     switch - MT
 *
 */

#define NAME           "x11-calc-33c"
#define BUILD          "0016"
#define DATE           "21 Oct 23"
#define AUTHOR         "MT"

#include <stdarg.h>    /* strlen(), etc. */
#include <stdio.h>     /* fprintf(), etc. */
#include <stdlib.h>    /* getenv(), etc. */

#include <X11/Xlib.h>  /* XOpenDisplay(), etc. */
#include <X11/Xutil.h> /* XSizeHints etc. */

#include "x11-calc-font.h"
#include "x11-calc-button.h"
#include "x11-calc-switch.h"
#include "x11-calc-label.h"
#include "x11-calc-colour.h"

#include "x11-calc-cpu.h"

#include "x11-calc.h"

#include "gcc-debug.h"

oregister o_mem[MEMORY_SIZE];

void v_init_switches(oswitch *h_switch[]) /* Define the switches. */
{
   /* Define the switches. */
   h_switch[0] = h_switch_create(00000, "OFF", "", "ON ", h_alternate_font, KBD_LEFT, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
   h_switch[1] = h_switch_create(00000, "PRGM", "", "RUN", h_alternate_font, KBD_LEFT + 3 * KEY_WIDTH + 2 * KEY_GAP, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
}

void v_init_buttons(obutton *h_button[]) {
   int i_left, i_top;

   /* Define top row of keys. */
   i_top = KBD_TOP + 2* (SWITCH_HEIGHT + 1); /* Assumes the function label and switch text use the same font */
   i_left = KBD_LEFT;
   h_button[0] = h_button_create(00064, ' ', "SST", "FIX", "", "BST", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[1] = h_button_create(00063, 000, "GSB", "SCI", "", "RTN", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[2] = h_button_create(00062, 000, "GTO", "ENG", "", "NOP", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[3] = h_button_create(00061, 'f', "f", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, YELLOW, BACKGROUND, YELLOW, YELLOW);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[4] = h_button_create(00060, 'g', "g", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_BLUE, BACKGROUND, LIGHT_BLUE, LIGHT_BLUE);

   /* Define second row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[5] = h_button_create(00224, 000, "X-Y", "x", "", "DEG", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[6] = h_button_create(00223, 000, "R", "y", "", "RAD", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[7] = h_button_create(00222, 000, "STO", "r", "", "GRD", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[8] = h_button_create(00221, 000, "RCL", "L.R", "", "x", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[9] = h_button_create(00220, 000, "E+", "E-", "", "s", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define third row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[10] = h_button_create(00163, 015, "ENTER", "PREFIX", "", "MANT", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, 2 * KEY_WIDTH + KEY_GAP, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += 2 * (KEY_WIDTH + KEY_GAP);
   h_button[11] = h_button_create(00162, 'c', "CHS", "PRGM", "", "INT", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[12] = h_button_create(00161, 'e', "EEX", "REG", "", "FRAC", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[13] = h_button_create(00160, 033, "CLX", "STK", "", "ABS", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define fourth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[14] = h_button_create(00243, '-', "-", "X\x1a\x59", "", "X<0", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[15] = h_button_create(00242, '7', "7", "SIN", "", "SIN-\xb9", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[16] = h_button_create(00241, '8', "8", "COS", "", "COS-\xb9", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[17] = h_button_create(00240, '9', "9", "TAN", "", "TAN-\xb9", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define fifth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[18] = h_button_create(00143, '+', "+", "X>Y", "", "X>0", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[19] = h_button_create(00142, '4', "4", "-R", "", "-P", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[20] = h_button_create(00141, '5', "5", "-RAD", "", "-DEG", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[21] = h_button_create(00140, '6', "6", "-H.MS", "", "-H", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define sixth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[22] = h_button_create(00323, '*', "\xd7", "X\x1d\x59", "", "X\x1d\x30", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[23] = h_button_create(00322, '1', "1", "LN", "", "eX", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[24] = h_button_create(00321, '2', "2", "LOG", "", "10x", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[25] = h_button_create(00320, '3', "3", "yX", "", "1/x", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define bottom row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[26] = h_button_create(00103, '/', "\xf7", "X=Y", "", "X=0", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[27] = h_button_create(00102, '0', "0", "/\xaf", "", "x\xb2", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[28] = h_button_create(00101, '.', ".", "LASTx", "", "\x1c", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[29] = h_button_create(00100, 000, "R/S", "PAUSE", "", "%", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
}

int i_rom[ROM_SIZE] = {
   00664, 00013, 01460, 00031, 01360, 01020, 01566, 00011,
   00432, 01410, 00774, 01352, 00022, 01156, 00752, 01152,
   00117, 00756, 01020, 00552, 00137, 00432, 00157, 00406,
   01146, 00412, 01304, 01274, 01020, 00032, 00774, 00642,
   01366, 00401, 00625, 00243, 01210, 01116, 01116, 00255,
   00664, 00003, 01010, 00551, 00072, 00126, 00351, 00535,
   00774, 00072, 00156, 00446, 00337, 00756, 00642, 00226,
   00272, 01020, 00616, 01174, 01062, 00377, 01222, 00032,
   00423, 01474, 00377, 00472, 01142, 00417, 00244, 00115,
   00720, 01672, 00423, 00756, 01672, 01020, 00132, 00405,
   00510, 00537, 00410, 00332, 00405, 00510, 00556, 01522,
   00113, 01020, 00610, 00710, 01020, 00272, 00257, 01366,
   00401, 00633, 01366, 00401, 01010, 00551, 00641, 00303,
   00072, 00366, 01062, 00667, 01222, 01056, 00016, 00022,
   00426, 00774, 01472, 00170, 01156, 00732, 00743, 00742,
   01032, 00737, 00472, 00620, 00354, 00205, 00676, 00356,
   00416, 01017, 01136, 01472, 00202, 00732, 01154, 00170,
   00032, 00232, 00222, 00356, 01363, 00032, 00662, 01216,
   01672, 00703, 01010, 01143, 00232, 01534, 00230, 01262,
   01151, 00303, 00774, 00072, 00652, 00652, 00752, 00752,
   01416, 00243, 00232, 00226, 01366, 00247, 00232, 00366,
   01416, 00257, 01732, 00656, 01332, 00257, 01243, 01152,
   01152, 00016, 01622, 01522, 00267, 00472, 00537, 01466,
   00273, 01262, 00132, 01032, 00774, 01506, 00305, 00416,
   01020, 00420, 00662, 01410, 01156, 01502, 00300, 00706,
   01407, 00434, 00314, 01262, 01361, 00303, 01562, 00401,
   00551, 00032, 00226, 01525, 01463, 00172, 00372, 00572,
   00572, 00632, 00372, 00436, 00272, 00556, 01603, 01166,
   00556, 00616, 01474, 01542, 00346, 01732, 01772, 00216,
   00432, 00132, 01274, 00530, 01772, 01723, 00742, 01632,
   01673, 00532, 00732, 00620, 01746, 01354, 00357, 00402,
   00232, 00372, 01020, 00471, 00301, 00243, 00132, 01010,
   00537, 00664, 00007, 00432, 01172, 00422, 00244, 00424,
   01444, 01317, 01544, 01327, 00444, 01335, 00144, 01341,
   01474, 00730, 00274, 01020, 00674, 00630, 00630, 01030,
   00630, 00530, 00230, 00430, 01130, 00130, 00130, 00630,
   00774, 01020, 00432, 00774, 00430, 00530, 00203, 00032,
   00064, 00551, 00226, 00372, 01675, 00372, 01004, 00655,
   00372, 01211, 00372, 00605, 01254, 00461, 01274, 00730,
   00222, 00372, 00373, 00172, 01162, 00453, 01646, 00232,
   00736, 00232, 01122, 00357, 00132, 00642, 00064, 01445,
   00777, 01646, 01122, 00447, 00022, 00472, 00642, 00357,
   01646, 00642, 00373, 00232, 01675, 00372, 00432, 00232,
   00064, 00551, 00064, 00351, 00426, 00257, 00420, 00762,
   01410, 01032, 00573, 00472, 00732, 01776, 00372, 00620,
   01020, 00756, 01672, 01352, 00614, 01522, 00551, 01216,
   01352, 00602, 00426, 00032, 00556, 01023, 00406, 01562,
   00576, 01172, 00412, 01304, 00424, 00577, 00422, 00664,
   00003, 01672, 01156, 01007, 00416, 01362, 00612, 00132,
   01032, 01256, 00436, 01020, 00232, 00706, 00706, 00706,
   00232, 01117, 00756, 01032, 01113, 00472, 01166, 01147,
   01027, 00232, 00716, 00232, 00732, 01034, 00623, 01552,
   00566, 01117, 00432, 00244, 00741, 01172, 00430, 00772,
   00422, 01772, 01544, 00724, 00444, 00666, 00144, 00700,
   01644, 00710, 00644, 00715, 00720, 01020, 00274, 01505,
   00030, 01030, 00530, 00330, 00130, 00730, 00674, 01020,
   01674, 01505, 00330, 00030, 01030, 00430, 01574, 01020,
   01174, 01505, 01505, 00374, 01020, 01074, 01505, 00274,
   01020, 00330, 00330, 01020, 01574, 00330, 00130, 00030,
   00130, 00730, 01130, 01030, 00030, 00430, 00330, 00474,
   01020, 00474, 00630, 01130, 00330, 00130, 00430, 00730,
   00130, 01030, 00030, 00530, 00630, 00774, 01020, 00432,
   00774, 00230, 00330, 00030, 00230, 00530, 01030, 00530,
   00030, 01130, 00230, 01130, 01130, 00430, 00774, 01020,
   00774, 01372, 01127, 01562, 01147, 00064, 00551, 01356,
   01205, 00756, 00032, 01626, 01356, 01226, 01646, 00162,
   01274, 00620, 01122, 00107, 00122, 00436, 00153, 01672,
   00742, 00122, 00172, 00420, 00522, 00410, 00222, 00732,
   01672, 01162, 00203, 01410, 00410, 00472, 00732, 01122,
   00137, 00262, 01122, 00522, 00303, 00132, 00732, 00353,
   00544, 01055, 00762, 00620, 00132, 00122, 00732, 00147,
   01162, 00720, 00372, 00164, 01211, 01672, 00372, 00407,
   00472, 01142, 00403, 01562, 01070, 00244, 01232, 00432,
   01431, 00064, 01361, 00022, 00734, 01117, 01262, 01224,
   00376, 00624, 01277, 00064, 00301, 00664, 00003, 01234,
   00401, 01010, 01526, 01140, 01310, 00232, 00164, 00007,
   01522, 01134, 00232, 00064, 00551, 00432, 00527, 01234,
   00401, 01010, 00172, 01512, 01134, 00656, 01116, 00736,
   01526, 01201, 01516, 01174, 00222, 00262, 00562, 00562,
   00622, 01362, 01175, 00404, 00422, 00372, 01310, 00372,
   00037, 01516, 01156, 00132, 00563, 00272, 01102, 01526,
   01213, 00432, 00477, 00064, 01361, 00416, 00064, 00641,
   01556, 01223, 01162, 00222, 00416, 00073, 00704, 00064,
   01361, 01123, 01356, 01111, 01172, 00372, 00066, 00164,
   01675, 00232, 01072, 01312, 01246, 01072, 00232, 00372,
   01352, 01253, 01272, 00206, 00620, 00732, 00554, 01254,
   00774, 01502, 01274, 00726, 00232, 00222, 00064, 00421,
   00064, 00535, 00426, 00477, 00656, 00620, 01323, 00372,
   00164, 01675, 00372, 00064, 00701, 00517, 00720, 01156,
   00254, 01306, 01020, 00630, 01344, 00421, 01457, 00374,
   01455, 01474, 00530, 00174, 01030, 00474, 01020, 01374,
   01455, 01474, 01130, 00674, 01020, 00174, 01455, 01574,
   01020, 00574, 01455, 00374, 01020, 00756, 00756, 00064,
   00701, 00410, 00164, 00211, 00064, 01757, 00232, 00164,
   00211, 00756, 00756, 00064, 00641, 00410, 00364, 01671,
   01663, 01210, 00610, 00710, 01366, 01500, 01362, 01403,
   00704, 01204, 00422, 00064, 00641, 00064, 00045, 01314,
   01154, 01504, 01572, 01420, 01010, 00710, 01310, 00432,
   00032, 00072, 00266, 01362, 01435, 00404, 01534, 01435,
   01234, 01435, 01214, 00704, 00414, 00774, 01352, 01626,
   00531, 00634, 01637, 01651, 00432, 00172, 00372, 01672,
   00642, 01206, 00333, 00132, 00232, 00064, 01361, 00410,
   00232, 00064, 00475, 01156, 00064, 01525, 00372, 00132,
   00710, 00232, 00064, 00651, 01552, 01637, 00132, 01163,
   00752, 00222, 01532, 01405, 00132, 01010, 00372, 01310,
   00372, 00064, 00511, 00564, 00305, 00132, 00232, 00710,
   00064, 00271, 01010, 01310, 00510, 00117, 01524, 00132,
   01020, 00172, 01332, 01546, 01102, 01532, 01631, 00232,
   00634, 01545, 01615, 00432, 00633, 01671, 00232, 00531,
   00432, 00264, 01435, 00372, 01671, 00572, 01772, 00372,
   01234, 01574, 01655, 00372, 00232, 01072, 00232, 00372,
   00432, 00064, 01361, 00022, 00734, 01600, 01655, 00472,
   00422, 01424, 01614, 00756, 00756, 00064, 00701, 01624,
   01614, 00172, 01732, 01032, 00064, 01445, 01524, 01125,
   01010, 01310, 00022, 00232, 00664, 00003, 01356, 01531,
   00132, 00624, 00401, 00531, 00064, 01065, 01615, 00774,
   00410, 00510, 00436, 00756, 01356, 01654, 00762, 00620,
   00654, 01643, 00510, 00657, 00410, 00432, 00762, 01772,
   01367, 00232, 00410, 00742, 00262, 00410, 01732, 01732,
   01122, 01333, 00022, 00472, 00232, 00172, 01632, 01307,
   00410, 00762, 00410, 00132, 00732, 00620, 00654, 01675,
   00372, 00510, 00064, 00701, 00022, 01503, 00756, 01646,
   01556, 01716, 00410, 00416, 00274, 00372, 00164, 00015,
   00372, 01557, 00472, 01142, 01553, 01672, 00402, 01366,
   01551, 00720, 01527, 01224, 01747, 01204, 01020, 01214,
   01020, 01672, 00756, 01556, 01751, 01020, 00774, 00432,
   00730, 01030, 00530, 00330, 01130, 01030, 00130, 00630,
   00330, 00330, 01130, 00730, 00530, 00774, 01020, 01653,
   01504, 00604, 01204, 01010, 00033, 00272, 00610, 00232,
   00032, 00072, 00226, 01362, 00022, 00704, 01224, 00021,
   00404, 00422, 00372, 01424, 00131, 01634, 00033, 00232,
   00272, 01772, 01632, 00164, 00211, 00372, 01156, 01552,
   00045, 01156, 00227, 00756, 01672, 00372, 00410, 00510,
   00572, 00572, 00572, 01772, 00372, 01552, 00076, 00164,
   00655, 00432, 00372, 00510, 00572, 00732, 01434, 00072,
   01672, 01772, 00372, 01032, 00437, 00472, 00372, 00510,
   00372, 01434, 00142, 01556, 00141, 00732, 00613, 01234,
   00120, 01214, 00424, 00116, 00404, 00357, 00414, 00357,
   01204, 00634, 00112, 00734, 00127, 00714, 00357, 00704,
   00357, 00364, 01671, 00233, 00132, 01032, 00364, 01615,
   00637, 00756, 01552, 00151, 01032, 00563, 00472, 00064,
   01361, 00022, 01424, 00166, 00372, 00510, 00372, 00064,
   00701, 00410, 00364, 01671, 00064, 00471, 01156, 00410,
   00510, 00756, 01153, 00732, 01163, 00432, 00032, 00642,
   00064, 01445, 01127, 00774, 00510, 01224, 00433, 01534,
   00200, 00372, 00710, 00564, 00475, 01310, 00710, 00132,
   00064, 00271, 00434, 00225, 01262, 00664, 00003, 00620,
   00644, 00203, 00756, 01137, 00432, 00372, 00164, 00015,
   00372, 00164, 00605, 00654, 00236, 00372, 00410, 01672,
   01672, 00432, 00774, 00130, 00410, 01274, 00630, 01353,
   01646, 01646, 01122, 01303, 00022, 00410, 00232, 01072,
   00472, 00410, 00172, 00262, 01142, 01313, 00232, 00726,
   00232, 01366, 00310, 01162, 00022, 01672, 01353, 00756,
   01162, 01437, 00422, 00410, 00232, 01132, 00510, 01224,
   00323, 01216, 00132, 01332, 00416, 00064, 00701, 00634,
   00200, 00132, 00232, 01364, 01725, 00332, 00150, 00232,
   00064, 00511, 00564, 00305, 00372, 00132, 01534, 00402,
   00710, 00232, 00064, 00651, 00232, 00410, 00616, 01310,
   00510, 00232, 00564, 00465, 01010, 01310, 00710, 00222,
   00170, 00232, 00410, 00064, 00471, 00064, 00301, 00000,
   00521, 00257, 00510, 00232, 01056, 00232, 00170, 00232,
   00064, 00701, 00422, 00521, 00464, 01003, 00432, 00624,
   00427, 01172, 00412, 01304, 00422, 00664, 00003, 01534,
   00175, 00432, 00247, 00624, 00441, 00132, 00064, 01065,
   00063, 01534, 00175, 00372, 00132, 00710, 00064, 00271,
   00475, 01310, 00710, 00464, 01113, 00000, 00000, 00000,
   00000, 00072, 00356, 00774, 00332, 00556, 00417, 00332,
   00364, 01645, 00642, 00373, 00720, 00353, 00064, 00535,
   00072, 00064, 01527, 00332, 01156, 00443, 00332, 00353,
   00620, 01354, 00504, 00332, 00403, 00064, 00301, 00734,
   00522, 01262, 00064, 00033, 00372, 00416, 01160, 00372,
   01020, 01175, 00264, 01673, 01175, 00032, 00226, 00372,
   00364, 01671, 00372, 00264, 01627, 01175, 00372, 00671,
   00127, 00506, 01746, 01546, 00551, 01020, 01326, 00571,
   00774, 00316, 00756, 00756, 01552, 00634, 00620, 01354,
   00573, 00332, 01020, 01156, 00733, 00432, 00326, 01034,
   00616, 00720, 01154, 00606, 01715, 01047, 00720, 01715,
   00620, 00620, 01715, 00272, 00332, 01153, 00032, 01705,
   00720, 01144, 00624, 00720, 01705, 00732, 00532, 00372,
   00064, 00535, 00064, 01463, 01312, 00571, 00767, 00064,
   00553, 01264, 01463, 01460, 00432, 01160, 00314, 00324,
   00660, 01150, 01250, 01350, 01450, 01550, 01650, 01750,
   01070, 00252, 01464, 01677, 00314, 00334, 01341, 00072,
   00510, 00272, 00310, 00210, 01714, 01724, 00674, 00416,
   00574, 00630, 01156, 01413, 00310, 00664, 00153, 00424,
   01616, 00634, 00731, 00734, 00726, 01624, 01354, 00202,
   00206, 00706, 01746, 00202, 00764, 00157, 01024, 00715,
   01523, 01024, 00740, 01224, 01704, 00734, 01616, 01467,
   01224, 01326, 01524, 01352, 01204, 00764, 01613, 01542,
   00754, 01674, 01342, 01131, 00674, 01746, 01746, 00664,
   01577, 01746, 00606, 00246, 01746, 00546, 00546, 01046,
   01034, 00551, 00032, 00256, 00632, 00416, 01020, 00000,
   00113, 01633, 00310, 00110, 00010, 00410, 00332, 00610,
   00332, 01160, 01070, 00774, 00242, 00252, 00432, 00202,
   01664, 00003, 00064, 00031, 00410, 01334, 01031, 00214,
   00114, 00110, 01414, 00351, 00341, 00224, 01276, 00114,
   01314, 00314, 00334, 01273, 01064, 01751, 00310, 00210,
   01714, 01724, 01050, 00114, 00314, 00334, 01063, 01334,
   01065, 01314, 00153, 01334, 01272, 01724, 01400, 00257,
   00764, 00053, 00224, 01076, 00134, 01110, 01070, 01174,
   01410, 00742, 00437, 00174, 00742, 00542, 00447, 01050,
   01020, 01070, 00742, 01174, 00030, 00437, 00224, 01131,
   00124, 01032, 00204, 01414, 01711, 01556, 01164, 00371,
   00523, 00371, 00214, 01607, 01711, 01356, 01164, 01410,
   01074, 01146, 01070, 01174, 01142, 00643, 00174, 01142,
   01050, 01711, 00723, 00104, 01711, 01356, 01162, 00314,
   00324, 01164, 00371, 01711, 00132, 00256, 01074, 00732,
   00720, 00254, 01167, 00674, 00420, 01106, 01556, 01222,
   00372, 00072, 00310, 00210, 00314, 00334, 01050, 01714,
   01724, 01207, 00310, 00424, 01341, 00232, 01711, 00132,
   01141, 01443, 01141, 01064, 00201, 01013, 01164, 01247,
   01131, 00412, 00520, 00520, 01156, 01153, 00232, 01020,
   00356, 00371, 01711, 01356, 01273, 01131, 00132, 01074,
   00732, 00720, 01154, 01250, 00412, 01356, 01265, 01156,
   01672, 01672, 00620, 00620, 01267, 00102, 00620, 00102,
   00372, 01360, 00341, 01304, 01711, 00723, 01711, 01356,
   01314, 01424, 01305, 01724, 01132, 00132, 01141, 00210,
   00132, 00341, 01464, 00303, 01070, 01374, 01542, 01323,
   01674, 01342, 01132, 00252, 01464, 01677, 00724, 01433,
   00256, 00174, 00706, 00706, 00706, 01070, 00206, 00212,
   01050, 01414, 00163, 00410, 01104, 00153, 01474, 01164,
   01415, 00153, 00174, 01637, 00574, 01637, 01074, 00602,
   00764, 00157, 01070, 00174, 01746, 01746, 01746, 01020,
   01564, 00041, 01050, 01414, 00523, 00000, 00000, 00000,
   00310, 01070, 01074, 01524, 01407, 00051, 00406, 00420,
   01514, 00020, 00414, 00614, 00714, 01014, 01214, 01514,
   01614, 01020, 01230, 01330, 01074, 00434, 01433, 00742,
   00624, 01433, 00742, 00051, 00314, 00334, 01240, 00664,
   01447, 00051, 00227, 00051, 00604, 00404, 00406, 01504,
   01050, 00664, 00233, 00051, 00704, 01004, 00233, 00000,
   00207, 00217, 00523, 00457, 00434, 01153, 00634, 01134,
   01730, 00051, 00604, 00030, 00237, 00530, 00030, 00157,
   00113, 01323, 01533, 01225, 00756, 00756, 00756, 00756,
   00554, 01424, 01613, 00434, 01521, 00634, 01475, 01630,
   00347, 00051, 01204, 00233, 00434, 01453, 00634, 01532,
   01530, 00347, 01730, 01330, 00157, 00756, 01604, 00756,
   00756, 01467, 01477, 01225, 00433, 01530, 01730, 00123,
   01530, 01747, 00434, 01556, 00624, 00644, 01530, 01163,
   00627, 00643, 00653, 00424, 01576, 00634, 01573, 00724,
   01573, 01024, 00641, 01630, 01530, 00157, 00634, 00664,
   00051, 00233, 00424, 01613, 00634, 01613, 00734, 01613,
   01130, 01730, 00157, 01530, 01430, 00123, 01230, 00123,
   01013, 01543, 01637, 01713, 00434, 01633, 00624, 01633,
   01730, 01230, 00157, 01030, 01530, 00123, 01530, 01147,
   00756, 00567, 00577, 01225, 00437, 00424, 01655, 00634,
   01655, 00724, 01655, 01024, 01660, 01230, 01330, 01020,
   00051, 00704, 01746, 01020, 00424, 01701, 00624, 01701,
   00734, 01701, 01034, 01701, 01224, 01701, 00051, 01004,
   00233, 01230, 01230, 00123, 00724, 01712, 01524, 01352,
   00704, 01613, 01346, 01352, 01757, 00756, 01504, 00756,
   00756, 00756, 01527, 01225, 00427, 00756, 00564, 01437,
   00434, 01735, 01430, 01330, 00123, 00051, 00704, 00030,
   01230, 00604, 01074, 00206, 00706, 00206, 00237, 00434,
   01755, 00634, 01636, 01030, 01047, 00051, 00030, 01330,
   01004, 01607, 00434, 01770, 00624, 01770, 01630, 01147,
   01030, 01630, 00123, 00202, 00530, 00664, 01673, 00724,
   00123, 00107, 00117, 00047, 00067, 01574, 01045, 01151,
   00123, 01574, 01045, 01521, 00123, 01574, 01045, 01235,
   00123, 01031, 00123, 01601, 01174, 00333, 01211, 00330,
   00230, 00337, 01633, 00603, 01142, 01142, 01142, 00337,
   00226, 00420, 00674, 01130, 00412, 00256, 01074, 01230,
   01230, 01474, 01402, 00077, 01074, 01402, 00075, 00530,
   01074, 01402, 00127, 00274, 01521, 00174, 00511, 00266,
   00432, 00674, 00630, 00372, 01020, 01602, 00220, 01074,
   01402, 00152, 01030, 01074, 01402, 00366, 01230, 01574,
   01535, 00730, 00130, 01174, 00515, 00246, 01656, 00652,
   01374, 00220, 00706, 00706, 00706, 00206, 01020, 01602,
   01506, 00135, 01611, 01235, 00337, 00274, 01235, 00327,
   00615, 01535, 00337, 01574, 00406, 01146, 01174, 00202,
   01374, 01020, 01602, 00330, 01074, 01402, 00221, 01502,
   00200, 00174, 00730, 00130, 00730, 00706, 00252, 00174,
   00220, 00000, 01657, 01673, 01142, 01142, 01142, 00337,
   01041, 01074, 01102, 01502, 00370, 00707, 01374, 01047,
   00274, 00130, 00430, 00620, 01020, 01413, 01433, 01041,
   00607, 00730, 01074, 00502, 00716, 01611, 00174, 00220,
   01041, 01323, 00130, 00130, 01057, 01407, 01427, 00274,
   01551, 01343, 01574, 00406, 01146, 00174, 01020, 00130,
   00230, 01057, 00607, 01647, 01337, 00133, 01317, 01211,
   00330, 00430, 00337, 01211, 00330, 00330, 00337, 01211,
   01565, 00337, 01433, 01637, 01513, 01707, 01143, 01041,
   01303, 01041, 00230, 00130, 00337, 01041, 00230, 00230,
   00337, 00000, 01413, 01503, 01343, 00137, 01323, 01303,
   01521, 00337, 01041, 01343, 00130, 00330, 01057, 00230,
   00330, 01057, 00230, 00430, 01057, 00230, 00530, 01057,
   01374, 01617, 00274, 00130, 00530, 01057, 00615, 01551,
   00337, 01041, 01637, 00730, 00330, 00337, 00730, 00430,
   00337, 01211, 00330, 00130, 00337, 01460, 00716, 00737,
   01611, 00707, 00510, 00372, 01424, 00544, 01410, 01070,
   00014, 01614, 01352, 00411, 01152, 00004, 01352, 00411,
   01604, 00332, 00272, 00024, 00444, 01552, 00432, 01074,
   00130, 00030, 01416, 00443, 00016, 01610, 00456, 01416,
   00440, 00233, 00016, 01610, 00656, 00516, 00217, 00233,
   01156, 00256, 00233, 00004, 00016, 01610, 00332, 00422,
   00774, 00620, 01116, 00247, 00024, 00461, 01352, 00461,
   00720, 00032, 00246, 00536, 00006, 00236, 01362, 00502,
   00034, 00523, 00756, 01352, 00501, 01152, 01352, 00526,
   00752, 01776, 00276, 00420, 01106, 00256, 01410, 00034,
   00532, 01624, 00615, 01352, 00520, 01410, 01216, 01152,
   00216, 01741, 00623, 00756, 00620, 00407, 00332, 00272,
   00022, 00457, 00022, 01512, 00606, 00603, 00662, 01116,
   01516, 00536, 00420, 01116, 00432, 00222, 00262, 00420,
   00652, 01017, 01112, 01322, 00557, 00774, 00430, 01274,
   00620, 01122, 00703, 00742, 00244, 00600, 00720, 00244,
   00600, 00720, 00244, 00600, 00720, 00742, 00742, 00717,
   00262, 00372, 01020, 01674, 00630, 00653, 01376, 00443,
   01672, 00756, 01556, 00610, 00613, 00356, 00652, 01116,
   01074, 00416, 00330, 01616, 01117, 00516, 01756, 01616,
   01137, 00516, 00316, 00774, 01173, 01102, 01116, 01207,
   00457, 00662, 01410, 01156, 00620, 00420, 00642, 01167,
   01173, 00256, 00574, 01030, 00030, 00730, 01074, 00420,
   00752, 01323, 00006, 01353, 01410, 01606, 01277, 00506,
   01506, 00674, 00420, 01152, 01756, 01756, 01160, 00070,
   00232, 01410, 01020, 00432, 01160, 00420, 01172, 00012,
   01344, 00715, 00652, 00620, 01443, 00732, 00732, 00174,
   00202, 00474, 01630, 01230, 01230, 01430, 01230, 00232,
   00072, 00114, 00214, 00310, 00210, 01714, 01724, 00735,
   01314, 00314, 00324, 00745, 01304, 00314, 00334, 00753,
   01334, 00755, 01677, 01334, 00757, 01734, 00745, 01314,
   00310, 01020, 01174, 00664, 01637, 01555, 00664, 00013,
   01674, 00706, 00706, 00706, 01020, 00000, 00000, 00000,
   01434, 01007, 00571, 00424, 01074, 00226, 00047, 00521,
   01166, 00716, 00716, 01174, 00706, 00742, 00133, 00726,
   00720, 00254, 01015, 00742, 00133, 00207, 01142, 00754,
   01034, 00704, 00416, 00213, 00724, 01037, 00662, 00620,
   01666, 00606, 00266, 00256, 00620, 01106, 01366, 01051,
   00665, 00410, 00305, 00434, 01057, 01164, 01741, 00664,
   00157, 01070, 00474, 00402, 00734, 01072, 00742, 00434,
   01072, 00742, 01050, 01020, 00216, 01674, 01646, 01646,
   01474, 00202, 00716, 00174, 01646, 00216, 00256, 01410,
   01352, 01114, 00412, 01216, 00665, 00064, 00031, 01154,
   01051, 00214, 00664, 00003, 01124, 01130, 00510, 01310,
   01114, 01404, 00432, 00276, 00420, 01020, 00510, 00372,
   01070, 00474, 01342, 01151, 01142, 00704, 01342, 01151,
   00404, 00332, 00420, 00416, 01020, 01410, 00172, 00016,
   00520, 00136, 00226, 00616, 00774, 01542, 01175, 01156,
   00620, 00424, 01165, 00726, 00727, 00226, 00116, 01020,
   01424, 01213, 00521, 00774, 00130, 00272, 01106, 00016,
   00404, 00704, 00247, 00571, 00424, 01234, 01366, 01245,
   00226, 00266, 01674, 00406, 01366, 01234, 01274, 00730,
   01422, 01234, 00332, 01037, 01175, 00410, 00277, 00332,
   00016, 00424, 01244, 01116, 01020, 00541, 01017, 01424,
   01253, 00704, 00037, 00571, 00704, 01175, 00305, 00277,
   01434, 01305, 00571, 01410, 00424, 01275, 01366, 01051,
   01262, 00420, 01201, 00316, 01167, 01674, 01646, 01646,
   01646, 00212, 01252, 00252, 00427, 00510, 01366, 01057,
   01410, 01262, 00000, 00513, 00010, 00772, 00410, 00432,
   00410, 00610, 00610, 01110, 01110, 01110, 01110, 00372,
   00132, 01710, 01710, 01132, 01564, 01277, 00270, 01514,
   00272, 01364, 01711, 00064, 00575, 01364, 01745, 00270,
   00064, 00575, 01562, 00762, 00064, 01505, 01524, 01122,
   01504, 00064, 00031, 01735, 01364, 01661, 01603, 00272,
   01124, 01374, 00510, 01310, 00232, 01310, 01020, 00000,
   00270, 01366, 00762, 00232, 00570, 00232, 00270, 00155,
   01524, 01122, 01504, 00165, 01611, 00370, 00027, 00064,
   01123, 00064, 01137, 00064, 01143, 00064, 00263, 00064,
   00017, 00064, 01507, 00064, 00577, 00064, 00033, 00064,
   00031, 00272, 01725, 00232, 01360, 01020, 01504, 00610,
   00370, 00232, 00710, 00064, 01125, 00135, 00710, 00272,
   00125, 00470, 00075, 00135, 00570, 01210, 00075, 00135,
   01210, 00232, 00272, 00125, 00670, 00075, 00135, 01210,
   00710, 00125, 00770, 00075, 00135, 01621, 00075, 00135,
   00664, 01617, 00404, 00503, 00704, 00477, 00404, 00604,
   01621, 01504, 00075, 01562, 00762, 01366, 00762, 00470,
   00232, 00270, 00125, 00175, 01024, 01562, 01745, 00370,
   00272, 00125, 01711, 00075, 00165, 01024, 01574, 01566,
   01555, 00434, 00762, 00624, 00762, 00150, 01004, 01745,
   00670, 00543, 01224, 01567, 01745, 00570, 00603, 01745,
   00370, 00272, 00570, 00607, 01224, 01603, 00250, 01204,
   01745, 00770, 00543, 00350, 01745, 01621, 00075, 00175,
   00424, 01703, 00634, 01626, 00724, 01650, 00370, 00232,
   00170, 00155, 00165, 01611, 00032, 01257, 00170, 00272,
   00270, 01366, 00762, 00125, 00165, 00145, 00165, 00372,
   00510, 01464, 01521, 00132, 00370, 00232, 00155, 01377,
   01601, 00510, 00272, 01745, 00270, 00125, 00370, 00105,
   01645, 00125, 00175, 01745, 00570, 00272, 01661, 00125,
   01711, 00115, 00170, 00155, 01745, 00270, 00155, 01745,
   00232, 00664, 00003, 00634, 01336, 00370, 01372, 00762,
   01565, 01745, 00270, 00272, 00710, 00125, 00570, 00105,
   01661, 00125, 00175, 01745, 00510, 00272, 00370, 00125,
   01711, 00115, 00510, 00155, 01363, 00410, 00610, 01020,
   00510, 01573, 01264, 01737, 00032, 00774, 00642, 00270,
   01020, 01725, 00370, 01020, 01725, 00170, 01020, 01725,
   00270, 01020, 01725, 00070, 01020, 00416, 01074, 00130,
   01753, 00416, 01160, 01020, 00000, 00000, 00000, 00074,
   00443, 00473, 00473, 00000, 00000, 01474, 01402, 00421,
   00022, 01563, 00513, 00523, 00533, 00563, 00573, 00607,
   00637, 00743, 00737, 00727, 01057, 00707, 00673, 01037,
   01033, 01043, 01543, 01423, 01313, 01327, 01247, 01223,
   00623, 00757, 00767, 00653, 01073, 00717, 00677, 01007,
   01003, 01013, 01457, 00663, 01357, 01363, 01257, 01233,
   00412, 00256, 00420, 01074, 01230, 01230, 01074, 01402,
   00106, 01474, 01402, 00425, 01074, 00530, 01074, 01402,
   00352, 01506, 00104, 00214, 00664, 01547, 01602, 00220,
   01474, 01402, 00116, 00510, 01264, 00003, 00716, 01410,
   00510, 00220, 01264, 01237, 00664, 00473, 01105, 01262,
   00064, 01111, 00664, 00003, 01105, 00543, 00064, 00251,
   00553, 00064, 00611, 00553, 00064, 00565, 00553, 00064,
   01471, 00553, 00064, 00167, 00064, 00223, 01004, 00564,
   00627, 00564, 00547, 00564, 00563, 01115, 01204, 00604,
   01004, 00264, 00003, 00164, 00237, 01004, 00164, 00517,
   01204, 00604, 01504, 01135, 00364, 00103, 01204, 00604,
   01135, 00464, 00027, 01135, 00464, 00003, 01135, 00264,
   01747, 00064, 00553, 01010, 01310, 00232, 01020, 00372,
   01070, 01414, 01362, 00242, 01162, 01362, 00241, 01604,
   01213, 01404, 00372, 01020, 01210, 01072, 01372, 00260,
   01267, 01210, 01072, 01572, 00260, 00664, 00371, 01314,
   00664, 00153, 01210, 01504, 01337, 01210, 00232, 01262,
   00064, 01141, 01363, 01262, 01566, 00301, 01524, 00260,
   01267, 01362, 00260, 01267, 01414, 01064, 01751, 00310,
   00210, 00564, 01377, 01521, 00364, 01671, 00572, 00572,
   01772, 00766, 00416, 00553, 01124, 00327, 01310, 01020,
   01521, 00710, 00553, 00662, 01102, 01557, 01074, 00502,
   01613, 00652, 00642, 01607, 01070, 00212, 01676, 00774,
   01564, 01123, 01602, 01070, 00252, 01506, 00373, 00674,
   00124, 00367, 00224, 00370, 00406, 00664, 01577, 00214,
   01374, 00564, 01637, 00674, 00124, 00403, 00224, 00403,
   00406, 00664, 01743, 00664, 00371, 00041, 00664, 01603,
   00204, 00226, 00212, 00716, 00674, 00706, 00706, 00226,
   01020, 00716, 00510, 01410, 00220, 01074, 01030, 01074,
   01402, 00421, 01630, 01074, 00202, 01756, 01160, 00070,
   00372, 00107, 00022, 00243, 00022, 00247, 00022, 00662,
   00662, 01070, 00222, 01050, 01267, 00631, 00016, 00064,
   01361, 01156, 00226, 01723, 00132, 00064, 00575, 00773,
   01364, 00453, 00233, 01047, 00427, 00407, 00417, 00432,
   00443, 01264, 01303, 01264, 01003, 01364, 00237, 01310,
   00664, 01617, 00213, 01057, 00517, 00437, 01223, 00010,
   00410, 00510, 01723, 01364, 00233, 01464, 01115, 01723,
   01110, 01723, 00223, 01267, 00343, 00613, 00267, 01731,
   00422, 01723, 00631, 00406, 00216, 01723, 01731, 00272,
   00774, 01352, 00555, 00756, 01020, 00756, 01356, 00565,
   01156, 00726, 00620, 01526, 00556, 01020, 01364, 00473,
   01364, 00463, 01262, 00132, 00064, 01141, 00064, 00031,
   01324, 00621, 01360, 00510, 01723, 00132, 00064, 00261,
   00773, 01364, 00477, 01364, 00003, 00527, 00543, 01364,
   00503, 01074, 00664, 01637, 00202, 00242, 01050, 00732,
   00520, 01710, 01267, 00000, 00000, 00733, 00743, 00570,
   01264, 01735, 00370, 01723, 00432, 00050, 00150, 00250,
   00350, 00450, 00550, 00650, 00750, 00664, 00153, 01532,
   01173, 00432, 00774, 00742, 00410, 00420, 00010, 01074,
   00130, 00430, 01310, 01310, 00530, 01154, 00674, 01310,
   00572, 01110, 01110, 01160, 00372, 00070, 00532, 00232,
   00472, 00232, 01110, 01110, 01110, 01360, 00432, 00070,
   01110, 01360, 00332, 01156, 01417, 01110, 00372, 00232,
   01110, 00272, 01110, 01664, 00353, 00432, 00774, 00230,
   00354, 00737, 00372, 00332, 00566, 00566, 00232, 01164,
   01727, 00000, 01703, 01013, 00753, 00757, 01027, 00323,
   01124, 00763, 01310, 00372, 00664, 00003, 00610, 00710,
   01020, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00212, 00242, 01050, 00520, 00520, 01710, 00432, 00420,
   01172, 00774, 01530, 01230, 01574, 01630, 01230, 01230,
   01430, 01230, 00232, 00432, 01074, 00130, 01160, 00470,
   00232, 01632, 01532, 01040, 00432, 01160, 00664, 00003,
   00032, 00410, 01074, 00130, 01730, 01160, 00372, 01360,
   00372, 01156, 00227, 00432, 00774, 00430, 01050, 01074,
   00130, 01160, 00432, 00410, 00450, 00232, 01164, 01555,
   00664, 00013, 00572, 01632, 01532, 01172, 01110, 00332,
   01160, 00372, 00070, 00532, 00232, 01032, 00232, 01110,
   01110, 01110, 01360, 00432, 00070, 01110, 01360, 00332,
   01156, 00403, 01110, 01632, 00432, 01074, 01530, 00230,
   01632, 01532, 01172, 01110, 01010, 01632, 01532, 01172,
   00510, 00774, 00742, 00410, 00432, 01172, 01160, 00514,
   00064, 00011, 00524, 01172, 00410, 00742, 00410, 00564,
   01215, 00524, 01172, 01064, 01725, 00524, 01172, 01001,
   00534, 00735, 00767, 00432, 00410, 01574, 00664, 01637,
   01460, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00572
};
