/*
 * x11-calc-34c.c - RPN (Reverse Polish) calculator simulator.
 *
 * Copyright(C) 2018   MT
 *
 * Model specific functions.
 *
 * This  program is free software: you can redistribute it and/or modify it
 * under  the terms of the GNU General Public License as published  by  the
 * Free  Software Foundation, either version 3 of the License, or (at  your
 * option) any later version.
 *
 * This  program  is distributed in the hope that it will  be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without even   the   implied   warranty   of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You  should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 23 Nov 21         - Initial version - MT
 * 25 Nov 21         - Reduced the font sizes - MT
 * 26 Nov 21         - Fixed ENTER key label colours - MT
 * 06 Dec 21         - Label text colour now explicitly defined - MT
 * 03 Jan 21         - Changed debug() macro so that debug code is executed
 *                     when DEBUG is defined (doesn't need to be true) - MT
 * 11 Jan 22         - Removed ROM_BANKS - MT
 * 12 Feb 22         - Updated layout and separated the initialisation code
 *                     for buttons and switches into two functions - MT
 * 21 Oct 23         - Updated switch parameters to accomodate a 3 position
 *                     switch - MT
 *
 */

#define NAME           "x11-calc-34c"
#define BUILD          "0008"
#define DATE           "21 Oct 23"
#define AUTHOR         "MT"

#include <stdarg.h>    /* strlen(), etc. */
#include <stdio.h>     /* fprintf(), etc. */
#include <stdlib.h>    /* getenv(), etc. */

#include <X11/Xlib.h>  /* XOpenDisplay(), etc. */
#include <X11/Xutil.h> /* XSizeHints etc. */

#include "x11-calc-font.h"
#include "x11-calc-button.h"
#include "x11-calc-switch.h"
#include "x11-calc-label.h"
#include "x11-calc-colour.h"

#include "x11-calc-cpu.h"

#include "x11-calc.h"

#include "gcc-debug.h"

oregister o_mem[MEMORY_SIZE];

void v_init_switches(oswitch *h_switch[]) /* Define the switches. */
{
   /* Define the switches. */
   h_switch[0] = h_switch_create(00000, "OFF", "", "ON ", h_alternate_font, KBD_LEFT, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
   h_switch[1] = h_switch_create(00000, "PRGM", "", "RUN", h_alternate_font, KBD_LEFT + 3 * KEY_WIDTH + 2 * KEY_GAP, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
}

void v_init_buttons(obutton *h_button[]) {
   int i_left, i_top;

   /* Define top row of keys. */
   i_top = KBD_TOP + 2* (SWITCH_HEIGHT + 1); /* Assumes the function label and switch text use the same font */
   i_left = KBD_LEFT;
   h_button[0] = h_button_create(00064, 000, "A", "FIX", "DEG", "DSP I", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[1] = h_button_create(00063, 000, "B", "SCI", "RAD", "RTN", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[2] = h_button_create(00062, 000, "GSB", "ENG", "GRD", "LBL", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[3] = h_button_create(00061, 'f', "f", "", "", "", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, YELLOW, BACKGROUND, YELLOW, YELLOW);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[4] = h_button_create(00060, 'g', "g", "", "", "", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_BLUE, BACKGROUND, LIGHT_BLUE, LIGHT_BLUE);

   /* Define second row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[5] = h_button_create(00224, 000, "X-Y", " x-I", " ", "x-(i)", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[6] = h_button_create(00223, 000, "GTO", "R^", "Rv", "DEL", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[7] = h_button_create(00222, 000, "STO", "I", "DSE", "BST", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[8] = h_button_create(00221, 000, "RCL", "(i)", "ISG", "SST", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[9] = h_button_create(00220, 'h', "h", "", "", "", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, BACKGROUND, BLACK, BLACK);

   /* Define third row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[10] = h_button_create(00163, 015, "ENTER", "MEM ", "PREFIX", "MANT", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, 2* KEY_WIDTH + KEY_GAP, KEY_HEIGHT, False, False, DARK_GREY, MID_BLUE, YELLOW, BLACK);
   i_left += 2 * (KEY_WIDTH + KEY_GAP);
   h_button[11] = h_button_create(00162, 'c', "CHS", " PRGM", " ", "INT", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[12] = h_button_create(00161, 'e', "EEX", " REG", " ", "FRAC", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[13] = h_button_create(00160, 033, "CLX", "E", " ", "ABS", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, DARK_GREY, YELLOW, MID_BLUE, BLACK);

   /* Define fourth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[14] = h_button_create(00243, '-', "-", "X\x1a\x59", "X<0", "%", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[15] = h_button_create(00242, '7', "7", "SIN", "-\xb9", "d%", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[16] = h_button_create(00241, '8', "8", "COS", "-\xb9", "x", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[17] = h_button_create(00240, '9', "9", "TAN", "-\xb9", "s", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define fifth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[18] = h_button_create(00143, '+', "+", "X>Y", "X>0", "SF", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[19] = h_button_create(00142, '4', "4", "-R", "-P", "y", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[20] = h_button_create(00141, '5', "5", "-D", "-R", "r", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[21] = h_button_create(00140, '6', "6", "-H.MS", "-H", "L.R", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define sixth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[22] = h_button_create(00323, '*', "\xd7", "X\x1d\x59", "X\x1d\x30", "CF", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[23] = h_button_create(00322, '1', "1", "LN", "eX", "x!", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[24] = h_button_create(00321, '2', "2", "LOG", "10x", "1/x", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[25] = h_button_create(00320, '3', "3", "V\xaf", "x\xb2", "yX", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define bottom row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[26] = h_button_create(00103, '/', "\xf7", "X=Y", "X=0", "F?", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[27] = h_button_create(00102, '0', "0", " INTER", " ", "LST x", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[28] = h_button_create(00101, '.', ".", " SOLVE", " ", "\x1c", h_large_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[29] = h_button_create(00100, 000, "R/S", "E+", "E-", "PSE", h_normal_font, h_alternate_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
}

int i_rom[] = {
   00440, 00063, 00073, 00107, 00747, 00757, 00773, 01113,
   01123, 01137, 01713, 01367, 00072, 00126, 00410, 00510,
   00416, 00062, 00422, 00410, 01074, 00620, 00652, 00752,
   00254, 00025, 00372, 01372, 00075, 00410, 00132, 01372,
   00075, 01456, 00150, 01022, 01522, 00047, 00317, 01232,
   00262, 01456, 00063, 00410, 00232, 00732, 00232, 00410,
   00132, 01116, 00132, 01456, 00075, 00656, 01772, 00222,
   00262, 00620, 01154, 00063, 00432, 00232, 00510, 00372,
   00472, 01152, 01152, 01152, 00232, 00410, 00510, 01362,
   00113, 00656, 01772, 00232, 00774, 01506, 00143, 00372,
   00232, 00774, 00272, 00556, 00607, 00766, 00607, 00316,
   00756, 00742, 00322, 00132, 01566, 00140, 00432, 00022,
   01020, 00316, 00553, 01502, 00117, 01156, 00706, 00617,
   00410, 00132, 01456, 00155, 00207, 00232, 00410, 01432,
   00164, 00410, 00232, 00217, 00410, 00232, 00410, 00132,
   00217, 00072, 00126, 00410, 00510, 00416, 00062, 00422,
   00410, 00616, 01062, 01027, 01222, 00032, 00410, 01274,
   00720, 01672, 01063, 00472, 01142, 01057, 00254, 00210,
   00510, 00423, 00072, 00126, 00410, 00510, 00416, 00062,
   00422, 01366, 00267, 00410, 01056, 01062, 01203, 01222,
   00410, 00232, 00132, 01472, 00251, 00410, 00732, 01156,
   00410, 00774, 00432, 01267, 00742, 01032, 01263, 00472,
   00732, 00620, 01154, 00255, 00232, 00510, 00477, 01474,
   00464, 00023, 00072, 00366, 00232, 01522, 00267, 00062,
   01332, 00347, 00332, 00132, 00572, 00572, 00632, 00372,
   00436, 00272, 00572, 01226, 00556, 00616, 01474, 01542,
   00322, 01732, 01772, 00216, 00432, 00132, 01274, 00530,
   01772, 01613, 00742, 01632, 01553, 00532, 00732, 01344,
   00345, 00620, 01746, 00402, 01557, 00232, 00503, 00032,
   00432, 00503, 00072, 00366, 00232, 00432, 00410, 00432,
   00774, 00130, 00372, 00232, 00410, 00232, 01137, 00432,
   01262, 00774, 00130, 00073, 00432, 01747, 00630, 01130,
   00330, 00130, 00430, 00730, 00130, 01030, 00030, 00530,
   00530, 01146, 00774, 01020, 00343, 00567, 00467, 00553,
   00670, 00222, 00774, 00346, 00650, 01170, 01674, 00706,
   00706, 00706, 00206, 00216, 01150, 00447, 00372, 00410,
   01170, 00266, 00166, 01726, 01726, 01726, 00374, 00346,
   00356, 01150, 00670, 00372, 00770, 00650, 01070, 00750,
   00226, 01772, 01772, 01772, 00362, 00410, 00372, 01020,
   00770, 01050, 00670, 00750, 00332, 00222, 00262, 00650,
   01170, 00226, 00474, 00706, 00706, 00706, 00226, 01150,
   00206, 01646, 01646, 01646, 01020, 00770, 00374, 00372,
   00410, 01170, 00620, 01772, 00354, 00522, 00362, 00232,
   00410, 01020, 01070, 00474, 00477, 00670, 01674, 00477,
   00072, 00366, 00232, 00614, 01247, 00614, 01014, 00062,
   00232, 00272, 00556, 01073, 01522, 00621, 00232, 00725,
   00774, 00232, 00436, 00272, 01053, 00132, 00172, 00410,
   00510, 01672, 01532, 00577, 00510, 00232, 01020, 00756,
   00747, 00774, 00642, 00132, 00064, 01217, 00644, 01752,
   00620, 00762, 00756, 01033, 00132, 01373, 00064, 01761,
   01247, 01004, 00703, 00774, 00332, 01142, 00232, 01532,
   00633, 00264, 00033, 01502, 00640, 01156, 00732, 01157,
   00410, 01021, 00703, 00072, 00366, 00232, 00604, 01326,
   01756, 01014, 00062, 01522, 00267, 01326, 00267, 00216,
   00256, 01356, 00623, 00516, 01337, 01256, 01004, 00036,
   00236, 00032, 00774, 01006, 01142, 00742, 00172, 00410,
   00510, 01417, 01672, 01162, 01413, 00510, 00472, 01122,
   01367, 00762, 00132, 00732, 00620, 01254, 00676, 00232,
   00172, 00706, 00706, 00706, 00232, 01474, 00730, 01216,
   01316, 01024, 01374, 01672, 00372, 00264, 00661, 00372,
   00264, 00155, 01366, 00777, 01154, 00733, 00072, 01474,
   00142, 00472, 01672, 00372, 00364, 01245, 01024, 00765,
   00132, 01032, 00132, 00472, 00132, 01174, 00264, 00155,
   01366, 00777, 01672, 01733, 01672, 00264, 00013, 01522,
   00774, 01156, 00436, 01034, 01006, 01262, 00064, 00461,
   00634, 01040, 00164, 00171, 00064, 00771, 00510, 01362,
   01044, 01116, 00372, 00077, 01672, 01321, 00132, 01374,
   00164, 01567, 00472, 01142, 00153, 00402, 00756, 00720,
   01020, 00072, 00366, 00232, 01004, 01522, 01050, 01014,
   00036, 00132, 00332, 00556, 00347, 00332, 01522, 01075,
   01274, 00620, 01244, 01213, 00756, 00307, 00661, 00372,
   01007, 00364, 01245, 01374, 00413, 00132, 00656, 01732,
   00243, 00766, 01032, 00407, 00472, 00732, 01156, 00507,
   01674, 01342, 01117, 01142, 01542, 01126, 00742, 00774,
   01047, 00232, 00726, 00232, 01342, 01102, 00432, 00774,
   01146, 00272, 00574, 00130, 01034, 01137, 01256, 00132,
   00272, 00434, 01151, 00164, 00341, 00064, 01735, 00164,
   00101, 00132, 00064, 00503, 00432, 00244, 00376, 01166,
   00430, 00766, 01544, 01671, 00444, 01706, 00144, 01722,
   01644, 01734, 00644, 01744, 01474, 00330, 01374, 01020,
   00742, 01032, 01003, 00472, 00644, 01214, 00732, 01156,
   00620, 00372, 00333, 00372, 00434, 01221, 01321, 00232,
   00132, 01274, 00630, 01674, 01366, 01312, 00720, 01342,
   01236, 01142, 00172, 00410, 00510, 01273, 00756, 01672,
   01162, 01123, 01772, 01772, 01772, 00642, 00132, 00272,
   01034, 01141, 00064, 01665, 00607, 01732, 01162, 01267,
   00472, 00662, 00510, 01137, 00410, 00510, 00172, 00372,
   00572, 00572, 00632, 00132, 01772, 01572, 01302, 00510,
   00232, 01020, 00656, 01363, 01232, 00422, 00410, 00756,
   00064, 01203, 00132, 00436, 00272, 01034, 01322, 01262,
   00164, 00725, 00434, 01326, 00164, 00341, 00064, 01761,
   00647, 00072, 00366, 00232, 00164, 00341, 01210, 00710,
   01522, 01771, 01717, 01356, 00267, 01156, 00736, 01526,
   01343, 01556, 01363, 00222, 00262, 00562, 00562, 00622,
   01362, 01363, 00704, 01210, 00022, 00232, 00414, 00164,
   01215, 01010, 00734, 01375, 01262, 00464, 00013, 01460,
   00040, 00040, 00040, 00040, 00040, 00040, 00040, 00774,
   01562, 00267, 01552, 00267, 00272, 00172, 00736, 01506,
   01426, 00656, 01416, 01432, 00752, 01020, 01116, 00067,
   00064, 01337, 00432, 00742, 01772, 00762, 00372, 01302,
   01443, 01706, 00756, 00032, 01602, 00247, 00732, 00472,
   00237, 01622, 00303, 01646, 00672, 00756, 00472, 00273,
   00106, 01142, 00177, 01162, 00177, 00732, 00156, 00436,
   00446, 00532, 00236, 01020, 01514, 00377, 01504, 01211,
   00432, 00774, 00130, 00731, 00050, 00170, 00272, 00710,
   00731, 00150, 00710, 00272, 00015, 00270, 01105, 00250,
   01210, 00370, 00232, 00731, 00350, 01210, 00232, 00272,
   00015, 00470, 01105, 00450, 00710, 01210, 00015, 00570,
   01105, 00550, 01201, 00464, 00027, 01211, 00370, 00232,
   01566, 01555, 01174, 00464, 00023, 00031, 00751, 01141,
   01211, 00170, 00232, 00031, 00464, 00003, 01534, 01571,
   01262, 00001, 01566, 01575, 00432, 01410, 00774, 01352,
   01606, 01156, 00752, 01152, 01037, 00756, 01020, 00552,
   01057, 00432, 01077, 00406, 01146, 00412, 00620, 00620,
   01020, 01534, 01626, 00232, 01262, 00232, 00005, 00753,
   00272, 01124, 01635, 00710, 01310, 00232, 01310, 01020,
   00710, 01250, 01225, 00272, 01020, 00432, 01160, 00070,
   01020, 00774, 00230, 00330, 00030, 00230, 00530, 01030,
   00530, 00030, 01130, 00230, 01130, 01130, 00430, 00372,
   01020, 00330, 00130, 00030, 00130, 00730, 01130, 01030,
   00030, 00430, 00330, 00230, 00474, 01020, 00374, 00330,
   00330, 00030, 01030, 00530, 00330, 00130, 00630, 01030,
   00674, 01020, 01374, 00330, 00330, 00330, 00030, 01030,
   00330, 00530, 01574, 01020, 00174, 00330, 00330, 00330,
   00330, 00130, 00374, 01020, 00574, 00330, 00330, 00330,
   00274, 01020, 00132, 00372, 00264, 00127, 00164, 00171,
   01366, 00267, 00510, 01562, 00267, 00032, 00072, 00264,
   00607, 00226, 01552, 00267, 00264, 01633, 00000, 00533,
   00067, 01060, 00043, 01474, 01060, 01104, 00610, 00127,
   00272, 00151, 00610, 01360, 00232, 00364, 00751, 00610,
   01554, 00024, 00114, 00214, 01114, 01314, 00132, 01060,
   00000, 01060, 01764, 00013, 00116, 00151, 00124, 00042,
   00234, 00057, 01670, 00774, 00564, 01725, 01770, 01374,
   00006, 01141, 01356, 00057, 01352, 00177, 00247, 00116,
   01474, 00430, 01474, 01402, 00066, 00347, 00630, 01474,
   00502, 01204, 01564, 01751, 00156, 00151, 00124, 00107,
   00224, 00107, 00432, 00032, 01650, 01750, 00503, 01564,
   01627, 00272, 01670, 01074, 01135, 00232, 00316, 01750,
   01410, 01314, 01524, 00242, 00014, 01670, 01374, 00246,
   01174, 00232, 00316, 00330, 01650, 00432, 00350, 00450,
   00710, 00150, 01210, 01072, 01572, 00225, 01532, 00220,
   00432, 00774, 00742, 01474, 00730, 01216, 00250, 00550,
   00610, 00016, 01515, 00316, 01750, 01314, 00124, 00173,
   00224, 00175, 00204, 00434, 00031, 01564, 01767, 00232,
   00410, 00416, 01474, 00330, 01474, 01524, 00213, 01402,
   00215, 01674, 00023, 01402, 00211, 00510, 00232, 00247,
   01374, 00642, 01127, 01102, 01102, 00232, 00673, 00642,
   01772, 00222, 00520, 01772, 00222, 00520, 01772, 00222,
   00520, 01020, 00116, 01374, 00706, 00706, 00706, 00706,
   01670, 01174, 00246, 00232, 01650, 01745, 01210, 00432,
   00610, 01050, 01310, 00232, 00750, 01262, 00064, 00061,
   00432, 01450, 01350, 01326, 01565, 00530, 01156, 00064,
   00755, 00770, 00064, 00071, 00610, 00016, 00656, 00656,
   01470, 00372, 00151, 00372, 00050, 01515, 01732, 01732,
   01732, 01732, 00717, 00656, 01770, 00236, 00710, 00364,
   00751, 01310, 01310, 01310, 00610, 01670, 00372, 00332,
   01141, 01374, 00306, 01650, 00232, 01020, 01574, 00023,
   01474, 01160, 01360, 00742, 01647, 00510, 01160, 00232,
   00070, 01072, 01572, 00346, 00232, 00742, 01673, 01260,
   01773, 00432, 01074, 00330, 01160, 00774, 00432, 01020,
   00040, 00040, 00040, 00040, 00040, 00040, 00040, 00040,
   00040, 01764, 00013, 00140, 00140, 00140, 01256, 00132,
   00516, 00464, 01747, 00105, 00710, 01566, 00432, 00416,
   00756, 01152, 00436, 00530, 00372, 00432, 01074, 00742,
   01160, 01770, 01772, 00032, 01106, 00002, 01552, 00453,
   01312, 00463, 00056, 01610, 00232, 00756, 01156, 01342,
   00416, 00402, 00077, 01456, 00452, 00263, 00105, 00050,
   00710, 01550, 00125, 00232, 00610, 00774, 00432, 00230,
   01250, 00572, 01750, 00045, 00710, 01350, 01170, 00422,
   00416, 01150, 00432, 01250, 01450, 00105, 01370, 00272,
   01570, 00001, 01450, 00770, 01262, 00272, 01070, 00001,
   01470, 00021, 00364, 00751, 01450, 00432, 00774, 00742,
   01650, 01262, 00272, 01270, 00001, 01562, 01017, 00021,
   01270, 00035, 01350, 01270, 00272, 00001, 01670, 00005,
   01370, 00021, 01770, 00035, 00432, 00230, 00530, 01156,
   00021, 00610, 00770, 01451, 00710, 00021, 00610, 00710,
   00272, 00770, 00001, 00610, 01451, 01350, 00016, 00656,
   00404, 00464, 01433, 00115, 00232, 01150, 01370, 00610,
   01350, 00016, 00656, 01037, 00115, 01170, 00001, 01150,
   01670, 00272, 01262, 00015, 01770, 00005, 01770, 00035,
   00432, 00130, 00530, 00021, 00045, 00055, 00105, 01170,
   00021, 00610, 00272, 01370, 00001, 00045, 00061, 00025,
   01270, 00362, 00410, 01170, 00362, 00410, 00011, 00055,
   01170, 00216, 01150, 00122, 00372, 01250, 00710, 00272,
   01470, 00001, 01450, 00610, 00105, 00230, 00272, 01670,
   00001, 00603, 01262, 00272, 01070, 00003, 00432, 01156,
   00410, 00432, 01130, 00130, 01030, 01130, 00330, 01030,
   00530, 00330, 00330, 00230, 00030, 00730, 00011, 00065,
   00222, 01262, 00222, 00011, 00164, 00101, 00065, 00432,
   01262, 01156, 00774, 00530, 00005, 00055, 00664, 01523,
   00065, 00264, 00645, 00464, 00013, 01542, 00775, 00474,
   01542, 00775, 00674, 01342, 00344, 00374, 00464, 00023,
   00040, 00040, 00040, 00040, 00040, 00040, 00040, 00040,
   00164, 00343, 01764, 00013, 00140, 00464, 01747, 00710,
   00272, 01270, 00031, 00610, 01770, 00272, 00051, 01370,
   00232, 01262, 00031, 01370, 01262, 00005, 00710, 00005,
   00432, 00530, 01156, 00021, 01370, 00005, 01350, 00061,
   00065, 00070, 00610, 01270, 00035, 01570, 01262, 00005,
   00710, 00005, 01570, 00610, 00410, 01770, 01310, 00051,
   00041, 00710, 00272, 00510, 00001, 00232, 01010, 00232,
   01262, 00035, 01511, 00011, 00432, 00530, 01156, 00021,
   00710, 00005, 00041, 01370, 00610, 00065, 01270, 00566,
   00523, 00762, 01776, 00756, 00272, 01250, 01262, 00015,
   01262, 01750, 00064, 01761, 01262, 01310, 00710, 01210,
   00232, 00031, 00710, 00005, 00610, 00051, 00710, 01350,
   01010, 00072, 00126, 00061, 00064, 01135, 00061, 00011,
   00610, 00162, 00332, 01250, 01170, 00216, 00256, 01150,
   00710, 01262, 00005, 00272, 01170, 01310, 00065, 00232,
   01350, 01570, 01262, 00272, 00710, 00001, 01450, 00710,
   01550, 00704, 01004, 00432, 01150, 01010, 00774, 00006,
   00520, 01074, 00330, 01310, 00630, 01074, 00242, 00604,
   01406, 01234, 00232, 00614, 00610, 00724, 01241, 01014,
   01213, 00714, 01170, 00272, 00432, 00774, 00430, 00015,
   00432, 00330, 00005, 01150, 01370, 01210, 00232, 01160,
   00070, 01262, 00001, 01470, 00005, 01650, 00051, 01370,
   00272, 00065, 00232, 00272, 00576, 00536, 01522, 01370,
   01753, 00010, 00772, 00610, 00432, 00610, 00410, 00410,
   01110, 01110, 01110, 01110, 00372, 00132, 01710, 01710,
   00764, 01007, 00164, 00173, 00164, 00551, 00164, 00615,
   01511, 00025, 01511, 00011, 00264, 00221, 00041, 01764,
   01401, 00072, 00366, 00272, 00041, 01326, 00760, 00710,
   00005, 00764, 01727, 00000, 01460, 01060, 01407, 00000,
   01060, 01020, 00000, 01060, 01020, 00000, 01060, 01020,
   00656, 01676, 01670, 00422, 01262, 00001, 01362, 01440,
   00714, 01004, 01210, 00710, 01416, 01436, 00232, 01160,
   00232, 00070, 01262, 00232, 00772, 01160, 00070, 00064,
   00061, 01170, 00064, 00755, 01670, 00064, 01121, 00432,
   00230, 01262, 00064, 00071, 01362, 01440, 00704, 01004,
   01210, 01370, 00232, 01160, 00232, 01360, 01670, 00272,
   01170, 00064, 01111, 01370, 00064, 00071, 01350, 01010,
   01034, 01511, 00710, 00232, 00756, 01310, 01416, 01235,
   01010, 00624, 01501, 00232, 01370, 00232, 01160, 00232,
   01360, 01764, 00011, 01170, 00762, 00437, 01162, 00564,
   00443, 00770, 01310, 01262, 00232, 01070, 01310, 00064,
   00061, 01570, 00610, 01370, 00410, 01764, 00011, 00164,
   00341, 00710, 00272, 00510, 00064, 00061, 00164, 00565,
   00064, 00771, 00610, 00164, 00565, 00022, 01370, 00064,
   00755, 00710, 00774, 00436, 00530, 01074, 01142, 00707,
   01152, 00064, 00071, 00364, 00751, 01310, 01764, 00011,
   01564, 00117, 00524, 00346, 00610, 00774, 00742, 00610,
   01020, 01132, 01532, 00346, 00761, 00420, 01074, 00130,
   01730, 01310, 01310, 00530, 01154, 01613, 01310, 00572,
   01110, 01110, 00414, 01561, 00372, 00232, 01110, 00272,
   01110, 00572, 01632, 01532, 00346, 01110, 00332, 00404,
   01561, 01632, 00432, 00574, 00130, 01730, 01632, 01532,
   00346, 01110, 01010, 01632, 01532, 00346, 00432, 01074,
   00230, 01535, 01074, 00330, 01535, 01172, 01160, 00761,
   00264, 01775, 00751, 00664, 01661, 01364, 00001, 01564,
   00301, 00751, 00664, 01665, 00751, 00664, 01701, 00751,
   00664, 01715, 00751, 00230, 00254, 01713, 00372, 00332,
   00572, 00572, 00232, 00664, 01731, 00464, 00007, 00761,
   00410, 00510, 00464, 01643, 01160, 00372, 00070, 00532,
   00232, 00424, 01762, 00472, 00232, 01110, 01110, 01110,
   01360, 00432, 00070, 01110, 01360, 00332, 01156, 01563,
   01110, 01020, 01032, 00000, 01623, 00164, 00465, 00064,
   01135, 00164, 00101, 00064, 01735, 00664, 01623, 00671,
   00164, 00343, 00040, 00164, 00173, 01366, 00047, 01362,
   00014, 00704, 01204, 00422, 00610, 00272, 00064, 00745,
   00001, 01210, 00232, 00272, 00064, 00745, 00015, 00011,
   01164, 01715, 01010, 01310, 00710, 00064, 01111, 01566,
   00070, 00032, 00343, 01224, 00772, 01204, 01020, 01010,
   00232, 00704, 01362, 00055, 00404, 00422, 01310, 01366,
   01101, 00032, 01473, 00215, 00307, 00072, 00272, 00126,
   01362, 00102, 00404, 01534, 00102, 01234, 00102, 01214,
   00704, 00414, 00774, 00216, 00256, 00556, 00443, 01307,
   01516, 00130, 00332, 01332, 00061, 00774, 01142, 01572,
   00130, 00624, 00063, 01201, 00032, 01116, 00232, 01473,
   00624, 00367, 00064, 01665, 00215, 00132, 00332, 00774,
   00436, 00756, 01356, 00152, 00762, 00620, 00654, 00141,
   00372, 01473, 00410, 00432, 00762, 01772, 00757, 00232,
   00410, 00742, 00262, 00410, 01732, 01732, 01122, 00723,
   00022, 00472, 00232, 00172, 01632, 00677, 00410, 00762,
   00410, 00132, 00732, 00620, 00654, 00173, 00372, 00064,
   01245, 00132, 00410, 00416, 00274, 00372, 01745, 00372,
   01113, 00472, 01142, 01107, 01672, 00402, 01366, 00313,
   00720, 01067, 00432, 00410, 01201, 00572, 01772, 01020,
   00774, 00432, 00730, 01030, 00530, 00330, 01130, 01030,
   00130, 00630, 00330, 00330, 01130, 00730, 00530, 00774,
   01020, 00634, 00135, 00001, 00001, 00064, 01761, 00164,
   00101, 00064, 01735, 00015, 00064, 00771, 00022, 00064,
   01365, 00015, 00064, 01711, 00022, 00216, 00256, 00556,
   00553, 00567, 00720, 01156, 00254, 00312, 00436, 00064,
   00461, 01234, 00330, 01151, 01262, 00222, 00422, 00011,
   00734, 00334, 01151, 00011, 01424, 00353, 01151, 00656,
   00656, 00064, 01135, 01624, 00353, 00432, 00774, 01130,
   01156, 00064, 00755, 00434, 00356, 01262, 01524, 01101,
   00714, 00414, 01264, 00147, 01174, 00464, 00023, 00464,
   00017, 00432, 01172, 00422, 00244, 00412, 01444, 00434,
   01544, 00444, 00444, 00452, 00144, 00456, 01474, 00730,
   00274, 01020, 00674, 00630, 00630, 01030, 00630, 00530,
   00230, 00430, 01130, 00130, 00130, 00630, 00774, 01020,
   00630, 01344, 00407, 00143, 00374, 00141, 01474, 00530,
   00174, 01030, 00474, 01020, 01374, 00141, 01474, 01130,
   00674, 01020, 00174, 00141, 01574, 01020, 00574, 00141,
   00374, 01020, 01504, 00604, 01010, 00232, 00032, 00072,
   00226, 01362, 00502, 00704, 00634, 00500, 01234, 00501,
   00404, 00422, 00372, 01424, 00616, 01634, 00513, 00232,
   00272, 01772, 01632, 00432, 00774, 00430, 00530, 00372,
   01156, 01552, 00527, 01156, 00537, 00756, 01672, 00372,
   00410, 00510, 00572, 00572, 00572, 01772, 00372, 01552,
   00563, 01032, 00607, 00472, 00732, 01156, 00607, 00432,
   00372, 00510, 00572, 01434, 00557, 01672, 01772, 00372,
   01032, 00763, 00472, 00372, 00510, 00372, 01434, 00627,
   01556, 00626, 00732, 01137, 01224, 00605, 01204, 00424,
   00603, 00404, 00703, 00414, 00703, 01214, 00634, 00577,
   00734, 00614, 00714, 00703, 00704, 00703, 01064, 01201,
   00543, 00132, 01032, 01064, 00215, 01163, 00756, 01552,
   00634, 01032, 01107, 00472, 01156, 00064, 00461, 01424,
   00652, 00510, 00572, 01156, 00064, 01121, 01064, 01151,
   00064, 00771, 00410, 00232, 00272, 00756, 01327, 00132,
   00732, 01343, 00620, 00644, 00752, 00756, 01313, 00132,
   00432, 00372, 01064, 01745, 00372, 01377, 00762, 01032,
   01373, 00472, 00620, 01776, 00732, 00654, 00671, 00410,
   01672, 01672, 00432, 00774, 00130, 00410, 01474, 00630,
   00630, 01563, 01646, 01646, 01122, 01513, 00022, 00410,
   00232, 01072, 00472, 00410, 00172, 00262, 01142, 01523,
   00232, 00726, 00232, 01366, 01041, 01162, 01156, 00022,
   01672, 01563, 00510, 01524, 01061, 01234, 01061, 00064,
   01665, 01264, 00307, 01152, 01152, 01552, 01012, 00752,
   00752, 01020, 01214, 01020, 00710, 00410, 00510, 00416,
   00103, 00040, 00040, 00040, 00040, 00040, 00040, 00040,
   00040, 00040, 00040, 00140, 00140, 00140, 00364, 00753,
   00045, 01310, 00061, 00025, 01234, 01031, 01010, 01310,
   00232, 00071, 00734, 01035, 01262, 01010, 01310, 00232,
   00373, 00422, 00410, 00232, 00510, 01132, 01524, 01052,
   01224, 01054, 01216, 00132, 01326, 01103, 00410, 00064,
   01215, 00634, 01076, 00055, 00061, 00025, 00064, 01761,
   01164, 01715, 01524, 00774, 00064, 01665, 00434, 01101,
   01262, 00464, 00013, 00432, 00774, 01146, 00574, 00130,
   00272, 00172, 00634, 01101, 00307, 00372, 01326, 01131,
   00774, 00316, 00756, 00756, 01552, 01173, 00620, 01354,
   01133, 00332, 00407, 01156, 00533, 00432, 00326, 01024,
   01156, 00720, 01154, 01146, 01001, 00647, 00720, 01001,
   00620, 00620, 01001, 00272, 00332, 00743, 00032, 00771,
   00720, 01144, 01164, 00720, 00771, 00732, 00532, 00372,
   00064, 00421, 00407, 01312, 01131, 00567, 01746, 00606,
   00246, 01746, 00546, 00546, 01046, 01024, 01373, 00032,
   00256, 00632, 00416, 01020, 00032, 01064, 01151, 00372,
   00710, 00021, 01161, 00035, 00407, 00272, 01161, 00015,
   01064, 01151, 00041, 00407, 00432, 00774, 01130, 00756,
   01020, 01511, 00032, 00774, 00642, 00232, 01364, 01475,
   01562, 00364, 01366, 00364, 00370, 01262, 00272, 00170,
   00015, 01501, 00570, 00272, 01511, 00015, 01521, 00011,
   00164, 00101, 00724, 01302, 00704, 01511, 00170, 01465,
   00270, 01317, 00061, 00424, 01330, 01024, 01417, 01004,
   01511, 00370, 01465, 00470, 01317, 00272, 01262, 00015,
   01531, 00055, 00364, 01227, 01531, 00063, 01764, 00013,
   01326, 00364, 00634, 01343, 00065, 00041, 00071, 00364,
   01141, 00032, 01627, 00710, 00272, 01511, 00015, 00170,
   01262, 00005, 01531, 00065, 00025, 00055, 00065, 01511,
   00370, 00021, 01521, 00011, 00065, 00045, 01511, 00035,
   00624, 01436, 00407, 00506, 01746, 01546, 01373, 01020,
   01460, 00040, 00040, 00040, 00040, 00040, 00040, 00040,
   00040, 00040, 00040, 00140, 00140, 00140, 00140, 00634,
   01440, 00065, 00025, 01522, 00364, 01366, 00364, 00710,
   01124, 01433, 01310, 00051, 00071, 00041, 00464, 00003,
   01522, 00364, 00065, 01522, 00364, 00725, 00072, 00126,
   00064, 01735, 00355, 00055, 00065, 00061, 00045, 00365,
   00035, 00051, 00624, 01436, 00645, 00364, 01141, 00604,
   00355, 00071, 00267, 01764, 00013, 00364, 01227, 00725,
   00432, 00774, 00130, 00625, 00050, 00170, 00272, 00710,
   00625, 00150, 00710, 00272, 00015, 00270, 00655, 00250,
   01210, 00370, 00232, 00625, 00350, 01210, 00232, 00272,
   00015, 00470, 00655, 00450, 00710, 01210, 00015, 00570,
   00655, 00550, 00711, 00464, 00027, 00434, 01550, 01262,
   01501, 00364, 00753, 00434, 01560, 00232, 01262, 00232,
   00005, 00647, 00355, 00710, 01360, 00364, 01213, 00470,
   00232, 00031, 00064, 01735, 00055, 00170, 00272, 00570,
   01475, 00061, 00025, 00055, 00570, 00272, 00270, 01475,
   00061, 00041, 00645, 00272, 00432, 00774, 00742, 01475,
   00350, 00272, 01441, 01475, 01362, 01661, 00370, 00422,
   00272, 00350, 01441, 01501, 00055, 00370, 00272, 00432,
   00774, 00742, 01501, 00061, 00041, 00055, 01441, 01216,
   01262, 00005, 01362, 01701, 00061, 00710, 01262, 00021,
   01367, 00370, 00272, 01441, 01216, 01475, 01362, 01701,
   00370, 00272, 00710, 01262, 00015, 00645, 00350, 00004,
   01537, 00710, 00756, 00756, 00756, 01262, 00000, 01367,
   00432, 00774, 00742, 01474, 00330, 01216, 01020, 01262,
   00064, 00063, 00470, 00350, 00270, 00150, 00014, 00710,
   00450, 00570, 00250, 00272, 00170, 01475, 00550, 00370,
   00272, 00470, 00031, 00432, 00742, 00766, 01262, 00005,
   00570, 00410, 00510, 00416, 00045, 00272, 00270, 00641,
   00550, 00272, 00270, 01072, 01372, 01770, 01464, 01563,
   00170, 00272, 00270, 01475, 00270, 01464, 01373, 01255,
   00000, 00123, 01653, 00037, 00047, 00564, 01123, 00564,
   00333, 00564, 01057, 00140, 00140, 00140, 00272, 00716,
   00310, 00710, 01410, 00220, 01372, 00364, 00470, 01372,
   00246, 00272, 00710, 01062, 01362, 00040, 01364, 01513,
   00022, 01262, 01111, 01562, 00230, 01372, 00230, 00370,
   01372, 00064, 01670, 01174, 00242, 00330, 01174, 00642,
   01402, 00063, 00202, 01650, 00470, 00350, 00270, 00150,
   00570, 00250, 00710, 00450, 00470, 00272, 00432, 00774,
   00742, 00766, 00064, 00745, 00055, 00370, 00272, 00470,
   01262, 01111, 01372, 00265, 00061, 00064, 01135, 01131,
   00272, 00072, 00126, 00055, 00432, 00774, 00742, 00756,
   00756, 01262, 01121, 01362, 00265, 00270, 00272, 00170,
   01262, 01111, 00055, 00065, 00064, 00771, 00270, 01121,
   00055, 00065, 00410, 01062, 01362, 00214, 00061, 00432,
   00762, 01172, 00064, 00755, 01131, 00550, 00272, 00270,
   01072, 01572, 00212, 00065, 00432, 00774, 00330, 00064,
   01121, 00270, 01121, 01131, 00550, 00272, 00270, 01072,
   01372, 00411, 00570, 01257, 00061, 00432, 00774, 00130,
   00766, 00713, 00064, 00063, 00064, 00073, 00364, 00753,
   00370, 01372, 00243, 01670, 01174, 01342, 00406, 01142,
   01650, 01764, 00567, 00710, 00350, 00363, 00710, 00450,
   00432, 00350, 00170, 00550, 01301, 00404, 00464, 00713,
   00610, 01670, 00356, 00016, 01020, 00032, 00656, 00656,
   00432, 00774, 00742, 00372, 00055, 00567, 01566, 00305,
   00222, 01252, 00756, 00742, 01527, 01522, 00314, 01562,
   00316, 00766, 01527, 01413, 01562, 00311, 01142, 01366,
   00323, 00742, 01523, 01156, 01166, 01131, 00550, 00272,
   00170, 01072, 01372, 00371, 00370, 00610, 00570, 00272,
   00170, 01072, 01572, 00346, 00034, 00354, 00570, 01301,
   00656, 01267, 01372, 00364, 00710, 00272, 00470, 01062,
   01562, 00036, 01364, 00737, 00710, 01310, 00570, 01310,
   01773, 00710, 01310, 00170, 01310, 00270, 00610, 00000,
   00155, 01572, 00775, 00214, 00114, 01507, 00470, 01310,
   00170, 01310, 00270, 00610, 00155, 01572, 01224, 00224,
   01224, 01374, 00713, 00710, 00364, 00751, 00610, 01554,
   00400, 00214, 00003, 00072, 01114, 01374, 01670, 00346,
   00272, 01770, 00464, 01141, 01074, 01142, 00247, 00402,
   00214, 01750, 00232, 01574, 00346, 01650, 01770, 01020,
   01460, 01410, 00416, 01160, 01770, 01664, 01315, 00272,
   01562, 00520, 01356, 00515, 00432, 01274, 01230, 00130,
   00230, 01116, 01516, 00737, 01426, 00737, 00420, 00232,
   00474, 01342, 00514, 00662, 00473, 00732, 00520, 01723,
   00422, 00732, 01356, 00534, 00520, 01156, 01356, 00534,
   00520, 01156, 01556, 00737, 00520, 00704, 01733, 00000,
   00416, 01474, 00530, 00216, 00416, 01074, 00130, 01160,
   01770, 01356, 00556, 00412, 01416, 00561, 00710, 01410,
   01020, 00574, 00464, 00023, 01471, 00364, 00751, 01554,
   00720, 01074, 00713, 01552, 00635, 01664, 01315, 00272,
   00710, 01632, 01562, 00612, 01532, 00630, 00364, 00035,
   00464, 00013, 01532, 00621, 00774, 00406, 00742, 00752,
   01043, 01356, 00635, 01156, 01356, 00635, 00432, 01043,
   01356, 00635, 01156, 01556, 00614, 01764, 01401, 00272,
   00710, 01471, 00064, 01761, 00164, 00341, 00164, 00565,
   00064, 00771, 00432, 00130, 00230, 00756, 00064, 00755,
   00164, 00341, 00432, 00774, 00756, 00530, 00530, 00064,
   00071, 01764, 01321, 00430, 01130, 00064, 01711, 01764,
   01525, 00330, 00030, 00330, 00430, 01030, 01764, 01543,
   00064, 00745, 00727, 00064, 01111, 00727, 00064, 00063,
   01360, 00710, 00464, 00003, 01064, 01151, 00572, 00766,
   00416, 01513, 01764, 00103, 01504, 00464, 00163, 00174,
   00713, 01010, 00064, 01111, 01043, 01060, 00464, 00447,
   00000, 01060, 01567, 01060, 01563, 01060, 01464, 00073,
   01060, 00307, 01060, 00723, 01060, 01443, 01060, 01457,
   01060, 01553, 01060, 01020, 00000, 01060, 01523, 01060,
   01141, 00710, 01410, 00716, 00220, 00205, 00016, 00064,
   00461, 01156, 00464, 00013, 00237, 00653, 01764, 00077,
   01210, 01262, 01625, 01562, 00755, 01123, 01562, 00755,
   00607, 00264, 00205, 00053, 01753, 00147, 00164, 00601,
   00053, 00272, 00774, 01352, 01300, 00756, 01020, 01124,
   01052, 01310, 00070, 01713, 01547, 01003, 00164, 00601,
   00432, 00410, 00510, 00364, 01245, 00372, 00064, 01135,
   00053, 00701, 01064, 00027, 01133, 01507, 00064, 01351,
   00053, 01210, 00222, 01262, 00222, 01625, 00232, 00507,
   01564, 00603, 01564, 01657, 01243, 00347, 00701, 01164,
   00313, 01210, 00232, 01156, 01156, 00064, 01121, 00053,
   00604, 00441, 01264, 01207, 00543, 01647, 01153, 01210,
   01072, 01372, 00755, 01123, 01210, 01262, 01625, 01362,
   00755, 01123, 01564, 01647, 01237, 01004, 01264, 00467,
   01764, 00045, 01362, 01171, 01604, 01162, 01562, 01171,
   01404, 01141, 00710, 01020, 00407, 01213, 01204, 01073,
   00032, 00364, 01245, 00710, 00064, 00755, 00264, 00071,
   00053, 01315, 00053, 00000, 01447, 01207, 00604, 01173,
   01210, 01072, 01572, 00755, 00464, 00123, 00264, 01547,
   01764, 00013, 01264, 01127, 00547, 01217, 00701, 01164,
   00333, 01204, 00604, 01504, 00701, 01064, 00327, 00604,
   00404, 00547, 01110, 01713, 01517, 00637, 00103, 01262,
   01010, 01625, 00053, 00205, 00406, 01366, 01270, 00216,
   01020, 00441, 01364, 00377, 01047, 00133, 00623, 01303,
   00756, 01356, 01310, 01156, 00726, 00620, 01526, 01301,
   01020, 00441, 00364, 00627, 00027, 00607, 00577, 01010,
   01533, 00272, 01533, 01210, 01156, 01156, 00064, 00745,
   00053, 00064, 01651, 00053, 01617, 01113, 01103, 01566,
   00741, 00464, 00017, 00422, 00053, 00064, 00063, 01564,
   01703, 01264, 01063, 00000, 01637, 01253, 01723, 01010,
   01310, 00232, 00464, 00003, 00432, 01160, 01770, 00610,
   01564, 01503, 01564, 00757, 00453, 00404, 01347, 01564,
   01713, 00040, 00432, 01074, 00742, 00742, 01160, 00070,
   01020, 00416, 01074, 00130, 01160, 01770, 01020, 00404,
   01410, 00432, 00061, 01311, 00441, 00650, 00022, 00216,
   01352, 01436, 01666, 00756, 00143, 00726, 00416, 00236,
   00272, 01156, 00750, 00274, 00006, 00461, 01311, 00441,
   01050, 00016, 00465, 01566, 01457, 00432, 00742, 00424,
   01462, 01262, 00232, 00670, 00535, 00650, 00272, 00770,
   00222, 00262, 00535, 00232, 00416, 01160, 00232, 01750,
   00011, 01070, 00272, 00670, 00424, 01021, 01664, 00627,
   00372, 00011, 00372, 01020, 00656, 00656, 00774, 01502,
   01524, 00726, 01116, 00477, 00232, 01020, 01262, 00064,
   00063, 00164, 00567, 00364, 00753, 00570, 00272, 00270,
   00531, 01205, 00710, 00272, 00470, 00531, 00545, 01271,
   01205, 00370, 00272, 00470, 00531, 01205, 00170, 00272,
   00270, 01251, 01262, 00262, 01231, 01221, 00164, 00101,
   00570, 00272, 00170, 01251, 00062, 01332, 01606, 01231,
   01261, 01262, 00262, 01241, 01221, 01037, 01241, 01121,
   01572, 01616, 01241, 01121, 01372, 00406, 00570, 01072,
   01372, 00406, 01464, 01243, 00432, 00774, 01156, 00530,
   01301, 00270, 00005, 00555, 00150, 00272, 00270, 01072,
   01020, 00164, 00343, 00545, 00064, 00107, 00164, 00467,
   00164, 00553, 00531, 00545, 00064, 01137, 00064, 01713,
   00064, 00757, 01664, 01317, 00432, 01262, 00756, 00756,
   00410, 00432, 00674, 00530, 01130, 00230, 00774, 01020,
   00710, 01262, 00272, 00432, 00774, 00330, 00535, 01362,
   01713, 00064, 01735, 01664, 00205, 00406, 01366, 01721,
   00216, 01362, 01724, 00432, 01020, 00432, 00756, 01020,
   00005, 01215, 01321, 00530, 00330, 01271, 01525, 00630,
   00530, 00330, 00530, 00130, 00005, 01205, 01231, 00432,
   00774, 00730, 01301, 00164, 00171, 01221, 00432, 01262,
   00410, 00432, 01030, 00430, 01030, 01271, 00432, 00430,
   01156, 00005, 01215, 01231, 01261, 00564, 01473, 00667,
   00440, 00063, 00073, 00107, 00747, 00757, 00773, 01113,
   01123, 01137, 01713, 01367, 00072, 00126, 00410, 00510,
   00416, 00062, 00422, 00410, 01074, 00620, 00652, 00752,
   00254, 00025, 00372, 01372, 00075, 00410, 00132, 01372,
   00075, 01456, 00150, 01022, 01522, 00047, 00317, 01232,
   00262, 01456, 00063, 00410, 00232, 00732, 00232, 00410,
   00132, 01116, 00132, 01456, 00075, 00656, 01772, 00222,
   00262, 00620, 01154, 00063, 00432, 00232, 00510, 00372,
   00472, 01152, 01152, 01152, 00232, 00410, 00510, 01362,
   00113, 00656, 01772, 00232, 00774, 01506, 00143, 00372,
   00232, 00774, 00272, 00556, 00607, 00766, 00607, 00316,
   00756, 00742, 00322, 00132, 01566, 00140, 00432, 00022,
   01020, 00316, 00553, 01502, 00117, 01156, 00706, 00617,
   00410, 00132, 01456, 00155, 00207, 00232, 00410, 01432,
   00164, 00410, 00232, 00217, 00410, 00232, 00410, 00132,
   00217, 00072, 00126, 00410, 00510, 00416, 00062, 00422,
   00410, 00616, 01062, 01027, 01222, 00032, 00410, 01274,
   00720, 01672, 01063, 00472, 01142, 01057, 00254, 00210,
   00510, 00423, 00072, 00126, 00410, 00510, 00416, 00062,
   00422, 01366, 00267, 00410, 01056, 01062, 01203, 01222,
   00410, 00232, 00132, 01472, 00251, 00410, 00732, 01156,
   00410, 00774, 00432, 01267, 00742, 01032, 01263, 00472,
   00732, 00620, 01154, 00255, 00232, 00510, 00477, 01474,
   00464, 00023, 00072, 00366, 00232, 01522, 00267, 00062,
   01332, 00347, 00332, 00132, 00572, 00572, 00632, 00372,
   00436, 00272, 00572, 01226, 00556, 00616, 01474, 01542,
   00322, 01732, 01772, 00216, 00432, 00132, 01274, 00530,
   01772, 01613, 00742, 01632, 01553, 00532, 00732, 01344,
   00345, 00620, 01746, 00402, 01557, 00232, 00503, 00032,
   00432, 00503, 00072, 00366, 00232, 00432, 00410, 00432,
   00774, 00130, 00372, 00232, 00410, 00232, 01137, 00432,
   01262, 00774, 00130, 00073, 00432, 01747, 00630, 01130,
   00330, 00130, 00430, 00730, 00130, 01030, 00030, 00530,
   00530, 01146, 00774, 01020, 00343, 00567, 00467, 00553,
   00670, 00222, 00774, 00346, 00650, 01170, 01674, 00706,
   00706, 00706, 00206, 00216, 01150, 00447, 00372, 00410,
   01170, 00266, 00166, 01726, 01726, 01726, 00374, 00346,
   00356, 01150, 00670, 00372, 00770, 00650, 01070, 00750,
   00226, 01772, 01772, 01772, 00362, 00410, 00372, 01020,
   00770, 01050, 00670, 00750, 00332, 00222, 00262, 00650,
   01170, 00226, 00474, 00706, 00706, 00706, 00226, 01150,
   00206, 01646, 01646, 01646, 01020, 00770, 00374, 00372,
   00410, 01170, 00620, 01772, 00354, 00522, 00362, 00232,
   00410, 01020, 01070, 00474, 00477, 00670, 01674, 00477,
   00072, 00366, 00232, 00614, 01247, 00614, 01014, 00062,
   00232, 00272, 00556, 01073, 01522, 00621, 00232, 00725,
   00774, 00232, 00436, 00272, 01053, 00132, 00172, 00410,
   00510, 01672, 01532, 00577, 00510, 00232, 01020, 00756,
   00747, 00774, 00642, 00132, 00064, 01217, 00644, 01752,
   00620, 00762, 00756, 01033, 00132, 01373, 00064, 01761,
   01247, 01004, 00703, 00774, 00332, 01142, 00232, 01532,
   00633, 00264, 00033, 01502, 00640, 01156, 00732, 01157,
   00410, 01021, 00703, 00072, 00366, 00232, 00604, 01326,
   01756, 01014, 00062, 01522, 00267, 01326, 00267, 00216,
   00256, 01356, 00623, 00516, 01337, 01256, 01004, 00036,
   00236, 00032, 00774, 01006, 01142, 00742, 00172, 00410,
   00510, 01417, 01672, 01162, 01413, 00510, 00472, 01122,
   01367, 00762, 00132, 00732, 00620, 01254, 00676, 00232,
   00172, 00706, 00706, 00706, 00232, 01474, 00730, 01216,
   01316, 01024, 01374, 01672, 00372, 00264, 00661, 00372,
   00264, 00155, 01366, 00777, 01154, 00733, 00072, 01474,
   00142, 00472, 01672, 00372, 00364, 01245, 01024, 00765,
   00132, 01032, 00132, 00472, 00132, 01174, 00264, 00155,
   01366, 00777, 01672, 01733, 01672, 00264, 00013, 01522,
   00774, 01156, 00436, 01034, 01006, 01262, 00064, 00461,
   00634, 01040, 00164, 00171, 00064, 00771, 00510, 01362,
   01044, 01116, 00372, 00077, 01672, 01321, 00132, 01374,
   00164, 01567, 00472, 01142, 00153, 00402, 00756, 00720,
   01020, 00072, 00366, 00232, 01004, 01522, 01050, 01014,
   00036, 00132, 00332, 00556, 00347, 00332, 01522, 01075,
   01274, 00620, 01244, 01213, 00756, 00307, 00661, 00372,
   01007, 00364, 01245, 01374, 00413, 00132, 00656, 01732,
   00243, 00766, 01032, 00407, 00472, 00732, 01156, 00507,
   01674, 01342, 01117, 01142, 01542, 01126, 00742, 00774,
   01047, 00232, 00726, 00232, 01342, 01102, 00432, 00774,
   01146, 00272, 00574, 00130, 01034, 01137, 01256, 00132,
   00272, 00434, 01151, 00164, 00341, 00064, 01735, 00164,
   00101, 00132, 00064, 00503, 00432, 00244, 00376, 01166,
   00430, 00766, 01544, 01671, 00444, 01706, 00144, 01722,
   01644, 01734, 00644, 01744, 01474, 00330, 01374, 01020,
   00742, 01032, 01003, 00472, 00644, 01214, 00732, 01156,
   00620, 00372, 00333, 00372, 00434, 01221, 01321, 00232,
   00132, 01274, 00630, 01674, 01366, 01312, 00720, 01342,
   01236, 01142, 00172, 00410, 00510, 01273, 00756, 01672,
   01162, 01123, 01772, 01772, 01772, 00642, 00132, 00272,
   01034, 01141, 00064, 01665, 00607, 01732, 01162, 01267,
   00472, 00662, 00510, 01137, 00410, 00510, 00172, 00372,
   00572, 00572, 00632, 00132, 01772, 01572, 01302, 00510,
   00232, 01020, 00656, 01363, 01232, 00422, 00410, 00756,
   00064, 01203, 00132, 00436, 00272, 01034, 01322, 01262,
   00164, 00725, 00434, 01326, 00164, 00341, 00064, 01761,
   00647, 00072, 00366, 00232, 00164, 00341, 01210, 00710,
   01522, 01771, 01717, 01356, 00267, 01156, 00736, 01526,
   01343, 01556, 01363, 00222, 00262, 00562, 00562, 00622,
   01362, 01363, 00704, 01210, 00022, 00232, 00414, 00164,
   01215, 01010, 00734, 01375, 01262, 00464, 00013, 01460,
   00040, 00040, 00040, 00040, 00040, 00040, 00040, 00774,
   01562, 00267, 01552, 00267, 00272, 00172, 00736, 01506,
   01426, 00656, 01416, 01432, 00752, 01020, 01116, 00067,
   00064, 01337, 00432, 00742, 01772, 00762, 00372, 01302,
   01443, 01706, 00756, 00032, 01602, 00247, 00732, 00472,
   00237, 01622, 00303, 01646, 00672, 00756, 00472, 00273,
   00106, 01142, 00177, 01162, 00177, 00732, 00156, 00436,
   00446, 00532, 00236, 01020, 01514, 00377, 01504, 01211,
   00432, 00774, 00130, 00731, 00050, 00170, 00272, 00710,
   00731, 00150, 00710, 00272, 00015, 00270, 01105, 00250,
   01210, 00370, 00232, 00731, 00350, 01210, 00232, 00272,
   00015, 00470, 01105, 00450, 00710, 01210, 00015, 00570,
   01105, 00550, 01201, 00464, 00027, 01211, 00370, 00232,
   01566, 01555, 01174, 00464, 00023, 00031, 00751, 01141,
   01211, 00170, 00232, 00031, 00464, 00003, 01534, 01571,
   01262, 00001, 01566, 01575, 00432, 01410, 00774, 01352,
   01606, 01156, 00752, 01152, 01037, 00756, 01020, 00552,
   01057, 00432, 01077, 00406, 01146, 00412, 00620, 00620,
   01020, 01534, 01626, 00232, 01262, 00232, 00005, 00753,
   00272, 01124, 01635, 00710, 01310, 00232, 01310, 01020,
   00710, 01250, 01225, 00272, 01020, 00432, 01160, 00070,
   01020, 00774, 00230, 00330, 00030, 00230, 00530, 01030,
   00530, 00030, 01130, 00230, 01130, 01130, 00430, 00372,
   01020, 00330, 00130, 00030, 00130, 00730, 01130, 01030,
   00030, 00430, 00330, 00230, 00474, 01020, 00374, 00330,
   00330, 00030, 01030, 00530, 00330, 00130, 00630, 01030,
   00674, 01020, 01374, 00330, 00330, 00330, 00030, 01030,
   00330, 00530, 01574, 01020, 00174, 00330, 00330, 00330,
   00330, 00130, 00374, 01020, 00574, 00330, 00330, 00330,
   00274, 01020, 00132, 00372, 00264, 00127, 00164, 00171,
   01366, 00267, 00510, 01562, 00267, 00032, 00072, 00264,
   00607, 00226, 01552, 00267, 00264, 01633, 00000, 00533,
   00063, 01060, 00737, 01474, 01060, 00757, 00272, 01664,
   01251, 00610, 01360, 00232, 01364, 01445, 00610, 01554,
   00023, 00114, 00214, 01114, 01314, 00132, 00157, 01060,
   00157, 01060, 01003, 00431, 00132, 01725, 00224, 01415,
   00114, 01404, 00314, 00334, 00177, 01464, 01741, 00414,
   00774, 00016, 00416, 00310, 00210, 01714, 01724, 00055,
   00114, 00314, 00334, 00070, 01424, 00072, 01404, 00123,
   01424, 00176, 01724, 00401, 00303, 00372, 00032, 01755,
   00451, 01464, 00003, 01104, 00610, 00123, 00224, 00112,
   00134, 00136, 00675, 00256, 00711, 01616, 01516, 00122,
   00416, 00567, 00420, 00574, 01356, 00137, 00252, 00730,
   01412, 00143, 00212, 00752, 01274, 01750, 01020, 00130,
   00130, 01630, 00563, 01474, 01342, 00152, 01142, 00574,
   00130, 00563, 00574, 00130, 00030, 01630, 00563, 01074,
   00130, 00723, 01074, 00230, 01160, 01770, 01020, 00764,
   00225, 00033, 00174, 01264, 01405, 00123, 01725, 01414,
   00711, 01221, 01556, 00367, 00072, 01102, 00630, 00372,
   00016, 00416, 00774, 00310, 00210, 00314, 00334, 00055,
   01714, 01724, 00220, 00310, 01161, 00272, 00410, 00232,
   00624, 00035, 00764, 00207, 00711, 01160, 00216, 00070,
   01112, 01112, 01713, 01020, 00232, 00410, 00232, 00436,
   00032, 01356, 00304, 00774, 00130, 00030, 00642, 00430,
   00236, 01410, 00536, 01152, 01313, 00674, 00730, 01474,
   01410, 01636, 01142, 01343, 01074, 01542, 00304, 00774,
   00130, 00030, 00530, 00536, 00420, 01574, 01106, 01020,
   00104, 00711, 00314, 00324, 00317, 00451, 01003, 01556,
   00200, 01314, 01372, 00315, 01674, 01342, 00344, 01664,
   01275, 01003, 00314, 00324, 00000, 00675, 00410, 00711,
   01356, 00176, 01464, 00333, 01221, 01102, 00630, 00376,
   00310, 00210, 01714, 01734, 01415, 01653, 00451, 00214,
   01314, 00167, 01772, 01772, 01207, 00664, 01073, 01161,
   01064, 01771, 01043, 00675, 00272, 00416, 00574, 01264,
   01733, 00420, 00310, 00020, 00734, 00411, 00774, 00016,
   01405, 01415, 00704, 00123, 00774, 00016, 01405, 01604,
   00123, 01574, 01405, 00016, 00216, 00414, 00664, 00203,
   00165, 00273, 01274, 00664, 01427, 01174, 00157, 00724,
   01055, 01624, 01070, 00444, 01314, 00155, 01674, 00000,
   00000, 00656, 00656, 00656, 00656, 00656, 00656, 01203,
   00063, 00023, 00177, 00523, 00000, 00000, 00664, 01117,
   00151, 01507, 00724, 00476, 00544, 01344, 00656, 01213,
   01003, 01267, 01617, 00724, 00453, 01624, 00453, 00444,
   01032, 00624, 00610, 01565, 00257, 00724, 01141, 00444,
   00454, 01074, 01430, 00767, 00664, 01247, 00724, 01605,
   00444, 00455, 01074, 01330, 00767, 00165, 00263, 00656,
   00656, 00656, 01447, 00724, 00455, 01624, 00455, 00444,
   01024, 00624, 00705, 01565, 00267, 01565, 00414, 01637,
   01353, 00467, 00533, 01624, 01644, 00724, 01575, 00444,
   01562, 00624, 01355, 01074, 01230, 01330, 00664, 00063,
   00724, 01267, 01624, 00451, 00444, 00451, 01565, 00247,
   00165, 00257, 00724, 00616, 00544, 01341, 00656, 00353,
   00107, 01647, 01713, 01763, 00000, 00000, 00016, 00724,
   00452, 00444, 00452, 01565, 00253, 00155, 00574, 00603,
   01053, 00353, 00577, 00724, 00456, 01624, 00456, 00444,
   00456, 00624, 00430, 01565, 00273, 01624, 00667, 00344,
   01120, 01224, 01124, 00724, 01132, 00444, 01136, 01074,
   00430, 00767, 00724, 01145, 00444, 00453, 01074, 01530,
   00767, 00664, 01437, 00664, 01447, 00165, 00267, 00664,
   00303, 00724, 00717, 01144, 01772, 00044, 01772, 00656,
   00656, 00656, 01437, 00724, 00454, 01624, 00454, 00444,
   01027, 00624, 00535, 01565, 00263, 00714, 01614, 00414,
   00774, 00016, 01020, 00724, 00470, 01624, 00555, 00664,
   00307, 00724, 01150, 01624, 01204, 00744, 01151, 00444,
   00310, 01167, 00724, 01162, 01624, 01210, 00444, 01372,
   00155, 00574, 00604, 01207, 01624, 00452, 00724, 01213,
   00444, 01324, 01425, 01674, 01204, 00564, 00253, 01074,
   00430, 01030, 00063, 00216, 01105, 00654, 01441, 01477,
   01074, 00430, 01130, 00063, 01074, 00130, 00163, 01074,
   00230, 00163, 01074, 00330, 01030, 00216, 00174, 00404,
   00012, 00464, 00257, 00716, 00177, 01421, 00564, 00607,
   01074, 01427, 00241, 00564, 00613, 00241, 00564, 01503,
   00656, 00654, 01070, 01356, 01014, 01156, 00716, 00207,
   01512, 01043, 00424, 01013, 00656, 00716, 00724, 01110,
   01624, 01112, 00720, 01116, 01154, 01102, 00216, 00063,
   00474, 00413, 00674, 00413, 01074, 00230, 00730, 00063,
   01074, 00642, 01474, 00203, 01421, 00016, 00416, 00230,
   01374, 00203, 01425, 01274, 00564, 01513, 01074, 00430,
   00703, 01074, 00130, 00630, 00063, 01074, 00130, 00473,
   00216, 00404, 00344, 00456, 00744, 00456, 01074, 00630,
   01230, 00063, 00216, 00404, 00624, 00455, 01224, 01176,
   01244, 01201, 01074, 00630, 01330, 00063, 01074, 01130,
   00763, 01074, 00730, 00763, 01074, 00030, 01630, 00063,
   01074, 00730, 00703, 01074, 00530, 00763, 01014, 01414,
   01514, 00414, 01437, 00724, 01045, 01624, 01007, 00444,
   01276, 01144, 01302, 01644, 00456, 01144, 00456, 01244,
   00456, 01074, 01730, 01074, 00202, 00404, 01674, 00564,
   00273, 00724, 01052, 01624, 01020, 00444, 01114, 01144,
   01301, 01644, 00455, 01244, 00455, 00656, 01207, 00354,
   00451, 00624, 00451, 01074, 00530, 00703, 01074, 01130,
   00703, 00656, 00656, 00273, 01474, 00016, 00652, 00614,
   01214, 00714, 01614, 01020, 01425, 00274, 00307, 01464,
   01253, 00174, 00464, 00757, 00314, 00324, 00024, 00464,
   00711, 01356, 00176, 00464, 01553, 01750, 01314, 00464,
   00167, 01474, 01130, 01633, 01474, 01030, 01074, 00314,
   00334, 00642, 01474, 01664, 01537, 01060, 00000, 01775,
   01060, 01364, 01771, 01060, 01564, 01621, 01060, 01264,
   01541, 01703, 01264, 00147, 00574, 00464, 00757, 01460,
   01314, 00310, 01464, 01741, 00210, 00416, 00574, 00630,
   01156, 00043, 00310, 00464, 00123, 01665, 01356, 01422,
   01552, 01424, 01664, 01123, 01324, 01430, 01724, 00357,
   00132, 00210, 00464, 01161, 00132, 00664, 01071, 01664,
   01603, 00314, 00334, 00075, 00167, 00310, 00420, 00110,
   00010, 00410, 00332, 00610, 00332, 01074, 00230, 01160,
   00232, 01360, 01650, 01750, 01074, 00130, 01730, 01160,
   00070, 00422, 00174, 00246, 01574, 00406, 00174, 00232,
   00246, 00774, 01630, 01230, 01630, 01632, 01532, 01521,
   01750, 00272, 01672, 01672, 01672, 01672, 01710, 00432,
   01020, 00174, 00430, 00406, 01360, 01474, 00430, 00216,
   01710, 00432, 01074, 00130, 01630, 00032, 01160, 00232,
   01360, 00232, 01156, 00567, 00432, 01172, 00774, 01530,
   01230, 01574, 01630, 01230, 01230, 01430, 01230, 00232,
   01264, 01543, 00314, 00334, 01575, 00072, 00710, 00272,
   00210, 01714, 01724, 01571, 00027, 00774, 00714, 00614,
   01014, 00414, 00016, 00464, 00257, 01665, 00432, 01650,
   00314, 01750, 00324, 01636, 01765, 00032, 01474, 01356,
   01636, 01160, 00232, 01360, 00232, 00742, 00742, 01142,
   01107, 01074, 01342, 01641, 00416, 01750, 00710, 00464,
   00003, 00416, 00130, 01107, 00432, 00474, 00630, 01674,
   00630, 00130, 00372, 01765, 00272, 01356, 01701, 01074,
   00130, 00530, 01074, 01406, 01701, 01502, 01731, 00030,
   01330, 01074, 01606, 01567, 00506, 01106, 00174, 00046,
   01567, 00232, 00464, 01221, 00006, 00432, 00474, 00730,
   00232, 01410, 01066, 01772, 01174, 01130, 00774, 01530,
   01630, 00374, 01730, 01730, 01230, 01630, 01730, 00420,
   00737, 01474, 00430, 01474, 00502, 00026, 00732, 00726,
   00726, 00726, 00726, 00726, 00716, 00432, 00374, 00730,
   00226, 01626, 00732, 00232, 01473, 00464, 00713, 01665,
   00224, 00356, 00124, 00024, 00204, 01314, 01356, 00322,
   00464, 01003, 00274, 00464, 00757, 00464, 00677, 00167,
   00117, 00547, 01763, 00307, 00367, 00503, 00523, 00517,
   00247, 00243, 00253, 00447, 00457, 00213, 00467, 00130,
   00330, 01164, 01657, 00130, 00330, 00374, 00230, 00530,
   00107, 00000, 00557, 01323, 00613, 00643, 00673, 00174,
   00730, 00663, 00730, 00130, 00374, 00230, 00330, 00107,
   00535, 00227, 00430, 00217, 00277, 00723, 01753, 00012,
   01447, 01474, 01030, 01474, 01402, 00213, 01374, 00130,
   00330, 00374, 00130, 00430, 00107, 01474, 01130, 01474,
   01402, 00577, 01142, 01402, 00603, 01374, 00130, 00230,
   00347, 00530, 00217, 00630, 00217, 00230, 00230, 00107,
   00130, 00130, 00347, 00535, 00230, 00430, 00107, 01164,
   01577, 01164, 00223, 00174, 00430, 00130, 00716, 00716,
   00274, 01467, 01402, 00634, 00174, 00330, 00330, 00577,
   01402, 00637, 00174, 00330, 00430, 00573, 01042, 01342,
   00643, 00174, 00230, 00567, 00130, 00330, 01164, 01637,
   00751, 00117, 00174, 00130, 00130, 01374, 01020, 01374,
   00530, 00130, 01174, 00202, 01030, 01174, 01042, 00127,
   01374, 00630, 01007, 01374, 00730, 01007, 00174, 00730,
   00330, 00274, 00133, 01165, 00430, 00730, 00430, 00107,
   01165, 00430, 00230, 00430, 00107, 00374, 00230, 00430,
   00130, 01020, 00274, 00130, 00530, 00174, 00227, 01311,
   00107, 01311, 00742, 00742, 00742, 00107, 01311, 01263,
   01311, 01257, 01164, 01037, 01402, 00631, 00174, 00330,
   00230, 00577, 00274, 00230, 00230, 00174, 00755, 00107,
   00751, 00274, 00133, 01230, 01416, 00362, 01374, 01112,
   00706, 00706, 00232, 00272, 01374, 00652, 01513, 00374,
   00246, 00107, 00652, 01537, 00130, 00430, 01477, 00652,
   01563, 00130, 00530, 01477, 00230, 01553, 00000, 00000,
   00743, 00777, 01043, 01057, 01073, 01117, 01143, 01213,
   01727, 01403, 01237, 01273, 01303, 01247, 01353, 00751,
   00274, 00077, 00652, 00742, 00220, 00374, 00230, 00330,
   00130, 01147, 01164, 01627, 01164, 00523, 00236, 00072,
   01574, 00342, 00630, 01574, 00342, 01142, 00272, 01174,
   00706, 00706, 00706, 00232, 00012, 01474, 01430, 00667,
   01253, 01373, 01403, 01413, 01277, 01423, 01443, 01477,
   01517, 01533, 01313, 01327, 01343, 01357, 01553, 00130,
   00230, 00274, 01064, 00077, 00730, 00330, 01474, 01030,
   01474, 01402, 00177, 01156, 01402, 00507, 01156, 01402,
   00514, 01374, 00730, 00330, 01474, 01156, 01156, 01402,
   00472, 00427, 01074, 00130, 00330, 01474, 01042, 00174,
   00232, 00706, 00706, 00706, 00232, 01064, 00347, 00475,
   00430, 00274, 01064, 00353, 00475, 00330, 00447, 01374,
   01730, 01730, 00330, 01020, 01474, 01030, 01474, 01402,
   00210, 01142, 01142, 01402, 00546, 01374, 00730, 00230,
   01474, 01156, 01156, 01402, 00472, 00427, 00274, 00230,
   00530, 00174, 00130, 00230, 01657, 01474, 01402, 00620,
   01142, 01402, 00574, 01142, 01402, 00571, 01374, 01064,
   00220, 01112, 01112, 00733, 00174, 00652, 00220, 00174,
   00130, 00230, 01637, 00174, 00130, 00130, 01637, 00374,
   00230, 00330, 00430, 00130, 00230, 00430, 01374, 01020,
   01074, 01502, 00303, 00716, 00652, 00652, 00174, 01064,
   00220, 00174, 00530, 01207, 00174, 00630, 01207, 00174,
   00730, 01064, 00567, 00274, 00130, 00530, 00174, 00230,
   00230, 01657, 00130, 00230, 01374, 01064, 00117, 00730,
   00330, 01657, 00330, 00130, 01657, 00330, 00230, 01657,
   00330, 00330, 01657, 00330, 00430, 01657, 01064, 00777,
   01064, 01043, 01064, 01057, 00230, 00230, 00274, 00447,
   00374, 00230, 00430, 00130, 00430, 00230, 01303, 00374,
   00130, 00330, 01457, 00374, 00230, 01507, 00374, 00230,
   00230, 01457, 00130, 00230, 00274, 01064, 00467, 00174,
   00102, 00642, 00102, 01374, 01020, 00230, 00430, 00274,
   00130, 00530, 01657, 00374, 00742, 01713, 01730, 00232,
   00432, 01020, 01142, 00372, 00274, 00330, 01674, 00330,
   00372, 01677, 01374, 00464, 00757, 00000, 00000, 00000,
   00464, 00713, 00464, 00677, 01152, 01352, 01011, 01750,
   01020, 00574, 00730, 01474, 00742, 00742, 00123, 01074,
   01342, 01026, 00416, 00037, 01142, 00037, 00130, 00030,
   00037, 00001, 01356, 01037, 00021, 01364, 01603, 00011,
   00256, 00001, 00216, 01750, 00167, 00624, 01277, 00604,
   00574, 00130, 00130, 01630, 00714, 01160, 01074, 01406,
   01275, 00232, 00410, 00372, 00070, 00232, 00713, 00410,
   00372, 00232, 00410, 00733, 00420, 01074, 00232, 00402,
   00032, 01132, 00246, 00732, 00732, 00246, 00732, 00732,
   00246, 01522, 01102, 00132, 00011, 01356, 01277, 00410,
   00001, 01556, 01127, 00574, 00130, 00130, 01630, 00232,
   00510, 00232, 01074, 01602, 01502, 01211, 00242, 01474,
   01402, 01213, 00132, 00410, 00510, 00774, 00720, 00720,
   01152, 00633, 00620, 00510, 01160, 00372, 00410, 00070,
   00372, 00132, 00724, 01261, 01502, 01215, 00620, 01002,
   01502, 01251, 00412, 00752, 01344, 01202, 00752, 00620,
   00620, 00763, 00256, 00714, 00614, 01234, 01356, 01564,
   01753, 00002, 00613, 00704, 00613, 00720, 00720, 01354,
   01164, 00412, 00752, 01542, 01226, 01156, 01156, 00410,
   00232, 00410, 01074, 01602, 01502, 01245, 00242, 01474,
   01402, 01247, 00132, 01074, 00663, 00002, 01213, 00704,
   01213, 00720, 00734, 01215, 00132, 00232, 00410, 00232,
   01337, 00132, 00232, 00410, 00232, 01302, 01067, 00720,
   00720, 00752, 01412, 01265, 00227, 00704, 00307, 00664,
   01507, 00432, 00420, 01172, 00012, 01344, 01312, 00652,
   00620, 01427, 00732, 00732, 00174, 00202, 00474, 01630,
   01230, 01230, 01430, 01230, 00232, 00072, 00114, 00214,
   00310, 00210, 01714, 01724, 01332, 01414, 00314, 00324,
   01342, 01404, 00314, 00334, 01350, 01434, 01352, 01663,
   01434, 01354, 01734, 01342, 01414, 00310, 01020, 00520,
   00520, 00520, 00520, 00520, 00520, 01020, 00730, 01056,
   01356, 01277, 00232, 00464, 00511, 01020, 01334, 01405,
   00335, 00624, 01543, 00226, 00037, 00431, 01166, 01174,
   00706, 00742, 00113, 00726, 00720, 00254, 01411, 00742,
   00113, 00167, 01142, 00754, 01430, 00704, 00416, 00173,
   00724, 01433, 00662, 00620, 01666, 00606, 00266, 00620,
   01106, 01366, 01444, 00501, 00610, 00070, 01574, 00402,
   00734, 01456, 00742, 00634, 01456, 00742, 01360, 00634,
   01465, 01674, 00706, 00706, 00706, 00464, 00127, 00710,
   00372, 01411, 01574, 01342, 01502, 00704, 01142, 01342,
   01502, 00604, 00332, 00416, 00420, 01020, 01124, 01512,
   00710, 01310, 01114, 01304, 01411, 00432, 00276, 00423,
   01410, 00172, 00016, 00520, 00136, 00226, 00616, 00774,
   01542, 01540, 01156, 00620, 00624, 01530, 00726, 00543,
   00226, 00116, 01020, 00174, 00706, 01421, 00216, 00256,
   01410, 01352, 01555, 00412, 01216, 00501, 01445, 00244,
   01444, 00610, 00464, 00107, 01411, 01324, 01600, 00431,
   00774, 00130, 00272, 01106, 00016, 00604, 00704, 00223,
   00335, 00624, 01621, 01366, 01631, 01674, 00226, 00266,
   00406, 01366, 01621, 01274, 00730, 01422, 01621, 00710,
   00763, 01115, 00327, 00710, 00016, 00624, 01630, 01116,
   01020, 00451, 00743, 01324, 01640, 00704, 00016, 00027,
   00335, 00704, 01115, 00634, 01444, 01421, 00223, 01334,
   01672, 00335, 01410, 00624, 01665, 01366, 01444, 01262,
   00420, 01121, 00316, 00610, 00327, 01421, 00212, 01252,
   00252, 00633, 00710, 01366, 01465, 01410, 01262, 00000,
   00464, 00003, 00464, 00677, 01674, 01646, 01646, 01646,
   01020, 01566, 01714, 00432, 01410, 00774, 01352, 01725,
   01156, 00752, 01152, 01533, 00756, 01020, 00552, 01553,
   00432, 01573, 00406, 01146, 00412, 00620, 00620, 01020,
   00314, 00334, 01747, 00604, 01314, 00464, 01003, 00664,
   01071, 01627, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 01460, 00602,
   00256, 01160, 00070, 01474, 00276, 00216, 00732, 00732,
   00132, 01152, 00077, 00720, 00720, 00732, 00732, 01152,
   00057, 00412, 00752, 00720, 01706, 01706, 00132, 00446,
   00232, 01360, 00321, 01074, 01602, 01502, 00047, 00242,
   01474, 01042, 01542, 00053, 01215, 00464, 01003, 01474,
   01502, 00053, 01116, 00156, 00474, 00006, 00520, 00520,
   00132, 01116, 00232, 00003, 00464, 00677, 01152, 01074,
   00357, 00720, 00720, 01152, 00347, 01160, 00372, 00070,
   00232, 00706, 00706, 01672, 01672, 00410, 00132, 01074,
   01602, 01502, 00161, 00242, 01474, 00232, 01402, 00172,
   00232, 01102, 00410, 00232, 01160, 00232, 00070, 00232,
   01264, 01675, 01264, 01675, 00474, 00106, 01474, 01424,
   00211, 00742, 01160, 00232, 01360, 00510, 01424, 00152,
   01116, 00437, 00232, 01074, 00030, 01630, 00232, 01414,
   00437, 01474, 01502, 00121, 01074, 00002, 01474, 01102,
   01404, 00507, 01160, 01112, 01512, 00207, 00432, 01360,
   00321, 01065, 01205, 01065, 01215, 00464, 00123, 00372,
   00777, 01074, 00130, 00030, 00613, 01152, 01352, 00222,
   01750, 01020, 00574, 00730, 01474, 00742, 00742, 01177,
   01074, 01342, 00235, 00416, 01103, 00130, 01103, 01142,
   01103, 00464, 00713, 01205, 00356, 00432, 01650, 00356,
   01750, 01020, 01516, 00255, 01663, 01314, 01410, 00432,
   00574, 00230, 00130, 00130, 01616, 01613, 00516, 00574,
   00130, 00030, 00530, 00216, 01416, 00344, 00216, 01616,
   00416, 01474, 00730, 00420, 00766, 01410, 01616, 01417,
   00516, 00420, 01474, 01502, 00317, 00516, 01166, 00026,
   01126, 01066, 01772, 01772, 01772, 00732, 00732, 00202,
   01074, 01334, 00334, 00642, 00321, 01356, 00342, 01074,
   01046, 01637, 00664, 01507, 00216, 01304, 01403, 01546,
   00354, 00752, 01052, 01613, 00724, 00665, 01205, 00124,
   00365, 00224, 00365, 00432, 01650, 00216, 00664, 01567,
   00710, 00372, 01324, 00616, 00321, 01174, 01342, 00405,
   00404, 01142, 01342, 00405, 00604, 01410, 00016, 01610,
   00416, 01474, 01230, 01416, 00505, 00332, 00116, 00424,
   00456, 01512, 00444, 00416, 01074, 00742, 01416, 00455,
   00456, 01416, 00452, 00435, 01352, 00437, 00720, 00471,
   00022, 01512, 00476, 01053, 00116, 00156, 00656, 00516,
   00267, 00157, 01156, 00256, 00157, 00404, 00116, 00435,
   00471, 00624, 00554, 01352, 00470, 01410, 01216, 01152,
   00216, 01674, 00706, 00706, 00706, 01073, 01376, 00455,
   01672, 00756, 01556, 00500, 01063, 00016, 00067, 00710,
   00422, 00774, 00620, 01116, 00453, 01020, 00032, 00246,
   00536, 00006, 00236, 01362, 00543, 00434, 00551, 00756,
   01352, 00542, 01152, 01552, 00541, 00710, 00272, 00022,
   00637, 00752, 01776, 00276, 00420, 01106, 00256, 01410,
   01020, 00756, 00620, 00613, 00356, 00652, 01116, 01074,
   00416, 00330, 01616, 00713, 00516, 01756, 01616, 00733,
   00516, 00316, 00774, 00767, 01102, 01116, 01003, 00317,
   00662, 01410, 01156, 00620, 00420, 00642, 00763, 00767,
   00662, 01116, 01516, 00610, 00420, 01116, 00420, 00432,
   00222, 00262, 00652, 01253, 01112, 01322, 00631, 00774,
   00430, 01274, 00620, 01122, 01153, 00742, 00244, 00655,
   00720, 00244, 00655, 00720, 00244, 00655, 00720, 00742,
   00742, 01167, 01674, 00630, 01123, 00262, 00372, 00016,
   00614, 00414, 01020, 01264, 00361, 00464, 00711, 01314,
   01114, 00424, 00357, 00124, 00710, 00224, 00710, 00204,
   00432, 01650, 00216, 01750, 00464, 01003, 00464, 00167,
   00132, 01670, 01574, 01542, 00723, 00374, 01542, 00723,
   00274, 01342, 01305, 00374, 00464, 00757, 00464, 00451,
   00464, 00117, 01464, 01253, 01664, 01047, 00764, 00003,
   01764, 01637, 00764, 01677, 01460, 01060, 00464, 00451,
   01627, 01060, 01563, 01060, 01573, 01060, 01533, 00404,
   01060, 01603, 01060, 01613, 01060, 01317, 01060, 01553,
   01060, 00000, 01060, 01264, 00363, 01060, 01433, 01060,
   01264, 01773, 01364, 01157, 01364, 01237, 01364, 00723,
   00601, 00716, 00716, 00674, 00720, 01112, 00063, 01020,
   00041, 01342, 00726, 00464, 00117, 00041, 00402, 01750,
   00117, 00041, 00130, 00137, 00432, 01160, 01750, 00601,
   01556, 01045, 01074, 00130, 01730, 00412, 01556, 01056,
   01007, 00032, 01160, 00232, 01360, 00232, 01156, 00247,
   01007, 00601, 01356, 01075, 00412, 00216, 00416, 01474,
   00630, 01416, 01045, 00574, 00513, 01474, 00630, 00227,
   00710, 01110, 01110, 01110, 00464, 00003, 01030, 01474,
   01402, 01031, 01142, 01402, 01061, 01142, 01402, 01034,
   01564, 01647, 00464, 00757, 01030, 01474, 01402, 01025,
   01142, 01402, 01224, 01142, 01402, 01201, 01564, 01657,
   00464, 00677, 01030, 01474, 01402, 01020, 00601, 01174,
   00230, 00743, 01130, 01474, 01402, 01206, 01142, 01402,
   01203, 00601, 01174, 00130, 00743, 00601, 01174, 00402,
   01710, 01610, 00732, 00732, 00732, 00732, 00174, 00202,
   01750, 00464, 00123, 00601, 00422, 01003, 00601, 00422,
   01063, 00601, 00422, 00762, 00762, 01003, 00710, 01310,
   00464, 00417, 00432, 01103, 01251, 01114, 00124, 01236,
   00224, 01237, 00432, 01650, 00664, 01567, 00214, 01314,
   01275, 01556, 01247, 01572, 01237, 00214, 01527, 01352,
   00755, 01163, 00416, 01074, 00230, 01160, 01020, 01670,
   00272, 01770, 01405, 01405, 01152, 01337, 00412, 01405,
   01574, 01646, 01646, 01646, 01750, 00232, 01650, 00232,
   01020, 01772, 00222, 00732, 01020, 00464, 00451, 00272,
   01670, 01405, 00652, 01405, 01405, 00116, 00232, 01750,
   01670, 01374, 00206, 00232, 01650, 00464, 00167, 00202,
   01074, 00430, 01074, 01402, 01161, 00633, 00432, 01020,
   00420, 00412, 00256, 01474, 00642, 00310, 01502, 01360,
   01074, 01230, 01074, 01402, 01357, 00716, 00003, 01474,
   01102, 00416, 01160, 01430, 01474, 01402, 00777, 01142,
   01142, 01402, 01441, 01764, 00220, 00000, 00000, 00000,
   01767, 00253, 00263, 00273, 00303, 00313, 00327, 00323,
   00357, 00353, 00563, 00603, 00613, 00627, 00404, 00177,
   01767, 00223, 00233, 00243, 01527, 01133, 01223, 01563,
   01473, 01263, 00643, 00663, 00703, 00723, 00404, 01564,
   01317, 00652, 00742, 00220, 01664, 00147, 01664, 00127,
   01664, 00103, 01664, 00433, 01664, 00523, 01664, 00613,
   01664, 00653, 01664, 00727, 00404, 00371, 01611, 00070,
   00464, 00003, 00404, 00371, 01360, 00343, 00216, 00016,
   01474, 00202, 00416, 00434, 01513, 01474, 00530, 01474,
   01416, 01532, 01230, 00420, 00516, 01601, 01356, 01523,
   00412, 01416, 01073, 00216, 01160, 00070, 00232, 00710,
   01410, 01020, 01330, 00457, 00371, 01262, 01564, 01713,
   00371, 00573, 00371, 01564, 01723, 00371, 01564, 01733,
   01402, 01216, 00741, 00567, 01402, 01004, 00741, 00573,
   01402, 01006, 00741, 00617, 01402, 01222, 00741, 00633,
   01770, 00422, 01665, 01156, 01552, 01613, 01556, 01073,
   00272, 00432, 00774, 00230, 01432, 01620, 00732, 00732,
   00520, 00404, 00413, 00272, 00016, 00732, 00520, 00467,
   01632, 01532, 01073, 01474, 01730, 00523, 01402, 01100,
   01656, 00371, 00370, 00272, 01124, 01640, 00710, 01310,
   00232, 01310, 00170, 00343, 01402, 01650, 00741, 00333,
   01770, 00232, 00710, 00333, 01402, 00757, 01770, 01665,
   01562, 01677, 01556, 01673, 00272, 00732, 00520, 01601,
   01770, 01664, 00743, 00432, 00774, 01130, 01323, 00272,
   00432, 01274, 00420, 01130, 00630, 01516, 01712, 01426,
   01712, 01457, 00266, 01772, 00626, 01323, 01402, 01722,
   00741, 00363, 01770, 00710, 00363, 01402, 01002, 01410,
   00710, 01611, 01564, 01767, 01402, 00760, 01564, 01743,
   00464, 00677, 00710, 01124, 01746, 01310, 01020, 00416,
   01160, 00741, 01360, 00232, 00343, 00272, 00774, 01410,
   01552, 01336, 00756, 01356, 01772, 01156, 00726, 00620,
   01526, 01763, 00406, 00216, 01020, 00464, 00117, 01053
};
