/*
 * x11-calc-37e.c - RPN (Reverse Polish) calculator simulator.
 *
 * Copyright(C) 2018   MT
 *
 * Model specific functions.
 *
 * This  program is free software: you can redistribute it and/or modify it
 * under  the terms of the GNU General Public License as published  by  the
 * Free  Software Foundation, either version 3 of the License, or (at  your
 * option) any later version.
 *
 * This  program  is distributed in the hope that it will  be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without even   the   implied   warranty   of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You  should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 02 Dec 21         - Initial version - MT
 * 06 Dec 21         - Label text colour now explicitly defined - MT
 * 03 Jan 21         - Changed debug() macro so that debug code is executed
 *                     when DEBUG is defined (doesn't need to be true) - MT
 * 11 Jan 22         - Removed ROM_BANKS - MT
 * 12 Jan 22         - Added mode switch - MT
 * 14 Jan 22         - Added keyboard shortcuts for 'n' and 'i' - MT
 * 12 Feb 22         - Updated layout and separated the initialisation code
 *                     for buttons and switches into two functions - MT
 * 21 Oct 23         - Updated switch parameters to accomodate a 3 position
 *                     switch - MT
 *
 */

#define NAME           "x11-calc-137e"
#define BUILD          "0008"
#define DATE           "12 Oct 23"
#define AUTHOR         "MT"

#include <stdarg.h>    /* strlen(), etc. */
#include <stdio.h>     /* fprintf(), etc. */
#include <stdlib.h>    /* getenv(), etc. */

#include <X11/Xlib.h>  /* XOpenDisplay(), etc. */
#include <X11/Xutil.h> /* XSizeHints etc. */

#include "x11-calc-font.h"
#include "x11-calc-button.h"
#include "x11-calc-switch.h"
#include "x11-calc-label.h"
#include "x11-calc-colour.h"

#include "x11-calc-cpu.h"

#include "x11-calc.h"

#include "gcc-debug.h"

oregister o_mem[MEMORY_SIZE];

void v_init_switches(oswitch *h_switch[]) /* Define the switches. */
{
   /* Define the switches. */
   h_switch[0] = h_switch_create(00000, "OFF", "", "ON ", h_alternate_font, KBD_LEFT, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
   h_switch[1] = h_switch_create(00000, "BEGIN", "", "END", h_alternate_font, KBD_LEFT + 3 * KEY_WIDTH + 2 * KEY_GAP, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
}

void v_init_buttons(obutton *h_button[]) {
   int i_left, i_top;

   /* Define top row of keys. */
   i_top = KBD_TOP + 2* (SWITCH_HEIGHT + 1); /* Assumes the function label and switch text use the same font */
   i_left = KBD_LEFT;
   h_button[0] = h_button_create(00064, 'n', "n", "12\xd7", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[1] = h_button_create(00063, 'i', "i", "12\xf7", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[2] = h_button_create(00062, 000, "PV", "1/x", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[3] = h_button_create(00061, 000, "PMT", "V\xaf", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[4] = h_button_create(00060, 000, "FV", "yX", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define second row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[5] = h_button_create(00224, 000, "STO", "eX", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[6] = h_button_create(00223, 000, "RCL", "ln", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[7] = h_button_create(00222, '%', "%", "d%", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[8] = h_button_create(00221, 000, "%T", "PRICE", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[9] = h_button_create(00220, 'f', "f", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, YELLOW, BACKGROUND, YELLOW, YELLOW);

   /* Define third row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[10] = h_button_create(00163, 015, "ENTER", "AMORT", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, 2 * KEY_WIDTH + KEY_GAP, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += 2 * (KEY_WIDTH + KEY_GAP);
   h_button[11] = h_button_create(00162, 'c', "CHS", "CL FIN", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[12] = h_button_create(00161, 'e', "X-Y", "Rv", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[13] = h_button_create(00160, 033, "CLx", "CL ALL", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define fourth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[14] = h_button_create(00243, '-', "-", "x", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[15] = h_button_create(00242, '7', "7", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[16] = h_button_create(00241, '8', "8", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[17] = h_button_create(00240, '9', "9", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define fifth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[18] = h_button_create(00143, '+', "+", "s", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[19] = h_button_create(00142, '4', "4", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[20] = h_button_create(00141, '5', "5", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[21] = h_button_create(00140, '6', "6", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define sixth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[22] = h_button_create(00323, '*', "\xd7", "y,r", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[23] = h_button_create(00322, '1', "1", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[24] = h_button_create(00321, '2', "2", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[25] = h_button_create(00320, '3', "3", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define bottom row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[26] = h_button_create(00103, '/', "\xf7", "n!", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[27] = h_button_create(00102, '0', "0", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[28] = h_button_create(00101, '.', "\xb7", "", "", "", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[29] = h_button_create(00100, 000, "E+", "E-", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
}

int i_rom[ROM_SIZE] = {
   00310, 00656, 00656, 01710, 01074, 00221, 00742, 01160,
   01260, 00432, 01160, 00574, 01530, 01260, 01050, 00010,
   00110, 00114, 01445, 00610, 00432, 01160, 00710, 00234,
   00263, 01264, 01643, 00034, 00020, 00110, 00004, 00107,
   00000, 00000, 00000, 01460, 00742, 01160, 01260, 01020,
   00032, 01610, 00266, 00410, 00510, 00774, 00422, 00620,
   01116, 00277, 00544, 00077, 01552, 00115, 01156, 00353,
   00016, 00507, 00344, 00075, 00620, 00762, 00333, 00510,
   00422, 01074, 01352, 00105, 01206, 01674, 00272, 00706,
   00706, 00706, 01104, 00574, 00563, 00016, 01672, 00756,
   00473, 00072, 00146, 00132, 00472, 01536, 00137, 01566,
   00077, 01522, 01771, 00262, 00420, 01106, 01020, 00006,
   01532, 00131, 00620, 00132, 00507, 00604, 00724, 00264,
   00716, 00716, 00710, 01715, 01174, 00642, 00713, 00706,
   00720, 00667, 01102, 00744, 00264, 01144, 00172, 00624,
   00172, 00662, 00172, 00620, 00620, 01106, 00132, 00520,
   00774, 01676, 00262, 01410, 01536, 00256, 00032, 00232,
   00132, 01257, 00710, 00372, 00432, 01134, 00221, 01674,
   00630, 00222, 00262, 00774, 01322, 00231, 00430, 01274,
   00620, 01162, 01143, 00742, 00244, 01015, 00720, 00244,
   01015, 00720, 00244, 01015, 00720, 00742, 00742, 01157,
   01366, 00264, 01262, 00014, 00610, 01323, 01502, 00207,
   01116, 00726, 01273, 00241, 00224, 00031, 01051, 00016,
   01414, 01410, 00310, 00210, 01714, 01724, 00274, 01734,
   00277, 00310, 00754, 00400, 00710, 00434, 00033, 01264,
   00773, 00774, 01366, 00376, 01410, 01352, 00324, 01156,
   00752, 01152, 01527, 00756, 01020, 00552, 01547, 01274,
   01773, 00406, 01146, 00412, 00214, 01274, 01020, 00274,
   00432, 00214, 00420, 01172, 00072, 00720, 00752, 00154,
   00345, 01630, 01230, 01230, 01430, 01230, 00232, 00732,
   00732, 00732, 01337, 00420, 00724, 00377, 00024, 00371,
   01310, 01114, 00704, 00036, 01126, 00114, 00432, 01020,
   01064, 00003, 00630, 01130, 00330, 00130, 00430, 00730,
   00130, 01030, 00030, 00530, 00530, 01146, 00774, 01020,
   00072, 00126, 00410, 00510, 00416, 00062, 00422, 00774,
   00410, 01074, 00620, 00652, 00752, 00254, 00432, 00372,
   01372, 00502, 00410, 00132, 01372, 00502, 01456, 00606,
   01022, 01522, 00454, 00343, 01232, 00262, 01456, 00470,
   00410, 00232, 00732, 00232, 00410, 00132, 01116, 00132,
   01456, 00502, 00656, 01772, 00222, 00262, 00620, 01154,
   00470, 00032, 00232, 00510, 00372, 00472, 01152, 01152,
   01152, 00232, 00410, 00510, 01362, 00520, 00656, 01772,
   00232, 00774, 01506, 00550, 00372, 00232, 00774, 00272,
   00556, 00633, 00766, 00633, 00316, 00756, 00742, 00322,
   00132, 01566, 00545, 00432, 00022, 01020, 00316, 00577,
   01502, 00524, 01156, 00706, 00643, 00072, 00126, 00410,
   00510, 00416, 00062, 00422, 00410, 00616, 01062, 00747,
   01222, 00032, 00410, 01274, 00720, 01672, 01003, 00472,
   01142, 00777, 00254, 00574, 00510, 00447, 00410, 00132,
   01456, 00613, 00233, 00232, 00410, 01432, 00622, 00410,
   00232, 00243, 00410, 00232, 00410, 00132, 00243, 00072,
   00126, 00410, 00510, 00416, 00062, 00422, 01366, 00337,
   00410, 01056, 01062, 01227, 01222, 00410, 00232, 00132,
   01472, 00656, 00410, 00732, 01156, 00410, 00774, 00432,
   01313, 00742, 01032, 01307, 00472, 00732, 00620, 01154,
   00662, 00232, 00510, 00523, 00072, 00366, 00232, 00432,
   00410, 00432, 00774, 00130, 00372, 00232, 00410, 00232,
   01163, 00432, 01262, 00774, 00130, 00113, 00432, 01457,
   00032, 00774, 01610, 00344, 00762, 00620, 01116, 01517,
   00272, 00516, 01717, 00256, 00720, 01144, 00376, 00656,
   01563, 01637, 00620, 00344, 00762, 01116, 01613, 00072,
   00146, 00466, 01703, 00022, 00662, 00756, 01672, 00620,
   00006, 00226, 01020, 00256, 01617, 00372, 00410, 01070,
   00266, 00166, 01726, 01726, 01726, 00374, 00346, 00356,
   01050, 00570, 00372, 00670, 00550, 00770, 00650, 00226,
   01772, 01772, 01772, 00362, 00410, 00372, 01020, 00570,
   00222, 00774, 00346, 00550, 01070, 01674, 00706, 00706,
   00706, 00206, 00216, 01050, 00273, 00670, 00750, 00570,
   00650, 00332, 00222, 00262, 00550, 01070, 00226, 00474,
   00706, 00706, 00706, 00226, 01050, 00206, 01646, 01646,
   01646, 01020, 00614, 01014, 00062, 00232, 00272, 00556,
   00603, 01522, 01146, 00232, 00411, 00774, 00232, 00436,
   00272, 00537, 00132, 00172, 00410, 00510, 01672, 01532,
   01114, 00510, 00232, 01020, 00756, 00433, 00774, 00642,
   00132, 00164, 01243, 00644, 01143, 00620, 00762, 00756,
   00517, 00132, 01113, 00072, 00366, 00232, 00604, 00317,
   00164, 01471, 00767, 00132, 00372, 01623, 01004, 00367,
   00774, 00332, 01142, 00232, 01532, 01157, 01527, 01502,
   01164, 01156, 00732, 00677, 00410, 00505, 00367, 00072,
   00366, 00232, 00604, 01326, 01757, 01014, 00062, 01522,
   00337, 01326, 00337, 00216, 00256, 01356, 01150, 00516,
   01057, 01256, 01004, 00036, 00236, 00032, 00774, 01006,
   01142, 00742, 00172, 00410, 00510, 01137, 01672, 01162,
   01133, 00510, 00472, 01122, 01107, 00762, 00132, 00732,
   00620, 01254, 01222, 00232, 00172, 00706, 00706, 00706,
   00232, 01474, 00730, 01216, 01316, 01343, 01374, 01672,
   00372, 00364, 00671, 00372, 01705, 01366, 01316, 01154,
   01257, 00072, 01474, 00142, 00472, 01672, 00372, 00364,
   00571, 01024, 01310, 00132, 01032, 00132, 00472, 00132,
   01174, 01705, 01366, 01316, 01672, 01447, 01522, 01351,
   01156, 00436, 01034, 01325, 01262, 00164, 00505, 00634,
   01366, 00164, 01725, 00164, 00711, 00510, 01362, 01421,
   01116, 00372, 01573, 01672, 00364, 01371, 00132, 01374,
   01307, 01672, 01507, 00072, 00366, 00232, 00614, 00767,
   00472, 01142, 01703, 00402, 00756, 00720, 01020, 01374,
   00330, 00330, 00330, 00030, 01030, 00330, 00530, 01574,
   01020, 00330, 00130, 00030, 00130, 00730, 01130, 01030,
   00030, 00430, 00330, 00230, 00474, 01020, 00072, 00366,
   00232, 01004, 01522, 01425, 01014, 00036, 00132, 00332,
   00556, 00233, 00332, 01522, 01451, 01274, 00620, 01244,
   01625, 00756, 00173, 00671, 00372, 01057, 00571, 01374,
   00273, 00132, 00656, 01732, 00127, 00766, 01032, 00267,
   00472, 00732, 01156, 00367, 01674, 01342, 01473, 01142,
   01542, 01502, 00742, 00774, 01117, 00232, 00726, 00232,
   01342, 01456, 00432, 00774, 01146, 00272, 00574, 00130,
   01034, 01513, 01256, 00132, 00272, 00134, 01525, 00264,
   00165, 00164, 01445, 00264, 00075, 00132, 00164, 00527,
   00574, 00330, 00330, 00330, 00274, 01020, 00774, 00230,
   00330, 00030, 00230, 00530, 01030, 00530, 00030, 01130,
   00230, 01130, 01130, 00430, 00372, 01020, 00432, 00244,
   00402, 01166, 00430, 00766, 01544, 01401, 00444, 01743,
   00144, 01367, 01644, 01602, 00644, 01530, 01474, 00330,
   01374, 01020, 00174, 00330, 00330, 00330, 00330, 00130,
   00374, 01020, 00742, 01032, 01053, 00472, 00644, 01626,
   00732, 01156, 00620, 00372, 00217, 00372, 00134, 01633,
   01371, 00232, 00132, 01274, 00630, 01674, 01366, 01724,
   00720, 01342, 01650, 01142, 00172, 00410, 00510, 01343,
   00756, 01672, 01162, 01173, 01772, 01772, 01772, 00642,
   00132, 00272, 01034, 01515, 00164, 01375, 00467, 01732,
   01162, 01337, 00472, 00662, 00510, 01207, 00410, 00510,
   00172, 00372, 00572, 00572, 00632, 00132, 01772, 01572,
   01714, 00510, 00232, 01020, 00656, 01433, 01232, 00422,
   00410, 00756, 00164, 01227, 00132, 00436, 00272, 01034,
   01734, 01262, 00264, 00411, 00134, 01740, 00264, 00165,
   00164, 01471, 00527, 00374, 00330, 00330, 00030, 01030,
   00530, 00330, 00130, 00630, 01030, 00674, 01020, 00164,
   01725, 01366, 00337, 00510, 01562, 00337, 00032, 00072,
   00467, 00762, 00620, 01672, 00064, 00557, 00000, 00116,
   00707, 01757, 00123, 00577, 01204, 00415, 00531, 00264,
   00555, 00270, 01315, 00245, 00370, 01315, 00111, 00401,
   00450, 00203, 00164, 01727, 00411, 00531, 00264, 00555,
   00470, 01315, 00245, 00370, 01315, 00111, 00401, 00250,
   01262, 00764, 00405, 00064, 01445, 01360, 00110, 00064,
   00113, 00264, 00075, 00531, 01224, 00057, 01262, 01366,
   00064, 00164, 01145, 00353, 00432, 01160, 00070, 00072,
   00366, 00232, 01334, 01506, 00521, 00531, 01315, 00111,
   00164, 00127, 01214, 00314, 01414, 01514, 01614, 01304,
   00334, 00113, 01314, 00432, 01160, 00070, 01224, 00121,
   01262, 00072, 00366, 00232, 00264, 00167, 00170, 01156,
   01156, 01362, 01506, 01552, 01506, 00574, 01337, 00411,
   00531, 00264, 00555, 00470, 01315, 00270, 00164, 00111,
   00245, 01366, 00135, 00671, 00350, 00203, 00111, 00164,
   01423, 00411, 00270, 01131, 01165, 01362, 00202, 01366,
   00202, 01204, 00470, 01262, 01131, 01165, 01366, 00202,
   01562, 00135, 00264, 00311, 01234, 00211, 00232, 01262,
   00232, 00521, 00531, 00072, 00366, 00232, 00264, 00311,
   00671, 00410, 00432, 01160, 00510, 00207, 00232, 00531,
   00164, 00665, 00521, 00370, 00337, 00111, 00401, 00521,
   00270, 00232, 00470, 00164, 00101, 00111, 01224, 00253,
   00410, 01262, 00410, 01366, 00135, 00164, 01161, 00410,
   00531, 01366, 00222, 00164, 00677, 01460, 01674, 00064,
   01603, 00174, 01337, 00774, 00272, 01552, 00316, 00726,
   00620, 01526, 00313, 00406, 00216, 00410, 00416, 01156,
   00222, 00164, 00507, 01156, 01377, 01417, 00432, 00410,
   00232, 01020, 00072, 00366, 00232, 00664, 01577, 00432,
   00530, 01162, 00766, 01474, 00330, 01216, 00164, 00111,
   01362, 00135, 00432, 00130, 00050, 00432, 01160, 00070,
   01366, 00135, 00164, 01361, 00521, 00564, 01151, 01262,
   00262, 00521, 00564, 01221, 01326, 00135, 00671, 00264,
   00751, 00664, 01157, 00411, 00564, 01121, 00070, 01562,
   00135, 01315, 01366, 00345, 01121, 01362, 00327, 01315,
   01215, 01145, 00750, 00670, 01535, 01262, 01525, 00550,
   00670, 01262, 00232, 00770, 01255, 01366, 00135, 01341,
   01366, 01237, 01362, 00435, 01604, 01121, 01401, 00550,
   00670, 01326, 00135, 01345, 01562, 00453, 01366, 00453,
   01545, 00150, 00303, 01404, 01221, 01326, 00135, 01341,
   00610, 00210, 00024, 00465, 01310, 01121, 00550, 01135,
   00570, 01362, 01070, 01522, 00477, 00222, 00617, 01331,
   01625, 00630, 01305, 00070, 01305, 01315, 01215, 01531,
   00750, 01145, 01531, 01424, 00516, 00650, 00770, 01331,
   01262, 00750, 01562, 00543, 01625, 00070, 00164, 01361,
   00070, 01262, 01535, 01625, 00330, 01305, 01471, 00670,
   01434, 00573, 01305, 01434, 00574, 01562, 00550, 00610,
   00710, 01545, 00150, 00550, 01121, 00104, 01605, 00170,
   01131, 00164, 01725, 01326, 00751, 01361, 01663, 01262,
   00272, 00710, 01257, 01345, 01562, 00577, 01545, 00550,
   01151, 00650, 00370, 01262, 01535, 00670, 01345, 00610,
   00570, 00735, 00570, 01522, 00623, 00170, 00735, 00710,
   01522, 00623, 00170, 01773, 01625, 00070, 01262, 00764,
   00737, 00650, 01624, 00646, 00470, 01334, 00651, 00272,
   00072, 00126, 01020, 00550, 01624, 00634, 00270, 01334,
   00637, 00232, 00370, 00164, 00103, 00264, 00167, 00164,
   00667, 00164, 01147, 00370, 01333, 01262, 00164, 00677,
   00570, 00410, 00510, 00416, 00164, 01423, 00464, 01527,
   00550, 01151, 00650, 01221, 00670, 01325, 01562, 00135,
   00750, 00570, 01175, 01625, 00230, 01305, 01315, 00550,
   01331, 00770, 01535, 01371, 00570, 00262, 00570, 00164,
   00113, 00550, 00114, 01625, 00230, 00272, 00070, 00164,
   01135, 01265, 00670, 00264, 00737, 00432, 01160, 00774,
   01020, 01121, 01262, 00262, 00710, 01325, 01401, 01215,
   01341, 00710, 01331, 00170, 01305, 00550, 01121, 01262,
   00262, 00164, 01375, 01265, 00670, 01615, 01175, 00104,
   00343, 01562, 01063, 01552, 01063, 00272, 00172, 00736,
   01506, 01061, 00656, 01416, 01017, 00752, 00333, 00432,
   00742, 01772, 00762, 00372, 01302, 01030, 01706, 00756,
   00032, 01602, 00173, 00732, 00472, 00163, 01622, 00227,
   01646, 00672, 00756, 00472, 00217, 00106, 01142, 00123,
   01162, 00123, 00732, 00156, 00436, 00446, 00532, 00236,
   00333, 01116, 00033, 00274, 00064, 01603, 00064, 00103,
   01321, 00210, 01311, 01321, 01341, 00264, 00751, 01321,
   00564, 01151, 01331, 00164, 00711, 01261, 01321, 01425,
   01321, 01465, 01425, 01366, 01120, 00164, 01161, 00517,
   01311, 01262, 00262, 01321, 01275, 01425, 01455, 01321,
   00564, 01221, 01331, 01455, 01321, 01425, 01366, 01227,
   01321, 01311, 01425, 01455, 01321, 01341, 01465, 01331,
   01326, 01242, 01265, 01275, 01321, 00564, 01221, 00432,
   01160, 00070, 01301, 01331, 01455, 01261, 01434, 01174,
   01321, 01311, 01331, 01455, 01562, 01322, 00432, 00774,
   00130, 00130, 00216, 00256, 00556, 01547, 00272, 00172,
   01014, 01441, 00164, 01161, 01262, 00262, 01331, 01455,
   01352, 01225, 00752, 01552, 01233, 01034, 01070, 01634,
   01233, 00164, 01375, 01465, 01262, 00756, 00756, 00150,
   00464, 00217, 01311, 00070, 01262, 01301, 00432, 00774,
   00230, 00164, 01145, 00657, 01341, 00164, 01423, 00370,
   00164, 00677, 00564, 01123, 00264, 00167, 00164, 01727,
   00670, 00374, 00372, 00410, 01070, 00620, 01772, 00354,
   01275, 00362, 00232, 00410, 01020, 00770, 00474, 01353,
   00570, 01674, 01353, 00164, 00127, 00222, 01262, 00222,
   00164, 01473, 00416, 01004, 01074, 00130, 01056, 01047,
   01043, 01516, 01322, 00266, 01466, 01206, 01043, 00062,
   00274, 01522, 00267, 00332, 00132, 00572, 00572, 00632,
   00372, 00436, 00272, 00572, 01226, 00556, 00616, 01474,
   01542, 01363, 01732, 01772, 00216, 00432, 00132, 01274,
   00530, 01772, 00764, 00033, 00000, 00000, 00000, 00000,
   00742, 01632, 00003, 00532, 00732, 00620, 01746, 01354,
   01401, 00402, 00132, 00164, 00503, 01570, 00325, 00401,
   01310, 01370, 00325, 00064, 00103, 01211, 01055, 00241,
   00341, 01065, 00361, 01111, 00550, 01211, 01055, 01131,
   00341, 01065, 00361, 01111, 00401, 01310, 00570, 00117,
   01370, 01075, 01055, 01470, 00272, 01270, 01101, 01065,
   00410, 01262, 00410, 00164, 00127, 00072, 00366, 00232,
   01270, 00410, 00510, 00416, 01366, 00266, 00164, 01163,
   01731, 00610, 00024, 01505, 01310, 00710, 01020, 01155,
   01055, 00710, 00232, 01270, 01101, 01570, 01035, 00241,
   01021, 00264, 00075, 01370, 00613, 00241, 01055, 00710,
   00232, 01270, 01101, 01370, 01035, 01155, 01021, 00264,
   00075, 01570, 00164, 00675, 01065, 00315, 01065, 00361,
   00341, 00550, 00241, 01055, 01131, 01021, 01111, 01055,
   01155, 01065, 00361, 01731, 01310, 00570, 00117, 00072,
   00366, 00232, 00164, 01473, 01770, 00072, 00366, 00232,
   01370, 00345, 00405, 00117, 01065, 00164, 00713, 00410,
   00510, 00416, 00301, 00264, 00167, 00164, 01727, 00272,
   00164, 00667, 01522, 00266, 00464, 01527, 01570, 01075,
   01055, 01670, 00263, 01370, 00232, 01570, 01101, 01055,
   01770, 00263, 01270, 00072, 00366, 00232, 00164, 01447,
   01714, 00314, 01724, 01650, 00550, 01366, 00271, 01562,
   00271, 00464, 01355, 01566, 00271, 00270, 01741, 00250,
   00370, 01741, 00350, 00432, 00405, 01310, 00170, 01156,
   01156, 00232, 00270, 01101, 01741, 00324, 01717, 00232,
   00432, 01160, 00070, 00232, 01526, 01717, 00432, 00650,
   00232, 00370, 00222, 00710, 01721, 00610, 00670, 00232,
   00370, 01721, 00650, 01010, 01721, 01310, 00670, 00232,
   00270, 01721, 00250, 00432, 01160, 00070, 00735, 00050,
   00570, 01215, 00550, 01724, 01762, 01366, 01762, 00210,
   01362, 01676, 00710, 00117, 00164, 00101, 00064, 01447,
   00164, 01503, 00000, 00000, 00000, 00000, 00000, 00105,
   00020, 00033, 01745, 00164, 01135, 00047, 01745, 00164,
   00665, 00610, 00710, 00104, 00110, 00004, 00233, 00656,
   01524, 00271, 01424, 00332, 01324, 00201, 01224, 00033,
   00755, 00064, 00643, 01565, 00232, 00070, 00232, 01454,
   00232, 01262, 00164, 00101, 00114, 00110, 00064, 01445,
   01360, 00710, 01144, 00726, 00064, 00113, 00432, 00743,
   00656, 00656, 00656, 00656, 00416, 01611, 01324, 00202,
   00716, 01524, 00500, 01634, 00123, 01516, 00255, 01327,
   01543, 01637, 00103, 01524, 00737, 01434, 00431, 00620,
   00620, 00620, 01414, 01204, 00064, 01347, 01524, 00534,
   01164, 00103, 00642, 00134, 00013, 00464, 00220, 01110,
   01433, 01224, 00731, 01324, 00731, 01424, 00731, 00656,
   00656, 00656, 01477, 01524, 00733, 01434, 00511, 00453,
   01534, 00056, 00064, 00047, 01524, 00646, 01164, 00517,
   00643, 01357, 01407, 01524, 00310, 01424, 00543, 01310,
   00004, 00064, 00157, 00774, 01614, 01214, 01314, 01414,
   01020, 01565, 01725, 00232, 01433, 00454, 00042, 00164,
   01135, 00223, 01314, 01604, 00463, 00755, 00064, 01243,
   01243, 00663, 00473, 01453, 01524, 00504, 00114, 00755,
   01404, 00463, 01554, 00205, 00164, 00665, 00223, 00656,
   00656, 00656, 00547, 01524, 00436, 01434, 00510, 00447,
   01324, 00212, 00755, 01504, 00463, 01074, 01102, 01516,
   00122, 01725, 00164, 00665, 01433, 01725, 00164, 01135,
   01433, 01710, 00747, 01524, 00127, 01010, 01310, 00232,
   01433, 01524, 00355, 00724, 00215, 01262, 00064, 00103,
   00764, 01243, 01524, 00501, 00755, 01304, 00463, 00656,
   00656, 00656, 00077, 01524, 00735, 01434, 00515, 00443,
   01164, 01347, 01565, 01360, 01433, 00416, 01156, 01756,
   01756, 00420, 00616, 01160, 00710, 01410, 01020, 00420,
   01524, 00237, 00755, 00064, 00627, 00432, 00050, 00150,
   00250, 00350, 00450, 00710, 00747, 00024, 00370, 01310,
   00070, 00232, 00432, 00774, 00130, 00230, 00756, 01020,
   01040, 01040, 00503, 00127, 00464, 00505, 00714, 01210,
   00710, 01522, 00440, 00323, 01010, 00164, 01135, 00373,
   01156, 01156, 01210, 01711, 00373, 00114, 00464, 01511,
   00373, 01566, 00414, 00274, 00064, 01603, 00764, 00067,
   00226, 01552, 00433, 00237, 01356, 00433, 01156, 00736,
   01526, 00444, 01556, 00464, 00222, 00262, 00562, 00562,
   00622, 01362, 00464, 00704, 01210, 00022, 00232, 00114,
   00264, 00735, 01010, 00734, 00476, 01262, 00064, 00103,
   00220, 00264, 01655, 00373, 00114, 00364, 00071, 00373,
   01262, 01010, 00164, 00101, 00373, 01010, 01711, 00373,
   00164, 01361, 00373, 00072, 00366, 01210, 00232, 01156,
   01156, 00164, 01145, 00373, 01210, 00232, 01262, 00164,
   00101, 00232, 00527, 00420, 00010, 00756, 00610, 00774,
   00432, 00610, 00410, 00410, 01110, 01110, 01110, 01110,
   00372, 00132, 01710, 01710, 01116, 01532, 00642, 00432,
   00742, 01474, 01160, 01360, 00742, 00753, 01160, 00232,
   00070, 00232, 01632, 01532, 00642, 00742, 00773, 00774,
   00742, 01260, 00514, 00064, 00215, 00524, 00727, 00742,
   00464, 01325, 00524, 00727, 00742, 01225, 00524, 00727,
   01174, 00230, 00754, 00631, 00372, 01030, 00754, 00635,
   00064, 01673, 00774, 00416, 01537, 01460, 01210, 00232,
   01156, 01156, 01262, 00072, 00366, 00232, 00164, 01471,
   01366, 00433, 00710, 00410, 00510, 00416, 00164, 01421,
   00373, 00272, 01370, 01605, 00710, 01705, 01470, 01615,
   01210, 01570, 01605, 01210, 00232, 01705, 01670, 01615,
   01210, 00710, 01711, 01770, 01615, 00032, 00662, 01672,
   01270, 01605, 00610, 00710, 01034, 00170, 01374, 00610,
   00163, 01174, 00163, 00764, 00127, 00764, 00527, 00664,
   00007, 00072, 00126, 01534, 00750, 00232, 01262, 00232,
   00164, 00111, 00064, 01445, 01154, 00757, 01004, 01360,
   01020, 00272, 00164, 00667, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00247
};
