/*
 * x11-calc-38c.c - RPN (Reverse Polish) calculator simulator.
 *
 * Copyright(C) 2018   MT
 *
 * Model specific functions.
 *
 * This  program is free software: you can redistribute it and/or modify it
 * under  the terms of the GNU General Public License as published  by  the
 * Free  Software Foundation, either version 3 of the License, or (at  your
 * option) any later version.
 *
 * This  program  is distributed in the hope that it will  be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without even   the   implied   warranty   of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You  should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 04 Dec 21         - Initial version - MT
 * 06 Dec 21         - Label text colour now explicitly defined - MT
 * 03 Jan 21         - Changed debug() macro so that debug code is executed
 *                     when DEBUG is defined (doesn't need to be true) - MT
 * 11 Jan 22         - Removed ROM_BANKS - MT
 * 14 Jan 22         - Added keyboard shortcuts for 'n' and 'i' - MT
 * 12 Feb 22         - Updated layout and separated the initialisation code
 *                     for buttons and switches into two functions - MT
 * 21 Oct 23         - Updated switch parameters to accomodate a 3 position
 *                     switch - MT
 *
 */

#define NAME           "x11-calc-38c"
#define BUILD          "0007"
#define DATE           "21 Oct 23"
#define AUTHOR         "MT"

#include <stdarg.h>    /* strlen(), etc. */
#include <stdio.h>     /* fprintf(), etc. */
#include <stdlib.h>    /* getenv(), etc. */

#include <X11/Xlib.h>  /* XOpenDisplay(), etc. */
#include <X11/Xutil.h> /* XSizeHints etc. */

#include "x11-calc-font.h"
#include "x11-calc-button.h"
#include "x11-calc-switch.h"
#include "x11-calc-label.h"
#include "x11-calc-colour.h"

#include "x11-calc-cpu.h"

#include "x11-calc.h"

#include "gcc-debug.h"

oregister o_mem[MEMORY_SIZE];

void v_init_switches(oswitch *h_switch[]) /* Define the switches. */
{
   h_switch[0] = h_switch_create(00000, "OFF", "", "ON ", h_alternate_font, KBD_LEFT, KBD_TOP, 2 * KEY_NUMERIC + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
   h_switch[1] = h_switch_create(00000, "BEGIN", "", "END", h_alternate_font, KBD_LEFT + 3 * KEY_WIDTH + 2 * KEY_GAP, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
}

void v_init_buttons(obutton *h_button[]) {
   int i_left, i_top;

   /* Define top row of keys. */
   i_top = KBD_TOP + 2* (SWITCH_HEIGHT + 1); /* Assumes the function label and switch text use the same font */
   i_left = KBD_LEFT;
   h_button[0] = h_button_create(00064, 'n', "n", "AMORT", "", "12\xd7", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[1] = h_button_create(00063, 'i', "i", "INT", "", "12\xf7", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[2] = h_button_create(00062, 000, "PV", "NPV", "", "CF\xb0", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[3] = h_button_create(00061, 000, "PMT", "RND", "", "CF\xb9", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[4] = h_button_create(00060, 000, "FV", "IRR", "", "N\xb9", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define second row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[5] = h_button_create(00224, 000, "STO", "V\xaf", "", "yX", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[6] = h_button_create(00223, 000, "RCL", "%T", "", "eX", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[7] = h_button_create(00222, 000, "%", "d %", "", "LN", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[8] = h_button_create(00221, 'f', "f", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False,  YELLOW, BACKGROUND, YELLOW, YELLOW);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[9] = h_button_create(00220, 'g', "g", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_BLUE, BACKGROUND, LIGHT_BLUE, LIGHT_BLUE);

   /* Define third row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[10] = h_button_create(00163, 015, "ENTER", "PREFIX", "", "LAST X", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, 2 * KEY_WIDTH + KEY_GAP, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += 2 * (KEY_WIDTH + KEY_GAP);
   h_button[11] = h_button_create(00162, 'c', "CHS", "FIN", "", "EEX", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[12] = h_button_create(00161, 'e', "X-Y", "E", "", "Rv", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[13] = h_button_create(00160, 033, "CLX", "ALL", "", "CLP", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define fourth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[14] = h_button_create(00243, '-', "-", "d DAYS", "", "P/R", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[15] = h_button_create(00242, '7', "7", "", "", "GTO", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[16] = h_button_create(00241, '8', "8", "", "", "BST", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[17] = h_button_create(00240, '9', "9", "", "", "SST", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define fifth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[18] = h_button_create(00143, '+', "+", "DATE", "", "MEM", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[19] = h_button_create(00142, '4', "4", "", "", "PSE", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[20] = h_button_create(00141, '5', "5", "", "", "X\x1a\x59", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[21] = h_button_create(00140, '6', "6", "", "", "X=0", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define sixth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[22] = h_button_create(00323, '*', "\xd7", "INTGR", "", "FRAC", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[23] = h_button_create(00322, '1', "1", "", "", "x,r", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[24] = h_button_create(00321, '2', "2", "", "", "y,r", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[25] = h_button_create(00320, '3', "3", "", "", "n\xb0", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define bottom row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[26] = h_button_create(00103, '/', "\xf7", "1/x", "", "xw", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[27] = h_button_create(00102, '0', "0", "", "", "x", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[28] = h_button_create(00101, '.', ".", "", "", "s", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[29] = h_button_create(00100, 000, "R/S", "E+", "", "E-", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
}

int i_rom[ROM_SIZE] = {
00440, 00063, 00073, 00107, 00747, 00757, 00773, 01113,
01123, 01137, 01713, 01367, 00072, 00126, 00410, 00510,
00416, 00062, 00422, 00410, 01074, 00620, 00652, 00752,
00254, 00025, 00372, 01372, 00075, 00410, 00132, 01372,
00075, 01456, 00150, 01022, 01522, 00047, 00317, 01232,
00262, 01456, 00063, 00410, 00232, 00732, 00232, 00410,
00132, 01116, 00132, 01456, 00075, 00656, 01772, 00222,
00262, 00620, 01154, 00063, 00432, 00232, 00510, 00372,
00472, 01152, 01152, 01152, 00232, 00410, 00510, 01362,
00113, 00656, 01772, 00232, 00774, 01506, 00143, 00372,
00232, 00774, 00272, 00556, 00607, 00766, 00607, 00316,
00756, 00742, 00322, 00132, 01566, 00140, 00432, 00022,
01020, 00316, 00553, 01502, 00117, 01156, 00706, 00617,
00410, 00132, 01456, 00155, 00207, 00232, 00410, 01432,
00164, 00410, 00232, 00217, 00410, 00232, 00410, 00132,
00217, 00072, 00126, 00410, 00510, 00416, 00062, 00422,
00410, 00616, 01062, 01027, 01222, 00032, 00410, 01274,
00720, 01672, 01063, 00472, 01142, 01057, 00254, 00210,
00510, 00423, 00072, 00126, 00410, 00510, 00416, 00062,
00422, 01366, 00267, 00410, 01056, 01062, 01203, 01222,
00410, 00232, 00132, 01472, 00251, 00410, 00732, 01156,
00410, 00774, 00432, 01267, 00742, 01032, 01263, 00472,
00732, 00620, 01154, 00255, 00232, 00510, 00477, 01474,
00464, 00023, 00072, 00366, 00232, 01522, 00267, 00062,
01332, 00347, 00332, 00132, 00572, 00572, 00632, 00372,
00436, 00272, 00572, 01226, 00556, 00616, 01474, 01542,
00322, 01732, 01772, 00216, 00432, 00132, 01274, 00530,
01772, 01613, 00742, 01632, 01553, 00532, 00732, 01344,
00345, 00620, 01746, 00402, 01557, 00232, 00503, 00032,
00432, 00503, 00072, 00366, 00232, 00432, 00410, 00432,
00774, 00130, 00372, 00232, 00410, 00232, 01137, 00432,
01262, 00774, 00130, 00073, 00432, 01747, 00630, 01130,
00330, 00130, 00430, 00730, 00130, 01030, 00030, 00530,
00530, 01146, 00774, 01020, 00343, 00567, 00467, 00553,
00670, 00222, 00774, 00346, 00650, 01170, 01674, 00706,
00706, 00706, 00206, 00216, 01150, 00447, 00372, 00410,
01170, 00266, 00166, 01726, 01726, 01726, 00374, 00346,
00356, 01150, 00670, 00372, 00770, 00650, 01070, 00750,
00226, 01772, 01772, 01772, 00362, 00410, 00372, 01020,
00770, 01050, 00670, 00750, 00332, 00222, 00262, 00650,
01170, 00226, 00474, 00706, 00706, 00706, 00226, 01150,
00206, 01646, 01646, 01646, 01020, 00770, 00374, 00372,
00410, 01170, 00620, 01772, 00354, 00522, 00362, 00232,
00410, 01020, 01070, 00474, 00477, 00670, 01674, 00477,
00072, 00366, 00232, 00614, 01247, 00614, 01014, 00062,
00232, 00272, 00556, 01073, 01522, 00621, 00232, 00725,
00774, 00232, 00436, 00272, 01053, 00132, 00172, 00410,
00510, 01672, 01532, 00577, 00510, 00232, 01020, 00756,
00747, 00774, 00642, 00132, 00064, 01217, 00644, 01752,
00620, 00762, 00756, 01033, 00132, 01373, 00064, 01761,
01247, 01004, 00703, 00774, 00332, 01142, 00232, 01532,
00633, 00264, 00033, 01502, 00640, 01156, 00732, 01157,
00410, 01021, 00703, 00072, 00366, 00232, 00604, 01326,
01756, 01014, 00062, 01522, 00267, 01326, 00267, 00216,
00256, 01356, 00623, 00516, 01337, 01256, 01004, 00036,
00236, 00032, 00774, 01006, 01142, 00742, 00172, 00410,
00510, 01417, 01672, 01162, 01413, 00510, 00472, 01122,
01367, 00762, 00132, 00732, 00620, 01254, 00676, 00232,
00172, 00706, 00706, 00706, 00232, 01474, 00730, 01216,
01316, 01024, 01374, 01672, 00372, 00264, 00661, 00372,
00264, 00155, 01366, 00777, 01154, 00733, 00072, 01474,
00142, 00472, 01672, 00372, 00364, 01245, 01024, 00765,
00132, 01032, 00132, 00472, 00132, 01174, 00264, 00155,
01366, 00777, 01672, 01733, 01672, 00264, 00013, 01522,
00774, 01156, 00436, 01034, 01006, 01262, 00064, 00461,
00634, 01040, 00164, 00171, 00064, 00771, 00510, 01362,
01044, 01116, 00372, 00077, 01672, 01321, 00132, 01374,
00164, 01567, 00472, 01142, 00153, 00402, 00756, 00720,
01020, 00072, 00366, 00232, 01004, 01522, 01050, 01014,
00036, 00132, 00332, 00556, 00347, 00332, 01522, 01075,
01274, 00620, 01244, 01213, 00756, 00307, 00661, 00372,
01007, 00364, 01245, 01374, 00413, 00132, 00656, 01732,
00243, 00766, 01032, 00407, 00472, 00732, 01156, 00507,
01674, 01342, 01117, 01142, 01542, 01126, 00742, 00774,
01047, 00232, 00726, 00232, 01342, 01102, 00432, 00774,
01146, 00272, 00574, 00130, 01034, 01137, 01256, 00132,
00272, 00434, 01151, 00164, 00341, 00064, 01735, 00164,
00101, 00132, 00064, 00503, 00432, 00244, 00376, 01166,
00430, 00766, 01544, 01671, 00444, 01706, 00144, 01722,
01644, 01734, 00644, 01744, 01474, 00330, 01374, 01020,
00742, 01032, 01003, 00472, 00644, 01214, 00732, 01156,
00620, 00372, 00333, 00372, 00434, 01221, 01321, 00232,
00132, 01274, 00630, 01674, 01366, 01312, 00720, 01342,
01236, 01142, 00172, 00410, 00510, 01273, 00756, 01672,
01162, 01123, 01772, 01772, 01772, 00642, 00132, 00272,
01034, 01141, 00064, 01665, 00607, 01732, 01162, 01267,
00472, 00662, 00510, 01137, 00410, 00510, 00172, 00372,
00572, 00572, 00632, 00132, 01772, 01572, 01302, 00510,
00232, 01020, 00656, 01363, 01232, 00422, 00410, 00756,
00064, 01203, 00132, 00436, 00272, 01034, 01322, 01262,
00164, 00725, 00434, 01326, 00164, 00341, 00064, 01761,
00647, 00072, 00366, 00232, 00164, 00341, 01210, 00710,
01522, 01771, 01717, 01356, 00267, 01156, 00736, 01526,
01343, 01556, 01363, 00222, 00262, 00562, 00562, 00622,
01362, 01363, 00704, 01210, 00022, 00232, 00414, 00164,
01215, 01010, 00734, 01375, 01262, 00464, 00013, 01460,
00040, 00040, 00040, 00040, 00040, 00040, 00040, 00774,
01562, 00267, 01552, 00267, 00272, 00172, 00736, 01506,
01426, 00656, 01416, 01432, 00752, 01020, 01116, 00067,
00064, 01337, 00432, 00742, 01772, 00762, 00372, 01302,
01443, 01706, 00756, 00032, 01602, 00247, 00732, 00472,
00237, 01622, 00303, 01646, 00672, 00756, 00472, 00273,
00106, 01142, 00177, 01162, 00177, 00732, 00156, 00436,
00446, 00532, 00236, 01020, 01514, 00377, 01504, 01211,
00432, 00774, 00130, 00731, 00050, 00170, 00272, 00710,
00731, 00150, 00710, 00272, 00015, 00270, 01105, 00250,
01210, 00370, 00232, 00731, 00350, 01210, 00232, 00272,
00015, 00470, 01105, 00450, 00710, 01210, 00015, 00570,
01105, 00550, 01201, 00464, 00027, 01211, 00370, 00232,
01566, 01555, 01174, 00464, 00023, 00031, 00751, 01141,
01211, 00170, 00232, 00031, 00464, 00003, 01534, 01571,
01262, 00001, 01566, 01575, 00432, 01410, 00774, 01352,
01606, 01156, 00752, 01152, 01037, 00756, 01020, 00552,
01057, 00432, 01077, 00406, 01146, 00412, 00620, 00620,
01020, 01534, 01626, 00232, 01262, 00232, 00005, 00753,
00272, 01124, 01635, 00710, 01310, 00232, 01310, 01020,
00710, 01250, 01225, 00272, 01020, 00432, 01160, 00070,
01020, 00774, 00230, 00330, 00030, 00230, 00530, 01030,
00530, 00030, 01130, 00230, 01130, 01130, 00430, 00372,
01020, 00330, 00130, 00030, 00130, 00730, 01130, 01030,
00030, 00430, 00330, 00230, 00474, 01020, 00374, 00330,
00330, 00030, 01030, 00530, 00330, 00130, 00630, 01030,
00674, 01020, 01374, 00330, 00330, 00330, 00030, 01030,
00330, 00530, 01574, 01020, 00174, 00330, 00330, 00330,
00330, 00130, 00374, 01020, 00574, 00330, 00330, 00330,
00274, 01020, 00132, 00372, 00264, 00127, 00164, 00171,
01366, 00267, 00510, 01562, 00267, 00032, 00072, 00264,
00607, 00226, 01552, 00267, 00264, 01633, 00000, 00533,
00033, 01060, 00223, 01474, 01060, 00057, 01060, 01020,
01060, 01164, 00267, 01060, 00364, 00751, 01060, 00257,
01060, 01564, 01477, 01060, 00664, 01147, 01060, 00664,
00023, 01060, 01374, 00023, 01060, 01460, 01060, 00000,
01060, 01735, 00443, 01060, 00272, 00432, 01160, 00710,
01250, 00232, 00033, 00574, 01230, 01230, 01074, 00716,
01412, 00076, 01402, 01017, 00034, 01230, 01574, 00230,
00530, 01374, 00730, 00174, 00706, 01643, 01402, 00164,
00652, 00477, 01574, 00230, 00230, 00024, 00343, 01501,
00070, 01124, 00006, 00610, 01310, 00710, 00033, 00652,
00603, 01575, 00024, 00343, 01501, 00710, 00110, 00551,
01360, 00043, 00364, 00751, 01554, 00007, 01074, 00023,
00730, 01074, 01402, 00164, 00732, 00212, 01672, 00216,
00024, 00270, 00752, 01427, 01761, 00064, 01111, 00551,
01360, 00710, 00110, 00043, 00174, 00024, 00026, 01775,
01474, 00564, 00220, 00642, 01023, 01374, 00230, 00230,
00024, 00347, 01655, 00443, 00642, 01063, 01374, 00230,
00430, 00034, 00565, 01637, 00642, 01227, 01374, 01601,
00024, 00347, 01655, 00527, 00574, 00530, 01612, 01327,
00512, 00274, 00230, 00230, 00034, 00041, 00174, 00130,
00402, 00742, 01112, 01207, 00147, 00642, 01123, 01102,
00574, 00730, 01412, 00164, 01374, 00230, 00530, 00024,
00347, 01656, 01112, 01775, 00747, 00274, 01601, 00137,
01575, 01374, 01030, 00130, 01374, 01142, 00752, 01367,
01637, 00752, 01457, 01761, 01467, 00752, 01407, 01761,
00064, 00745, 00677, 01761, 01262, 00064, 00061, 00677,
01656, 00656, 00656, 00656, 01074, 00642, 01670, 01756,
00752, 01756, 01406, 00032, 00216, 01160, 01020, 01574,
00230, 00130, 01020, 01374, 00730, 00330, 00716, 01174,
00706, 00206, 00147, 01656, 01656, 00416, 01474, 00730,
01616, 01523, 00516, 01116, 01563, 01156, 01567, 00216,
01252, 01756, 01756, 01567, 01655, 00070, 00232, 00710,
01410, 01020, 01656, 00220, 00464, 00117, 00724, 01076,
01262, 00464, 00033, 00717, 01233, 00753, 01243, 00767,
00664, 00147, 01262, 01010, 00064, 00061, 01007, 01010,
00064, 00745, 01007, 01366, 00003, 01010, 00064, 01111,
01007, 00664, 01743, 00164, 00601, 01007, 00264, 00205,
01007, 00664, 01007, 01464, 01725, 00710, 00714, 00264,
01547, 00432, 00457, 00364, 00035, 01007, 00664, 01677,
01464, 00537, 01464, 01357, 01464, 01453, 01464, 01313,
00464, 00217, 01156, 01156, 01210, 00143, 00664, 01457,
00664, 01507, 01310, 00464, 00057, 01110, 01053, 00764,
00523, 00432, 00764, 00437, 00764, 00423, 00764, 01257,
00764, 00773, 01564, 00053, 01564, 00733, 01564, 01003,
01214, 01124, 00544, 01310, 00664, 01541, 01310, 01204,
01570, 01262, 01310, 00664, 01551, 00047, 01064, 00203,
01404, 01164, 00313, 01264, 01357, 01656, 01656, 01710,
00464, 00163, 01214, 01264, 00637, 01264, 00677, 00064,
01651, 00464, 00223, 00364, 00373, 00364, 00363, 01010,
01310, 00232, 00464, 00033, 00064, 01351, 01007, 00664,
01415, 01770, 00232, 00064, 01111, 01223, 00072, 00366,
01210, 00232, 01156, 01156, 00064, 01121, 01007, 00664,
01415, 01670, 00064, 00745, 00464, 00447, 01364, 00767,
01204, 00757, 01017, 00343, 01027, 00727, 00403, 00103,
00764, 00003, 01262, 01210, 00064, 00061, 01362, 00034,
00764, 00057, 01417, 00433, 00477, 00553, 00453, 01777,
01464, 00311, 01007, 00432, 01160, 01270, 01223, 01063,
00257, 00117, 00247, 00443, 01303, 00603, 00033, 01777,
01464, 00155, 01007, 01464, 00155, 00510, 01007, 01133,
00233, 00113, 00467, 00507, 00333, 00703, 01037, 01777,
01210, 00232, 01262, 00064, 00061, 00232, 01143, 00563,
01517, 00137, 01503, 00523, 00533, 01403, 00307, 01777,
00207, 00353, 00363, 00317, 00023, 01313, 01343, 00573,
00373, 00157, 00217, 00543, 01603, 00673, 00413, 00124,
00402, 00574, 01330, 01612, 00420, 00024, 00236, 00464,
01735, 00710, 00110, 01104, 00104, 00464, 00537, 00642,
01502, 00173, 00024, 00347, 00734, 01036, 01024, 01133,
00173, 00604, 00724, 00036, 00716, 00716, 00710, 00461,
01174, 00642, 00233, 00706, 00720, 00207, 01102, 00744,
00036, 01144, 01056, 00624, 01056, 00662, 00172, 00620,
00620, 01106, 00132, 00520, 00774, 01676, 00262, 01410,
01536, 01107, 00032, 00232, 00132, 00417, 01024, 01172,
01366, 00036, 01262, 01114, 00610, 00464, 00173, 01502,
01073, 01116, 00726, 00437, 00420, 00724, 00007, 01124,
01122, 01310, 01014, 00704, 00036, 01126, 00114, 00432,
01020, 00056, 00667, 00174, 00710, 00706, 00172, 01410,
01674, 01646, 01646, 01646, 00156, 00016, 01074, 01312,
01155, 01006, 00547, 00146, 00016, 00520, 00456, 01522,
01164, 01116, 00736, 00677, 00216, 00132, 01665, 00254,
00006, 00417, 01674, 00202, 01242, 00202, 00573, 00714,
01104, 00724, 01220, 00461, 00072, 00774, 00742, 00242,
01674, 00106, 01004, 01526, 01103, 01014, 00106, 00417,
01366, 01177, 00464, 00201, 01674, 01306, 01211, 00417,
01656, 00030, 00730, 00356, 01074, 01670, 00406, 01410,
01116, 01233, 00214, 01650, 00464, 00163, 00234, 01253,
01116, 01257, 01217, 01116, 01303, 00630, 01730, 01217,
00420, 01146, 00420, 01156, 01410, 01006, 01313, 00446,
00716, 00202, 00256, 00716, 00716, 00216, 00174, 01412,
00004, 00216, 01217, 00432, 01160, 00774, 00130, 00230,
00756, 00272, 01020, 01415, 01770, 00710, 00064, 00745,
00053, 01415, 01670, 00710, 00232, 00064, 01111, 00053,
00432, 01160, 01770, 00272, 01670, 00064, 00745, 01570,
01262, 00064, 00755, 00432, 00330, 00630, 01224, 01351,
00530, 01474, 00430, 00064, 01121, 00364, 00753, 00432,
01160, 00050, 00150, 00250, 00350, 00450, 00550, 01223,
00432, 01160, 00070, 00574, 01366, 00004, 00364, 00627,
00432, 01474, 01060, 00000, 01060, 01574, 00464, 00023,
01060, 01064, 00053, 01060, 01562, 00032, 01156, 00113,
00416, 01766, 01556, 00032, 00674, 01546, 00032, 01074,
00130, 01160, 00416, 01030, 00232, 01670, 00436, 00762,
01772, 00752, 01772, 00420, 00656, 01410, 01626, 00217,
00420, 01056, 00343, 00216, 00256, 01074, 01502, 01501,
00030, 01230, 01074, 01046, 00407, 00030, 00630, 00407,
01556, 00032, 01074, 00130, 01530, 00256, 01074, 00030,
01330, 01160, 00070, 00763, 00045, 01564, 00025, 00372,
00332, 00061, 00710, 01360, 00432, 01160, 00372, 01750,
00611, 00372, 00432, 01053, 00045, 00061, 00610, 01124,
01532, 01310, 00045, 01464, 01035, 01360, 00464, 00467,
00045, 00061, 00416, 01474, 00420, 01130, 01616, 01474,
00730, 00356, 00316, 01074, 00673, 00756, 01006, 00667,
00446, 01160, 00070, 00232, 00574, 00630, 00753, 00520,
00520, 01152, 01146, 00737, 01410, 01020, 00601, 00372,
00710, 01562, 00032, 01205, 01156, 01043, 00416, 01766,
01556, 00032, 00774, 00206, 00674, 01506, 00032, 00206,
00372, 00520, 00520, 01152, 01107, 00232, 00567, 00022,
00674, 00006, 00774, 01502, 01637, 00726, 01203, 00656,
00232, 00774, 01504, 01372, 01651, 01514, 01142, 01372,
01652, 00742, 01020, 00601, 01135, 00464, 00447, 01755,
01725, 00420, 01074, 00130, 01730, 01310, 01310, 00530,
01154, 01667, 01564, 01575, 00372, 00232, 01110, 00272,
01110, 00572, 01751, 01110, 00332, 00404, 01564, 01621,
01632, 00432, 00574, 00130, 01730, 01751, 01110, 01010,
01751, 00432, 01074, 00230, 00330, 01725, 00410, 00510,
01474, 01160, 01360, 01142, 01547, 00510, 01160, 00232,
00070, 01751, 01142, 01573, 01725, 00264, 01775, 01715,
00464, 00165, 01064, 01745, 00464, 00101, 01715, 01664,
01775, 01715, 00043, 00524, 01405, 00610, 00774, 00742,
00610, 01020, 01632, 01532, 01405, 01020, 00000, 01410,
00040, 00040, 01540, 00040, 00040, 01440, 00000, 01673,
00040, 01440, 00432, 01160, 01770, 01020, 01374, 00603,
01070, 00764, 00063, 00101, 00410, 00764, 00611, 00764,
01135, 00232, 00047, 00432, 01074, 00130, 01160, 01020,
00310, 00114, 01214, 00045, 01050, 01014, 01314, 01614,
00432, 00650, 00750, 00115, 00510, 00232, 01624, 00142,
00015, 01366, 00074, 01604, 01362, 00070, 01262, 01004,
00650, 00750, 01070, 00550, 01070, 01224, 00126, 00011,
01050, 01262, 00232, 00051, 00001, 00372, 01770, 00272,
00045, 00232, 01322, 00053, 01050, 00670, 01366, 01071,
01204, 01334, 00045, 00570, 00011, 01127, 00025, 01050,
01362, 00053, 00670, 01366, 01071, 01324, 00224, 00274,
00464, 00023, 01034, 00145, 01262, 00015, 00670, 00005,
00650, 01324, 00167, 01362, 00157, 01304, 00363, 01262,
00272, 00770, 00001, 01362, 00074, 00670, 00347, 01562,
00074, 00051, 00410, 00045, 00510, 01050, 00432, 00650,
00115, 00670, 00001, 00650, 01070, 00011, 01050, 01562,
00200, 00670, 00272, 00155, 00432, 00774, 00530, 01156,
00015, 01750, 01174, 00603, 00570, 00272, 00155, 01516,
00232, 01666, 01666, 01670, 00474, 00206, 01574, 00206,
01650, 00710, 01124, 00245, 01310, 00045, 01314, 01050,
00610, 00432, 00550, 00750, 00210, 00115, 00510, 00015,
00770, 00005, 00750, 00115, 00232, 00025, 00432, 00530,
01156, 00021, 00710, 00005, 00410, 00101, 00125, 00510,
00015, 00410, 00101, 00272, 00045, 00510, 00015, 00570,
00005, 00550, 00115, 00710, 00001, 00610, 01070, 00011,
01050, 00272, 01324, 00475, 00570, 00410, 00155, 01670,
00232, 01574, 00006, 00732, 01556, 00337, 01766, 00232,
01426, 00344, 00045, 01263, 00710, 01750, 00051, 00510,
01650, 01304, 00045, 00770, 00650, 01247, 00432, 01160,
01670, 01156, 01156, 01362, 00437, 01552, 00437, 01674,
00603, 01460, 00000, 00000, 00000, 00000, 00000, 00000,
00040, 00040, 01540, 00040, 00040, 00040, 00040, 01040,
01040, 01040, 01440, 01440, 01440, 01440, 01440, 01064,
00127, 00064, 01737, 00000, 00072, 00366, 00232, 00057,
01170, 00474, 00406, 01362, 00437, 00756, 01776, 01020,
00404, 00310, 00210, 00164, 01233, 00410, 00510, 00416,
00064, 01713, 00141, 00764, 00063, 00045, 00710, 01650,
01410, 01414, 00045, 00255, 01064, 01671, 00011, 00114,
00710, 01124, 00533, 01310, 00557, 01262, 00272, 00045,
00001, 01362, 00342, 01670, 00272, 00041, 00670, 01262,
00031, 00610, 00570, 00272, 00770, 00031, 00710, 00005,
00064, 01665, 00055, 01070, 00272, 00770, 01262, 00031,
00201, 00310, 01414, 00055, 01104, 01714, 01724, 00535,
00032, 00072, 01314, 00055, 00065, 01474, 00042, 00055,
00045, 00232, 01424, 00556, 00432, 01650, 00736, 01516,
00562, 01676, 00041, 01170, 00474, 00246, 00232, 01150,
01724, 01065, 00251, 00075, 01524, 01074, 00232, 01262,
00121, 00065, 00201, 00310, 00610, 00071, 00025, 01352,
00613, 00556, 01727, 00055, 00071, 00055, 00105, 01366,
00625, 00071, 00035, 00055, 01153, 00251, 00075, 00232,
01262, 00121, 00251, 01262, 00372, 00061, 00021, 00071,
00064, 00105, 00410, 00055, 01424, 00772, 00251, 00075,
00045, 00510, 00015, 01262, 00232, 01670, 00232, 01650,
00710, 00015, 01670, 00005, 01650, 00071, 00055, 00251,
00075, 00132, 00071, 00005, 00055, 00065, 00105, 01366,
00704, 00051, 00241, 01503, 00051, 00251, 00075, 00232,
00750, 00011, 00770, 00021, 00432, 00530, 01156, 00021,
00055, 00251, 00072, 00366, 00232, 00051, 00025, 00045,
01670, 00005, 01650, 00041, 00141, 01464, 01035, 00272,
01362, 00556, 00065, 01424, 01125, 01326, 01065, 00045,
01670, 00225, 01064, 00155, 01770, 00005, 00406, 00130,
00530, 00216, 00256, 01264, 00143, 01152, 01152, 01552,
01131, 01057, 00071, 00055, 00310, 01557, 00000, 00000,
00040, 00040, 00040, 01540, 00040, 00040, 01040, 01040,
01040, 01040, 01440, 01440, 01440, 01440, 01440, 00140,
01140, 00410, 00314, 01140, 00005, 00061, 00064, 01713,
00556, 00177, 00416, 00272, 00172, 00126, 00263, 01516,
01045, 00126, 01426, 01035, 00153, 01074, 00416, 00130,
01056, 00257, 00263, 01404, 00061, 00035, 01262, 00262,
00051, 00011, 00055, 01434, 00540, 00061, 00101, 00756,
00756, 00611, 01650, 01227, 00310, 00210, 01424, 01113,
00065, 00232, 01262, 00232, 00045, 01670, 00121, 00272,
00045, 00232, 01650, 00041, 01164, 00251, 00372, 00065,
00121, 00055, 00065, 01164, 01757, 01271, 00611, 01550,
01227, 00216, 01424, 01126, 00071, 00101, 00611, 01650,
00764, 01113, 00372, 00045, 00332, 00364, 00753, 00045,
01414, 01262, 00410, 01470, 00272, 01370, 00737, 01214,
01404, 00045, 00410, 01470, 01262, 00272, 01570, 01262,
00372, 00041, 00372, 00650, 00232, 00750, 00031, 00105,
00510, 00072, 00366, 00272, 01326, 01221, 00404, 00604,
01764, 01705, 00075, 00031, 00064, 01121, 00041, 00075,
01113, 00015, 00770, 00021, 00075, 01224, 01231, 01070,
00021, 00324, 01235, 00055, 01255, 01224, 01260, 00051,
00011, 01434, 01126, 00611, 01350, 00610, 01124, 01251,
01310, 00464, 00707, 00031, 01564, 00025, 00051, 00027,
00075, 00045, 01570, 01262, 00005, 00051, 01755, 01262,
00611, 01450, 01227, 00045, 01570, 01214, 00272, 01370,
00001, 00055, 00045, 01470, 01262, 00410, 00031, 00115,
00105, 00324, 01315, 01255, 00055, 00065, 00045, 01370,
01735, 00410, 00770, 01366, 01365, 00065, 00025, 01262,
00262, 01362, 01347, 01366, 01362, 01204, 00065, 00045,
01570, 01262, 01735, 00065, 00025, 01562, 00367, 01764,
01701, 00055, 00071, 01764, 01701, 00061, 00035, 01224,
01362, 01262, 00611, 01750, 01227, 00510, 01713, 00021,
00061, 00011, 00071, 01366, 00367, 00037, 00232, 01470,
00040, 00040, 00000, 01470, 00040, 00230, 00040, 00040,
01040, 01040, 01440, 01440, 00045, 01262, 01564, 00027,
00272, 01074, 00230, 01160, 00232, 00550, 00432, 01160,
01624, 01450, 01570, 01324, 01376, 00257, 00272, 01074,
00230, 01160, 00232, 00650, 00432, 01160, 01624, 01432,
01370, 01334, 01376, 00272, 00072, 00126, 01020, 00171,
00101, 00041, 00570, 01262, 00021, 01562, 00367, 00750,
00670, 00272, 00570, 00650, 00432, 00025, 00045, 00015,
00410, 00041, 00510, 00550, 00021, 00770, 00005, 00064,
01365, 00570, 00262, 00570, 00007, 00432, 01172, 00430,
00766, 01474, 00730, 00005, 01362, 00367, 00432, 00130,
01750, 01770, 01366, 00367, 00064, 01651, 00055, 00221,
01262, 00262, 00055, 00131, 01332, 00367, 00051, 00064,
01711, 01522, 00367, 00164, 01231, 01264, 00333, 00650,
00432, 00230, 00272, 00045, 00031, 00055, 00770, 00164,
01217, 01326, 00367, 01164, 00227, 00314, 01304, 00334,
01602, 01314, 01414, 01614, 00061, 01770, 01562, 00367,
00015, 01366, 01531, 00061, 01362, 01515, 00015, 00101,
00171, 00410, 00041, 00510, 00750, 00670, 00005, 01262,
00451, 00550, 00670, 01262, 00232, 00770, 00001, 00570,
00745, 01366, 01071, 01362, 01646, 01604, 00061, 00275,
00550, 00670, 00745, 01562, 01705, 01366, 01705, 00675,
00272, 00045, 00232, 01650, 00610, 00210, 01124, 01671,
01310, 00061, 00410, 00041, 00510, 00550, 00064, 01761,
00570, 01522, 01715, 00222, 01713, 01404, 00131, 00041,
00570, 00745, 01562, 00367, 01323, 00021, 00432, 00630,
00035, 00045, 00035, 00015, 00101, 00041, 00455, 00750,
00171, 00041, 00455, 01424, 01736, 00650, 00770, 00021,
01262, 00750, 01562, 01762, 00045, 00064, 01651, 01770,
01262, 00005, 00432, 00330, 00035, 00371, 00670, 01434,
01774, 00035, 01434, 01775, 01562, 01767, 00610, 00710,
00675, 00650, 01764, 00077, 00755, 01764, 00437, 01731,
00432, 01074, 00230, 01160, 00164, 00467, 01037, 00256,
00437, 01040, 01727, 01203, 01077, 00127, 00003, 00432,
01074, 00230, 01160, 00164, 00553, 00432, 01074, 00230,
01160, 00164, 00567, 00774, 00272, 01552, 00056, 00726,
00620, 01526, 00053, 00406, 00216, 00410, 00416, 01156,
00222, 00064, 00463, 01156, 00177, 00217, 00432, 00410,
00232, 01020, 00032, 00774, 01610, 00344, 00126, 00620,
01116, 00327, 00272, 00516, 00037, 00256, 00720, 01144,
00104, 00656, 00373, 00457, 00432, 01020, 00620, 00344,
00126, 01116, 00433, 00072, 00146, 00466, 00523, 00022,
00662, 00756, 01672, 00620, 00006, 00226, 01020, 01031,
01075, 01125, 01251, 01201, 01271, 00741, 00272, 01725,
00232, 00650, 01031, 01075, 00701, 01251, 01201, 01271,
00741, 00364, 00751, 00364, 01141, 00670, 00464, 00033,
01755, 00370, 01231, 01075, 01755, 00272, 00470, 01163,
01522, 00562, 00064, 01367, 01755, 00170, 00232, 00370,
01235, 01075, 01755, 00272, 00570, 01163, 01755, 00072,
00366, 00232, 00064, 01737, 01262, 00064, 00071, 00432,
01074, 00230, 01160, 00164, 00343, 01755, 00170, 01231,
01075, 01755, 00272, 00270, 01241, 01201, 00064, 00107,
00432, 01074, 00230, 01160, 00164, 00173, 00272, 01262,
00064, 00747, 01755, 00410, 00510, 00416, 01366, 00562,
00064, 01137, 01755, 00570, 00072, 00366, 00232, 00170,
01255, 00464, 00447, 00761, 01075, 00710, 00232, 01755,
01241, 00370, 01061, 01125, 01711, 00164, 00101, 01755,
00170, 01543, 01125, 01075, 00710, 00232, 01755, 01241,
00170, 01061, 00761, 01711, 00164, 00101, 01755, 00370,
00064, 00755, 01201, 01171, 01201, 01271, 01251, 00272,
01725, 00232, 00650, 01125, 01075, 00701, 01711, 00741,
01075, 00761, 01201, 01271, 00364, 00751, 01310, 00670,
00464, 00223, 01201, 00064, 00773, 01074, 00432, 00230,
01160, 00432, 01020, 00432, 01160, 00070, 01020, 00000,
01174, 00464, 00023, 00027, 00043, 00072, 00366, 00232,
00064, 01763, 01714, 00314, 01724, 00412, 00661, 00710,
00550, 01366, 00400, 01562, 00400, 01464, 00155, 01566,
00400, 00432, 01160, 01570, 00671, 01550, 01470, 00671,
01450, 00432, 00610, 01124, 00446, 01310, 00710, 01310,
01670, 01156, 01156, 00232, 01570, 00064, 00745, 00671,
00232, 00324, 00467, 01770, 01566, 00467, 00032, 01470,
00372, 00661, 00232, 00650, 00232, 00122, 00710, 00641,
00610, 00670, 00232, 00432, 01160, 01470, 00641, 00232,
00661, 00232, 00650, 01010, 00641, 01310, 00670, 00272,
00432, 01160, 01570, 00641, 01550, 01770, 00025, 01750,
00661, 00570, 01464, 01035, 00550, 01724, 00546, 01366,
00546, 00210, 00416, 01160, 01362, 00450, 00464, 00467,
00064, 00061, 00364, 00753, 01464, 01727, 01464, 00313,
00374, 00007, 00574, 00007, 01574, 00007, 01204, 01210,
00661, 01314, 00314, 01414, 01514, 00232, 00774, 01777,
01214, 01464, 00155, 01566, 00560, 00737, 01664, 01315,
01010, 01310, 00232, 00464, 00223, 00410, 01010, 00570,
00272, 00432, 01160, 00510, 00610, 01250, 01674, 00642,
01375, 00064, 01111, 01464, 00155, 01371, 00064, 00745,
01556, 00714, 01366, 00714, 00272, 00620, 00520, 01654,
00645, 00710, 00420, 01162, 01556, 00657, 01772, 00174,
01730, 00232, 00202, 01064, 00155, 00474, 00330, 01574,
00330, 00110, 00372, 00114, 00764, 00023, 00272, 00432,
00774, 00730, 01020, 01772, 01324, 00710, 01534, 01363,
01402, 01360, 01664, 01717, 00730, 00774, 01223, 00010,
00772, 00610, 00432, 00610, 00410, 00410, 01110, 01110,
01110, 00372, 00132, 01710, 01710, 00764, 01277, 01310,
00572, 01110, 01110, 00414, 01160, 00372, 00070, 00532,
00232, 00424, 00772, 00472, 00232, 01110, 01110, 01110,
01360, 00432, 00070, 01110, 01360, 00332, 01156, 01623,
01110, 01020, 01032, 00000, 01663, 00750, 00710, 01562,
00560, 00535, 00174, 01546, 00560, 00575, 00432, 00474,
00330, 01424, 00703, 00474, 01426, 01022, 01126, 00174,
00006, 00774, 00130, 00532, 01235, 00755, 00232, 01325,
01115, 01331, 01141, 01265, 00661, 01325, 00550, 00715,
01056, 00426, 01755, 00661, 01331, 01025, 00130, 00230,
00130, 00530, 01325, 01025, 01051, 00374, 00430, 01101,
01131, 01331, 01615, 01615, 00725, 01241, 00755, 00232,
01325, 01115, 01331, 00570, 01325, 00661, 01325, 01025,
01171, 01131, 00535, 00474, 00475, 00030, 00430, 01426,
01300, 01070, 01166, 01174, 00402, 00751, 00327, 01672,
01070, 00206, 01574, 00206, 01050, 00272, 01007, 01156,
00563, 00416, 01746, 01373, 01556, 00560, 01373, 00324,
01276, 00266, 00674, 00706, 00706, 01615, 00226, 00726,
00726, 00206, 00232, 01373, 01025, 00430, 00730, 01030,
00130, 00630, 00430, 01474, 01107, 01672, 00474, 01070,
00206, 00216, 01050, 01070, 00232, 00726, 00726, 00726,
00726, 00726, 00016, 00656, 00022, 00432, 01474, 00230,
00774, 01020, 00650, 00330, 00630, 01424, 01222, 00530,
00230, 00530, 01020, 00755, 00430, 00416, 00064, 01113,
01070, 01574, 00406, 00525, 01171, 01253, 00330, 00030,
01424, 01245, 00630, 00274, 00130, 01156, 01020, 00725,
00556, 01051, 00064, 00745, 01333, 01070, 00274, 00406,
00232, 00775, 01353, 00650, 00770, 01262, 01464, 00155,
00510, 00232, 00670, 00064, 00061, 00650, 00272, 01020,
01141, 00535, 01615, 00274, 00475, 00130, 00430, 00774,
01426, 01315, 01130, 01130, 01507, 01030, 00730, 01674,
00130, 00626, 00575, 01156, 00064, 00461, 00272, 00210,
01324, 01346, 01210, 01751, 01304, 01224, 00775, 00272,
00710, 01355, 00173, 01666, 01666, 01020, 01234, 00615,
00710, 01751, 01315, 01404, 01010, 01310, 00232, 00007,
01574, 01504, 00002, 01235, 01141, 01265, 01334, 00606,
01314, 01567, 01072, 01572, 00560, 00570, 01020, 01460,
00040, 01240, 00045, 01470, 00040, 00040, 00000, 01040,
01040, 01040, 01440, 01440, 01440, 01440, 01440, 00410,
00045, 00510, 01650, 01364, 00061, 00404, 01364, 00725,
00045, 01670, 01262, 01564, 00025, 00051, 01326, 01442,
00425, 00227, 00045, 01464, 01035, 00710, 01262, 00021,
01364, 00275, 01364, 00101, 00041, 00570, 01164, 00225,
00710, 00021, 00045, 01670, 00064, 01121, 00232, 00041,
00232, 00650, 00045, 01464, 01035, 00064, 01665, 00055,
00770, 00164, 01215, 00663, 00065, 00064, 01713, 01562,
01513, 01364, 00675, 00550, 01364, 00221, 00410, 01470,
01262, 00272, 00041, 00510, 00650, 00001, 00670, 01164,
00225, 00610, 00570, 01262, 00272, 00710, 00001, 00570,
01522, 01554, 00045, 01670, 01262, 00272, 00710, 00001,
00710, 01522, 01554, 01670, 00404, 00072, 00366, 00272,
00055, 00210, 01364, 00061, 00055, 00065, 00164, 01231,
00055, 01364, 00221, 00051, 00025, 00421, 00055, 00071,
00055, 00222, 01262, 00222, 00064, 01761, 00071, 01366,
01613, 00035, 01073, 00045, 01464, 01035, 00055, 00011,
00071, 00005, 00055, 01364, 00131, 00051, 00005, 00055,
00071, 01366, 01723, 00055, 01364, 00061, 00071, 00005,
00055, 00065, 00222, 01262, 00222, 00064, 01761, 00051,
01326, 01731, 00425, 00011, 00055, 01364, 00131, 01770,
00021, 00051, 00005, 00421, 01434, 01673, 00055, 01364,
00061, 00051, 00005, 01562, 01743, 00432, 00130, 00130,
00216, 00256, 00556, 01653, 00272, 00172, 01014, 00061,
00035, 01262, 00262, 00051, 00005, 00364, 00751, 00254,
01723, 01034, 01560, 01634, 01727, 00064, 01665, 01264,
00333, 01364, 00061, 01770, 01262, 00021, 00432, 00230,
00064, 01121, 01257, 00416, 01004, 01074, 00130, 01056,
01437, 01433, 01516, 01743, 00266, 01466, 01704, 01433,
00614, 01014, 00062, 00232, 00272, 00756, 00164, 00653,
00000, 00000, 00000, 00000, 00000, 00000, 00000, 00360,
00440, 00063, 00073, 00107, 00747, 00757, 00773, 01113,
01123, 01137, 01713, 01367, 00072, 00126, 00410, 00510,
00416, 00062, 00422, 00410, 01074, 00620, 00652, 00752,
00254, 00025, 00372, 01372, 00075, 00410, 00132, 01372,
00075, 01456, 00150, 01022, 01522, 00047, 00317, 01232,
00262, 01456, 00063, 00410, 00232, 00732, 00232, 00410,
00132, 01116, 00132, 01456, 00075, 00656, 01772, 00222,
00262, 00620, 01154, 00063, 00432, 00232, 00510, 00372,
00472, 01152, 01152, 01152, 00232, 00410, 00510, 01362,
00113, 00656, 01772, 00232, 00774, 01506, 00143, 00372,
00232, 00774, 00272, 00556, 00607, 00766, 00607, 00316,
00756, 00742, 00322, 00132, 01566, 00140, 00432, 00022,
01020, 00316, 00553, 01502, 00117, 01156, 00706, 00617,
00410, 00132, 01456, 00155, 00207, 00232, 00410, 01432,
00164, 00410, 00232, 00217, 00410, 00232, 00410, 00132,
00217, 00072, 00126, 00410, 00510, 00416, 00062, 00422,
00410, 00616, 01062, 01027, 01222, 00032, 00410, 01274,
00720, 01672, 01063, 00472, 01142, 01057, 00254, 00210,
00510, 00423, 00072, 00126, 00410, 00510, 00416, 00062,
00422, 01366, 00267, 00410, 01056, 01062, 01203, 01222,
00410, 00232, 00132, 01472, 00251, 00410, 00732, 01156,
00410, 00774, 00432, 01267, 00742, 01032, 01263, 00472,
00732, 00620, 01154, 00255, 00232, 00510, 00477, 01474,
00464, 00023, 00072, 00366, 00232, 01522, 00267, 00062,
01332, 00347, 00332, 00132, 00572, 00572, 00632, 00372,
00436, 00272, 00572, 01226, 00556, 00616, 01474, 01542,
00322, 01732, 01772, 00216, 00432, 00132, 01274, 00530,
01772, 01613, 00742, 01632, 01553, 00532, 00732, 01344,
00345, 00620, 01746, 00402, 01557, 00232, 00503, 00032,
00432, 00503, 00072, 00366, 00232, 00432, 00410, 00432,
00774, 00130, 00372, 00232, 00410, 00232, 01137, 00432,
01262, 00774, 00130, 00073, 00432, 01747, 00630, 01130,
00330, 00130, 00430, 00730, 00130, 01030, 00030, 00530,
00530, 01146, 00774, 01020, 00343, 00567, 00467, 00553,
00670, 00222, 00774, 00346, 00650, 01170, 01674, 00706,
00706, 00706, 00206, 00216, 01150, 00447, 00372, 00410,
01170, 00266, 00166, 01726, 01726, 01726, 00374, 00346,
00356, 01150, 00670, 00372, 00770, 00650, 01070, 00750,
00226, 01772, 01772, 01772, 00362, 00410, 00372, 01020,
00770, 01050, 00670, 00750, 00332, 00222, 00262, 00650,
01170, 00226, 00474, 00706, 00706, 00706, 00226, 01150,
00206, 01646, 01646, 01646, 01020, 00770, 00374, 00372,
00410, 01170, 00620, 01772, 00354, 00522, 00362, 00232,
00410, 01020, 01070, 00474, 00477, 00670, 01674, 00477,
00072, 00366, 00232, 00614, 01247, 00614, 01014, 00062,
00232, 00272, 00556, 01073, 01522, 00621, 00232, 00725,
00774, 00232, 00436, 00272, 01053, 00132, 00172, 00410,
00510, 01672, 01532, 00577, 00510, 00232, 01020, 00756,
00747, 00774, 00642, 00132, 00064, 01217, 00644, 01752,
00620, 00762, 00756, 01033, 00132, 01373, 00064, 01761,
01247, 01004, 00703, 00774, 00332, 01142, 00232, 01532,
00633, 00264, 00033, 01502, 00640, 01156, 00732, 01157,
00410, 01021, 00703, 00072, 00366, 00232, 00604, 01326,
01756, 01014, 00062, 01522, 00267, 01326, 00267, 00216,
00256, 01356, 00623, 00516, 01337, 01256, 01004, 00036,
00236, 00032, 00774, 01006, 01142, 00742, 00172, 00410,
00510, 01417, 01672, 01162, 01413, 00510, 00472, 01122,
01367, 00762, 00132, 00732, 00620, 01254, 00676, 00232,
00172, 00706, 00706, 00706, 00232, 01474, 00730, 01216,
01316, 01024, 01374, 01672, 00372, 00264, 00661, 00372,
00264, 00155, 01366, 00777, 01154, 00733, 00072, 01474,
00142, 00472, 01672, 00372, 00364, 01245, 01024, 00765,
00132, 01032, 00132, 00472, 00132, 01174, 00264, 00155,
01366, 00777, 01672, 01733, 01672, 00264, 00013, 01522,
00774, 01156, 00436, 01034, 01006, 01262, 00064, 00461,
00634, 01040, 00164, 00171, 00064, 00771, 00510, 01362,
01044, 01116, 00372, 00077, 01672, 01321, 00132, 01374,
00164, 01567, 00472, 01142, 00153, 00402, 00756, 00720,
01020, 00072, 00366, 00232, 01004, 01522, 01050, 01014,
00036, 00132, 00332, 00556, 00347, 00332, 01522, 01075,
01274, 00620, 01244, 01213, 00756, 00307, 00661, 00372,
01007, 00364, 01245, 01374, 00413, 00132, 00656, 01732,
00243, 00766, 01032, 00407, 00472, 00732, 01156, 00507,
01674, 01342, 01117, 01142, 01542, 01126, 00742, 00774,
01047, 00232, 00726, 00232, 01342, 01102, 00432, 00774,
01146, 00272, 00574, 00130, 01034, 01137, 01256, 00132,
00272, 00434, 01151, 00164, 00341, 00064, 01735, 00164,
00101, 00132, 00064, 00503, 00432, 00244, 00376, 01166,
00430, 00766, 01544, 01671, 00444, 01706, 00144, 01722,
01644, 01734, 00644, 01744, 01474, 00330, 01374, 01020,
00742, 01032, 01003, 00472, 00644, 01214, 00732, 01156,
00620, 00372, 00333, 00372, 00434, 01221, 01321, 00232,
00132, 01274, 00630, 01674, 01366, 01312, 00720, 01342,
01236, 01142, 00172, 00410, 00510, 01273, 00756, 01672,
01162, 01123, 01772, 01772, 01772, 00642, 00132, 00272,
01034, 01141, 00064, 01665, 00607, 01732, 01162, 01267,
00472, 00662, 00510, 01137, 00410, 00510, 00172, 00372,
00572, 00572, 00632, 00132, 01772, 01572, 01302, 00510,
00232, 01020, 00656, 01363, 01232, 00422, 00410, 00756,
00064, 01203, 00132, 00436, 00272, 01034, 01322, 01262,
00164, 00725, 00434, 01326, 00164, 00341, 00064, 01761,
00647, 00072, 00366, 00232, 00164, 00341, 01210, 00710,
01522, 01771, 01717, 01356, 00267, 01156, 00736, 01526,
01343, 01556, 01363, 00222, 00262, 00562, 00562, 00622,
01362, 01363, 00704, 01210, 00022, 00232, 00414, 00164,
01215, 01010, 00734, 01375, 01262, 00464, 00013, 01460,
00040, 00040, 00040, 00040, 00040, 00040, 00040, 00774,
01562, 00267, 01552, 00267, 00272, 00172, 00736, 01506,
01426, 00656, 01416, 01432, 00752, 01020, 01116, 00067,
00064, 01337, 00432, 00742, 01772, 00762, 00372, 01302,
01443, 01706, 00756, 00032, 01602, 00247, 00732, 00472,
00237, 01622, 00303, 01646, 00672, 00756, 00472, 00273,
00106, 01142, 00177, 01162, 00177, 00732, 00156, 00436,
00446, 00532, 00236, 01020, 01514, 00377, 01504, 01211,
00432, 00774, 00130, 00731, 00050, 00170, 00272, 00710,
00731, 00150, 00710, 00272, 00015, 00270, 01105, 00250,
01210, 00370, 00232, 00731, 00350, 01210, 00232, 00272,
00015, 00470, 01105, 00450, 00710, 01210, 00015, 00570,
01105, 00550, 01201, 00464, 00027, 01211, 00370, 00232,
01566, 01555, 01174, 00464, 00023, 00031, 00751, 01141,
01211, 00170, 00232, 00031, 00464, 00003, 01534, 01571,
01262, 00001, 01566, 01575, 00432, 01410, 00774, 01352,
01606, 01156, 00752, 01152, 01037, 00756, 01020, 00552,
01057, 00432, 01077, 00406, 01146, 00412, 00620, 00620,
01020, 01534, 01626, 00232, 01262, 00232, 00005, 00753,
00272, 01124, 01635, 00710, 01310, 00232, 01310, 01020,
00710, 01250, 01225, 00272, 01020, 00432, 01160, 00070,
01020, 00774, 00230, 00330, 00030, 00230, 00530, 01030,
00530, 00030, 01130, 00230, 01130, 01130, 00430, 00372,
01020, 00330, 00130, 00030, 00130, 00730, 01130, 01030,
00030, 00430, 00330, 00230, 00474, 01020, 00374, 00330,
00330, 00030, 01030, 00530, 00330, 00130, 00630, 01030,
00674, 01020, 01374, 00330, 00330, 00330, 00030, 01030,
00330, 00530, 01574, 01020, 00174, 00330, 00330, 00330,
00330, 00130, 00374, 01020, 00574, 00330, 00330, 00330,
00274, 01020, 00132, 00372, 00264, 00127, 00164, 00171,
01366, 00267, 00510, 01562, 00267, 00032, 00072, 00264,
00607, 00226, 01552, 00267, 00264, 01633, 00000, 00533,
01460, 01060, 00233, 00000, 01060, 01023, 01060, 00347,
01060, 00357, 00000, 01060, 00553, 00420, 01060, 01020,
01060, 00001, 00033, 01060, 00764, 01617, 01060, 00664,
00220, 01060, 00664, 00377, 01060, 00527, 01060, 00427,
01060, 01151, 00033, 01060, 00764, 01717, 00310, 01755,
00656, 00656, 01710, 00701, 00232, 01670, 00374, 00256,
01606, 01506, 00135, 01074, 00406, 01650, 00010, 01160,
01250, 00110, 00114, 00055, 00610, 01554, 00100, 00214,
01755, 00710, 00224, 01651, 01351, 00224, 01651, 01151,
00016, 01414, 01410, 00310, 00210, 01714, 01724, 00115,
01734, 00120, 00310, 00754, 00400, 00710, 00024, 01521,
01134, 00071, 00110, 01104, 00353, 00741, 01074, 00130,
00761, 00432, 00701, 00574, 01530, 01650, 00432, 00610,
00010, 00432, 01172, 00374, 01530, 01230, 01730, 01073,
00374, 01630, 00330, 00230, 01530, 01030, 00530, 01020,
00416, 01474, 00420, 00032, 01160, 00232, 01360, 00232,
00742, 00763, 01020, 00174, 00432, 00214, 00420, 01172,
00072, 00620, 00752, 01154, 00211, 00374, 01630, 01230,
01230, 01430, 01230, 00232, 00732, 00732, 00732, 01755,
01174, 00443, 00710, 00372, 00432, 01034, 00241, 01674,
00630, 00222, 00262, 00774, 01322, 00251, 00430, 01274,
00620, 01162, 01243, 00742, 00244, 00270, 00720, 00244,
00270, 00720, 00244, 00270, 00720, 00742, 00742, 01257,
00372, 01020, 00032, 01610, 00266, 00410, 00510, 00774,
00422, 00620, 01116, 01407, 00544, 00321, 01552, 00337,
01156, 01463, 00016, 01617, 00344, 00317, 00620, 00762,
01443, 00510, 00422, 01074, 01352, 00327, 01206, 01674,
00272, 00706, 00706, 00706, 01004, 00574, 01673, 00016,
01672, 00756, 01603, 00072, 00146, 00132, 00472, 01536,
00361, 01566, 00321, 01522, 00367, 00262, 00420, 01106,
01020, 00006, 01532, 00353, 00620, 00132, 01617, 00762,
00620, 01672, 01667, 01074, 00432, 00130, 01160, 01020,
00420, 00432, 00020, 01116, 01116, 01116, 01116, 00174,
01116, 01116, 01614, 00716, 00464, 00447, 01544, 00526,
00144, 00451, 00474, 01157, 00656, 01244, 00444, 00544,
00660, 00044, 00444, 00656, 00716, 00354, 00440, 00774,
00720, 01116, 01154, 00440, 01614, 00764, 00527, 00274,
00607, 01074, 01330, 00673, 01102, 01624, 00023, 00227,
00353, 01323, 01407, 00656, 00000, 00000, 00354, 00703,
00374, 00563, 00354, 00677, 00674, 00763, 00674, 01157,
01653, 01613, 00127, 00144, 00670, 01544, 00516, 00444,
00406, 01074, 01530, 01130, 00216, 00223, 00374, 00567,
00554, 00710, 01604, 00063, 00274, 00127, 01074, 01330,
01063, 00144, 01617, 00656, 00656, 00656, 00044, 00203,
00656, 00656, 01477, 00144, 01670, 01544, 00737, 00444,
00404, 01074, 01230, 00457, 01074, 01230, 01030, 00463,
01767, 00767, 00773, 00444, 00020, 01554, 00577, 00034,
01665, 00774, 01157, 00656, 00656, 00656, 00656, 00656,
01544, 00605, 00144, 00605, 00774, 00620, 01467, 01074,
01430, 00673, 01074, 01230, 00730, 00463, 00574, 01157,
01357, 00373, 00757, 00073, 00000, 00000, 01544, 00612,
00144, 00554, 01574, 00016, 00053, 00144, 01164, 00563,
00547, 01167, 01263, 00144, 01517, 01544, 00734, 00444,
00403, 01074, 01330, 00457, 00154, 00535, 01074, 01157,
01502, 00454, 00656, 00057, 00354, 00700, 00674, 00777,
01074, 01530, 00673, 01444, 00616, 00374, 01157, 00656,
00656, 00656, 00656, 01444, 00524, 00444, 00447, 00656,
01544, 00715, 00144, 00715, 00774, 00656, 00557, 00656,
00656, 00656, 00123, 00144, 00574, 01544, 00607, 00444,
00405, 01074, 01430, 00457, 01074, 01430, 01063, 01074,
01530, 01063, 00444, 00760, 00044, 00203, 01454, 00520,
01674, 00047, 00354, 00600, 00034, 00010, 00464, 00527,
01674, 00043, 00010, 00610, 01030, 00254, 00764, 00272,
00632, 00572, 00372, 00464, 01137, 01670, 00144, 01030,
01554, 00574, 00024, 01521, 00372, 00464, 00741, 00372,
01756, 00752, 01756, 00113, 01160, 00232, 01360, 00232,
01020, 00061, 01142, 00107, 00010, 00610, 00014, 01670,
00034, 01051, 00000, 00000, 01756, 00752, 01756, 01474,
00032, 00061, 00742, 00207, 01274, 00030, 00030, 00574,
01530, 01074, 00406, 01650, 00214, 00464, 00527, 01125,
00330, 01303, 01105, 01777, 01325, 00530, 00130, 00377,
01125, 01003, 01325, 01243, 01125, 00730, 00430, 00232,
00432, 00674, 00630, 01534, 01107, 00374, 00330, 01474,
00730, 00372, 01670, 00016, 01074, 01346, 01140, 01474,
00742, 00517, 00577, 01074, 00202, 01656, 00656, 01474,
00563, 01410, 00456, 00420, 00742, 00547, 01410, 00656,
01274, 00236, 00720, 00732, 01554, 01142, 00206, 00226,
01130, 00226, 01020, 01125, 01613, 01125, 01577, 01325,
00303, 01325, 00230, 00333, 01670, 01074, 00256, 01546,
01427, 01656, 00202, 00742, 01746, 00764, 00153, 01325,
00730, 00333, 01325, 01577, 01105, 01677, 01325, 00630,
00333, 01125, 01037, 01125, 01677, 00330, 00373, 01105,
01377, 01574, 00230, 00230, 01504, 00274, 00230, 00530,
01343, 01325, 01277, 01125, 01277, 01325, 00367, 01105,
01477, 01125, 01777, 01325, 01777, 01125, 00713, 01125,
00230, 01303, 00363, 01157, 01167, 01147, 00367, 00730,
00330, 00377, 01125, 00330, 00333, 00274, 00230, 00430,
00174, 01020, 01313, 01417, 01023, 01427, 01317, 00716,
00716, 00464, 00133, 01125, 01377, 01325, 01377, 00707,
01227, 00327, 01507, 01527, 01707, 01717, 01513, 00656,
01377, 01125, 00330, 00230, 00377, 01125, 01477, 01607,
00657, 01627, 00277, 00667, 00677, 01013, 00303, 00656,
01477, 01325, 00230, 01517, 01325, 00430, 00333, 01623,
01033, 01037, 01047, 01057, 00313, 01727, 01067, 00656,
01577, 01325, 01513, 01325, 01477, 01325, 01677, 00323,
00343, 01003, 01237, 01207, 00353, 01217, 01243, 00656,
00664, 01677, 01060, 00103, 01060, 00234, 00571, 01647,
01060, 00564, 01713, 01060, 01366, 01440, 01211, 00203,
01330, 00464, 00745, 00750, 01050, 01150, 00203, 01142,
00213, 00756, 00630, 01650, 00024, 01521, 00271, 00235,
00464, 00527, 00716, 00642, 00157, 00406, 00157, 00014,
00210, 01714, 01724, 01451, 00310, 01020, 00004, 00232,
00410, 01514, 00345, 00455, 00432, 01166, 01324, 01077,
01317, 01670, 00216, 01074, 00716, 01646, 00216, 01304,
01356, 01506, 01314, 01156, 00742, 01160, 00216, 00070,
01020, 01772, 01772, 01112, 00447, 00216, 01020, 00024,
01026, 00420, 00271, 00564, 00747, 00034, 00015, 00172,
00735, 01224, 01563, 01650, 00345, 01234, 01540, 00432,
01074, 00132, 00372, 00643, 00732, 00732, 00720, 00720,
01152, 00623, 00106, 00544, 01560, 00620, 00620, 00106,
00372, 01360, 00507, 01152, 00557, 00464, 01017, 00420,
01214, 01670, 01074, 01146, 01017, 00630, 01007, 00742,
00756, 01650, 01020, 00256, 00502, 00502, 00777, 00716,
00716, 01612, 01512, 01615, 01204, 00402, 01007, 00024,
01647, 01404, 01670, 01074, 01546, 01627, 00751, 00271,
00235, 01670, 00410, 00232, 01434, 01661, 01211, 00510,
00351, 01313, 00735, 01234, 00017, 00406, 01007, 01211,
00507, 00735, 01224, 01051, 01734, 01660, 00734, 01054,
00210, 00345, 00455, 00464, 00067, 00710, 00072, 01603,
00432, 00574, 01530, 01574, 00742, 00272, 00730, 00372,
01670, 01612, 01410, 00466, 01112, 01417, 01756, 01756,
00256, 01474, 00630, 00516, 00174, 00656, 00706, 00706,
00706, 00432, 00474, 00630, 01674, 00630, 00372, 00232,
00774, 01530, 01130, 00374, 01730, 01730, 01230, 01130,
00272, 00241, 01647, 00724, 01747, 00464, 01351, 00464,
01151, 00416, 00420, 00574, 00630, 00310, 00210, 01156,
01677, 00310, 00203, 00420, 00224, 01774, 00714, 00614,
00204, 01424, 01054, 01113, 01211, 00664, 00263, 00506,
00040, 00040, 01540, 00040, 00040, 01440, 00000, 01673,
00040, 01440, 00432, 01160, 01770, 01020, 01374, 00603,
01070, 00764, 00063, 00101, 00410, 00764, 00611, 00764,
01135, 00232, 00047, 00432, 01074, 00130, 01160, 01020,
00310, 00114, 01214, 00045, 01050, 01014, 01314, 01614,
00432, 00650, 00750, 00115, 00510, 00232, 01624, 00142,
00015, 01366, 00074, 01604, 01362, 00070, 01262, 01004,
00650, 00750, 01070, 00550, 01070, 01224, 00126, 00011,
01050, 01262, 00232, 00051, 00001, 00372, 01770, 00272,
00045, 00232, 01322, 00053, 01050, 00670, 01366, 01071,
01204, 01334, 00045, 00570, 00011, 01127, 00025, 01050,
01362, 00053, 00670, 01366, 01071, 01324, 00224, 00274,
00464, 00023, 01034, 00145, 01262, 00015, 00670, 00005,
00650, 01324, 00167, 01362, 00157, 01304, 00363, 01262,
00272, 00770, 00001, 01362, 00074, 00670, 00347, 01562,
00074, 00051, 00410, 00045, 00510, 01050, 00432, 00650,
00115, 00670, 00001, 00650, 01070, 00011, 01050, 01562,
00200, 00670, 00272, 00155, 00432, 00774, 00530, 01156,
00015, 01750, 01174, 00603, 00570, 00272, 00155, 01516,
00232, 01666, 01666, 01670, 00474, 00206, 01574, 00206,
01650, 00710, 01124, 00245, 01310, 00045, 01314, 01050,
00610, 00432, 00550, 00750, 00210, 00115, 00510, 00015,
00770, 00005, 00750, 00115, 00232, 00025, 00432, 00530,
01156, 00021, 00710, 00005, 00410, 00101, 00125, 00510,
00015, 00410, 00101, 00272, 00045, 00510, 00015, 00570,
00005, 00550, 00115, 00710, 00001, 00610, 01070, 00011,
01050, 00272, 01324, 00475, 00570, 00410, 00155, 01670,
00232, 01574, 00006, 00732, 01556, 00337, 01766, 00232,
01426, 00344, 00045, 01263, 00710, 01750, 00051, 00510,
01650, 01304, 00045, 00770, 00650, 01247, 00432, 01160,
01670, 01156, 01156, 01362, 00437, 01552, 00437, 01674,
00603, 01460, 00000, 00000, 00000, 00000, 00000, 00000,
00040, 00040, 01540, 00040, 00040, 00040, 00040, 01040,
01040, 01040, 01440, 01440, 01440, 01440, 01440, 01064,
00127, 00064, 01737, 00000, 00072, 00366, 00232, 00057,
01170, 00474, 00406, 01362, 00437, 00756, 01776, 01020,
00404, 00310, 00210, 00164, 01233, 00410, 00510, 00416,
00064, 01713, 00141, 00764, 00063, 00045, 00710, 01650,
01410, 01414, 00045, 00255, 01064, 01671, 00011, 00114,
00710, 01124, 00533, 01310, 00557, 01262, 00272, 00045,
00001, 01362, 00342, 01670, 00272, 00041, 00670, 01262,
00031, 00610, 00570, 00272, 00770, 00031, 00710, 00005,
00064, 01665, 00055, 01070, 00272, 00770, 01262, 00031,
00201, 00310, 01414, 00055, 01104, 01714, 01724, 00535,
00032, 00072, 01314, 00055, 00065, 01474, 00042, 00055,
00045, 00232, 01424, 00556, 00432, 01650, 00736, 01516,
00562, 01676, 00041, 01170, 00474, 00246, 00232, 01150,
01724, 01065, 00251, 00075, 01524, 01074, 00232, 01262,
00121, 00065, 00201, 00310, 00610, 00071, 00025, 01352,
00613, 00556, 01727, 00055, 00071, 00055, 00105, 01366,
00625, 00071, 00035, 00055, 01153, 00251, 00075, 00232,
01262, 00121, 00251, 01262, 00372, 00061, 00021, 00071,
00064, 00105, 00410, 00055, 01424, 00772, 00251, 00075,
00045, 00510, 00015, 01262, 00232, 01670, 00232, 01650,
00710, 00015, 01670, 00005, 01650, 00071, 00055, 00251,
00075, 00132, 00071, 00005, 00055, 00065, 00105, 01366,
00704, 00051, 00241, 01503, 00051, 00251, 00075, 00232,
00750, 00011, 00770, 00021, 00432, 00530, 01156, 00021,
00055, 00251, 00072, 00366, 00232, 00051, 00025, 00045,
01670, 00005, 01650, 00041, 00141, 01464, 01035, 00272,
01362, 00556, 00065, 01424, 01125, 01326, 01065, 00045,
01670, 00225, 01064, 00155, 01770, 00005, 00406, 00130,
00530, 00216, 00256, 01264, 00143, 01152, 01152, 01552,
01131, 01057, 00071, 00055, 00310, 01557, 00000, 00000,
00040, 00040, 00040, 01540, 00040, 00040, 01040, 01040,
01040, 01040, 01440, 01440, 01440, 01440, 01440, 00140,
01140, 00410, 00314, 01140, 00005, 00061, 00064, 01713,
00556, 00177, 00416, 00272, 00172, 00126, 00263, 01516,
01045, 00126, 01426, 01035, 00153, 01074, 00416, 00130,
01056, 00257, 00263, 01404, 00061, 00035, 01262, 00262,
00051, 00011, 00055, 01434, 00540, 00061, 00101, 00756,
00756, 00611, 01650, 01227, 00310, 00210, 01424, 01113,
00065, 00232, 01262, 00232, 00045, 01670, 00121, 00272,
00045, 00232, 01650, 00041, 01164, 00251, 00372, 00065,
00121, 00055, 00065, 01164, 01757, 01271, 00611, 01550,
01227, 00216, 01424, 01126, 00071, 00101, 00611, 01650,
00764, 01113, 00372, 00045, 00332, 00364, 00753, 00045,
01414, 01262, 00410, 01470, 00272, 01370, 00737, 01214,
01404, 00045, 00410, 01470, 01262, 00272, 01570, 01262,
00372, 00041, 00372, 00650, 00232, 00750, 00031, 00105,
00510, 00072, 00366, 00272, 01326, 01221, 00404, 00604,
01764, 01705, 00075, 00031, 00064, 01121, 00041, 00075,
01113, 00015, 00770, 00021, 00075, 01224, 01231, 01070,
00021, 00324, 01235, 00055, 01255, 01224, 01260, 00051,
00011, 01434, 01126, 00611, 01350, 00610, 01124, 01251,
01310, 00464, 00707, 00031, 01564, 00025, 00051, 00027,
00075, 00045, 01570, 01262, 00005, 00051, 01755, 01262,
00611, 01450, 01227, 00045, 01570, 01214, 00272, 01370,
00001, 00055, 00045, 01470, 01262, 00410, 00031, 00115,
00105, 00324, 01315, 01255, 00055, 00065, 00045, 01370,
01735, 00410, 00770, 01366, 01365, 00065, 00025, 01262,
00262, 01362, 01347, 01366, 01362, 01204, 00065, 00045,
01570, 01262, 01735, 00065, 00025, 01562, 00367, 01764,
01701, 00055, 00071, 01764, 01701, 00061, 00035, 01224,
01362, 01262, 00611, 01750, 01227, 00510, 01713, 00021,
00061, 00011, 00071, 01366, 00367, 00037, 00232, 01470,
00040, 00040, 00000, 01470, 00040, 00230, 00040, 00040,
01040, 01040, 01440, 01440, 00045, 01262, 01564, 00027,
00272, 01074, 00230, 01160, 00232, 00550, 00432, 01160,
01624, 01450, 01570, 01324, 01376, 00257, 00272, 01074,
00230, 01160, 00232, 00650, 00432, 01160, 01624, 01432,
01370, 01334, 01376, 00272, 00072, 00126, 01020, 00171,
00101, 00041, 00570, 01262, 00021, 01562, 00367, 00750,
00670, 00272, 00570, 00650, 00432, 00025, 00045, 00015,
00410, 00041, 00510, 00550, 00021, 00770, 00005, 00064,
01365, 00570, 00262, 00570, 00007, 00432, 01172, 00430,
00766, 01474, 00730, 00005, 01362, 00367, 00432, 00130,
01750, 01770, 01366, 00367, 00064, 01651, 00055, 00221,
01262, 00262, 00055, 00131, 01332, 00367, 00051, 00064,
01711, 01522, 00367, 00164, 01231, 01264, 00333, 00650,
00432, 00230, 00272, 00045, 00031, 00055, 00770, 00164,
01217, 01326, 00367, 01164, 00227, 00314, 01304, 00334,
01602, 01314, 01414, 01614, 00061, 01770, 01562, 00367,
00015, 01366, 01531, 00061, 01362, 01515, 00015, 00101,
00171, 00410, 00041, 00510, 00750, 00670, 00005, 01262,
00451, 00550, 00670, 01262, 00232, 00770, 00001, 00570,
00745, 01366, 01071, 01362, 01646, 01604, 00061, 00275,
00550, 00670, 00745, 01562, 01705, 01366, 01705, 00675,
00272, 00045, 00232, 01650, 00610, 00210, 01124, 01671,
01310, 00061, 00410, 00041, 00510, 00550, 00064, 01761,
00570, 01522, 01715, 00222, 01713, 01404, 00131, 00041,
00570, 00745, 01562, 00367, 01323, 00021, 00432, 00630,
00035, 00045, 00035, 00015, 00101, 00041, 00455, 00750,
00171, 00041, 00455, 01424, 01736, 00650, 00770, 00021,
01262, 00750, 01562, 01762, 00045, 00064, 01651, 01770,
01262, 00005, 00432, 00330, 00035, 00371, 00670, 01434,
01774, 00035, 01434, 01775, 01562, 01767, 00610, 00710,
00675, 00650, 01764, 00077, 00755, 01764, 00437, 01731,
00432, 01074, 00230, 01160, 00164, 00467, 01037, 00256,
00437, 01040, 01727, 01203, 01077, 00127, 00003, 00432,
01074, 00230, 01160, 00164, 00553, 00432, 01074, 00230,
01160, 00164, 00567, 00774, 00272, 01552, 00056, 00726,
00620, 01526, 00053, 00406, 00216, 00410, 00416, 01156,
00222, 00064, 00463, 01156, 00177, 00217, 00432, 00410,
00232, 01020, 00032, 00774, 01610, 00344, 00126, 00620,
01116, 00327, 00272, 00516, 00037, 00256, 00720, 01144,
00104, 00656, 00373, 00457, 00432, 01020, 00620, 00344,
00126, 01116, 00433, 00072, 00146, 00466, 00523, 00022,
00662, 00756, 01672, 00620, 00006, 00226, 01020, 01031,
01075, 01125, 01251, 01201, 01271, 00741, 00272, 01725,
00232, 00650, 01031, 01075, 00701, 01251, 01201, 01271,
00741, 00364, 00751, 00364, 01141, 00670, 00464, 00033,
01755, 00370, 01231, 01075, 01755, 00272, 00470, 01163,
01522, 00562, 00064, 01367, 01755, 00170, 00232, 00370,
01235, 01075, 01755, 00272, 00570, 01163, 01755, 00072,
00366, 00232, 00064, 01737, 01262, 00064, 00071, 00432,
01074, 00230, 01160, 00164, 00343, 01755, 00170, 01231,
01075, 01755, 00272, 00270, 01241, 01201, 00064, 00107,
00432, 01074, 00230, 01160, 00164, 00173, 00272, 01262,
00064, 00747, 01755, 00410, 00510, 00416, 01366, 00562,
00064, 01137, 01755, 00570, 00072, 00366, 00232, 00170,
01255, 00464, 00447, 00761, 01075, 00710, 00232, 01755,
01241, 00370, 01061, 01125, 01711, 00164, 00101, 01755,
00170, 01543, 01125, 01075, 00710, 00232, 01755, 01241,
00170, 01061, 00761, 01711, 00164, 00101, 01755, 00370,
00064, 00755, 01201, 01171, 01201, 01271, 01251, 00272,
01725, 00232, 00650, 01125, 01075, 00701, 01711, 00741,
01075, 00761, 01201, 01271, 00364, 00751, 01310, 00670,
00464, 00223, 01201, 00064, 00773, 01074, 00432, 00230,
01160, 00432, 01020, 00432, 01160, 00070, 01020, 00000,
01174, 00464, 00023, 00027, 00043, 00072, 00366, 00232,
00064, 01763, 01714, 00314, 01724, 00412, 00661, 00710,
00550, 01366, 00400, 01562, 00400, 01464, 00155, 01566,
00400, 00432, 01160, 01570, 00671, 01550, 01470, 00671,
01450, 00432, 00610, 01124, 00446, 01310, 00710, 01310,
01670, 01156, 01156, 00232, 01570, 00064, 00745, 00671,
00232, 00324, 00467, 01770, 01566, 00467, 00032, 01470,
00372, 00661, 00232, 00650, 00232, 00122, 00710, 00641,
00610, 00670, 00232, 00432, 01160, 01470, 00641, 00232,
00661, 00232, 00650, 01010, 00641, 01310, 00670, 00272,
00432, 01160, 01570, 00641, 01550, 01770, 00025, 01750,
00661, 00570, 01464, 01035, 00550, 01724, 00546, 01366,
00546, 00210, 00416, 01160, 01362, 00450, 00464, 00467,
00064, 00061, 00364, 00753, 01464, 01727, 01464, 00313,
00374, 00007, 00574, 00007, 01574, 00007, 01204, 01210,
00661, 01314, 00314, 01414, 01514, 00232, 00774, 01777,
01214, 01464, 00155, 01566, 00560, 00737, 01664, 01315,
01010, 01310, 00232, 00464, 00223, 00410, 01010, 00570,
00272, 00432, 01160, 00510, 00610, 01250, 01674, 00642,
01375, 00064, 01111, 01464, 00155, 01371, 00064, 00745,
01556, 00714, 01366, 00714, 00272, 00620, 00520, 01654,
00645, 00710, 00420, 01162, 01556, 00657, 01772, 00174,
01730, 00232, 00202, 01064, 00155, 00474, 00330, 01574,
00330, 00110, 00372, 00114, 00764, 00023, 00272, 00432,
00774, 00730, 01020, 01772, 01324, 00710, 01534, 01363,
01402, 01360, 01664, 01717, 00730, 00774, 01223, 00010,
00772, 00610, 00432, 00610, 00410, 00410, 01110, 01110,
01110, 00372, 00132, 01710, 01710, 00764, 01277, 01310,
00572, 01110, 01110, 00414, 01160, 00372, 00070, 00532,
00232, 00424, 00772, 00472, 00232, 01110, 01110, 01110,
01360, 00432, 00070, 01110, 01360, 00332, 01156, 01623,
01110, 01020, 01032, 00000, 01663, 00750, 00710, 01562,
00560, 00535, 00174, 01546, 00560, 00575, 00432, 00474,
00330, 01424, 00703, 00474, 01426, 01022, 01126, 00174,
00006, 00774, 00130, 00532, 01235, 00755, 00232, 01325,
01115, 01331, 01141, 01265, 00661, 01325, 00550, 00715,
01056, 00426, 01755, 00661, 01331, 01025, 00130, 00230,
00130, 00530, 01325, 01025, 01051, 00374, 00430, 01101,
01131, 01331, 01615, 01615, 00725, 01241, 00755, 00232,
01325, 01115, 01331, 00570, 01325, 00661, 01325, 01025,
01171, 01131, 00535, 00474, 00475, 00030, 00430, 01426,
01300, 01070, 01166, 01174, 00402, 00751, 00327, 01672,
01070, 00206, 01574, 00206, 01050, 00272, 01007, 01156,
00563, 00416, 01746, 01373, 01556, 00560, 01373, 00324,
01276, 00266, 00674, 00706, 00706, 01615, 00226, 00726,
00726, 00206, 00232, 01373, 01025, 00430, 00730, 01030,
00130, 00630, 00430, 01474, 01107, 01672, 00474, 01070,
00206, 00216, 01050, 01070, 00232, 00726, 00726, 00726,
00726, 00726, 00016, 00656, 00022, 00432, 01474, 00230,
00774, 01020, 00650, 00330, 00630, 01424, 01222, 00530,
00230, 00530, 01020, 00755, 00430, 00416, 00064, 01113,
01070, 01574, 00406, 00525, 01171, 01253, 00330, 00030,
01424, 01245, 00630, 00274, 00130, 01156, 01020, 00725,
00556, 01051, 00064, 00745, 01333, 01070, 00274, 00406,
00232, 00775, 01353, 00650, 00770, 01262, 01464, 00155,
00510, 00232, 00670, 00064, 00061, 00650, 00272, 01020,
01141, 00535, 01615, 00274, 00475, 00130, 00430, 00774,
01426, 01315, 01130, 01130, 01507, 01030, 00730, 01674,
00130, 00626, 00575, 01156, 00064, 00461, 00272, 00210,
01324, 01346, 01210, 01751, 01304, 01224, 00775, 00272,
00710, 01355, 00173, 01666, 01666, 01020, 01234, 00615,
00710, 01751, 01315, 01404, 01010, 01310, 00232, 00007,
01574, 01504, 00002, 01235, 01141, 01265, 01334, 00606,
01314, 01567, 01072, 01572, 00560, 00570, 01020, 01460,
00040, 01240, 00045, 01470, 00040, 00040, 00000, 01040,
01040, 01040, 01440, 01440, 01440, 01440, 01440, 00410,
00045, 00510, 01650, 01364, 00061, 00404, 01364, 00725,
00045, 01670, 01262, 01564, 00025, 00051, 01326, 01442,
00425, 00227, 00045, 01464, 01035, 00710, 01262, 00021,
01364, 00275, 01364, 00101, 00041, 00570, 01164, 00225,
00710, 00021, 00045, 01670, 00064, 01121, 00232, 00041,
00232, 00650, 00045, 01464, 01035, 00064, 01665, 00055,
00770, 00164, 01215, 00663, 00065, 00064, 01713, 01562,
01513, 01364, 00675, 00550, 01364, 00221, 00410, 01470,
01262, 00272, 00041, 00510, 00650, 00001, 00670, 01164,
00225, 00610, 00570, 01262, 00272, 00710, 00001, 00570,
01522, 01554, 00045, 01670, 01262, 00272, 00710, 00001,
00710, 01522, 01554, 01670, 00404, 00072, 00366, 00272,
00055, 00210, 01364, 00061, 00055, 00065, 00164, 01231,
00055, 01364, 00221, 00051, 00025, 00421, 00055, 00071,
00055, 00222, 01262, 00222, 00064, 01761, 00071, 01366,
01613, 00035, 01073, 00045, 01464, 01035, 00055, 00011,
00071, 00005, 00055, 01364, 00131, 00051, 00005, 00055,
00071, 01366, 01723, 00055, 01364, 00061, 00071, 00005,
00055, 00065, 00222, 01262, 00222, 00064, 01761, 00051,
01326, 01731, 00425, 00011, 00055, 01364, 00131, 01770,
00021, 00051, 00005, 00421, 01434, 01673, 00055, 01364,
00061, 00051, 00005, 01562, 01743, 00432, 00130, 00130,
00216, 00256, 00556, 01653, 00272, 00172, 01014, 00061,
00035, 01262, 00262, 00051, 00005, 00364, 00751, 00254,
01723, 01034, 01560, 01634, 01727, 00064, 01665, 01264,
00333, 01364, 00061, 01770, 01262, 00021, 00432, 00230,
00064, 01121, 01257, 00416, 01004, 01074, 00130, 01056,
01437, 01433, 01516, 01743, 00266, 01466, 01704, 01433,
00614, 01014, 00062, 00232, 00272, 00756, 00164, 00653,
00000, 00000, 00000, 00000, 00000, 00000, 00000, 00360
};
