/*
 * x11-calc-38e.c - RPN (Reverse Polish) calculator simulator.
 *
 * Copyright(C) 2018   MT
 *
 * Model specific functions.
 *
 * This  program is free software: you can redistribute it and/or modify it
 * under  the terms of the GNU General Public License as published  by  the
 * Free  Software Foundation, either version 3 of the License, or (at  your
 * option) any later version.
 *
 * This  program  is distributed in the hope that it will  be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without even   the   implied   warranty   of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You  should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 11 Dec 22         - Initial version derived from hp38c - MT
 * 21 Oct 23         - Updated switch parameters to accomodate a 3 position
 *                     switch - MT
 *
 */

#define NAME           "x11-calc-38e"
#define BUILD          "0002"
#define DATE           "21 Oct 23"
#define AUTHOR         "MT"

#include <stdarg.h>    /* strlen(), etc. */
#include <stdio.h>     /* fprintf(), etc. */
#include <stdlib.h>    /* getenv(), etc. */

#include <X11/Xlib.h>  /* XOpenDisplay(), etc. */
#include <X11/Xutil.h> /* XSizeHints etc. */

#include "x11-calc-font.h"
#include "x11-calc-button.h"
#include "x11-calc-switch.h"
#include "x11-calc-label.h"
#include "x11-calc-colour.h"

#include "x11-calc-cpu.h"

#include "x11-calc.h"

#include "gcc-debug.h"

oregister o_mem[MEMORY_SIZE];

void v_init_switches(oswitch *h_switch[]) /* Define the switches. */
{
   h_switch[0] = h_switch_create(00000, "OFF", "", "ON ", h_alternate_font, KBD_LEFT, KBD_TOP, 2 * KEY_NUMERIC + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
   h_switch[1] = h_switch_create(00000, "BEGIN", "", "END", h_alternate_font, KBD_LEFT + 3 * KEY_WIDTH + 2 * KEY_GAP, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
}

void v_init_buttons(obutton *h_button[]) {
   int i_left, i_top;

   /* Define top row of keys. */
   i_top = KBD_TOP + 2* (SWITCH_HEIGHT + 1); /* Assumes the function label and switch text use the same font */
   i_left = KBD_LEFT;
   h_button[0] = h_button_create(00064, 'n', "n", "AMORT", "", "12\xd7", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[1] = h_button_create(00063, 'i', "i", "INT", "", "12\xf7", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[2] = h_button_create(00062, 000, "PV", "NPV", "", "CF\xb0", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[3] = h_button_create(00061, 000, "PMT", "RND", "", "CF\xb9", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[4] = h_button_create(00060, 000, "FV", "IRR", "", "N\xb9", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define second row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[5] = h_button_create(00224, 000, "STO", "V\xaf", "", "yX", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[6] = h_button_create(00223, 000, "RCL", "%T", "", "eX", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[7] = h_button_create(00222, 000, "%", "d %", "", "LN", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[8] = h_button_create(00221, 'f', "f", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False,  YELLOW, BACKGROUND, YELLOW, YELLOW);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[9] = h_button_create(00220, 'g', "g", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_BLUE, BACKGROUND, LIGHT_BLUE, LIGHT_BLUE);

   /* Define third row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[10] = h_button_create(00163, 015, "ENTER", "PREFIX", "", "LAST X", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, 2 * KEY_WIDTH + KEY_GAP, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += 2 * (KEY_WIDTH + KEY_GAP);
   h_button[11] = h_button_create(00162, 'c', "CHS", "FIN", "", "EEX", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[12] = h_button_create(00161, 'e', "X-Y", "E", "", "Rv", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[13] = h_button_create(00160, 033, "CLX", "ALL", "", "CLP", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, YELLOW, MID_BLUE, BLACK);

   /* Define fourth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[14] = h_button_create(00243, '-', "-", "d DAYS", "", "P/R", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[15] = h_button_create(00242, '7', "7", "", "", "GTO", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[16] = h_button_create(00241, '8', "8", "", "", "BST", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[17] = h_button_create(00240, '9', "9", "", "", "SST", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define fifth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[18] = h_button_create(00143, '+', "+", "DATE", "", "MEM", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[19] = h_button_create(00142, '4', "4", "", "", "PSE", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[20] = h_button_create(00141, '5', "5", "", "", "X\x1a\x59", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[21] = h_button_create(00140, '6', "6", "", "", "X=0", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define sixth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[22] = h_button_create(00323, '*', "\xd7", "INTGR", "", "FRAC", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[23] = h_button_create(00322, '1', "1", "", "", "x,r", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[24] = h_button_create(00321, '2', "2", "", "", "y,r", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[25] = h_button_create(00320, '3', "3", "", "", "n\xb0", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define bottom row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[26] = h_button_create(00103, '/', "\xf7", "1/x", "", "xw", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP );
   h_button[27] = h_button_create(00102, '0', "0", "", "", "x", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[28] = h_button_create(00101, '.', ".", "", "", "s", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[29] = h_button_create(00100, 000, "R/S", "E+", "", "E-", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
}

int i_rom[ROM_SIZE] = {
   00310, 00656, 00656, 01710, 01074, 00221, 00742, 01160,
   01260, 00432, 01160, 00574, 01530, 01260, 01050, 00010,
   00110, 00114, 01445, 00610, 00432, 01160, 00710, 00234,
   00263, 01264, 01643, 00034, 00020, 00110, 00004, 00107,
   00000, 00000, 00000, 01460, 00742, 01160, 01260, 01020,
   00032, 01610, 00266, 00410, 00510, 00774, 00422, 00620,
   01116, 00277, 00544, 00077, 01552, 00115, 01156, 00353,
   00016, 00507, 00344, 00075, 00620, 00762, 00333, 00510,
   00422, 01074, 01352, 00105, 01206, 01674, 00272, 00706,
   00706, 00706, 01104, 00574, 00563, 00016, 01672, 00756,
   00473, 00072, 00146, 00132, 00472, 01536, 00137, 01566,
   00077, 01522, 01771, 00262, 00420, 01106, 01020, 00006,
   01532, 00131, 00620, 00132, 00507, 00604, 00724, 00264,
   00716, 00716, 00710, 01715, 01174, 00642, 00713, 00706,
   00720, 00667, 01102, 00744, 00264, 01144, 00172, 00624,
   00172, 00662, 00172, 00620, 00620, 01106, 00132, 00520,
   00774, 01676, 00262, 01410, 01536, 00256, 00032, 00232,
   00132, 01257, 00710, 00372, 00432, 01134, 00221, 01674,
   00630, 00222, 00262, 00774, 01322, 00231, 00430, 01274,
   00620, 01162, 01143, 00742, 00244, 01015, 00720, 00244,
   01015, 00720, 00244, 01015, 00720, 00742, 00742, 01157,
   01366, 00264, 01262, 00014, 00610, 01323, 01502, 00207,
   01116, 00726, 01273, 00241, 00224, 00031, 01051, 00016,
   01414, 01410, 00310, 00210, 01714, 01724, 00274, 01734,
   00277, 00310, 00754, 00400, 00710, 00434, 00033, 01264,
   00773, 00774, 01366, 00376, 01410, 01352, 00324, 01156,
   00752, 01152, 01527, 00756, 01020, 00552, 01547, 01274,
   01773, 00406, 01146, 00412, 00214, 01274, 01020, 00274,
   00432, 00214, 00420, 01172, 00072, 00720, 00752, 00154,
   00345, 01630, 01230, 01230, 01430, 01230, 00232, 00732,
   00732, 00732, 01337, 00420, 00724, 00377, 00024, 00371,
   01310, 01114, 00704, 00036, 01126, 00114, 00432, 01020,
   01064, 00003, 00630, 01130, 00330, 00130, 00430, 00730,
   00130, 01030, 00030, 00530, 00530, 01146, 00774, 01020,
   00072, 00126, 00410, 00510, 00416, 00062, 00422, 00774,
   00410, 01074, 00620, 00652, 00752, 00254, 00432, 00372,
   01372, 00502, 00410, 00132, 01372, 00502, 01456, 00606,
   01022, 01522, 00454, 00343, 01232, 00262, 01456, 00470,
   00410, 00232, 00732, 00232, 00410, 00132, 01116, 00132,
   01456, 00502, 00656, 01772, 00222, 00262, 00620, 01154,
   00470, 00032, 00232, 00510, 00372, 00472, 01152, 01152,
   01152, 00232, 00410, 00510, 01362, 00520, 00656, 01772,
   00232, 00774, 01506, 00550, 00372, 00232, 00774, 00272,
   00556, 00633, 00766, 00633, 00316, 00756, 00742, 00322,
   00132, 01566, 00545, 00432, 00022, 01020, 00316, 00577,
   01502, 00524, 01156, 00706, 00643, 00072, 00126, 00410,
   00510, 00416, 00062, 00422, 00410, 00616, 01062, 00747,
   01222, 00032, 00410, 01274, 00720, 01672, 01003, 00472,
   01142, 00777, 00254, 00574, 00510, 00447, 00410, 00132,
   01456, 00613, 00233, 00232, 00410, 01432, 00622, 00410,
   00232, 00243, 00410, 00232, 00410, 00132, 00243, 00072,
   00126, 00410, 00510, 00416, 00062, 00422, 01366, 00337,
   00410, 01056, 01062, 01227, 01222, 00410, 00232, 00132,
   01472, 00656, 00410, 00732, 01156, 00410, 00774, 00432,
   01313, 00742, 01032, 01307, 00472, 00732, 00620, 01154,
   00662, 00232, 00510, 00523, 00072, 00366, 00232, 00432,
   00410, 00432, 00774, 00130, 00372, 00232, 00410, 00232,
   01163, 00432, 01262, 00774, 00130, 00113, 00432, 01457,
   00032, 00774, 01610, 00344, 00762, 00620, 01116, 01517,
   00272, 00516, 01717, 00256, 00720, 01144, 00376, 00656,
   01563, 01637, 00620, 00344, 00762, 01116, 01613, 00072,
   00146, 00466, 01703, 00022, 00662, 00756, 01672, 00620,
   00006, 00226, 01020, 00256, 01617, 00372, 00410, 01070,
   00266, 00166, 01726, 01726, 01726, 00374, 00346, 00356,
   01050, 00570, 00372, 00670, 00550, 00770, 00650, 00226,
   01772, 01772, 01772, 00362, 00410, 00372, 01020, 00570,
   00222, 00774, 00346, 00550, 01070, 01674, 00706, 00706,
   00706, 00206, 00216, 01050, 00273, 00670, 00750, 00570,
   00650, 00332, 00222, 00262, 00550, 01070, 00226, 00474,
   00706, 00706, 00706, 00226, 01050, 00206, 01646, 01646,
   01646, 01020, 00614, 01014, 00062, 00232, 00272, 00556,
   00603, 01522, 01146, 00232, 00411, 00774, 00232, 00436,
   00272, 00537, 00132, 00172, 00410, 00510, 01672, 01532,
   01114, 00510, 00232, 01020, 00756, 00433, 00774, 00642,
   00132, 00164, 01243, 00644, 01143, 00620, 00762, 00756,
   00517, 00132, 01113, 00072, 00366, 00232, 00604, 00317,
   00164, 01471, 00767, 00132, 00372, 01623, 01004, 00367,
   00774, 00332, 01142, 00232, 01532, 01157, 01527, 01502,
   01164, 01156, 00732, 00677, 00410, 00505, 00367, 00072,
   00366, 00232, 00604, 01326, 01757, 01014, 00062, 01522,
   00337, 01326, 00337, 00216, 00256, 01356, 01150, 00516,
   01057, 01256, 01004, 00036, 00236, 00032, 00774, 01006,
   01142, 00742, 00172, 00410, 00510, 01137, 01672, 01162,
   01133, 00510, 00472, 01122, 01107, 00762, 00132, 00732,
   00620, 01254, 01222, 00232, 00172, 00706, 00706, 00706,
   00232, 01474, 00730, 01216, 01316, 01343, 01374, 01672,
   00372, 00364, 00671, 00372, 01705, 01366, 01316, 01154,
   01257, 00072, 01474, 00142, 00472, 01672, 00372, 00364,
   00571, 01024, 01310, 00132, 01032, 00132, 00472, 00132,
   01174, 01705, 01366, 01316, 01672, 01447, 01522, 01351,
   01156, 00436, 01034, 01325, 01262, 00164, 00505, 00634,
   01366, 00164, 01725, 00164, 00711, 00510, 01362, 01421,
   01116, 00372, 01573, 01672, 00364, 01371, 00132, 01374,
   01307, 01672, 01507, 00072, 00366, 00232, 00614, 00767,
   00472, 01142, 01703, 00402, 00756, 00720, 01020, 01374,
   00330, 00330, 00330, 00030, 01030, 00330, 00530, 01574,
   01020, 00330, 00130, 00030, 00130, 00730, 01130, 01030,
   00030, 00430, 00330, 00230, 00474, 01020, 00072, 00366,
   00232, 01004, 01522, 01425, 01014, 00036, 00132, 00332,
   00556, 00233, 00332, 01522, 01451, 01274, 00620, 01244,
   01625, 00756, 00173, 00671, 00372, 01057, 00571, 01374,
   00273, 00132, 00656, 01732, 00127, 00766, 01032, 00267,
   00472, 00732, 01156, 00367, 01674, 01342, 01473, 01142,
   01542, 01502, 00742, 00774, 01117, 00232, 00726, 00232,
   01342, 01456, 00432, 00774, 01146, 00272, 00574, 00130,
   01034, 01513, 01256, 00132, 00272, 00134, 01525, 00264,
   00165, 00164, 01445, 00264, 00075, 00132, 00164, 00527,
   00574, 00330, 00330, 00330, 00274, 01020, 00774, 00230,
   00330, 00030, 00230, 00530, 01030, 00530, 00030, 01130,
   00230, 01130, 01130, 00430, 00372, 01020, 00432, 00244,
   00402, 01166, 00430, 00766, 01544, 01401, 00444, 01743,
   00144, 01367, 01644, 01602, 00644, 01530, 01474, 00330,
   01374, 01020, 00174, 00330, 00330, 00330, 00330, 00130,
   00374, 01020, 00742, 01032, 01053, 00472, 00644, 01626,
   00732, 01156, 00620, 00372, 00217, 00372, 00134, 01633,
   01371, 00232, 00132, 01274, 00630, 01674, 01366, 01724,
   00720, 01342, 01650, 01142, 00172, 00410, 00510, 01343,
   00756, 01672, 01162, 01173, 01772, 01772, 01772, 00642,
   00132, 00272, 01034, 01515, 00164, 01375, 00467, 01732,
   01162, 01337, 00472, 00662, 00510, 01207, 00410, 00510,
   00172, 00372, 00572, 00572, 00632, 00132, 01772, 01572,
   01714, 00510, 00232, 01020, 00656, 01433, 01232, 00422,
   00410, 00756, 00164, 01227, 00132, 00436, 00272, 01034,
   01734, 01262, 00264, 00411, 00134, 01740, 00264, 00165,
   00164, 01471, 00527, 00374, 00330, 00330, 00030, 01030,
   00530, 00330, 00130, 00630, 01030, 00674, 01020, 00164,
   01725, 01366, 00337, 00510, 01562, 00337, 00032, 00072,
   00467, 00762, 00620, 01672, 00064, 00557, 00000, 00116,
   00707, 01757, 00123, 00577, 01204, 00415, 00531, 00264,
   00555, 00270, 01315, 00245, 00370, 01315, 00111, 00401,
   00450, 00203, 00164, 01727, 00411, 00531, 00264, 00555,
   00470, 01315, 00245, 00370, 01315, 00111, 00401, 00250,
   01262, 00764, 00301, 00064, 01445, 01360, 00110, 00064,
   00113, 00264, 00075, 00531, 01224, 00057, 01262, 01366,
   00064, 00164, 01145, 00353, 00432, 01160, 00070, 00072,
   00366, 00232, 01334, 01465, 00521, 00531, 01315, 00111,
   00164, 00127, 01214, 00314, 01304, 01414, 01614, 01514,
   00334, 00113, 01314, 00432, 01160, 00070, 01224, 00121,
   01262, 00072, 00366, 00232, 00264, 00167, 00170, 01156,
   01156, 01362, 01465, 01552, 01465, 00574, 01337, 00411,
   00531, 00264, 00555, 00470, 01315, 00270, 00164, 00111,
   00245, 01366, 00135, 00671, 00350, 00203, 00111, 00164,
   01423, 00411, 00270, 01131, 01165, 01362, 00202, 01366,
   00202, 01204, 00470, 01262, 01131, 01165, 01366, 00202,
   01562, 00135, 00264, 00311, 01234, 00211, 00232, 01262,
   00232, 00521, 00531, 00072, 00366, 00232, 00264, 00311,
   00671, 00410, 00432, 01160, 00510, 00207, 00232, 00531,
   00164, 00665, 00521, 00370, 00337, 00111, 00401, 00521,
   00270, 00232, 00470, 00164, 00101, 00111, 01224, 00253,
   00410, 01262, 00410, 01366, 00135, 00164, 01161, 00410,
   00531, 01366, 00222, 00164, 00677, 01460, 01674, 00064,
   01603, 00174, 01337, 00774, 00272, 01552, 00316, 00726,
   00620, 01526, 00313, 00406, 00216, 00410, 00416, 01156,
   00222, 00164, 00507, 01156, 01377, 01417, 00432, 00410,
   00232, 01020, 00072, 00366, 00232, 00664, 00343, 00432,
   00530, 01162, 00766, 01474, 00330, 01216, 00164, 00111,
   01362, 00135, 00432, 00130, 00050, 00432, 01160, 00070,
   01366, 00135, 00164, 01361, 00521, 00564, 01151, 01262,
   00262, 00521, 00564, 01221, 01326, 00135, 00671, 00264,
   00751, 00664, 01257, 00411, 00564, 01121, 00070, 01562,
   00135, 01315, 01366, 00345, 01121, 01362, 00327, 01315,
   01215, 01145, 00750, 00670, 01535, 01262, 01525, 00550,
   00670, 01262, 00232, 00770, 01255, 01366, 00135, 01341,
   01366, 01257, 01362, 00435, 01604, 01121, 01401, 00550,
   00670, 01326, 00135, 01345, 01562, 00453, 01366, 00453,
   01545, 00150, 00303, 01404, 01221, 01326, 00135, 01341,
   00610, 00210, 00024, 00465, 01310, 01121, 00550, 01135,
   00570, 01362, 01110, 01522, 00477, 00222, 00617, 01331,
   01625, 00630, 01305, 00070, 01305, 01315, 01215, 01531,
   00750, 01145, 01531, 01424, 00516, 00650, 00770, 01331,
   01262, 00750, 01562, 00543, 01625, 00070, 00164, 01361,
   00070, 01262, 01535, 01625, 00330, 01305, 01471, 00670,
   01434, 00573, 01305, 01434, 00574, 01562, 00550, 00610,
   00710, 01545, 00150, 00550, 01121, 00104, 01605, 00170,
   01131, 00164, 01725, 01326, 00751, 01361, 01663, 01262,
   00272, 00710, 01257, 01345, 01562, 00577, 01545, 00550,
   01151, 00650, 00370, 01262, 01535, 00670, 01345, 00610,
   00570, 00735, 00570, 01522, 00623, 00170, 00735, 00710,
   01522, 00623, 00170, 01773, 01625, 00070, 01262, 00764,
   00657, 00650, 01624, 00646, 00470, 01334, 00651, 00272,
   00072, 00126, 01020, 00550, 01624, 00634, 00270, 01334,
   00637, 00232, 00370, 00164, 00103, 00264, 00167, 00164,
   00667, 00164, 01147, 00370, 01333, 01262, 00164, 00677,
   00570, 00410, 00510, 00416, 00164, 01423, 00464, 01527,
   00550, 01151, 00650, 01221, 00670, 01325, 01562, 00135,
   00750, 00570, 01175, 01625, 00230, 01305, 01315, 00550,
   01331, 00770, 01535, 01371, 00570, 00262, 00570, 00164,
   00113, 00550, 00114, 01625, 00230, 00272, 00070, 00164,
   01135, 01265, 00670, 00264, 00737, 00432, 01160, 00774,
   01020, 01121, 01262, 00262, 00710, 01325, 01401, 01215,
   01341, 00710, 01331, 00170, 01305, 00550, 01121, 01262,
   00262, 00164, 01375, 01265, 00670, 01615, 01175, 00104,
   00443, 01464, 00643, 01060, 00164, 01375, 01060, 01020,
   01060, 00007, 01060, 00464, 00531, 00033, 00000, 01060,
   00164, 01445, 00033, 00264, 00167, 01060, 00164, 00125,
   00033, 00000, 00000, 01060, 00164, 00711, 00033, 00164,
   01727, 01060, 00164, 01161, 00033, 01060, 00115, 00033,
   01060, 00175, 00033, 01060, 01605, 00033, 01060, 01505,
   00033, 01060, 01571, 00033, 00000, 01060, 01645, 00033,
   01060, 01664, 00225, 00033, 01060, 01664, 01055, 00000,
   00000, 01060, 00264, 00751, 01060, 00064, 01445, 00033,
   00115, 00210, 01411, 00115, 01505, 00264, 00751, 00115,
   00564, 01151, 00175, 00164, 00711, 01361, 00115, 01571,
   00115, 01631, 01571, 01366, 01140, 00164, 01161, 00617,
   01411, 01262, 00262, 00115, 01375, 01571, 01621, 00115,
   00564, 01221, 00175, 01621, 00115, 01571, 01366, 01247,
   00115, 01411, 01571, 01621, 00115, 01505, 01631, 00175,
   01326, 01262, 01365, 01375, 00115, 00564, 01221, 00432,
   01160, 00070, 01401, 00175, 01621, 01361, 01434, 01214,
   00115, 01411, 00175, 01621, 01562, 01304, 00432, 00774,
   00130, 00130, 00216, 00256, 00556, 01457, 00272, 00172,
   01014, 01605, 00164, 01161, 01262, 00262, 00175, 01621,
   01352, 01245, 00752, 01552, 01253, 01034, 01110, 01634,
   01253, 00164, 01375, 01631, 01262, 00756, 00756, 00150,
   00464, 00217, 01411, 00070, 01262, 01401, 00432, 00774,
   00230, 00164, 01145, 00757, 01505, 00164, 01423, 00370,
   00164, 00677, 00564, 01123, 00416, 01004, 01074, 00130,
   01056, 01147, 01143, 01516, 01304, 00266, 01466, 01226,
   01143, 00670, 00374, 00372, 00410, 01070, 00620, 01772,
   00354, 01326, 00362, 00232, 00410, 01020, 00770, 00474,
   01517, 00570, 01674, 01517, 00164, 00127, 00222, 01262,
   00222, 00164, 01473, 01160, 00232, 01360, 00232, 01142,
   01657, 00010, 01650, 01750, 00610, 01564, 00733, 00210,
   01714, 01724, 01370, 00310, 01020, 00000, 00000, 00000,
   01370, 00221, 00550, 01570, 00221, 00127, 01131, 00771,
   00151, 00235, 01001, 00255, 01031, 00550, 01131, 00771,
   01051, 00235, 01001, 00255, 01031, 00275, 01310, 00570,
   00064, 00103, 01370, 01011, 00771, 01470, 00272, 01270,
   01021, 01001, 00164, 00127, 00072, 00366, 00232, 01270,
   00410, 00510, 00416, 01366, 00266, 00164, 01163, 01651,
   00610, 00024, 01464, 01310, 00710, 01020, 01075, 00771,
   00710, 00232, 01270, 01021, 01570, 00755, 00151, 00741,
   00264, 00075, 01370, 00507, 00151, 00771, 00710, 00232,
   01270, 01021, 01370, 00755, 01075, 00741, 00264, 00075,
   01570, 00164, 00675, 01001, 00211, 01001, 00255, 00235,
   00550, 00151, 00771, 01051, 00741, 01031, 00771, 01075,
   01001, 00255, 01651, 01310, 00570, 00647, 01010, 01310,
   00232, 01464, 00643, 00072, 00366, 00232, 00164, 01473,
   01770, 00072, 00366, 00232, 01370, 00241, 00301, 00143,
   01001, 00164, 00713, 01262, 00164, 00111, 00264, 00167,
   00164, 01727, 00272, 01262, 00164, 00667, 01522, 00266,
   00464, 01527, 01570, 01011, 00771, 01670, 00173, 01370,
   00232, 01570, 01015, 00771, 01770, 00173, 01270, 00072,
   00366, 00232, 00164, 01447, 01714, 00314, 01724, 01634,
   00550, 01366, 00271, 01562, 00271, 00464, 01355, 01566,
   00271, 00270, 01661, 00250, 00370, 01661, 00350, 00432,
   00301, 01310, 00170, 01156, 01156, 00232, 00270, 01021,
   01661, 00324, 01703, 00232, 00432, 01160, 00070, 00232,
   01526, 01703, 00432, 00650, 00232, 00370, 00222, 00710,
   01641, 00610, 00670, 00232, 00370, 01641, 00650, 01010,
   01641, 01310, 00670, 00232, 00270, 01641, 00250, 00432,
   01160, 00070, 00655, 00050, 00570, 01135, 00550, 01724,
   01746, 01366, 01746, 00210, 01362, 01662, 00710, 00143,
   00164, 00101, 00064, 01447, 00164, 01503, 00212, 00752,
   00752, 00032, 01160, 00232, 01360, 00232, 00756, 00752,
   01713, 00432, 01160, 00574, 01530, 01264, 00633, 00225,
   00420, 00432, 00020, 01116, 01116, 01116, 01116, 00174,
   01116, 01116, 01614, 00716, 00064, 01343, 01544, 00126,
   00144, 00051, 00474, 01147, 00656, 01244, 00044, 00544,
   00260, 00044, 00044, 00656, 00716, 00354, 00040, 00774,
   00720, 01116, 01154, 00040, 01614, 01264, 00323, 00274,
   00607, 01074, 01330, 00673, 01102, 01624, 01376, 00227,
   00343, 01323, 01407, 00656, 00354, 00303, 00374, 00563,
   00354, 00277, 00674, 00763, 00674, 01147, 00274, 00127,
   01767, 01613, 00127, 00144, 00270, 01544, 00116, 00444,
   00006, 01074, 01530, 01130, 00216, 00223, 00374, 00567,
   00554, 00310, 01604, 00063, 00774, 01147, 01074, 01330,
   01063, 00144, 01247, 00656, 00656, 00656, 00044, 01125,
   00656, 00656, 01477, 00144, 00557, 01544, 00337, 00444,
   00004, 01074, 01230, 00457, 01074, 01230, 01030, 00463,
   01663, 00767, 00773, 00444, 00401, 01554, 00177, 00424,
   00124, 01564, 00027, 00656, 00656, 00656, 00656, 00656,
   01544, 00205, 00144, 00205, 00774, 00620, 01467, 01074,
   01430, 00673, 01074, 01230, 00730, 00463, 00574, 01147,
   01357, 00363, 00757, 00073, 01544, 00212, 00144, 00154,
   01574, 00016, 00053, 00144, 01130, 00563, 01674, 00043,
   00547, 01157, 01263, 00144, 01173, 01544, 00334, 00444,
   00003, 01074, 01330, 00457, 00154, 00135, 01074, 01147,
   01502, 00054, 00656, 00057, 00354, 00300, 00674, 00777,
   01074, 01530, 00673, 01444, 00216, 00374, 01147, 00656,
   00656, 00656, 00656, 01444, 00076, 00444, 00047, 00656,
   01544, 00315, 00144, 00315, 00774, 00656, 00557, 00656,
   00656, 00656, 00123, 00144, 00352, 01544, 00207, 00444,
   00005, 01074, 01430, 00457, 01074, 01430, 01063, 01074,
   01530, 01063, 00444, 00236, 00044, 01125, 01454, 00120,
   01674, 00047, 00374, 00763, 01070, 00144, 00561, 01554,
   00174, 00424, 01176, 01260, 01074, 00406, 01050, 01756,
   01756, 00130, 00032, 00664, 01677, 00354, 00200, 00664,
   00227, 00010, 00772, 00610, 00432, 00610, 00410, 00410,
   01110, 01110, 01110, 01110, 00372, 00132, 01710, 01710,
   01132, 01532, 00541, 00341, 00232, 00574, 01530, 01050,
   00232, 00130, 00341, 01074, 00230, 00330, 00351, 00774,
   00064, 00215, 00571, 00464, 01325, 00571, 00515, 00571,
   01464, 01015, 00571, 00664, 00015, 00571, 01174, 00230,
   00754, 00457, 00372, 01030, 00754, 00463, 00064, 01673,
   01474, 01730, 00774, 00742, 01474, 00410, 00510, 01160,
   01360, 01142, 00377, 00510, 01160, 00232, 00070, 00232,
   01632, 01532, 00541, 01142, 00423, 01260, 01020, 01125,
   00330, 01303, 00220, 01460, 01105, 01777, 01325, 00530,
   00130, 01020, 01125, 01003, 01325, 01243, 00742, 00534,
   00661, 00774, 00416, 00610, 00064, 01603, 01125, 00730,
   01337, 01125, 01613, 01125, 01577, 01325, 00503, 01464,
   01543, 00434, 01203, 00256, 01756, 00752, 01756, 00764,
   01673, 01325, 00230, 00543, 00414, 01070, 00707, 01325,
   00730, 00543, 01325, 01577, 01105, 01677, 01325, 00630,
   00543, 01125, 01037, 01125, 01677, 00330, 00643, 01105,
   01377, 01574, 00230, 00230, 01504, 00274, 00230, 00530,
   01343, 01325, 01277, 01125, 01277, 01325, 00637, 01105,
   01477, 01125, 01777, 01325, 01777, 01125, 00753, 01125,
   00230, 01303, 00633, 01157, 01167, 01147, 00637, 00730,
   00330, 01020, 01125, 00330, 00543, 00274, 00230, 00430,
   00174, 01020, 01313, 01417, 01023, 01427, 01317, 00716,
   00716, 01364, 01537, 01125, 01377, 01325, 01377, 00747,
   01227, 00537, 01507, 01527, 01707, 01717, 01513, 00656,
   01377, 01125, 00330, 00230, 01020, 01125, 01477, 01607,
   00647, 01627, 00477, 00657, 00667, 01013, 00503, 00656,
   01477, 01325, 00230, 01517, 01325, 00430, 00543, 01623,
   01033, 01037, 01047, 01057, 00523, 01727, 01067, 00656,
   01577, 01325, 01513, 01325, 01477, 01325, 01677, 00533,
   00553, 01003, 01237, 01207, 00563, 01217, 01243, 00656,
   01164, 01677, 00404, 00232, 00410, 01514, 01455, 00725,
   00432, 01166, 01324, 01063, 01713, 00232, 00432, 00674,
   00630, 01534, 01025, 00374, 00330, 01474, 00730, 00372,
   01070, 01074, 00016, 00202, 01656, 01346, 01051, 00656,
   00656, 00756, 01474, 00237, 01410, 00456, 00420, 00742,
   00223, 01274, 00236, 00732, 00720, 01554, 01053, 00206,
   00226, 01130, 00226, 01020, 00434, 01362, 00172, 01045,
   01224, 01123, 01050, 01455, 01234, 01077, 00432, 01074,
   00132, 00372, 00437, 00732, 00732, 00720, 00720, 01152,
   00417, 00106, 00544, 01117, 00620, 00620, 00106, 00372,
   01360, 00741, 00773, 01152, 00353, 01174, 00064, 01603,
   01070, 01074, 01346, 01154, 01142, 00633, 00630, 00742,
   00742, 00627, 01074, 00130, 00633, 01156, 01050, 00424,
   01176, 00011, 01411, 01033, 00256, 01656, 00202, 01746,
   00756, 00630, 00633, 01772, 01772, 01112, 00717, 00216,
   00416, 01160, 01020, 00424, 00574, 00404, 00420, 00015,
   00065, 01064, 00523, 01074, 01371, 00214, 00710, 00064,
   00157, 00420, 01214, 01070, 00256, 01074, 01506, 01223,
   00742, 01050, 01020, 00002, 01506, 01231, 01730, 01630,
   01067, 00256, 00502, 00502, 01103, 01116, 00716, 00716,
   01612, 01512, 01244, 01204, 01156, 00402, 01107, 00424,
   01300, 01404, 01070, 01074, 01546, 01260, 00742, 01050,
   00011, 01411, 01070, 00410, 00232, 01434, 01360, 01355,
   00510, 01461, 01707, 01045, 01234, 01222, 00406, 01107,
   01355, 00773, 00065, 00414, 00664, 01737, 00574, 00630,
   00030, 01030, 01547, 01070, 00216, 01074, 00716, 01646,
   00216, 01304, 01356, 01332, 01314, 01346, 01306, 01156,
   00742, 01160, 00216, 00070, 01020, 00642, 01502, 01446,
   00424, 01710, 00734, 01346, 01124, 01470, 00064, 00653,
   01045, 01224, 01203, 01734, 01357, 00734, 01205, 00210,
   01455, 00725, 00574, 01230, 01230, 01074, 00716, 01412,
   01750, 01402, 01335, 00424, 01501, 01656, 00030, 00730,
   00356, 01074, 01070, 00406, 01410, 01116, 01033, 00214,
   01050, 00064, 01423, 01574, 00230, 00130, 01020, 00764,
   00003, 00752, 00353, 00205, 00363, 00232, 01070, 01756,
   00752, 01756, 01406, 01435, 00663, 00064, 01603, 00764,
   00333, 00070, 00232, 00710, 01410, 01020, 00642, 01563,
   01374, 00230, 00230, 00424, 01710, 01461, 01713, 00764,
   00423, 00174, 00424, 00522, 00215, 01474, 01564, 00220,
   01464, 00013, 00205, 01262, 00164, 00101, 01347, 00664,
   00243, 01574, 00230, 00530, 01374, 00730, 00174, 00706,
   01447, 00752, 00107, 00205, 00164, 00665, 01347, 01564,
   00367, 00642, 00723, 01102, 00574, 00730, 01412, 01461,
   01374, 00230, 00530, 00424, 01710, 00215, 00220, 01262,
   01210, 00164, 00101, 01362, 01206, 00677, 01074, 00130,
   00330, 01503, 01656, 01656, 00216, 01160, 01020, 01366,
   01206, 01264, 01355, 01633, 00574, 00530, 01612, 01527,
   00512, 00274, 00230, 00230, 00651, 00434, 01762, 00174,
   00130, 00402, 00742, 01156, 01013, 01020, 00234, 01613,
   01116, 01057, 00043, 01116, 01077, 00742, 00043, 00420,
   01146, 00420, 01156, 01410, 01006, 01107, 00446, 00716,
   00202, 00256, 00716, 00716, 00216, 01412, 01125, 00216,
   00043, 00652, 01247, 00055, 00424, 01704, 00631, 00710,
   01347, 00730, 01074, 01402, 01461, 00732, 00212, 01672,
   00216, 00424, 01673, 01461, 00752, 00447, 00205, 00164,
   01135, 01464, 00663, 00055, 01374, 01030, 00130, 01374,
   01142, 00752, 01403, 01443, 01374, 00730, 00330, 00716,
   01174, 00706, 00206, 01020, 01656, 01074, 00030, 01130,
   01656, 01074, 00606, 00127, 00167, 00274, 00061, 00651,
   00424, 01577, 01564, 00277, 00642, 01737, 01374, 00230,
   00430, 00424, 01710, 01656, 01656, 01710, 01264, 01033,
   01402, 01461, 00652, 01207, 01574, 00230, 00230, 00424,
   01704, 00631, 00070, 00764, 00301, 00064, 00103, 00642,
   00507, 01374, 00061, 00424, 01710, 01461, 01237, 00471,
   00056, 00123, 00174, 00710, 00706, 00172, 01410, 01674,
   01646, 01646, 01646, 00156, 00016, 01074, 01312, 00024,
   01006, 00003, 00146, 00016, 00520, 00456, 01522, 00033,
   01116, 00736, 00133, 00216, 00132, 00064, 01445, 01144,
   01257, 00064, 01257, 01674, 00202, 01242, 00202, 00027,
   00714, 00004, 00724, 00072, 00064, 01715, 00072, 00774,
   00742, 00242, 01674, 00106, 01104, 01526, 00041, 01114,
   00106, 00207, 01366, 00050, 00064, 01051, 01674, 01306,
   00063, 00207, 00464, 00505, 00714, 01210, 00710, 01522,
   00112, 00573, 00226, 01552, 00175, 00507, 01356, 00175,
   01156, 00736, 01526, 00116, 01556, 00136, 00222, 00262,
   00562, 00562, 00622, 01362, 00136, 00704, 01210, 00022,
   00232, 00114, 00264, 00735, 00734, 00147, 01262, 01010,
   01664, 00747, 01274, 00773, 00110, 01475, 01024, 00302,
   00610, 00064, 00113, 00264, 01655, 00643, 00114, 00364,
   00071, 00643, 00464, 01511, 00643, 00274, 00064, 01603,
   00164, 01361, 00643, 01460, 01010, 00164, 00101, 00643,
   01010, 01225, 00643, 01210, 00164, 01135, 00637, 01156,
   01156, 01210, 01225, 00643, 00072, 00366, 01210, 00232,
   01156, 01156, 00164, 01145, 00643, 01210, 00232, 01262,
   00164, 00101, 00232, 01133, 00272, 00164, 00667, 00272,
   01370, 01431, 00710, 01221, 01470, 01441, 01210, 01570,
   01431, 01210, 00232, 01221, 01670, 01441, 01210, 00710,
   01225, 01770, 01441, 00032, 00662, 01672, 01270, 01431,
   01034, 00471, 01374, 00773, 01074, 00773, 00072, 00126,
   01534, 00315, 00232, 01262, 00232, 00164, 00111, 00064,
   01445, 01366, 00326, 01154, 00326, 01004, 01360, 01020,
   00432, 00574, 01530, 01574, 00742, 00272, 00730, 00372,
   01070, 01612, 01410, 00466, 01112, 01617, 01756, 01756,
   00256, 01474, 00730, 00516, 00174, 00656, 01116, 00706,
   00706, 00706, 00232, 00774, 01530, 01130, 00374, 01730,
   01730, 01230, 01130, 00232, 00432, 00474, 00630, 01674,
   00630, 00372, 00664, 01735, 00417, 00710, 00072, 00272,
   00013, 01160, 00710, 00024, 00416, 01310, 00070, 00232,
   00432, 00774, 00130, 00230, 00756, 01020, 01464, 01123,
   01656, 01364, 01623, 00420, 00224, 00445, 00714, 00614,
   00204, 01424, 00447, 01264, 01253, 01264, 01355, 00214,
   01264, 01033, 00416, 01001, 00164, 00665, 00610, 00710,
   00110, 00004, 00104, 01464, 00667, 01010, 01310, 00232,
   00673, 01664, 00755, 00064, 00167, 00724, 00501, 00064,
   00241, 00064, 01051, 00416, 00420, 00574, 00630, 00310,
   00210, 01156, 00447, 00310, 00064, 01423, 00764, 01163,
   01504, 01464, 01237, 01204, 01210, 01314, 00314, 01414,
   01514, 00232, 00774, 01664, 01777, 01214, 00464, 01355,
   01566, 00152, 00523, 01764, 01315, 00740, 01310, 00357,
   01656, 00464, 00220, 00724, 00645, 01262, 00064, 00103,
   00432, 00050, 00150, 00250, 00350, 00450, 01074, 00230,
   01160, 01260, 01156, 01160, 00432, 01750, 00243, 01440,
   01160, 00710, 00077, 01262, 01464, 01023, 00432, 01250,
   01350, 01450, 01550, 01650, 00763, 00764, 00033, 00416,
   00045, 00164, 01135, 00673, 00464, 01355, 01347, 00464,
   01355, 00510, 01347, 00664, 00053, 00432, 00357, 00416,
   00756, 00045, 00164, 00665, 00673, 01124, 00043, 00040,
   01110, 00673, 00503, 01067, 00507, 00143, 00157, 00064,
   00627, 00416, 00756, 01001, 00164, 01135, 00273, 00164,
   01501, 01640, 01640, 00253, 01640, 00473, 00633, 00716,
   00716, 00124, 00550, 01364, 01537, 01464, 00753, 01427,
   01507, 01023, 01517, 01307, 00703, 01640, 00657, 00642,
   01377, 01464, 00413, 01464, 00253, 00764, 00703, 00133,
   01607, 01017, 01243, 01640, 01033, 01640, 00327, 00642,
   01477, 01464, 00733, 01464, 01043, 01464, 01057, 00517,
   01137, 01617, 01123, 01640, 01640, 01337, 01167, 00642,
   01577, 01464, 00717, 01464, 01167, 01464, 01077, 00567,
   01527, 01627, 01707, 01640, 01717, 01157, 01727, 00642,
   01564, 01677, 01611, 00170, 01751, 00270, 01262, 01751,
   00432, 00330, 00630, 01224, 01016, 00530, 01474, 01204,
   00430, 00164, 01145, 00064, 01447, 01611, 00164, 01471,
   00372, 00332, 00225, 00710, 01360, 00432, 01160, 00372,
   01360, 01051, 00372, 00432, 01203, 01562, 00304, 01156,
   01737, 01766, 00674, 00416, 01546, 00304, 01474, 01030,
   00232, 01070, 00436, 00762, 01772, 00752, 01772, 00420,
   00656, 01410, 01626, 00337, 00420, 01056, 00427, 00216,
   00256, 01160, 00070, 01410, 01020, 01556, 00304, 01074,
   00130, 01530, 00256, 00470, 00417, 01010, 00755, 00570,
   01674, 00130, 01021, 00164, 01135, 00464, 01355, 01021,
   00164, 00665, 01556, 01351, 01366, 01351, 00272, 00620,
   00520, 01654, 01137, 00710, 00420, 01162, 01556, 01151,
   01772, 00174, 01730, 00232, 00202, 00432, 00474, 00330,
   01574, 00330, 00110, 00372, 00114, 00224, 00503, 01064,
   00523, 00755, 01277, 00410, 01535, 00510, 00610, 01650,
   00432, 01160, 00710, 01020, 00272, 00432, 00774, 00730,
   01020, 01611, 00225, 00416, 01474, 00420, 01130, 01616,
   01474, 00730, 00664, 00327, 01045, 00372, 00710, 01562,
   00304, 01431, 01156, 01173, 00416, 01766, 01556, 00304,
   00774, 00206, 00674, 01506, 00304, 00206, 00372, 00520,
   00520, 01152, 01237, 00232, 01417, 01670, 01601, 00064,
   00103, 01772, 01324, 01266, 01534, 01763, 01402, 01760,
   01764, 01717, 00747, 01535, 01267, 01611, 00225, 01601,
   01611, 00164, 01445, 01360, 00710, 01277, 00774, 01372,
   01314, 01142, 01372, 01315, 00742, 01020, 01214, 01601,
   00011, 01310, 00270, 01262, 01310, 00011, 01277, 00432,
   01074, 00130, 01160, 01020, 00432, 00143, 00664, 00043,
   00764, 00303, 00432, 01160, 00070, 00272, 00072, 00126,
   01020, 00730, 00774, 00573, 00127, 01045, 00022, 00674,
   00006, 00432, 00756, 00164, 00505, 01431, 01273, 01556,
   00304, 00253, 00164, 00677, 01123, 00750, 00710, 01562,
   00152, 00535, 00174, 01546, 00152, 00575, 00432, 00474,
   00330, 01424, 01261, 00474, 01426, 01422, 01126, 00174,
   00006, 00774, 00130, 00532, 01235, 00755, 00232, 01325,
   01115, 01331, 01141, 01265, 00661, 01325, 00550, 00715,
   01056, 00426, 01755, 00661, 01331, 01025, 00130, 00230,
   00130, 00530, 01325, 01025, 01051, 00374, 00430, 01101,
   01131, 01331, 01615, 01615, 00725, 01241, 00755, 00232,
   01325, 01115, 01331, 00570, 01325, 00661, 01325, 01025,
   01171, 01131, 00535, 00474, 00475, 00030, 00430, 01426,
   01700, 01070, 01166, 01174, 00402, 00751, 00327, 01672,
   01070, 00206, 01574, 00206, 01050, 00272, 01007, 01156,
   00563, 00416, 01746, 01373, 01556, 00152, 01373, 00324,
   01676, 00266, 00674, 00706, 00706, 01615, 00226, 00726,
   00726, 00206, 00232, 01373, 01025, 00430, 00730, 01030,
   00130, 00630, 00430, 01474, 01107, 01672, 00474, 01070,
   00206, 00216, 01050, 01070, 00232, 00726, 00726, 00726,
   00726, 00726, 00016, 00656, 00022, 00432, 01474, 00230,
   00774, 01020, 00650, 00330, 00630, 01424, 01622, 00530,
   00230, 00530, 01020, 00755, 00430, 00416, 00164, 01137,
   01070, 01574, 00406, 00525, 01171, 01253, 00330, 00030,
   01424, 01645, 00630, 00274, 00130, 01156, 01020, 00725,
   00556, 01051, 00164, 00665, 01333, 01070, 00274, 00406,
   00232, 00775, 01353, 00650, 00770, 01262, 00464, 01355,
   00510, 00232, 00670, 00164, 00101, 00650, 00272, 01020,
   01141, 00535, 01615, 00274, 00475, 00130, 00430, 00774,
   01426, 01715, 01130, 01130, 01507, 01030, 00730, 01674,
   00130, 00626, 00575, 01156, 00164, 00505, 00272, 00210,
   01324, 01746, 01210, 01751, 01304, 01224, 01375, 00272,
   00710, 01355, 00173, 01666, 01666, 01020, 01234, 01115,
   00710, 01751, 01315, 01404, 01010, 01310, 00232, 00007,
   01574, 01504, 00002, 01235, 01141, 01265, 01334, 00543,
   01314, 01567, 01072, 01572, 00152, 00570, 01020, 00424,
   00310, 00656, 00656, 01710, 01074, 00221, 00742, 01160,
   01260, 00432, 01160, 00574, 01530, 01260, 01050, 00010,
   00110, 00114, 01445, 00610, 00432, 01160, 00710, 00234,
   00263, 01264, 01643, 00034, 00020, 00110, 00004, 00107,
   00000, 00000, 00000, 01460, 00742, 01160, 01260, 01020,
   00032, 01610, 00266, 00410, 00510, 00774, 00422, 00620,
   01116, 00277, 00544, 00077, 01552, 00115, 01156, 00353,
   00016, 00507, 00344, 00075, 00620, 00762, 00333, 00510,
   00422, 01074, 01352, 00105, 01206, 01674, 00272, 00706,
   00706, 00706, 01104, 00574, 00563, 00016, 01672, 00756,
   00473, 00072, 00146, 00132, 00472, 01536, 00137, 01566,
   00077, 01522, 01771, 00262, 00420, 01106, 01020, 00006,
   01532, 00131, 00620, 00132, 00507, 00604, 00724, 00264,
   00716, 00716, 00710, 01715, 01174, 00642, 00713, 00706,
   00720, 00667, 01102, 00744, 00264, 01144, 00172, 00624,
   00172, 00662, 00172, 00620, 00620, 01106, 00132, 00520,
   00774, 01676, 00262, 01410, 01536, 00256, 00032, 00232,
   00132, 01257, 00710, 00372, 00432, 01134, 00221, 01674,
   00630, 00222, 00262, 00774, 01322, 00231, 00430, 01274,
   00620, 01162, 01143, 00742, 00244, 01015, 00720, 00244,
   01015, 00720, 00244, 01015, 00720, 00742, 00742, 01157,
   01366, 00264, 01262, 00014, 00610, 01323, 01502, 00207,
   01116, 00726, 01273, 00241, 00224, 00031, 01051, 00016,
   01414, 01410, 00310, 00210, 01714, 01724, 00274, 01734,
   00277, 00310, 00754, 00400, 00710, 00434, 00033, 01264,
   00773, 00774, 01366, 00376, 01410, 01352, 00324, 01156,
   00752, 01152, 01527, 00756, 01020, 00552, 01547, 01274,
   01773, 00406, 01146, 00412, 00214, 01274, 01020, 00274,
   00432, 00214, 00420, 01172, 00072, 00720, 00752, 00154,
   00345, 01630, 01230, 01230, 01430, 01230, 00232, 00732,
   00732, 00732, 01337, 00420, 00724, 00377, 00024, 00371,
   01310, 01114, 00704, 00036, 01126, 00114, 00432, 01020,
   01064, 00003, 00630, 01130, 00330, 00130, 00430, 00730,
   00130, 01030, 00030, 00530, 00530, 01146, 00774, 01020,
   00072, 00126, 00410, 00510, 00416, 00062, 00422, 00774,
   00410, 01074, 00620, 00652, 00752, 00254, 00432, 00372,
   01372, 00502, 00410, 00132, 01372, 00502, 01456, 00606,
   01022, 01522, 00454, 00343, 01232, 00262, 01456, 00470,
   00410, 00232, 00732, 00232, 00410, 00132, 01116, 00132,
   01456, 00502, 00656, 01772, 00222, 00262, 00620, 01154,
   00470, 00032, 00232, 00510, 00372, 00472, 01152, 01152,
   01152, 00232, 00410, 00510, 01362, 00520, 00656, 01772,
   00232, 00774, 01506, 00550, 00372, 00232, 00774, 00272,
   00556, 00633, 00766, 00633, 00316, 00756, 00742, 00322,
   00132, 01566, 00545, 00432, 00022, 01020, 00316, 00577,
   01502, 00524, 01156, 00706, 00643, 00072, 00126, 00410,
   00510, 00416, 00062, 00422, 00410, 00616, 01062, 00747,
   01222, 00032, 00410, 01274, 00720, 01672, 01003, 00472,
   01142, 00777, 00254, 00574, 00510, 00447, 00410, 00132,
   01456, 00613, 00233, 00232, 00410, 01432, 00622, 00410,
   00232, 00243, 00410, 00232, 00410, 00132, 00243, 00072,
   00126, 00410, 00510, 00416, 00062, 00422, 01366, 00337,
   00410, 01056, 01062, 01227, 01222, 00410, 00232, 00132,
   01472, 00656, 00410, 00732, 01156, 00410, 00774, 00432,
   01313, 00742, 01032, 01307, 00472, 00732, 00620, 01154,
   00662, 00232, 00510, 00523, 00072, 00366, 00232, 00432,
   00410, 00432, 00774, 00130, 00372, 00232, 00410, 00232,
   01163, 00432, 01262, 00774, 00130, 00113, 00432, 01457,
   00032, 00774, 01610, 00344, 00762, 00620, 01116, 01517,
   00272, 00516, 01717, 00256, 00720, 01144, 00376, 00656,
   01563, 01637, 00620, 00344, 00762, 01116, 01613, 00072,
   00146, 00466, 01703, 00022, 00662, 00756, 01672, 00620,
   00006, 00226, 01020, 00256, 01617, 00372, 00410, 01070,
   00266, 00166, 01726, 01726, 01726, 00374, 00346, 00356,
   01050, 00570, 00372, 00670, 00550, 00770, 00650, 00226,
   01772, 01772, 01772, 00362, 00410, 00372, 01020, 00570,
   00222, 00774, 00346, 00550, 01070, 01674, 00706, 00706,
   00706, 00206, 00216, 01050, 00273, 00670, 00750, 00570,
   00650, 00332, 00222, 00262, 00550, 01070, 00226, 00474,
   00706, 00706, 00706, 00226, 01050, 00206, 01646, 01646,
   01646, 01020, 00614, 01014, 00062, 00232, 00272, 00556,
   00603, 01522, 01146, 00232, 00411, 00774, 00232, 00436,
   00272, 00537, 00132, 00172, 00410, 00510, 01672, 01532,
   01114, 00510, 00232, 01020, 00756, 00433, 00774, 00642,
   00132, 00164, 01243, 00644, 01143, 00620, 00762, 00756,
   00517, 00132, 01113, 00072, 00366, 00232, 00604, 00317,
   00164, 01471, 00767, 00132, 00372, 01623, 01004, 00367,
   00774, 00332, 01142, 00232, 01532, 01157, 01527, 01502,
   01164, 01156, 00732, 00677, 00410, 00505, 00367, 00072,
   00366, 00232, 00604, 01326, 01757, 01014, 00062, 01522,
   00337, 01326, 00337, 00216, 00256, 01356, 01150, 00516,
   01057, 01256, 01004, 00036, 00236, 00032, 00774, 01006,
   01142, 00742, 00172, 00410, 00510, 01137, 01672, 01162,
   01133, 00510, 00472, 01122, 01107, 00762, 00132, 00732,
   00620, 01254, 01222, 00232, 00172, 00706, 00706, 00706,
   00232, 01474, 00730, 01216, 01316, 01343, 01374, 01672,
   00372, 00364, 00671, 00372, 01705, 01366, 01316, 01154,
   01257, 00072, 01474, 00142, 00472, 01672, 00372, 00364,
   00571, 01024, 01310, 00132, 01032, 00132, 00472, 00132,
   01174, 01705, 01366, 01316, 01672, 01447, 01522, 01351,
   01156, 00436, 01034, 01325, 01262, 00164, 00505, 00634,
   01366, 00164, 01725, 00164, 00711, 00510, 01362, 01421,
   01116, 00372, 01573, 01672, 00364, 01371, 00132, 01374,
   01307, 01672, 01507, 00072, 00366, 00232, 00614, 00767,
   00472, 01142, 01703, 00402, 00756, 00720, 01020, 01374,
   00330, 00330, 00330, 00030, 01030, 00330, 00530, 01574,
   01020, 00330, 00130, 00030, 00130, 00730, 01130, 01030,
   00030, 00430, 00330, 00230, 00474, 01020, 00072, 00366,
   00232, 01004, 01522, 01425, 01014, 00036, 00132, 00332,
   00556, 00233, 00332, 01522, 01451, 01274, 00620, 01244,
   01625, 00756, 00173, 00671, 00372, 01057, 00571, 01374,
   00273, 00132, 00656, 01732, 00127, 00766, 01032, 00267,
   00472, 00732, 01156, 00367, 01674, 01342, 01473, 01142,
   01542, 01502, 00742, 00774, 01117, 00232, 00726, 00232,
   01342, 01456, 00432, 00774, 01146, 00272, 00574, 00130,
   01034, 01513, 01256, 00132, 00272, 00134, 01525, 00264,
   00165, 00164, 01445, 00264, 00075, 00132, 00164, 00527,
   00574, 00330, 00330, 00330, 00274, 01020, 00774, 00230,
   00330, 00030, 00230, 00530, 01030, 00530, 00030, 01130,
   00230, 01130, 01130, 00430, 00372, 01020, 00432, 00244,
   00402, 01166, 00430, 00766, 01544, 01401, 00444, 01743,
   00144, 01367, 01644, 01602, 00644, 01530, 01474, 00330,
   01374, 01020, 00174, 00330, 00330, 00330, 00330, 00130,
   00374, 01020, 00742, 01032, 01053, 00472, 00644, 01626,
   00732, 01156, 00620, 00372, 00217, 00372, 00134, 01633,
   01371, 00232, 00132, 01274, 00630, 01674, 01366, 01724,
   00720, 01342, 01650, 01142, 00172, 00410, 00510, 01343,
   00756, 01672, 01162, 01173, 01772, 01772, 01772, 00642,
   00132, 00272, 01034, 01515, 00164, 01375, 00467, 01732,
   01162, 01337, 00472, 00662, 00510, 01207, 00410, 00510,
   00172, 00372, 00572, 00572, 00632, 00132, 01772, 01572,
   01714, 00510, 00232, 01020, 00656, 01433, 01232, 00422,
   00410, 00756, 00164, 01227, 00132, 00436, 00272, 01034,
   01734, 01262, 00264, 00411, 00134, 01740, 00264, 00165,
   00164, 01471, 00527, 00374, 00330, 00330, 00030, 01030,
   00530, 00330, 00130, 00630, 01030, 00674, 01020, 00164,
   01725, 01366, 00337, 00510, 01562, 00337, 00032, 00072,
   00467, 00762, 00620, 01672, 00064, 00557, 00000, 00116,
   01074, 00064, 01603, 01474, 00007, 00664, 00113, 00664,
   00343, 00664, 00227, 00664, 00307, 00664, 00363, 00664,
   00243, 00410, 00764, 01705, 00510, 00350, 00432, 01160,
   00055, 00664, 00155, 01352, 00037, 00556, 01747, 00045,
   00055, 00045, 00664, 00075, 01366, 00051, 00055, 00725,
   00307, 00710, 00035, 00065, 00232, 01262, 00232, 00072,
   00126, 00432, 01160, 00045, 00710, 00035, 01262, 00372,
   00432, 01160, 00664, 00255, 00664, 00141, 00055, 00664,
   00125, 00410, 00045, 01424, 00310, 00710, 00035, 00065,
   00432, 01160, 00510, 00664, 00131, 01262, 00410, 00170,
   00232, 00510, 00150, 00764, 01705, 00370, 00664, 00131,
   00432, 01160, 00170, 00025, 00150, 00055, 00045, 00710,
   00035, 00065, 00432, 01160, 00132, 00055, 00025, 00045,
   00664, 00271, 00664, 00075, 01366, 00167, 00075, 00705,
   01047, 00232, 00410, 00232, 00372, 00664, 00207, 00075,
   00710, 00035, 00065, 00432, 01160, 00232, 00750, 00664,
   00311, 00770, 00664, 00141, 00432, 00530, 01156, 00664,
   00141, 00045, 00710, 00035, 00072, 00366, 00232, 00432,
   01160, 00075, 00664, 00155, 00170, 00025, 00150, 00710,
   00664, 00061, 00610, 00710, 01362, 01234, 01424, 01255,
   00664, 00271, 01326, 01265, 00170, 00410, 00510, 00416,
   00705, 00764, 01745, 01770, 00025, 00774, 00406, 01160,
   00130, 00530, 00216, 00256, 00556, 01353, 00416, 00272,
   00172, 01463, 01516, 00302, 00126, 01426, 00300, 01333,
   00126, 01463, 01074, 00416, 00130, 01056, 01457, 01463,
   00055, 00045, 01137, 01404, 00664, 00255, 00725, 01262,
   00262, 00075, 00664, 00125, 00045, 01424, 01265, 00664,
   01013, 00310, 00210, 01424, 00350, 00664, 00271, 00232,
   01262, 00232, 00170, 00025, 00664, 00255, 00705, 00150,
   00710, 00035, 00372, 00432, 01160, 00664, 00271, 00025,
   00664, 00255, 00705, 00045, 00664, 00271, 00045, 00310,
   01137, 01152, 01152, 01352, 00037, 00406, 01146, 00574,
   00130, 01424, 01260, 00664, 00305, 00664, 00075, 00664,
   00421, 00150, 00610, 00207, 00150, 00610, 00024, 00421,
   01310, 00710, 00664, 01313, 00064, 01423, 00670, 00272,
   00764, 01745, 00432, 00774, 00530, 01156, 00664, 00131,
   01750, 00174, 00064, 01603, 00062, 01522, 01370, 00332,
   00132, 00572, 00572, 00632, 00372, 00436, 00272, 00572,
   01226, 00556, 00616, 01474, 01542, 00467, 01732, 01772,
   00216, 00432, 00132, 01274, 00530, 01772, 00427, 00742,
   01632, 00377, 00532, 00732, 00620, 01746, 01354, 00500,
   00402, 00132, 00164, 00503, 00356, 00432, 01074, 00507,
   00756, 01006, 00503, 00446, 00230, 01160, 00070, 00232,
   00574, 00630, 00573, 00520, 00520, 01152, 01146, 00557,
   01410, 00664, 00033, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
   00072, 00366, 00232, 01060, 00235, 00000, 01060, 01020,
   01060, 01237, 01060, 01773, 00072, 00366, 00232, 01060,
   00072, 00126, 00410, 00510, 00416, 01060, 00072, 00126,
   00410, 00510, 00416, 01060, 00072, 00126, 00410, 00510,
   00416, 01060, 00072, 00366, 00232, 01060, 01363, 01460,
   01060, 00774, 01433, 01060, 00642, 01020, 01060, 00764,
   01737, 01060, 00072, 00366, 00232, 01060, 00564, 00463,
   01060, 00564, 00223, 00000, 01060, 00232, 00104, 00310,
   00210, 01060, 01514, 00463, 01060, 00310, 01334, 00021,
   00767, 00072, 00366, 00367, 00022, 00674, 00006, 00774,
   01502, 01124, 00726, 00527, 00656, 01532, 01131, 01504,
   00263, 01102, 01532, 01054, 01020, 01262, 00272, 00275,
   00070, 00101, 01362, 01627, 00432, 01074, 00230, 01160,
   00370, 00232, 00275, 00670, 00161, 01262, 00610, 00770,
   00232, 00570, 00161, 00710, 00111, 00015, 00225, 00670,
   00232, 00770, 01262, 00161, 00373, 00225, 01414, 01714,
   01724, 01177, 01724, 01265, 01314, 00032, 00072, 00225,
   00271, 01474, 00042, 00225, 00275, 00070, 00341, 01224,
   00003, 00275, 00070, 00610, 01424, 01231, 00432, 00150,
   01163, 00024, 01234, 01310, 00710, 00341, 00361, 00275,
   01524, 00331, 00232, 01262, 00211, 00271, 00373, 00170,
   00051, 00311, 00225, 01404, 01023, 00271, 00241, 00155,
   00421, 00250, 00014, 00064, 00103, 00255, 00075, 00756,
   00756, 00421, 00150, 01313, 00710, 00424, 00424, 00150,
   01410, 00051, 00311, 00225, 00275, 00773, 01562, 01370,
   01552, 01370, 00272, 00172, 00736, 01506, 01366, 00656,
   01416, 01324, 00752, 00043, 00432, 00742, 01772, 00762,
   00372, 01302, 01335, 01706, 00756, 00032, 01602, 01617,
   00732, 00472, 01607, 01622, 01653, 01646, 00672, 00756,
   00472, 01643, 00106, 01142, 01547, 01162, 01547, 00732,
   00156, 00436, 00446, 00532, 00236, 00043, 01116, 01457,
   00274, 00064, 01603, 00000, 00000, 00000, 00310, 01114,
   01735, 00070, 01015, 01224, 00000, 01735, 00550, 01014,
   01314, 01614, 00432, 00650, 00750, 00570, 01015, 00410,
   01025, 01735, 00510, 00232, 01624, 01531, 01035, 01366,
   01446, 01604, 01362, 01436, 01262, 01004, 00650, 00750,
   00570, 00232, 01745, 00232, 01750, 01735, 00570, 01124,
   01474, 00664, 00311, 00550, 01262, 00232, 01735, 00070,
   01045, 01362, 01415, 00070, 00550, 00670, 01366, 00414,
   01324, 01524, 01104, 00037, 00664, 00061, 00550, 01362,
   01415, 00670, 01366, 00414, 01334, 00003, 01745, 01770,
   00272, 01735, 01666, 01516, 01516, 01666, 01070, 00474,
   00206, 00216, 01050, 01067, 01745, 01770, 00664, 00311,
   00443, 01034, 01534, 01262, 01035, 00670, 01055, 00650,
   01324, 01556, 01362, 01546, 01304, 00233, 01262, 00272,
   00770, 01045, 01362, 01446, 00670, 00177, 01562, 01446,
   01735, 00070, 00550, 00432, 00650, 00570, 01015, 01025,
   01735, 00670, 01045, 00650, 00570, 00664, 00311, 00550,
   01362, 00426, 00733, 00664, 00343, 00664, 00363, 00664,
   00133, 00664, 00103, 00664, 00113, 00710, 00024, 01621,
   01310, 01735, 00150, 00550, 00750, 01314, 00610, 00170,
   00210, 01015, 00410, 00510, 01025, 00510, 01035, 01735,
   00570, 01055, 00550, 00170, 01015, 01025, 01735, 00232,
   00664, 00061, 00432, 00774, 00530, 01156, 00664, 00141,
   00710, 01055, 00410, 00170, 01015, 01025, 00510, 01035,
   00410, 01735, 00170, 01015, 00272, 01735, 00510, 01035,
   00770, 01055, 00750, 00170, 01015, 01025, 00710, 01045,
   00610, 01735, 00170, 00664, 00311, 00150, 00272, 01324,
   01135, 01070, 00232, 00736, 00022, 00016, 00774, 01502,
   01733, 00726, 01563, 00656, 00232, 01262, 01045, 01562,
   01627, 00570, 00650, 00770, 00232, 01745, 00710, 01750,
   01735, 01304, 00550, 00750, 01705, 00232, 00350, 01735,
   01137, 00432, 00752, 00752, 01772, 01160, 01020, 00432,
   01727, 00432, 01717, 00000, 00000, 00000, 00000, 00662,
   00420, 00432, 00020, 01116, 01116, 01116, 01116, 00174,
   01116, 01116, 01614, 00716, 00064, 01343, 01544, 00126,
   00144, 00051, 00474, 01147, 00656, 01244, 00044, 00544,
   00260, 00044, 00044, 00656, 00716, 00354, 00040, 00774,
   00720, 01116, 01154, 00040, 01614, 01264, 00323, 00274,
   00607, 01074, 01330, 00673, 01102, 01624, 01376, 00227,
   00343, 01323, 01407, 00656, 00354, 00303, 00374, 00563,
   00354, 00277, 00674, 00763, 00674, 01147, 00274, 00127,
   01767, 01613, 00127, 00144, 00270, 01544, 00116, 00444,
   00006, 01074, 01530, 01130, 00216, 00223, 00374, 00567,
   00554, 00310, 01604, 00063, 00774, 01147, 01074, 01330,
   01063, 00144, 01247, 00656, 00656, 00656, 00044, 01125,
   00656, 00656, 01477, 00144, 00557, 01544, 00337, 00444,
   00004, 01074, 01230, 00457, 01074, 01230, 01030, 00463,
   01663, 00767, 00773, 00444, 00401, 01554, 00177, 00424,
   00124, 01564, 00027, 00656, 00656, 00656, 00656, 00656,
   01544, 00205, 00144, 00205, 00774, 00620, 01467, 01074,
   01430, 00673, 01074, 01230, 00730, 00463, 00574, 01147,
   01357, 00363, 00757, 00073, 01544, 00212, 00144, 00154,
   01574, 00016, 00053, 00144, 01130, 00563, 01674, 00043,
   00547, 01157, 01263, 00144, 01173, 01544, 00334, 00444,
   00003, 01074, 01330, 00457, 00154, 00135, 01074, 01147,
   01502, 00054, 00656, 00057, 00354, 00300, 00674, 00777,
   01074, 01530, 00673, 01444, 00216, 00374, 01147, 00656,
   00656, 00656, 00656, 01444, 00076, 00444, 00047, 00656,
   01544, 00315, 00144, 00315, 00774, 00656, 00557, 00656,
   00656, 00656, 00123, 00144, 00352, 01544, 00207, 00444,
   00005, 01074, 01430, 00457, 01074, 01430, 01063, 01074,
   01530, 01063, 00444, 00236, 00044, 01125, 01454, 00120,
   01674, 00047, 00374, 00763, 01070, 00144, 00561, 01554,
   00174, 00424, 01176, 01260, 01074, 00406, 01050, 01756,
   01756, 00130, 00032, 00664, 01677, 00354, 00200, 00664,
   00227, 00010, 00772, 00610, 00432, 00610, 00410, 00410,
   01110, 01110, 01110, 01110, 00372, 00132, 01710, 01710,
   01132, 01532, 00541, 00341, 00232, 00574, 01530, 01050,
   00232, 00130, 00341, 01074, 00230, 00330, 00351, 00774,
   00064, 00215, 00571, 00464, 01325, 00571, 00515, 00571,
   01464, 01015, 00571, 00664, 00015, 00571, 01174, 00230,
   00754, 00457, 00372, 01030, 00754, 00463, 00064, 01673,
   01474, 01730, 00774, 00742, 01474, 00410, 00510, 01160,
   01360, 01142, 00377, 00510, 01160, 00232, 00070, 00232,
   01632, 01532, 00541, 01142, 00423, 01260, 01020, 01125,
   00330, 01303, 00220, 01460, 01105, 01777, 01325, 00530,
   00130, 01020, 01125, 01003, 01325, 01243, 00742, 00534,
   00661, 00774, 00416, 00610, 00064, 01603, 01125, 00730,
   01337, 01125, 01613, 01125, 01577, 01325, 00503, 01464,
   01543, 00434, 01203, 00256, 01756, 00752, 01756, 00764,
   01673, 01325, 00230, 00543, 00414, 01070, 00707, 01325,
   00730, 00543, 01325, 01577, 01105, 01677, 01325, 00630,
   00543, 01125, 01037, 01125, 01677, 00330, 00643, 01105,
   01377, 01574, 00230, 00230, 01504, 00274, 00230, 00530,
   01343, 01325, 01277, 01125, 01277, 01325, 00637, 01105,
   01477, 01125, 01777, 01325, 01777, 01125, 00753, 01125,
   00230, 01303, 00633, 01157, 01167, 01147, 00637, 00730,
   00330, 01020, 01125, 00330, 00543, 00274, 00230, 00430,
   00174, 01020, 01313, 01417, 01023, 01427, 01317, 00716,
   00716, 01364, 01537, 01125, 01377, 01325, 01377, 00747,
   01227, 00537, 01507, 01527, 01707, 01717, 01513, 00656,
   01377, 01125, 00330, 00230, 01020, 01125, 01477, 01607,
   00647, 01627, 00477, 00657, 00667, 01013, 00503, 00656,
   01477, 01325, 00230, 01517, 01325, 00430, 00543, 01623,
   01033, 01037, 01047, 01057, 00523, 01727, 01067, 00656,
   01577, 01325, 01513, 01325, 01477, 01325, 01677, 00533,
   00553, 01003, 01237, 01207, 00563, 01217, 01243, 00656,
   01164, 01677, 00404, 00232, 00410, 01514, 01455, 00725,
   00432, 01166, 01324, 01063, 01713, 00232, 00432, 00674,
   00630, 01534, 01025, 00374, 00330, 01474, 00730, 00372,
   01070, 01074, 00016, 00202, 01656, 01346, 01051, 00656,
   00656, 00756, 01474, 00237, 01410, 00456, 00420, 00742,
   00223, 01274, 00236, 00732, 00720, 01554, 01053, 00206,
   00226, 01130, 00226, 01020, 00434, 01362, 00172, 01045,
   01224, 01123, 01050, 01455, 01234, 01077, 00432, 01074,
   00132, 00372, 00437, 00732, 00732, 00720, 00720, 01152,
   00417, 00106, 00544, 01117, 00620, 00620, 00106, 00372,
   01360, 00741, 00773, 01152, 00353, 01174, 00064, 01603,
   01070, 01074, 01346, 01154, 01142, 00633, 00630, 00742,
   00742, 00627, 01074, 00130, 00633, 01156, 01050, 00424,
   01176, 00011, 01411, 01033, 00256, 01656, 00202, 01746,
   00756, 00630, 00633, 01772, 01772, 01112, 00717, 00216,
   00416, 01160, 01020, 00424, 00574, 00404, 00420, 00015,
   00065, 01064, 00523, 01074, 01371, 00214, 00710, 00064,
   00157, 00420, 01214, 01070, 00256, 01074, 01506, 01223,
   00742, 01050, 01020, 00002, 01506, 01231, 01730, 01630,
   01067, 00256, 00502, 00502, 01103, 01116, 00716, 00716,
   01612, 01512, 01244, 01204, 01156, 00402, 01107, 00424,
   01300, 01404, 01070, 01074, 01546, 01260, 00742, 01050,
   00011, 01411, 01070, 00410, 00232, 01434, 01360, 01355,
   00510, 01461, 01707, 01045, 01234, 01222, 00406, 01107,
   01355, 00773, 00065, 00414, 00664, 01737, 00574, 00630,
   00030, 01030, 01547, 01070, 00216, 01074, 00716, 01646,
   00216, 01304, 01356, 01332, 01314, 01346, 01306, 01156,
   00742, 01160, 00216, 00070, 01020, 00642, 01502, 01446,
   00424, 01710, 00734, 01346, 01124, 01470, 00064, 00653,
   01045, 01224, 01203, 01734, 01357, 00734, 01205, 00210,
   01455, 00725, 00574, 01230, 01230, 01074, 00716, 01412,
   01750, 01402, 01335, 00424, 01501, 01656, 00030, 00730,
   00356, 01074, 01070, 00406, 01410, 01116, 01033, 00214,
   01050, 00064, 01423, 01574, 00230, 00130, 01020, 00764,
   00003, 00752, 00353, 00205, 00363, 00232, 01070, 01756,
   00752, 01756, 01406, 01435, 00663, 00064, 01603, 00764,
   00333, 00070, 00232, 00710, 01410, 01020, 00642, 01563,
   01374, 00230, 00230, 00424, 01710, 01461, 01713, 00764,
   00423, 00174, 00424, 00522, 00215, 01474, 01564, 00220,
   01464, 00013, 00205, 01262, 00164, 00101, 01347, 00664,
   00243, 01574, 00230, 00530, 01374, 00730, 00174, 00706,
   01447, 00752, 00107, 00205, 00164, 00665, 01347, 01564,
   00367, 00642, 00723, 01102, 00574, 00730, 01412, 01461,
   01374, 00230, 00530, 00424, 01710, 00215, 00220, 01262,
   01210, 00164, 00101, 01362, 01206, 00677, 01074, 00130,
   00330, 01503, 01656, 01656, 00216, 01160, 01020, 01366,
   01206, 01264, 01355, 01633, 00574, 00530, 01612, 01527,
   00512, 00274, 00230, 00230, 00651, 00434, 01762, 00174,
   00130, 00402, 00742, 01156, 01013, 01020, 00234, 01613,
   01116, 01057, 00043, 01116, 01077, 00742, 00043, 00420,
   01146, 00420, 01156, 01410, 01006, 01107, 00446, 00716,
   00202, 00256, 00716, 00716, 00216, 01412, 01125, 00216,
   00043, 00652, 01247, 00055, 00424, 01704, 00631, 00710,
   01347, 00730, 01074, 01402, 01461, 00732, 00212, 01672,
   00216, 00424, 01673, 01461, 00752, 00447, 00205, 00164,
   01135, 01464, 00663, 00055, 01374, 01030, 00130, 01374,
   01142, 00752, 01403, 01443, 01374, 00730, 00330, 00716,
   01174, 00706, 00206, 01020, 01656, 01074, 00030, 01130,
   01656, 01074, 00606, 00127, 00167, 00274, 00061, 00651,
   00424, 01577, 01564, 00277, 00642, 01737, 01374, 00230,
   00430, 00424, 01710, 01656, 01656, 01710, 01264, 01033,
   01402, 01461, 00652, 01207, 01574, 00230, 00230, 00424,
   01704, 00631, 00070, 00764, 00301, 00064, 00103, 00642,
   00507, 01374, 00061, 00424, 01710, 01461, 01237, 00471,
   00056, 00123, 00174, 00710, 00706, 00172, 01410, 01674,
   01646, 01646, 01646, 00156, 00016, 01074, 01312, 00024,
   01006, 00003, 00146, 00016, 00520, 00456, 01522, 00033,
   01116, 00736, 00133, 00216, 00132, 00064, 01445, 01144,
   01257, 00064, 01257, 01674, 00202, 01242, 00202, 00027,
   00714, 00004, 00724, 00072, 00064, 01715, 00072, 00774,
   00742, 00242, 01674, 00106, 01104, 01526, 00041, 01114,
   00106, 00207, 01366, 00050, 00064, 01051, 01674, 01306,
   00063, 00207, 00464, 00505, 00714, 01210, 00710, 01522,
   00112, 00573, 00226, 01552, 00175, 00507, 01356, 00175,
   01156, 00736, 01526, 00116, 01556, 00136, 00222, 00262,
   00562, 00562, 00622, 01362, 00136, 00704, 01210, 00022,
   00232, 00114, 00264, 00735, 00734, 00147, 01262, 01010,
   01664, 00747, 01274, 00773, 00110, 01475, 01024, 00302,
   00610, 00064, 00113, 00264, 01655, 00643, 00114, 00364,
   00071, 00643, 00464, 01511, 00643, 00274, 00064, 01603,
   00164, 01361, 00643, 01460, 01010, 00164, 00101, 00643,
   01010, 01225, 00643, 01210, 00164, 01135, 00637, 01156,
   01156, 01210, 01225, 00643, 00072, 00366, 01210, 00232,
   01156, 01156, 00164, 01145, 00643, 01210, 00232, 01262,
   00164, 00101, 00232, 01133, 00272, 00164, 00667, 00272,
   01370, 01431, 00710, 01221, 01470, 01441, 01210, 01570,
   01431, 01210, 00232, 01221, 01670, 01441, 01210, 00710,
   01225, 01770, 01441, 00032, 00662, 01672, 01270, 01431,
   01034, 00471, 01374, 00773, 01074, 00773, 00072, 00126,
   01534, 00315, 00232, 01262, 00232, 00164, 00111, 00064,
   01445, 01366, 00326, 01154, 00326, 01004, 01360, 01020,
   00432, 00574, 01530, 01574, 00742, 00272, 00730, 00372,
   01070, 01612, 01410, 00466, 01112, 01617, 01756, 01756,
   00256, 01474, 00730, 00516, 00174, 00656, 01116, 00706,
   00706, 00706, 00232, 00774, 01530, 01130, 00374, 01730,
   01730, 01230, 01130, 00232, 00432, 00474, 00630, 01674,
   00630, 00372, 00664, 01735, 00417, 00710, 00072, 00272,
   00013, 01160, 00710, 00024, 00416, 01310, 00070, 00232,
   00432, 00774, 00130, 00230, 00756, 01020, 01464, 01123,
   01656, 01364, 01623, 00420, 00224, 00445, 00714, 00614,
   00204, 01424, 00447, 01264, 01253, 01264, 01355, 00214,
   01264, 01033, 00416, 01001, 00164, 00665, 00610, 00710,
   00110, 00004, 00104, 01464, 00667, 01010, 01310, 00232,
   00673, 01664, 00755, 00064, 00167, 00724, 00501, 00064,
   00241, 00064, 01051, 00416, 00420, 00574, 00630, 00310,
   00210, 01156, 00447, 00310, 00064, 01423, 00764, 01163,
   01504, 01464, 01237, 01204, 01210, 01314, 00314, 01414,
   01514, 00232, 00774, 01664, 01777, 01214, 00464, 01355,
   01566, 00152, 00523, 01764, 01315, 00740, 01310, 00357,
   01656, 00464, 00220, 00724, 00645, 01262, 00064, 00103,
   00432, 00050, 00150, 00250, 00350, 00450, 01074, 00230,
   01160, 01260, 01156, 01160, 00432, 01750, 00243, 01440,
   01160, 00710, 00077, 01262, 01464, 01023, 00432, 01250,
   01350, 01450, 01550, 01650, 00763, 00764, 00033, 00416,
   00045, 00164, 01135, 00673, 00464, 01355, 01347, 00464,
   01355, 00510, 01347, 00664, 00053, 00432, 00357, 00416,
   00756, 00045, 00164, 00665, 00673, 01124, 00043, 00040,
   01110, 00673, 00503, 01067, 00507, 00143, 00157, 00064,
   00627, 00416, 00756, 01001, 00164, 01135, 00273, 00164,
   01501, 01640, 01640, 00253, 01640, 00473, 00633, 00716,
   00716, 00124, 00550, 01364, 01537, 01464, 00753, 01427,
   01507, 01023, 01517, 01307, 00703, 01640, 00657, 00642,
   01377, 01464, 00413, 01464, 00253, 00764, 00703, 00133,
   01607, 01017, 01243, 01640, 01033, 01640, 00327, 00642,
   01477, 01464, 00733, 01464, 01043, 01464, 01057, 00517,
   01137, 01617, 01123, 01640, 01640, 01337, 01167, 00642,
   01577, 01464, 00717, 01464, 01167, 01464, 01077, 00567,
   01527, 01627, 01707, 01640, 01717, 01157, 01727, 00642,
   01564, 01677, 01611, 00170, 01751, 00270, 01262, 01751,
   00432, 00330, 00630, 01224, 01016, 00530, 01474, 01204,
   00430, 00164, 01145, 00064, 01447, 01611, 00164, 01471,
   00372, 00332, 00225, 00710, 01360, 00432, 01160, 00372,
   01360, 01051, 00372, 00432, 01203, 01562, 00304, 01156,
   01737, 01766, 00674, 00416, 01546, 00304, 01474, 01030,
   00232, 01070, 00436, 00762, 01772, 00752, 01772, 00420,
   00656, 01410, 01626, 00337, 00420, 01056, 00427, 00216,
   00256, 01160, 00070, 01410, 01020, 01556, 00304, 01074,
   00130, 01530, 00256, 00470, 00417, 01010, 00755, 00570,
   01674, 00130, 01021, 00164, 01135, 00464, 01355, 01021,
   00164, 00665, 01556, 01351, 01366, 01351, 00272, 00620,
   00520, 01654, 01137, 00710, 00420, 01162, 01556, 01151,
   01772, 00174, 01730, 00232, 00202, 00432, 00474, 00330,
   01574, 00330, 00110, 00372, 00114, 00224, 00503, 01064,
   00523, 00755, 01277, 00410, 01535, 00510, 00610, 01650,
   00432, 01160, 00710, 01020, 00272, 00432, 00774, 00730,
   01020, 01611, 00225, 00416, 01474, 00420, 01130, 01616,
   01474, 00730, 00664, 00327, 01045, 00372, 00710, 01562,
   00304, 01431, 01156, 01173, 00416, 01766, 01556, 00304,
   00774, 00206, 00674, 01506, 00304, 00206, 00372, 00520,
   00520, 01152, 01237, 00232, 01417, 01670, 01601, 00064,
   00103, 01772, 01324, 01266, 01534, 01763, 01402, 01760,
   01764, 01717, 00747, 01535, 01267, 01611, 00225, 01601,
   01611, 00164, 01445, 01360, 00710, 01277, 00774, 01372,
   01314, 01142, 01372, 01315, 00742, 01020, 01214, 01601,
   00011, 01310, 00270, 01262, 01310, 00011, 01277, 00432,
   01074, 00130, 01160, 01020, 00432, 00143, 00664, 00043,
   00764, 00303, 00432, 01160, 00070, 00272, 00072, 00126,
   01020, 00730, 00774, 00573, 00127, 01045, 00022, 00674,
   00006, 00432, 00756, 00164, 00505, 01431, 01273, 01556,
   00304, 00253, 00164, 00677, 01123, 00750, 00710, 01562,
   00152, 00535, 00174, 01546, 00152, 00575, 00432, 00474,
   00330, 01424, 01261, 00474, 01426, 01422, 01126, 00174,
   00006, 00774, 00130, 00532, 01235, 00755, 00232, 01325,
   01115, 01331, 01141, 01265, 00661, 01325, 00550, 00715,
   01056, 00426, 01755, 00661, 01331, 01025, 00130, 00230,
   00130, 00530, 01325, 01025, 01051, 00374, 00430, 01101,
   01131, 01331, 01615, 01615, 00725, 01241, 00755, 00232,
   01325, 01115, 01331, 00570, 01325, 00661, 01325, 01025,
   01171, 01131, 00535, 00474, 00475, 00030, 00430, 01426,
   01700, 01070, 01166, 01174, 00402, 00751, 00327, 01672,
   01070, 00206, 01574, 00206, 01050, 00272, 01007, 01156,
   00563, 00416, 01746, 01373, 01556, 00152, 01373, 00324,
   01676, 00266, 00674, 00706, 00706, 01615, 00226, 00726,
   00726, 00206, 00232, 01373, 01025, 00430, 00730, 01030,
   00130, 00630, 00430, 01474, 01107, 01672, 00474, 01070,
   00206, 00216, 01050, 01070, 00232, 00726, 00726, 00726,
   00726, 00726, 00016, 00656, 00022, 00432, 01474, 00230,
   00774, 01020, 00650, 00330, 00630, 01424, 01622, 00530,
   00230, 00530, 01020, 00755, 00430, 00416, 00164, 01137,
   01070, 01574, 00406, 00525, 01171, 01253, 00330, 00030,
   01424, 01645, 00630, 00274, 00130, 01156, 01020, 00725,
   00556, 01051, 00164, 00665, 01333, 01070, 00274, 00406,
   00232, 00775, 01353, 00650, 00770, 01262, 00464, 01355,
   00510, 00232, 00670, 00164, 00101, 00650, 00272, 01020,
   01141, 00535, 01615, 00274, 00475, 00130, 00430, 00774,
   01426, 01715, 01130, 01130, 01507, 01030, 00730, 01674,
   00130, 00626, 00575, 01156, 00164, 00505, 00272, 00210,
   01324, 01746, 01210, 01751, 01304, 01224, 01375, 00272,
   00710, 01355, 00173, 01666, 01666, 01020, 01234, 01115,
   00710, 01751, 01315, 01404, 01010, 01310, 00232, 00007,
   01574, 01504, 00002, 01235, 01141, 01265, 01334, 00543,
   01314, 01567, 01072, 01572, 00152, 00570, 01020, 00424
};
