/*
 * x11-calc-67.c - RPN (Reverse Polish) calculator simulator.
 *
 * Copyright(C) 2018   MT
 *
 * Model specific functions.
 *
 * This  program is free software: you can redistribute it and/or modify it
 * under  the terms of the GNU General Public License as published  by  the
 * Free  Software Foundation, either version 3 of the License, or (at  your
 * option) any later version.
 *
 * This  program  is distributed in the hope that it will  be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without even   the   implied   warranty   of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You  should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 06 Dec 21         - Initial version - MT
 *                   - Simplified keyboard constants - MT
 * 10 Dec 21         - Keyboard shortcuts for labels now uppercase to avoid
 *                     conflicting with existing shortcuts - MT
 * 21 Dec 21         - Added keyboard shortcut for single step - MT
 * 22 Dec 21         - Added keyboard shortcuts for shift keys - MT
 * 03 Jan 21         - Changed debug() macro so that debug code is executed
 *                     when DEBUG is defined (doesn't need to be true) - MT
 * 11 Jan 22         - Removed ROM_BANKS - MT
 * 15 Jan 22         - Changed 'PSE' to 'PAUSE' - MT
 * 12 Feb 22         - Updated layout and separated the initialisation code
 *                     for buttons and switches into two functions - MT
 * 26 Feb 22         - Moved keys to make more room for the card - MT
 * 28 Feb 22         - Fix prgm/run switch labels - MT
 * 21 Oct 23         - Updated switch parameters to accomodate a 3 position
 *                     switch - MT
 *
 */

#define NAME           "x11-calc-67"
#define BUILD          "0012"
#define DATE           "21 Oct 23"
#define AUTHOR         "MT"

#include <stdarg.h>    /* strlen(), etc. */
#include <stdio.h>     /* fprintf(), etc. */
#include <stdlib.h>    /* getenv(), etc. */

#include <X11/Xlib.h>  /* XOpenDisplay(), etc. */
#include <X11/Xutil.h> /* XSizeHints etc. */

#include "x11-calc-font.h"
#include "x11-calc-button.h"
#include "x11-calc-switch.h"
#include "x11-calc-label.h"
#include "x11-calc-colour.h"

#include "x11-calc-cpu.h"

#include "x11-calc.h"

#include "gcc-debug.h"

oregister o_mem[MEMORY_SIZE];

void v_init_switches(oswitch *h_switch[]) /* Define the switches. */
{
   h_switch[0] = h_switch_create(00000, "OFF", "", "ON ", h_alternate_font, KBD_LEFT, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
   h_switch[1] = h_switch_create(00000, "PRGM", "", "RUN", h_alternate_font, KBD_LEFT + 3 * KEY_WIDTH + 2 * KEY_GAP, KBD_TOP, 2 * KEY_WIDTH + KEY_GAP, SWITCH_HEIGHT, True, MID_GREY, DARK_GREY);
}

void v_init_buttons(obutton *h_button[]) {
   int i_left, i_top, i_count = 0;

   /* Define top row of keys. */
   i_top = KBD_TOP + 2* (SWITCH_HEIGHT + 1); /* Assumes the function label and switch text use the same font */
   i_top = KBD_TOP + KEY_HEIGHT + 2 * SCALE_HEIGHT + 1; /* Leave gap for card */
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00244, 'A', "A", "a", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00243, 'B', "B", "b", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00242, 'C', "C", "c", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00241, 'D', "D", "d", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00240, 'E', "E", "e", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);

   /* Define second row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00224, 000, "E+", "x ", "s", "E-", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00223, 000, "GTO", "GSB", "f", "RTN", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00222, 000, "DSP", "FIX", "SCI", "ENG", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00221, 000, "(i)", "RND", "", "X-I", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00220, ' ', "SST", "LBL", "f", "BST", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);

   /* Define third row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00024, 'f', "f", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, YELLOW, BACKGROUND, YELLOW, YELLOW);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00023, 'g', "g", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, LIGHT_BLUE, BACKGROUND, LIGHT_BLUE, LIGHT_BLUE);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00022, 000, "STO", "DSZ", "(i) ", "STO I", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00021, 000, "RCL", " ISZ", "(i)", "RCL I", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00020, 'h', "h", "", "", "", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, BLACK, BLACK, BLACK, BLACK);

   /* Define fourth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00063, 015, "ENTER", "W/DATA", "MERGE", "        DEG", h_normal_font, h_small_font, h_alternate_font, KBD_LEFT, i_top, 2 * KEY_WIDTH + KEY_GAP, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += 2 * (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00062, 'c', "CHS", "P-S", "", "RAD", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00061, 'e', "EEX", "CLREG", "", "GRD", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);
   i_left += (KEY_WIDTH + KEY_GAP);
   h_button[i_count++] = h_button_create(00060, 033, "CLX", "CLPRGM", "", "DEL", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, BLACK, BLACK);

   /* Define fifth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00103, '-', "-", "X=0", "X=Y", "SF", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP);
   h_button[i_count++] = h_button_create(00102, '7', "7", "LN", "eX", "X-Y", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[i_count++] = h_button_create(00101, '8', "8", "LOG", "10x", "Rv", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[i_count++] = h_button_create(00100, '9', "9", "V\xaf", "x\xb2", "R^", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define sixth row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00123, '+', "+", "X\x1d\x30", "X\x1d\x59", "CF", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP);
   h_button[i_count++] = h_button_create(00122, '4', "4", "SIN", "-\xb9", "1/x", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[i_count++] = h_button_create(00121, '5', "5", "COS", "-\xb9", "yX", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[i_count++] = h_button_create(00120, '6', "6", "TAN", "-\xb9", "ABS", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define seventh row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00143, '*', "\xd7", "X<0", "X\x1a\x59", "F?", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP);
   h_button[i_count++] = h_button_create(00142, '1', "1", "-R", "-P", "PAUSE", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[i_count++] = h_button_create(00141, '2', "2", "-D", "-R", "\x1c", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[i_count++] = h_button_create(00140, '3', "3", "-H", "-HMS", "REG", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);

   /* Define bottom row of keys. */
   i_top += KBD_ROW;
   i_left = KBD_LEFT;
   h_button[i_count++] = h_button_create(00163, '/', "\xf7", "X>0", "X>Y", "N!", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_WIDTH, KEY_HEIGHT, False, False, GREEN, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_WIDTH + 2 * KEY_GAP);
   h_button[i_count++] = h_button_create(00162, '0', "0", "%", "%CH", "LST x", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[i_count++] = h_button_create(00161, '.', ".", "INT", "FRAC", "HMS+", h_large_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
   i_left += (KEY_NUMERIC + 2 * KEY_GAP );
   h_button[i_count++] = h_button_create(00160, 000, "R/S", "-x-", "STK", "SPACE", h_normal_font, h_small_font, h_alternate_font, i_left, i_top, KEY_NUMERIC, KEY_HEIGHT, False, False, LIGHT_GRAY, YELLOW, MID_BLUE, BLACK);
}

int i_rom[ROM_SIZE] = {
00000, 01743, 00264, 00217, 01074, 00330, 01160, 01570,
01020, 00256, 01160, 00070, 00232, 00520, 00520, 01152,
00067, 01020, 00564, 01303, 01550, 01020, 00610, 00464,
00035, 00372, 00262, 00232, 00417, 00104, 00021, 01356,
00043, 01334, 00044, 00111, 01514, 01477, 00224, 00061,
00124, 00103, 00204, 01414, 00021, 01556, 00060, 00111,
00223, 00214, 00111, 01104, 00420, 01500, 01300, 01414,
00264, 01025, 00567, 00372, 00332, 01104, 01414, 00523,
01114, 00433, 00372, 01104, 00564, 00175, 00372, 00334,
00114, 00471, 00214, 00114, 01414, 00523, 00224, 00122,
00134, 00123, 00113, 01020, 01300, 00420, 00314, 00264,
01025, 01500, 00324, 00257, 00471, 00332, 00224, 00304,
00432, 00114, 00314, 00422, 00410, 01324, 00317, 01764,
01431, 00132, 00172, 01424, 00157, 00464, 00035, 00264,
00711, 01760, 00310, 00210, 01714, 01724, 00164, 00314,
01500, 00324, 00263, 00114, 00300, 00324, 00204, 01334,
00206, 01314, 00372, 00373, 01334, 00315, 00314, 00560,
00324, 01324, 01734, 00167, 00310, 00372, 00400, 00120,
00416, 00212, 01656, 01474, 00530, 00516, 01152, 01127,
01616, 00716, 00416, 00574, 00430, 00314, 00434, 00254,
00634, 00254, 00512, 01024, 00251, 00512, 00724, 00251,
00512, 00410, 00164, 00220, 00410, 00364, 00220, 00432,
00410, 01400, 00637, 01400, 00720, 00000, 00000, 00000,
00000, 01154, 00206, 00410, 00762, 01413, 01500, 00410,
00314, 00417, 00410, 01033, 01714, 01734, 00353, 00314,
00500, 00324, 00351, 00214, 00323, 00372, 01304, 00021,
00264, 00477, 00045, 00764, 01721, 00264, 00377, 01324,
00161, 00372, 00021, 00124, 00355, 00224, 00355, 00317,
00314, 00111, 00324, 01366, 01100, 00000, 00314, 01364,
01073, 00400, 01663, 00500, 00021, 00045, 00210, 00232,
00410, 01464, 00107, 01034, 00124, 00471, 00214, 00323,
00432, 00410, 00432, 00610, 00432, 00264, 00003, 00000,
00000, 00756, 00756, 01147, 00756, 00756, 00756, 00756,
00756, 00756, 00756, 00756, 00756, 00756, 00756, 00756,
00756, 00330, 00177, 00756, 00756, 00756, 00503, 00756,
00756, 00756, 00756, 00756, 00756, 00613, 00430, 00272,
00410, 00264, 01025, 01324, 00340, 01464, 00107, 00364,
01637, 01504, 00064, 00613, 00364, 00753, 00364, 01023,
00364, 01343, 00364, 01477, 00264, 01733, 01364, 01477,
00364, 00107, 00264, 00313, 00364, 01037, 00000, 00000,
00557, 01523, 00553, 00527, 00533, 00363, 00737, 00753,
00273, 00263, 00756, 00756, 00230, 00177, 00000, 00333,
00756, 00756, 00756, 00137, 00143, 00103, 00107, 01003,
00000, 01243, 01737, 01763, 01013, 00000, 00117, 00137,
00463, 00763, 00756, 00756, 00173, 00163, 00457, 00756,
00756, 00756, 00530, 00364, 00353, 00323, 00147, 00073,
01653, 01247, 00756, 00756, 00756, 00756, 00303, 00730,
01730, 00177, 01130, 00743, 01204, 00530, 00414, 00247,
01030, 00773, 00630, 00773, 00000, 00363, 00647, 00637,
00273, 00263, 00756, 00756, 00756, 00756, 01243, 00077,
00756, 00343, 00153, 00000, 01757, 01063, 01463, 00756,
01163, 00756, 00756, 01053, 00530, 00177, 00027, 00037,
01457, 00756, 01607, 00613, 00013, 01253, 00756, 01137,
00756, 00756, 00756, 00756, 00453, 01403, 00313, 00057,
01417, 01257, 00756, 00756, 00756, 00756, 00303, 00000,
00000, 01730, 00264, 01025, 00704, 00247, 01330, 01353,
01630, 00414, 00247, 01230, 01407, 00363, 00653, 00643,
00273, 00263, 00756, 00756, 00756, 00756, 01737, 00353,
00756, 00127, 00157, 00000, 01753, 01067, 01467, 00756,
01563, 00756, 00756, 01453, 00756, 01233, 00023, 00033,
01657, 00756, 01633, 00063, 01057, 01747, 00756, 01537,
00000, 00756, 00756, 00756, 01547, 01347, 00007, 00067,
01373, 00453, 00756, 00756, 00756, 00756, 00237, 00756,
00756, 00756, 00756, 00756, 00756, 00030, 00177, 00000,
01760, 00320, 01160, 01260, 01074, 00330, 01160, 01260,
01670, 01572, 01023, 01000, 00432, 00274, 00130, 00230,
00230, 00230, 01650, 00171, 01074, 00742, 01160, 01260,
00742, 01160, 01260, 00110, 00064, 00363, 00064, 00021,
00432, 01550, 01020, 00432, 01474, 00235, 00163, 00232,
00420, 00432, 01102, 00232, 01160, 00232, 01360, 01102,
00257, 01020, 01334, 00125, 00432, 01000, 01074, 00230,
00235, 01074, 00130, 00235, 00171, 01650, 00043, 00232,
00510, 00674, 00206, 00232, 00432, 00372, 00310, 00210,
00314, 01714, 01724, 01111, 00310, 00064, 01537, 00464,
01711, 00510, 00236, 01524, 01127, 00416, 01025, 00410,
01570, 01556, 00322, 00510, 00416, 01156, 00232, 00216,
00372, 00072, 00467, 00256, 01322, 01147, 01112, 00774,
01746, 01352, 01156, 01666, 01152, 00647, 01746, 01746,
01746, 01020, 00615, 01174, 00732, 00426, 01362, 01174,
00720, 01102, 01162, 00733, 01352, 01201, 01152, 00720,
00763, 01646, 00330, 00372, 01020, 00414, 00614, 00714,
01014, 01214, 01514, 01020, 00574, 00630, 00230, 00272,
01074, 00330, 01160, 01570, 01356, 01234, 00752, 01412,
01243, 00412, 00742, 01217, 01074, 00742, 01402, 01243,
00402, 00324, 01235, 01550, 01020, 00464, 01307, 00032,
00432, 00214, 01274, 01630, 01230, 01230, 01430, 01230,
00420, 01146, 00232, 00372, 00310, 00210, 00410, 00574,
00430, 01156, 01347, 00210, 01146, 01363, 00210, 01714,
01724, 01277, 00410, 00314, 00300, 00334, 01312, 00314,
01734, 01303, 00300, 01724, 01317, 00334, 01312, 00210,
00372, 00100, 00064, 00323, 01025, 00764, 01743, 00604,
01110, 01110, 01110, 00372, 00432, 01474, 00330, 00410,
01414, 00420, 00310, 01764, 01431, 00132, 00172, 01424,
01353, 00464, 00035, 00711, 00210, 00410, 00424, 01764,
00624, 01766, 00764, 01733, 00000, 00000, 00304, 01061,
00064, 00223, 00372, 01237, 01537, 00764, 01767, 00000,
00064, 00523, 00264, 01607, 00013, 01037, 00713, 01433,
01023, 00753, 00756, 00756, 00756, 00756, 01177, 00423,
00756, 00756, 00247, 00000, 00756, 00756, 00143, 00637,
00756, 00756, 00756, 00053, 00543, 00000, 00756, 00756,
01053, 00623, 00000, 00433, 01123, 01057, 00653, 00756,
00103, 00756, 00130, 00363, 00000, 00533, 01457, 00443,
00457, 00503, 00756, 00756, 00756, 00756, 01303, 00756,
00756, 00756, 00756, 00756, 00756, 00756, 00374, 00756,
00620, 01354, 01477, 00733, 00164, 00077, 00030, 00733,
01601, 00630, 00743, 01601, 00704, 01204, 01530, 00743,
00434, 00770, 01234, 00770, 00164, 01647, 00064, 00167,
01430, 00720, 00434, 00412, 00734, 00412, 01024, 00412,
01004, 00620, 00030, 00743, 01630, 00756, 00643, 01230,
00756, 00547, 00434, 01447, 00734, 01447, 00624, 01447,
01030, 00603, 01601, 00730, 01204, 01447, 00164, 00177,
00164, 00247, 00424, 01600, 00624, 01600, 01605, 01007,
01601, 00404, 00604, 00743, 01601, 00704, 01007, 01601,
01004, 01007, 00756, 00424, 01654, 00634, 01643, 00724,
01656, 01224, 01476, 00363, 00424, 01452, 00624, 01452,
01234, 01452, 01004, 00574, 01730, 01730, 00743, 00424,
01654, 00624, 01656, 01034, 01654, 00752, 01552, 01755,
00232, 00716, 00232, 00743, 01542, 01566, 00130, 00733,
01024, 01670, 00724, 01474, 00624, 01670, 01224, 01474,
00314, 01100, 00324, 01676, 01330, 00363, 00430, 01074,
01000, 00256, 00716, 00416, 00164, 00220, 01601, 01130,
00704, 00404, 00743, 00424, 01721, 00634, 01727, 00330,
00337, 01024, 01467, 00330, 01224, 01467, 00343, 01342,
01717, 00742, 01563, 01477, 01142, 01024, 01717, 00337,
01214, 00414, 00614, 00714, 01014, 01514, 01020, 01224,
01753, 01230, 00363, 01430, 00363, 01152, 01014, 00372,
00410, 00372, 00464, 01307, 00764, 01763, 00764, 01737,
00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
01374, 00432, 01130, 00063, 01434, 00000, 00072, 01074,
00330, 01160, 00314, 01670, 01410, 00575, 00324, 00023,
00174, 01542, 00066, 00711, 00216, 00256, 01674, 01342,
00060, 01374, 00652, 01116, 00243, 01116, 01142, 00267,
01162, 01162, 00402, 01116, 00656, 00516, 00216, 00303,
01116, 00257, 00223, 01116, 00157, 01142, 00217, 00207,
00752, 00317, 01216, 00420, 00314, 01020, 01374, 00316,
01352, 00124, 00774, 00766, 01342, 00107, 01142, 00756,
00357, 00711, 00334, 00105, 01166, 00752, 00317, 00756,
00023, 01155, 00334, 00004, 01166, 00427, 00324, 00105,
00711, 00334, 00105, 00756, 01356, 00116, 01362, 00133,
01162, 01156, 00523, 01342, 00000, 01142, 00547, 00272,
00432, 01174, 00006, 01374, 00206, 00242, 01162, 01102,
00633, 00262, 00774, 01142, 01122, 00657, 01020, 01162,
01374, 00742, 01174, 00272, 00762, 01102, 00723, 01162,
00314, 00774, 00106, 00146, 01326, 00232, 01362, 00232,
01222, 01162, 00222, 00002, 00620, 01122, 01017, 00466,
00006, 00132, 00162, 00156, 00132, 01526, 00232, 00736,
00662, 01676, 00304, 01512, 00231, 00656, 01512, 00157,
01153, 00656, 01020, 00314, 00132, 00172, 00466, 01153,
00036, 01103, 01516, 00245, 00656, 01116, 01616, 01277,
00574, 00130, 00030, 00430, 01616, 01277, 01616, 00656,
00216, 01410, 01356, 00321, 00436, 01156, 00272, 00574,
00230, 00230, 00430, 01616, 01357, 00232, 01216, 01156,
00216, 00732, 00732, 00732, 01174, 00730, 01447, 00420,
00656, 01410, 01636, 01437, 00536, 00716, 00652, 01672,
00232, 00272, 01464, 01203, 01274, 00230, 00330, 00230,
01773, 00704, 01671, 00334, 00351, 01074, 00330, 01671,
00334, 00351, 00416, 01230, 01474, 00714, 01671, 00324,
00360, 00410, 00332, 00410, 01464, 01663, 01564, 01473,
00264, 01757, 01410, 00436, 00032, 01074, 01342, 00412,
01142, 01342, 00324, 01274, 00130, 00230, 00236, 00474,
00730, 01474, 01636, 01142, 00013, 00474, 00130, 01636,
01152, 00037, 00674, 00420, 01106, 01020, 01366, 01025,
00664, 00503, 00664, 01303, 00232, 01534, 00430, 01262,
00664, 00747, 00175, 01360, 01020, 00664, 00147, 01566,
00442, 00432, 01352, 00452, 01410, 01156, 00752, 01152,
00257, 00756, 01020, 00774, 00552, 00303, 00432, 00323,
00406, 01146, 00412, 00304, 01274, 01020, 01074, 00330,
01160, 01020, 01504, 00610, 00331, 00470, 00232, 00710,
00125, 00151, 00710, 00272, 00165, 00232, 00570, 00121,
00151, 00670, 01210, 00121, 00151, 01210, 00232, 00272,
00165, 00232, 00770, 00121, 00151, 01210, 00710, 00165,
00232, 01070, 00121, 00151, 00432, 00774, 00742, 00232,
01170, 00121, 00151, 00314, 00064, 00403, 00410, 00331,
00432, 00774, 00742, 00232, 01170, 00135, 00372, 00332,
00410, 01326, 01025, 01322, 01025, 00610, 00670, 00272,
00165, 01170, 00071, 00570, 01524, 00577, 00770, 00135,
00510, 00071, 00422, 00111, 01524, 01001, 01504, 00175,
01010, 01310, 00470, 00737, 00372, 00331, 01170, 00372,
01326, 01025, 00610, 00670, 00232, 01170, 00071, 01524,
01001, 01504, 01010, 01310, 00470, 01123, 00032, 00774,
00642, 01366, 01025, 00664, 00477, 00432, 00774, 00742,
00232, 00121, 00151, 01352, 00656, 00432, 01564, 00707,
01074, 00330, 01160, 01570, 01152, 01423, 00574, 00630,
01474, 01142, 01423, 01730, 01074, 01342, 00703, 01142,
01542, 00704, 00304, 00230, 00064, 00123, 01210, 01116,
01116, 00664, 00141, 00064, 00417, 01210, 01504, 01532,
00723, 00264, 01753, 00610, 00710, 00121, 01210, 00232,
00656, 00656, 00664, 00501, 01457, 00000, 00000, 00000,
00432, 00742, 01772, 00762, 00372, 01302, 00751, 01706,
00756, 00032, 01602, 01677, 00732, 00472, 01667, 01622,
01733, 01646, 00672, 00756, 00472, 01723, 00106, 01142,
01627, 01162, 01627, 00732, 00156, 00436, 00446, 00532,
00236, 00064, 00417, 00774, 01562, 01025, 01552, 01025,
00272, 00172, 00736, 01506, 01023, 00435, 00656, 01416,
00740, 00752, 00007, 01116, 00047, 00264, 01753, 01010,
00435, 00072, 00126, 00235, 00421, 00774, 00072, 00156,
00446, 00223, 00756, 00642, 00226, 00272, 01020, 00616,
01174, 01062, 00263, 01222, 00032, 00307, 01474, 00263,
00472, 01142, 00303, 00244, 01072, 00720, 01672, 00307,
00756, 01672, 01020, 00132, 00271, 00510, 00423, 00410,
00332, 00271, 00510, 00556, 01522, 01070, 01020, 00610,
00710, 01020, 00272, 00143, 01366, 01025, 01010, 00435,
00511, 00167, 00072, 00366, 01062, 00537, 01222, 01056,
00016, 00022, 00426, 00774, 00573, 00742, 01032, 00567,
00472, 00620, 00354, 01153, 00676, 00356, 00416, 00647,
01136, 01472, 01150, 00732, 01154, 01136, 00032, 00232,
00222, 00356, 01167, 00032, 00662, 01216, 01672, 00553,
01010, 00755, 00167, 00774, 00072, 00652, 00652, 00752,
00752, 01416, 01204, 00232, 00226, 01366, 01210, 00232,
00366, 01416, 01220, 01732, 00656, 01332, 01220, 01047,
01152, 01152, 00016, 01622, 01522, 01230, 00472, 00423,
01466, 01234, 01262, 00132, 01032, 00774, 01506, 01244,
00416, 01020, 01064, 00067, 01502, 01241, 00706, 01213,
00434, 01253, 01262, 01165, 00167, 01562, 01025, 00435,
00032, 00226, 01321, 01257, 00172, 00372, 00572, 00572,
00632, 00372, 00436, 00272, 00556, 01377, 01166, 00556,
00616, 01474, 01542, 01305, 01732, 01772, 00216, 00432,
00132, 01274, 00530, 01772, 01517, 00742, 01632, 01467,
00532, 00732, 00620, 01746, 01354, 01316, 00402, 00232,
00372, 01020, 00610, 01074, 00330, 01160, 00670, 01010,
01310, 00470, 00007, 00372, 01751, 00007, 00435, 01653,
00435, 01262, 00372, 01751, 01010, 01310, 00132, 01751,
00741, 00564, 00175, 01004, 01617, 00506, 01746, 01546,
01365, 01020, 01326, 01405, 00774, 00316, 00756, 00756,
01552, 01450, 00620, 01354, 01407, 00332, 01020, 01156,
00013, 00432, 00326, 01034, 01432, 00720, 01154, 01422,
00265, 00127, 00720, 00265, 00620, 00620, 00265, 00272,
00332, 00233, 00032, 00255, 00720, 01144, 01440, 00720,
00255, 00732, 00532, 00372, 00664, 00421, 00664, 01257,
01312, 01405, 00047, 01746, 00606, 00246, 01746, 00546,
00546, 01046, 01034, 01365, 00032, 00256, 00632, 00416,
01020, 00032, 00664, 00435, 00226, 00372, 01064, 00115,
00372, 01004, 00765, 00372, 01321, 00372, 00715, 01254,
01504, 01274, 00730, 00222, 00372, 00507, 00172, 01162,
00567, 01646, 00232, 00736, 00232, 01122, 00473, 00132,
00642, 00664, 01241, 01107, 01646, 01122, 00563, 00022,
00472, 00642, 00473, 01646, 00642, 00507, 00232, 01064,
00115, 00372, 00432, 00232, 00664, 00435, 00664, 00235,
00426, 00367, 00762, 01032, 00713, 00472, 00732, 01776,
00372, 00620, 01020, 00756, 01672, 01352, 01636, 01522,
01573, 01216, 01352, 01624, 00426, 00032, 00556, 01133,
00406, 01562, 01620, 01172, 00412, 00304, 00424, 01621,
00422, 00064, 00417, 01672, 01156, 01117, 00416, 01362,
01634, 00132, 01032, 01256, 00436, 01020, 00232, 00706,
00706, 00706, 00232, 01227, 00756, 01032, 01223, 00472,
01166, 01257, 01137, 00232, 00716, 00232, 00732, 01034,
01645, 01552, 01610, 01227, 00432, 00244, 01777, 01172,
00430, 00772, 00422, 01772, 01544, 01746, 00444, 01710,
00144, 01722, 01644, 01732, 00644, 01737, 00720, 01020,
00274, 01615, 00030, 01030, 00530, 00330, 00130, 00730,
00674, 01020, 01674, 01615, 00330, 00030, 01030, 00430,
01574, 01020, 01174, 01615, 01615, 00374, 01020, 01074,
01615, 00274, 01020, 00330, 00330, 01020, 01574, 00330,
00130, 00030, 00130, 00730, 01130, 01030, 00030, 00430,
00330, 00474, 01020, 00000, 01060, 01060, 01060, 01060,
01060, 01060, 01060, 01060, 01060, 01060, 01060, 00474,
00630, 01130, 00330, 00130, 00430, 00730, 00130, 01030,
00030, 00530, 00630, 00774, 01020, 00420, 00662, 01410,
01156, 00664, 01223, 00432, 00774, 00230, 00330, 00030,
00230, 00530, 01030, 00530, 00030, 01130, 00230, 01130,
01130, 00430, 00774, 01020, 00774, 01372, 00173, 01562,
00213, 00664, 00435, 01356, 00251, 00756, 00032, 01626,
01356, 00267, 01646, 00162, 01274, 00620, 01122, 00327,
00122, 00436, 00373, 01672, 00742, 00122, 00172, 00420,
00522, 00410, 00222, 00732, 01672, 01162, 00423, 01410,
00410, 00472, 00732, 01122, 00357, 00262, 01122, 00522,
00523, 00132, 00732, 00573, 00544, 00121, 00762, 00620,
00132, 00122, 00732, 00367, 01162, 00720, 00372, 00764,
01321, 01672, 00372, 00627, 00472, 01142, 00623, 01562,
00134, 00244, 00273, 00432, 01625, 00664, 01165, 00022,
00734, 00163, 01262, 01224, 00744, 00624, 00337, 00664,
00165, 00064, 00417, 01234, 00202, 01010, 01526, 00204,
01310, 00232, 00264, 01753, 01522, 00200, 00232, 00664,
00435, 00432, 00747, 01234, 00202, 01010, 00172, 01512,
00200, 00656, 01116, 00736, 01526, 00245, 01516, 00240,
00222, 00262, 00562, 00562, 00622, 01362, 00241, 00404,
00422, 00372, 01310, 00372, 00257, 01516, 00222, 00132,
01003, 00272, 01102, 01526, 00257, 00432, 00717, 00664,
01165, 00664, 00511, 00522, 01122, 00416, 00313, 00704,
00664, 01165, 01327, 01356, 00155, 01172, 00372, 00066,
00115, 00232, 01072, 01312, 00306, 01072, 00232, 00372,
01352, 00313, 01272, 00206, 00620, 00732, 00554, 00314,
00774, 01502, 00334, 00726, 00232, 00222, 00664, 00305,
00664, 00421, 00426, 00717, 00656, 00620, 01523, 00372,
00115, 00372, 00664, 00551, 00737, 00720, 01156, 00254,
00345, 01020, 01210, 00610, 00710, 01366, 00463, 01362,
00364, 00704, 01204, 00422, 00664, 00511, 00022, 00564,
00211, 00314, 01154, 00467, 01572, 00402, 01010, 00710,
01310, 00432, 00032, 00072, 00266, 01362, 00417, 00404,
01534, 00417, 01234, 00417, 01214, 00704, 00414, 00774,
01352, 00616, 00445, 00634, 00630, 01601, 00432, 00172,
00372, 01672, 00642, 01206, 00243, 00132, 00232, 00664,
01165, 00410, 00232, 00664, 00361, 01156, 00664, 01321,
00372, 00132, 00710, 00232, 00664, 00521, 00022, 01552,
00630, 00132, 01123, 00752, 00222, 01532, 00367, 00132,
01010, 00372, 01310, 00372, 00664, 00375, 01364, 00621,
00132, 00232, 00710, 00664, 00155, 01010, 01310, 00510,
00027, 01534, 00515, 00610, 00710, 01020, 00172, 01332,
00534, 01102, 01532, 00621, 00232, 00634, 00532, 01545,
00432, 00563, 01264, 00215, 00232, 00445, 00432, 01064,
01631, 00372, 01264, 00215, 00572, 01772, 00372, 01234,
00563, 01605, 00372, 00232, 01072, 00232, 00372, 00432,
00664, 01165, 00022, 00734, 00567, 01605, 00472, 00422,
00024, 00604, 00756, 00756, 00664, 00551, 00022, 01624,
00604, 00172, 01732, 01032, 00664, 01241, 01524, 00171,
01010, 01310, 00022, 00232, 00064, 00417, 01356, 00516,
00132, 00624, 00202, 00445, 00664, 00715, 00022, 01545,
00774, 00410, 00510, 00436, 00756, 01356, 00645, 00762,
00620, 00654, 00634, 00510, 00607, 00410, 00432, 00762,
01772, 01333, 00232, 00410, 00742, 00262, 00410, 01732,
01732, 01122, 01277, 00022, 00472, 00232, 00172, 01632,
01253, 00410, 00762, 00410, 00132, 00732, 00620, 00654,
00666, 00372, 00664, 00551, 01433, 01646, 01122, 01427,
00022, 00416, 00410, 00274, 00372, 01641, 00372, 01507,
00472, 01142, 01503, 01672, 00402, 01366, 00537, 00720,
01463, 01224, 00735, 01204, 01020, 01214, 01020, 01672,
00756, 01556, 00737, 01020, 00132, 01010, 00764, 00657,
00432, 01172, 00422, 00244, 00771, 01444, 01012, 01544,
01020, 00444, 01026, 00144, 01032, 01474, 00730, 00274,
01020, 00674, 00630, 00630, 01030, 00630, 00530, 00230,
00430, 01130, 00130, 00130, 00630, 00313, 00630, 01344,
00766, 00033, 00374, 00031, 00174, 01030, 00474, 01020,
01374, 00031, 01474, 01130, 00674, 01020, 00174, 00031,
01574, 01020, 00574, 00031, 00374, 01020, 00432, 00774,
00430, 00530, 00313, 00774, 00432, 00730, 01030, 00530,
00330, 01130, 01030, 00130, 00630, 00330, 00330, 01130,
00730, 00530, 00774, 01020, 01504, 00604, 01204, 01010,
00353, 00272, 00610, 00710, 00232, 00032, 00072, 00226,
01362, 01107, 00704, 01224, 01106, 00404, 00422, 00372,
00024, 01215, 01634, 01120, 00232, 00272, 01772, 01632,
00171, 00372, 01156, 01552, 01131, 01156, 00547, 00756,
01672, 00372, 00410, 00510, 00572, 00572, 00572, 01772,
00372, 01552, 01162, 00764, 00765, 00432, 00372, 00510,
00572, 00732, 00034, 01156, 01672, 01772, 00372, 01032,
00757, 00472, 00372, 00510, 00372, 00034, 01225, 01556,
01224, 00732, 01127, 01234, 01204, 01214, 00424, 01202,
00404, 00677, 00414, 00677, 01204, 00634, 01176, 00734,
01213, 00714, 00677, 00704, 00677, 00215, 00553, 00132,
01032, 01164, 01545, 01153, 00756, 01552, 01234, 01032,
01077, 00472, 00664, 01165, 00022, 00024, 01251, 00372,
00510, 00372, 00664, 00551, 00022, 00410, 00215, 00664,
00355, 01156, 00410, 00510, 00756, 01467, 00732, 01477,
00432, 00032, 00642, 00664, 01241, 01443, 00774, 00510,
01224, 01521, 01534, 01263, 00372, 00710, 01364, 01011,
01310, 00710, 00132, 00664, 00155, 00434, 01310, 01262,
00064, 00417, 00620, 00644, 01266, 00756, 01453, 00432,
00372, 01164, 01641, 00372, 00764, 00715, 00654, 01321,
00372, 00410, 01672, 01672, 00432, 00774, 00130, 00410,
01274, 00630, 01667, 01646, 01646, 01122, 01617, 00022,
00410, 00232, 01072, 00472, 00410, 00172, 00262, 01142,
01627, 00232, 00726, 00232, 01366, 01373, 01162, 00022,
01672, 01667, 00756, 01162, 01753, 00422, 00410, 00232,
01132, 00510, 01224, 01406, 01216, 00132, 01332, 01504,
00664, 00551, 00022, 00634, 01263, 00172, 01074, 00442,
00143, 00732, 00676, 00147, 00662, 01672, 00172, 00756,
00732, 00236, 00664, 00375, 00621, 01534, 01470, 00372,
00132, 00710, 00232, 00664, 00521, 00232, 00410, 00616,
01310, 00510, 00232, 01001, 01010, 01310, 00710, 00216,
00016, 01672, 00410, 00664, 00355, 00664, 00165, 00613,
00372, 00132, 00510, 00232, 01056, 00016, 01672, 00664,
00551, 00422, 01264, 01317, 00432, 00624, 01515, 01172,
00412, 00304, 00422, 00064, 00417, 01534, 01260, 00432,
00603, 00624, 01530, 00132, 00664, 00715, 01264, 01317,
01534, 01260, 00372, 00132, 00710, 00664, 00155, 01011,
01310, 00710, 01264, 01427, 00072, 00356, 00774, 00332,
00556, 00733, 00332, 01164, 01575, 00642, 00707, 00720,
00667, 00664, 00421, 00072, 00664, 01323, 00332, 01156,
00757, 00332, 00667, 00620, 01354, 01567, 00332, 00717,
00664, 00165, 00734, 01605, 01262, 00564, 00177, 00520,
00520, 00520, 00520, 00520, 00520, 01020, 01074, 00334,
01625, 00416, 00130, 01360, 01433, 01160, 00372, 00410,
00070, 00376, 00316, 00752, 00752, 00752, 01410, 01252,
00420, 01233, 00720, 00720, 00706, 00706, 01152, 01213,
00070, 00232, 00520, 00520, 01646, 01646, 00242, 00620,
00242, 00332, 01353, 00272, 01160, 00070, 00474, 00206,
00520, 00520, 00232, 01474, 01360, 00232, 01142, 01317,
01074, 01142, 01542, 01663, 00510, 00372, 00064, 00527,
00520, 00520, 00520, 00520, 00520, 00520, 01020, 01334,
01706, 00372, 00410, 00064, 00021, 01356, 01704, 01074,
00620, 00620, 01152, 01543, 00272, 01160, 00070, 00232,
00706, 00706, 01074, 00246, 01703, 01160, 00346, 00070,
00206, 01441, 01441, 01160, 00306, 00232, 01360, 00332,
01146, 01542, 01745, 00232, 01160, 01772, 01772, 01360,
00510, 00372, 00314, 00264, 01737, 00000, 00000, 00000,
00163, 00207, 00163, 00233, 00233, 00143, 00203, 01533,
01333, 01507, 01363, 00253, 01437, 00273, 01457, 00064,
00363, 00510, 00256, 00012, 00332, 00774, 00314, 00220,
00410, 01764, 01431, 00510, 01410, 00716, 01564, 00220,
00604, 01474, 01230, 01474, 01764, 00373, 01410, 00716,
01664, 00220, 01004, 01074, 00642, 00642, 01074, 00642,
00642, 01474, 00332, 00410, 00642, 00347, 01204, 01564,
01357, 01102, 00232, 01074, 00272, 00732, 00732, 00212,
00732, 00732, 00256, 00620, 01254, 00100, 00064, 00021,
01556, 00114, 00064, 00111, 01074, 00620, 00620, 01152,
00467, 01160, 00372, 00070, 00372, 00132, 01442, 00205,
00720, 00720, 01354, 00126, 00747, 01160, 00232, 00070,
00232, 01532, 00144, 00747, 01074, 01442, 00205, 01174,
01442, 00205, 01674, 01442, 00205, 00274, 01442, 00205,
01574, 01442, 00205, 00474, 01442, 00205, 01274, 01442,
00205, 01074, 01146, 01542, 00135, 00624, 00765, 00230,
00604, 00567, 01574, 00132, 00507, 00102, 01442, 00212,
00102, 00543, 00102, 00620, 01442, 00220, 00720, 00543,
00102, 01442, 00225, 00102, 01073, 00752, 00620, 00620,
00254, 00225, 00752, 00752, 00752, 01410, 01252, 00272,
00510, 00372, 00064, 00021, 01034, 00262, 00232, 00474,
00706, 00706, 00706, 00232, 00224, 00262, 00204, 00124,
00262, 00432, 00216, 01550, 00064, 00317, 01565, 01424,
01422, 00564, 00071, 01413, 01565, 01424, 00052, 01262,
00664, 00745, 00564, 00175, 00324, 00765, 01513, 01565,
01424, 00056, 01403, 01565, 01424, 00017, 00664, 00145,
01413, 01641, 01360, 00510, 00064, 00357, 01641, 01134,
00332, 01310, 00232, 00064, 00417, 00216, 00256, 01474,
00742, 01623, 01564, 01357, 01230, 01404, 01416, 00362,
00332, 00410, 01074, 00402, 01160, 00070, 00132, 00232,
01410, 01414, 01020, 00432, 01550, 00077, 01400, 01414,
01104, 00064, 00527, 00324, 01256, 00064, 00463, 00000,
01747, 00107, 00123, 00307, 00173, 00323, 00363, 00407,
00333, 00343, 00427, 00423, 00433, 00353, 00463, 00664,
01553, 00564, 01171, 00133, 00664, 00451, 00064, 00417,
00610, 00710, 00422, 00133, 01464, 01733, 00564, 01433,
00163, 00473, 01173, 01203, 01213, 01237, 00143, 00403,
01223, 01273, 01253, 01247, 01257, 01313, 00443, 00064,
00363, 00664, 01265, 00133, 00564, 00357, 00764, 00347,
01064, 01653, 01264, 00323, 01010, 01310, 00232, 01204,
00604, 01004, 01064, 00223, 01204, 00604, 01264, 00347,
00372, 01404, 00064, 00133, 01664, 01337, 00664, 00017,
00677, 00653, 00763, 00707, 00663, 01017, 01013, 00747,
00720, 00720, 00720, 01057, 00404, 00603, 00404, 01504,
00432, 01160, 01770, 00434, 00550, 00232, 00564, 01227,
01371, 00633, 01210, 01072, 01372, 00566, 00717, 01210,
01072, 01572, 00566, 00064, 00111, 00314, 00510, 00064,
00357, 01210, 01504, 00773, 01210, 00232, 01262, 00664,
00745, 01017, 01262, 01566, 00610, 01524, 00566, 00717,
01362, 00566, 00717, 01670, 00272, 00344, 00624, 00744,
00624, 00030, 00720, 01360, 01502, 00566, 00717, 01766,
01766, 01601, 01471, 00232, 01764, 00313, 00564, 01063,
00564, 00633, 00564, 01467, 01004, 00764, 00633, 00564,
00353, 01204, 00604, 01504, 01164, 00013, 01345, 00406,
00216, 00133, 01345, 00016, 00664, 01165, 01156, 00226,
00133, 01664, 00173, 00432, 01160, 01770, 00274, 00620,
01766, 01354, 00677, 01352, 00706, 00432, 01224, 00773,
00624, 00627, 01766, 01565, 00464, 01547, 00314, 01366,
00731, 01410, 01166, 00724, 00726, 00420, 00742, 01473,
00304, 01020, 01356, 00743, 01156, 01356, 00744, 01156,
01356, 00745, 01737, 01766, 01766, 01474, 01020, 01766,
01565, 01074, 01730, 01531, 01156, 00334, 00073, 01330,
01474, 01471, 01156, 00334, 00073, 00510, 00372, 00264,
01757, 00064, 00233, 01362, 00747, 01551, 01772, 01772,
01772, 00372, 00064, 00021, 00464, 01711, 00520, 00520,
00520, 00372, 01410, 00464, 01213, 01305, 00230, 00230,
00137, 01305, 00430, 00133, 01305, 00030, 00030, 01650,
00064, 00463, 00064, 00413, 00364, 00023, 00625, 00272,
01352, 01044, 00756, 01020, 00756, 01356, 01054, 01156,
00726, 00620, 01526, 01045, 01020, 01200, 00064, 00527,
01227, 01747, 01247, 00107, 00067, 00163, 00123, 00553,
00563, 00613, 01513, 01617, 00513, 00517, 01717, 00533,
00643, 01763, 01773, 00657, 00673, 00267, 00703, 01737,
00753, 01027, 01017, 01043, 01067, 01057, 00503, 01457,
00264, 01767, 01004, 00625, 00664, 01617, 01564, 01355,
01464, 01537, 00625, 00573, 00625, 01262, 01010, 00664,
00745, 01753, 00664, 00135, 01753, 00610, 00710, 01020,
00372, 00664, 01633, 00731, 00710, 01753, 00764, 01753,
00432, 01160, 01770, 00372, 01750, 00153, 01134, 01171,
01310, 01020, 00731, 01264, 00215, 00572, 00572, 01772,
00766, 00416, 01753, 00004, 01033, 00014, 01614, 01457,
00014, 01604, 01457, 00064, 00013, 00410, 00432, 01074,
00402, 01160, 00372, 00070, 00232, 00332, 00330, 01160,
00070, 00232, 01360, 00332, 01160, 00232, 01360, 00332,
00742, 01077, 00410, 00064, 00357, 01010, 01310, 00232,
01753, 00072, 01114, 00160, 01434, 00373, 00060, 00064,
00373, 00372, 01764, 01431, 01670, 01674, 01020, 00372,
01074, 00330, 01160, 01570, 00124, 01300, 00234, 00363,
00422, 01772, 01772, 01772, 01572, 01310, 00064, 00307,
01360, 00124, 01306, 00064, 00363, 01410, 00332, 00664,
00461, 01753, 00625, 00232, 01264, 00171, 00756, 00756,
00664, 00511, 00022, 00410, 01264, 00215, 00664, 00355,
00664, 00165, 01753, 00625, 00032, 00226, 00372, 01264,
00215, 00372, 00756, 00756, 00664, 00551, 00022, 00410,
01264, 00171, 01573, 01564, 01355, 01464, 01513, 01110,
01110, 01110, 00064, 00417, 00364, 00003, 00264, 01763,
01431, 01674, 01542, 01405, 00404, 00474, 01342, 01411,
00704, 01374, 01020, 00642, 00077, 01564, 01357, 00141,
00030, 00127, 00672, 00141, 00130, 01650, 00064, 00363,
01431, 01670, 00774, 00716, 00716, 00720, 00652, 00167,
01020, 00716, 00652, 00220, 00372, 01262, 00064, 00417,
01664, 01467, 01557, 01757, 01637, 01457, 00243, 00133,
01402, 01413, 01431, 01670, 01374, 00530, 01374, 00732,
01142, 00337, 00202, 01650, 00064, 00463, 00624, 01460,
01402, 01441, 01424, 01506, 01245, 00437, 00001, 00424,
01566, 01362, 01643, 00734, 01516, 00742, 00674, 01162,
00716, 00716, 01542, 01532, 01512, 01535, 00766, 00724,
01542, 00633, 00724, 01546, 00623, 00734, 01545, 00742,
01574, 00627, 01574, 00130, 00274, 00742, 01750, 01746,
00762, 00574, 01162, 00720, 00706, 01562, 01552, 01352,
01563, 01152, 00657, 00106, 01770, 00763, 01074, 00216,
00706, 01474, 00242, 00216, 01750, 00256, 00274, 01772,
00620, 01354, 01577, 01410, 01326, 01643, 01112, 00156,
01352, 01615, 00412, 01216, 01156, 01512, 01620, 01113,
00012, 01216, 00516, 00232, 01512, 01637, 01352, 01637,
00432, 01312, 01645, 00372, 01414, 00060, 01217, 01312,
01642, 01216, 00356, 00064, 00523, 01172, 00412, 00362,
01157, 01404, 01134, 01656, 00332, 01310, 01104, 01431,
01670, 01474, 00130, 01500, 00324, 01671, 00224, 01673,
01353, 01400, 01650, 00432, 00314, 00372, 00432, 00752,
01230, 01674, 00230, 00230, 01374, 01020, 01074, 00330,
01160, 01770, 01020, 01434, 01721, 01431, 00674, 01542,
01727, 01245, 00372, 00774, 00130, 00372, 01162, 01674,
00030, 00030, 01603, 01424, 01742, 01245, 00474, 00742,
01750, 01217, 01431, 00474, 01342, 01737, 01603, 01410,
01434, 01444, 00001, 00424, 01763, 00372, 01366, 01761,
01262, 00372, 01217, 00574, 01152, 01352, 01771, 00130,
00763, 00330, 00763, 00332, 01310, 01114, 00064, 00373,
00000, 01743, 00264, 00217, 01074, 00330, 01160, 01570,
01020, 00256, 01160, 00070, 00232, 00520, 00520, 01152,
00067, 01020, 00564, 01303, 01550, 01020, 00610, 00464,
00035, 00372, 00262, 00232, 00417, 00104, 00021, 01356,
00043, 01334, 00044, 00111, 01514, 01477, 00224, 00061,
00124, 00103, 00204, 01414, 00021, 01556, 00060, 00111,
00223, 00214, 00111, 01104, 00420, 01500, 01300, 01414,
00264, 01025, 00567, 00372, 00332, 01104, 01414, 00523,
01114, 00433, 00372, 01104, 00564, 00175, 00372, 00334,
00114, 00471, 00214, 00114, 01414, 00523, 00224, 00122,
00134, 00123, 00113, 01020, 01300, 00420, 00314, 00264,
01025, 01500, 00324, 00257, 00471, 00332, 00224, 00304,
00432, 00114, 00314, 00422, 00410, 01324, 00317, 01764,
01431, 00132, 00172, 01424, 00157, 00464, 00035, 00264,
00711, 01760, 00310, 00210, 01714, 01724, 00164, 00314,
01500, 00324, 00263, 00114, 00300, 00324, 00204, 01334,
00206, 01314, 00372, 00373, 01334, 00315, 00314, 00560,
00324, 01324, 01734, 00167, 00310, 00372, 00400, 00120,
00416, 00212, 01656, 01474, 00530, 00516, 01152, 01127,
01616, 00716, 00416, 00574, 00430, 00314, 00434, 00254,
00634, 00254, 00512, 01024, 00251, 00512, 00724, 00251,
00512, 00410, 00164, 00220, 00410, 00364, 00220, 00432,
00410, 01400, 00637, 01400, 00720, 00000, 00000, 00000,
00000, 01154, 00206, 00410, 00762, 01413, 01500, 00410,
00314, 00417, 00410, 01033, 01714, 01734, 00353, 00314,
00500, 00324, 00351, 00214, 00323, 00372, 01304, 00021,
00264, 00477, 00045, 00764, 01721, 00264, 00377, 01324,
00161, 00372, 00021, 00124, 00355, 00224, 00355, 00317,
00314, 00111, 00324, 01366, 01100, 00000, 00314, 01364,
01073, 00400, 01663, 00500, 00021, 00045, 00210, 00232,
00410, 01464, 00107, 01034, 00124, 00471, 00214, 00323,
00432, 00410, 00432, 00610, 00432, 00264, 00003, 00000,
00000, 00756, 00756, 01147, 00756, 00756, 00756, 00756,
00756, 00756, 00756, 00756, 00756, 00756, 00756, 00756,
00756, 00330, 00177, 00756, 00756, 00756, 00503, 00756,
00756, 00756, 00756, 00756, 00756, 00613, 00430, 00272,
00410, 00264, 01025, 01324, 00340, 01464, 00107, 00364,
01637, 01504, 00064, 00613, 00364, 00753, 00364, 01023,
00364, 01343, 00364, 01477, 00264, 01733, 01364, 01477,
00364, 00107, 00264, 00313, 00364, 01037, 00000, 00000,
00557, 01523, 00553, 00527, 00533, 00363, 00737, 00753,
00273, 00263, 00756, 00756, 00230, 00177, 00000, 00333,
00756, 00756, 00756, 00137, 00143, 00103, 00107, 01003,
00000, 01243, 01737, 01763, 01013, 00000, 00117, 00137,
00463, 00763, 00756, 00756, 00173, 00163, 00457, 00756,
00756, 00756, 00530, 00364, 00353, 00323, 00147, 00073,
01653, 01247, 00756, 00756, 00756, 00756, 00303, 00730,
01730, 00177, 01130, 00743, 01204, 00530, 00414, 00247,
01030, 00773, 00630, 00773, 00000, 00363, 00647, 00637,
00273, 00263, 00756, 00756, 00756, 00756, 01243, 00077,
00756, 00343, 00153, 00000, 01757, 01063, 01463, 00756,
01163, 00756, 00756, 01053, 00530, 00177, 00027, 00037,
01457, 00756, 01607, 00613, 00013, 01253, 00756, 01137,
00756, 00756, 00756, 00756, 00453, 01403, 00313, 00057,
01417, 01257, 00756, 00756, 00756, 00756, 00303, 00000,
00000, 01730, 00264, 01025, 00704, 00247, 01330, 01353,
01630, 00414, 00247, 01230, 01407, 00363, 00653, 00643,
00273, 00263, 00756, 00756, 00756, 00756, 01737, 00353,
00756, 00127, 00157, 00000, 01753, 01067, 01467, 00756,
01563, 00756, 00756, 01453, 00756, 01233, 00023, 00033,
01657, 00756, 01633, 00063, 01057, 01747, 00756, 01537,
00000, 00756, 00756, 00756, 01547, 01347, 00007, 00067,
01373, 00453, 00756, 00756, 00756, 00756, 00237, 00756,
00756, 00756, 00756, 00756, 00756, 00030, 00177, 00000,
01760, 00320, 01160, 01260, 01074, 00330, 01160, 01260,
01670, 01572, 01023, 01000, 00432, 00274, 00130, 00230,
00230, 00230, 01650, 00171, 01074, 00742, 01160, 01260,
00742, 01160, 01260, 00110, 00064, 00363, 00064, 00021,
00432, 01550, 01020, 00432, 01474, 00235, 00163, 00232,
00420, 00432, 01102, 00232, 01160, 00232, 01360, 01102,
00257, 01020, 01334, 00125, 00432, 01000, 01074, 00230,
00235, 01074, 00130, 00235, 00171, 01650, 00043, 00232,
00510, 00674, 00206, 00232, 00432, 00372, 00310, 00210,
00314, 01714, 01724, 01111, 00310, 00064, 01537, 00464,
01711, 00510, 00236, 01524, 01127, 00416, 01025, 00410,
01570, 01556, 00322, 00510, 00416, 01156, 00232, 00216,
00372, 00072, 00467, 00256, 01322, 01147, 01112, 00774,
01746, 01352, 01156, 01666, 01152, 00647, 01746, 01746,
01746, 01020, 00615, 01174, 00732, 00426, 01362, 01174,
00720, 01102, 01162, 00733, 01352, 01201, 01152, 00720,
00763, 01646, 00330, 00372, 01020, 00414, 00614, 00714,
01014, 01214, 01514, 01020, 00574, 00630, 00230, 00272,
01074, 00330, 01160, 01570, 01356, 01234, 00752, 01412,
01243, 00412, 00742, 01217, 01074, 00742, 01402, 01243,
00402, 00324, 01235, 01550, 01020, 00464, 01307, 00032,
00432, 00214, 01274, 01630, 01230, 01230, 01430, 01230,
00420, 01146, 00232, 00372, 00310, 00210, 00410, 00574,
00430, 01156, 01347, 00210, 01146, 01363, 00210, 01714,
01724, 01277, 00410, 00314, 00300, 00334, 01312, 00314,
01734, 01303, 00300, 01724, 01317, 00334, 01312, 00210,
00372, 00100, 00064, 00323, 01025, 00764, 01743, 00604,
01110, 01110, 01110, 00372, 00432, 01474, 00330, 00410,
01414, 00420, 00310, 01764, 01431, 00132, 00172, 01424,
01353, 00464, 00035, 00711, 00210, 00410, 00424, 01764,
00624, 01766, 00764, 01733, 00000, 00000, 00304, 01061,
00064, 00223, 00372, 01237, 01537, 00764, 01767, 00000,
00064, 00523, 00264, 01607, 00013, 01037, 00713, 01433,
01023, 00753, 00756, 00756, 00756, 00756, 01177, 00423,
00756, 00756, 00247, 00000, 00756, 00756, 00143, 00637,
00756, 00756, 00756, 00053, 00543, 00000, 00756, 00756,
01053, 00623, 00000, 00433, 01123, 01057, 00653, 00756,
00103, 00756, 00130, 00363, 00000, 00533, 01457, 00443,
00457, 00503, 00756, 00756, 00756, 00756, 01303, 00756,
00756, 00756, 00756, 00756, 00756, 00756, 00374, 00756,
00620, 01354, 01477, 00733, 00164, 00077, 00030, 00733,
01601, 00630, 00743, 01601, 00704, 01204, 01530, 00743,
00434, 00770, 01234, 00770, 00164, 01647, 00064, 00167,
01430, 00720, 00434, 00412, 00734, 00412, 01024, 00412,
01004, 00620, 00030, 00743, 01630, 00756, 00643, 01230,
00756, 00547, 00434, 01447, 00734, 01447, 00624, 01447,
01030, 00603, 01601, 00730, 01204, 01447, 00164, 00177,
00164, 00247, 00424, 01600, 00624, 01600, 01605, 01007,
01601, 00404, 00604, 00743, 01601, 00704, 01007, 01601,
01004, 01007, 00756, 00424, 01654, 00634, 01643, 00724,
01656, 01224, 01476, 00363, 00424, 01452, 00624, 01452,
01234, 01452, 01004, 00574, 01730, 01730, 00743, 00424,
01654, 00624, 01656, 01034, 01654, 00752, 01552, 01755,
00232, 00716, 00232, 00743, 01542, 01566, 00130, 00733,
01024, 01670, 00724, 01474, 00624, 01670, 01224, 01474,
00314, 01100, 00324, 01676, 01330, 00363, 00430, 01074,
01000, 00256, 00716, 00416, 00164, 00220, 01601, 01130,
00704, 00404, 00743, 00424, 01721, 00634, 01727, 00330,
00337, 01024, 01467, 00330, 01224, 01467, 00343, 01342,
01717, 00742, 01563, 01477, 01142, 01024, 01717, 00337,
01214, 00414, 00614, 00714, 01014, 01514, 01020, 01224,
01753, 01230, 00363, 01430, 00363, 01152, 01014, 00372,
00410, 00372, 00464, 01307, 00764, 01763, 00764, 01737,
00000, 00000, 00000, 00000, 00000, 00000, 00000, 00000,
00117, 01707, 00766, 01113, 01237, 01143, 01167, 01073,
01065, 01133, 01020, 01123, 01117, 01243, 01157, 00230,
01711, 01172, 01020, 00701, 01030, 01117, 01362, 00430,
01475, 01243, 01053, 01172, 01172, 01017, 01030, 00107,
00773, 01003, 01166, 01147, 01237, 01027, 01037, 01166,
00733, 01047, 01020, 01123, 01117, 01053, 01166, 01107,
01172, 00727, 00743, 01705, 00763, 00123, 00757, 00742,
01065, 00673, 00766, 00717, 00766, 00473, 01166, 01103,
01053, 00123, 00617, 01237, 01166, 00627, 01107, 01113,
00717, 00157, 00163, 01017, 01172, 01013, 00772, 00717,
00742, 01061, 00637, 00742, 01061, 00742, 01166, 00643,
01172, 01172, 01172, 00657, 01166, 00603, 01166, 01172,
00330, 01115, 01723, 01201, 00123, 01201, 00157, 00742,
00742, 00766, 00107, 01115, 01731, 01237, 00742, 01172,
00426, 01166, 01020, 00772, 01243, 01705, 01142, 01123,
00701, 00430, 01117, 00766, 00230, 01123, 00730, 01713,
01711, 00173, 01175, 00430, 01123, 01711, 01147, 01711,
01117, 01166, 01030, 01123, 01142, 01142, 01142, 01020,
01711, 01061, 01142, 00772, 00772, 01020, 00766, 01243,
00701, 00230, 00107, 00230, 01707, 01705, 01123, 01166,
01166, 01166, 00707, 01362, 00366, 01475, 00742, 00742,
00742, 01020, 01441, 01717, 01362, 00260, 01475, 01237,
01711, 01353, 01711, 00762, 01727, 01172, 00742, 01717,
01562, 00317, 01441, 01333, 01455, 01717, 00701, 01362,
00332, 01020, 01362, 00306, 01455, 01713, 01731, 01243,
00274, 00330, 00130, 00174, 00230, 01374, 01020, 00274,
00330, 00330, 01757, 01705, 00762, 01727, 00766, 01243,
01705, 00766, 00630, 00230, 01074, 00716, 00220, 00000,
01547, 01373, 00766, 01547, 01543, 01547, 01413, 01517,
01217, 01313, 01343, 01253, 00133, 01363, 01263, 01441,
00766, 00766, 00766, 00766, 00766, 01020, 00030, 01142,
00274, 00330, 00530, 00174, 00530, 00130, 00174, 01020,
00202, 00242, 00762, 00762, 00174, 00330, 00030, 01630,
00212, 00464, 00220, 00642, 00107, 00430, 01074, 00230,
00127, 01042, 01074, 00130, 00422, 01102, 00000, 00023,
00274, 00230, 00230, 00766, 01020, 00432, 01172, 01674,
00251, 01155, 01142, 00177, 00410, 00310, 00372, 01414,
00064, 01717, 00620, 00000, 01714, 01724, 00467, 01204,
00500, 01534, 00506, 00310, 00624, 00526, 00223, 01234,
00506, 01004, 00424, 00617, 01474, 00620, 01302, 00475,
00330, 00720, 00342, 00302, 01504, 00263, 00000, 00000,
01152, 00257, 01354, 00452, 01020, 00436, 01176, 00251,
01155, 00251, 01155, 00251, 01155, 00251, 01514, 01474,
01142, 00563, 00410, 00227, 00410, 01110, 01110, 01110,
00310, 00372, 00264, 01603, 00404, 00310, 01221, 00372,
01750, 00420, 00432, 01274, 01130, 01674, 01730, 01730,
00232, 00172, 01672, 01672, 01672, 00432, 01172, 00236,
00332, 00072, 00210, 01474, 00251, 01160, 00410, 00070,
00603, 01474, 00251, 01160, 00310, 00232, 00070, 00410,
01360, 00666, 00672, 01122, 00707, 00734, 00622, 01221,
01770, 00227, 00232, 00704, 00174, 00230, 00030, 01274,
00530, 00232, 00707, 00620, 01302, 00633, 00342, 01474,
01020, 00000, 00000, 00000, 01074, 00330, 01160, 01020,
00372, 01221, 00332, 01750, 00172, 01470, 00232, 01370,
01034, 00670, 01426, 00670, 01166, 01350, 01770, 01377,
01166, 01350, 01770, 01160, 00372, 01360, 00372, 01174,
01020, 01542, 01251, 00604, 01414, 01204, 01443, 01404,
00764, 01035, 00432, 01160, 01770, 00422, 01352, 00721,
00432, 01766, 00620, 00054, 00721, 01556, 00731, 01766,
01567, 01156, 01356, 00735, 01130, 01221, 00424, 00741,
01450, 00174, 00230, 00530, 01350, 00332, 01174, 00530,
01474, 01730, 00664, 01465, 01434, 00760, 00404, 01241,
01156, 01142, 01653, 01130, 01074, 01424, 00770, 00330,
00232, 01221, 01370, 00174, 01142, 01174, 01130, 01350,
00232, 01465, 00564, 01241, 01156, 01142, 00007, 01741,
00451, 00564, 01221, 01474, 01670, 00130, 01650, 00434,
01301, 01224, 01641, 00724, 00703, 01407, 00764, 00133,
00764, 00337, 00660, 00131, 00330, 01074, 00130, 01730,
00141, 01074, 00230, 01605, 00461, 00724, 01641, 00764,
01061, 00131, 00430, 01074, 00130, 01605, 00461, 00764,
01207, 00410, 00660, 00420, 00310, 00764, 01061, 00131,
00130, 01074, 00330, 01130, 00141, 01605, 00461, 00724,
01641, 00764, 01061, 00131, 00230, 01074, 00330, 01605,
00461, 00277, 00764, 01237, 01700, 00474, 01715, 00272,
00711, 01360, 00735, 00232, 01142, 01160, 00372, 00070,
00032, 01374, 00246, 00520, 00520, 00520, 00520, 00520,
00520, 00520, 00406, 00132, 00472, 00532, 00711, 01360,
01005, 00372, 01360, 01005, 00232, 01142, 00527, 01360,
01005, 00453, 01074, 01130, 01130, 01160, 01020, 00314,
00432, 01410, 00100, 00324, 01205, 00756, 00753, 00764,
01303, 00314, 00100, 00334, 01202, 00420, 01474, 00314,
01700, 00324, 01406, 01020, 00410, 01074, 00314, 01300,
00334, 01223, 01004, 00760, 01324, 01032, 01605, 00100,
00711, 00735, 01370, 01674, 00406, 00372, 00332, 01162,
01362, 00707, 01162, 01362, 00704, 01162, 01362, 01254,
01427, 01142, 01142, 01427, 00404, 00764, 00645, 01465,
00764, 01321, 01174, 01142, 01277, 01741, 00451, 01024,
01273, 00764, 00425, 00434, 01301, 01224, 01641, 00724,
01304, 00764, 01061, 01133, 00604, 00764, 00645, 01204,
01074, 01142, 01277, 00432, 01573, 00232, 00624, 01313,
00711, 00735, 01370, 01374, 00406, 00532, 00372, 00735,
01374, 01370, 00346, 00406, 00532, 00372, 00232, 01174,
01020, 00310, 01700, 00260, 00100, 01374, 01701, 00100,
00272, 00735, 00232, 00174, 01715, 00100, 00674, 01707,
00620, 00000, 00000, 00000, 00420, 01354, 01360, 01020,
00624, 01405, 00232, 00711, 00735, 01374, 01370, 00172,
00372, 00146, 01032, 01532, 01410, 01020, 01374, 00232,
01342, 01657, 00032, 00416, 00604, 00704, 01504, 01142,
01142, 00123, 00564, 01437, 00564, 01407, 01074, 00330,
01160, 01670, 00272, 00732, 00620, 00454, 01433, 00422,
00174, 00620, 00562, 01342, 01446, 00762, 01354, 01441,
00226, 00774, 00402, 01634, 01456, 00230, 00034, 01461,
00130, 00374, 00406, 01772, 01772, 01274, 01020, 01474,
01160, 00232, 00070, 00232, 01532, 01503, 01142, 00343,
00704, 00774, 00130, 00416, 01020, 00624, 01273, 01074,
00330, 01160, 01770, 00232, 00732, 00732, 00374, 01666,
00620, 00754, 01517, 00006, 00232, 00562, 00543, 00742,
00620, 01154, 01525, 00274, 00014, 01614, 01342, 01546,
00004, 01142, 01342, 01546, 00014, 01604, 00130, 01650,
01020, 01074, 00330, 01160, 01570, 01356, 01563, 01024,
01567, 00432, 01550, 00574, 00730, 00230, 01730, 01074,
01152, 00757, 01146, 00252, 00574, 00530, 01112, 01152,
00773, 00212, 01212, 00376, 01174, 01730, 01750, 00774,
01342, 01613, 00704, 01020, 01524, 01657, 00072, 01274,
01330, 01230, 01530, 00406, 00272, 01106, 00210, 00314,
01714, 01724, 01630, 01724, 01641, 00560, 00334, 01633,
01020, 01524, 01657, 00510, 00314, 00064, 00357, 00314,
01700, 00560, 00324, 01112, 00360, 00100, 01020, 01235,
00360, 00510, 00264, 01753, 00372, 01100, 00332, 00314,
01160, 01074, 01342, 01732, 01474, 01413, 00520, 00520,
00720, 00720, 01152, 01373, 00070, 00206, 00202, 00232,
01360, 00332, 01156, 01160, 00070, 01344, 01721, 00620,
00206, 00232, 00332, 01074, 01146, 01342, 01732, 00232,
01360, 00232, 01020, 00564, 00167, 00564, 00467, 00564,
01007, 00564, 00623, 01172, 01074, 00212, 00030, 01230,
01474, 01402, 00413, 00564, 00003, 00000, 00000, 00000,
00000, 00000, 00000, 00000, 00000, 00432, 01617, 01557,
01567, 00664, 01063, 00664, 00307, 01577, 01607, 00000,
00630, 01130, 00330, 00130, 00430, 00730, 00130, 01030,
00030, 00530, 00630, 00774, 01020, 00420, 00662, 01410,
01156, 00664, 01223, 00432, 00774, 00230, 00330, 00030,
00230, 00530, 01030, 00530, 00030, 01130, 00230, 01130,
01130, 00430, 00774, 01020, 00774, 01372, 00173, 01562,
00213, 00664, 00435, 01356, 00251, 00756, 00032, 01626,
01356, 00267, 01646, 00162, 01274, 00620, 01122, 00327,
00122, 00436, 00373, 01672, 00742, 00122, 00172, 00420,
00522, 00410, 00222, 00732, 01672, 01162, 00423, 01410,
00410, 00472, 00732, 01122, 00357, 00262, 01122, 00522,
00523, 00132, 00732, 00573, 00544, 00121, 00762, 00620,
00132, 00122, 00732, 00367, 01162, 00720, 00372, 00764,
01321, 01672, 00372, 00627, 00472, 01142, 00623, 01562,
00134, 00244, 00273, 00432, 01625, 00664, 01165, 00022,
00734, 00163, 01262, 01224, 00744, 00624, 00337, 00664,
00165, 00064, 00417, 01234, 00202, 01010, 01526, 00204,
01310, 00232, 00264, 01753, 01522, 00200, 00232, 00664,
00435, 00432, 00747, 01234, 00202, 01010, 00172, 01512,
00200, 00656, 01116, 00736, 01526, 00245, 01516, 00240,
00222, 00262, 00562, 00562, 00622, 01362, 00241, 00404,
00422, 00372, 01310, 00372, 00257, 01516, 00222, 00132,
01003, 00272, 01102, 01526, 00257, 00432, 00717, 00664,
01165, 00664, 00511, 00522, 01122, 00416, 00313, 00704,
00664, 01165, 01327, 01356, 00155, 01172, 00372, 00066,
00115, 00232, 01072, 01312, 00306, 01072, 00232, 00372,
01352, 00313, 01272, 00206, 00620, 00732, 00554, 00314,
00774, 01502, 00334, 00726, 00232, 00222, 00664, 00305,
00664, 00421, 00426, 00717, 00656, 00620, 01523, 00372,
00115, 00372, 00664, 00551, 00737, 00720, 01156, 00254,
00345, 01020, 01210, 00610, 00710, 01366, 00463, 01362,
00364, 00704, 01204, 00422, 00664, 00511, 00022, 00564,
00211, 00314, 01154, 00467, 01572, 00402, 01010, 00710,
01310, 00432, 00032, 00072, 00266, 01362, 00417, 00404,
01534, 00417, 01234, 00417, 01214, 00704, 00414, 00774,
01352, 00616, 00445, 00634, 00630, 01601, 00432, 00172,
00372, 01672, 00642, 01206, 00243, 00132, 00232, 00664,
01165, 00410, 00232, 00664, 00361, 01156, 00664, 01321,
00372, 00132, 00710, 00232, 00664, 00521, 00022, 01552,
00630, 00132, 01123, 00752, 00222, 01532, 00367, 00132,
01010, 00372, 01310, 00372, 00664, 00375, 01364, 00621,
00132, 00232, 00710, 00664, 00155, 01010, 01310, 00510,
00027, 01534, 00515, 00610, 00710, 01020, 00172, 01332,
00534, 01102, 01532, 00621, 00232, 00634, 00532, 01545,
00432, 00563, 01264, 00215, 00232, 00445, 00432, 01064,
01631, 00372, 01264, 00215, 00572, 01772, 00372, 01234,
00563, 01605, 00372, 00232, 01072, 00232, 00372, 00432,
00664, 01165, 00022, 00734, 00567, 01605, 00472, 00422,
00024, 00604, 00756, 00756, 00664, 00551, 00022, 01624,
00604, 00172, 01732, 01032, 00664, 01241, 01524, 00171,
01010, 01310, 00022, 00232, 00064, 00417, 01356, 00516,
00132, 00624, 00202, 00445, 00664, 00715, 00022, 01545,
00774, 00410, 00510, 00436, 00756, 01356, 00645, 00762,
00620, 00654, 00634, 00510, 00607, 00410, 00432, 00762,
01772, 01333, 00232, 00410, 00742, 00262, 00410, 01732,
01732, 01122, 01277, 00022, 00472, 00232, 00172, 01632,
01253, 00410, 00762, 00410, 00132, 00732, 00620, 00654,
00666, 00372, 00664, 00551, 01433, 01646, 01122, 01427,
00022, 00416, 00410, 00274, 00372, 01641, 00372, 01507,
00472, 01142, 01503, 01672, 00402, 01366, 00537, 00720,
01463, 01224, 00735, 01204, 01020, 01214, 01020, 01672,
00756, 01556, 00737, 01020, 00132, 01010, 00764, 00657,
00432, 01172, 00422, 00244, 00771, 01444, 01012, 01544,
01020, 00444, 01026, 00144, 01032, 01474, 00730, 00274,
01020, 00674, 00630, 00630, 01030, 00630, 00530, 00230,
00430, 01130, 00130, 00130, 00630, 00313, 00630, 01344,
00766, 00033, 00374, 00031, 00174, 01030, 00474, 01020,
01374, 00031, 01474, 01130, 00674, 01020, 00174, 00031,
01574, 01020, 00574, 00031, 00374, 01020, 00432, 00774,
00430, 00530, 00313, 00774, 00432, 00730, 01030, 00530,
00330, 01130, 01030, 00130, 00630, 00330, 00330, 01130,
00730, 00530, 00774, 01020, 01504, 00604, 01204, 01010,
00353, 00272, 00610, 00710, 00232, 00032, 00072, 00226,
01362, 01107, 00704, 01224, 01106, 00404, 00422, 00372,
00024, 01215, 01634, 01120, 00232, 00272, 01772, 01632,
00171, 00372, 01156, 01552, 01131, 01156, 00547, 00756,
01672, 00372, 00410, 00510, 00572, 00572, 00572, 01772,
00372, 01552, 01162, 00764, 00765, 00432, 00372, 00510,
00572, 00732, 00034, 01156, 01672, 01772, 00372, 01032,
00757, 00472, 00372, 00510, 00372, 00034, 01225, 01556,
01224, 00732, 01127, 01234, 01204, 01214, 00424, 01202,
00404, 00677, 00414, 00677, 01204, 00634, 01176, 00734,
01213, 00714, 00677, 00704, 00677, 00215, 00553, 00132,
01032, 01164, 01545, 01153, 00756, 01552, 01234, 01032,
01077, 00472, 00664, 01165, 00022, 00024, 01251, 00372,
00510, 00372, 00664, 00551, 00022, 00410, 00215, 00664,
00355, 01156, 00410, 00510, 00756, 01467, 00732, 01477,
00432, 00032, 00642, 00664, 01241, 01443, 00774, 00510,
01224, 01521, 01534, 01263, 00372, 00710, 01364, 01011,
01310, 00710, 00132, 00664, 00155, 00434, 01310, 01262,
00064, 00417, 00620, 00644, 01266, 00756, 01453, 00432,
00372, 01164, 01641, 00372, 00764, 00715, 00654, 01321,
00372, 00410, 01672, 01672, 00432, 00774, 00130, 00410,
01274, 00630, 01667, 01646, 01646, 01122, 01617, 00022,
00410, 00232, 01072, 00472, 00410, 00172, 00262, 01142,
01627, 00232, 00726, 00232, 01366, 01373, 01162, 00022,
01672, 01667, 00756, 01162, 01753, 00422, 00410, 00232,
01132, 00510, 01224, 01406, 01216, 00132, 01332, 01504,
00664, 00551, 00022, 00634, 01263, 00172, 01074, 00442,
00143, 00732, 00676, 00147, 00662, 01672, 00172, 00756,
00732, 00236, 00664, 00375, 00621, 01534, 01470, 00372,
00132, 00710, 00232, 00664, 00521, 00232, 00410, 00616,
01310, 00510, 00232, 01001, 01010, 01310, 00710, 00216,
00016, 01672, 00410, 00664, 00355, 00664, 00165, 00613,
00372, 00132, 00510, 00232, 01056, 00016, 01672, 00664,
00551, 00422, 01264, 01317, 00432, 00624, 01515, 01172,
00412, 00304, 00422, 00064, 00417, 01534, 01260, 00432,
00603, 00624, 01530, 00132, 00664, 00715, 01264, 01317,
01534, 01260, 00372, 00132, 00710, 00664, 00155, 01011,
01310, 00710, 01264, 01427, 00072, 00356, 00774, 00332,
00556, 00733, 00332, 01164, 01575, 00642, 00707, 00720,
00667, 00664, 00421, 00072, 00664, 01323, 00332, 01156,
00757, 00332, 00667, 00620, 01354, 01567, 00332, 00717,
00664, 00165, 00734, 01605, 01262, 00564, 00177, 00520,
00520, 00520, 00520, 00520, 00520, 01020, 01074, 00334,
01625, 00416, 00130, 01360, 01433, 01160, 00372, 00410,
00070, 00376, 00316, 00752, 00752, 00752, 01410, 01252,
00420, 01233, 00720, 00720, 00706, 00706, 01152, 01213,
00070, 00232, 00520, 00520, 01646, 01646, 00242, 00620,
00242, 00332, 01353, 00272, 01160, 00070, 00474, 00206,
00520, 00520, 00232, 01474, 01360, 00232, 01142, 01317,
01074, 01142, 01542, 01663, 00510, 00372, 00064, 00527,
00520, 00520, 00520, 00520, 00520, 00520, 01020, 01334,
01706, 00372, 00410, 00064, 00021, 01356, 01704, 01074,
00620, 00620, 01152, 01543, 00272, 01160, 00070, 00232,
00706, 00706, 01074, 00246, 01703, 01160, 00346, 00070,
00206, 01441, 01441, 01160, 00306, 00232, 01360, 00332,
01146, 01542, 01745, 00232, 01160, 01772, 01772, 01360,
00510, 00372, 00314, 00264, 01737, 00000, 00000, 00000,
00163, 00207, 00163, 00233, 00233, 00143, 00203, 01533,
01333, 01507, 01363, 00253, 01437, 00273, 01457, 00064,
00363, 00510, 00256, 00012, 00332, 00774, 00314, 00220,
00410, 01764, 01431, 00510, 01410, 00716, 01564, 00220,
00604, 01474, 01230, 01474, 01764, 00373, 01410, 00716,
01664, 00220, 01004, 01074, 00642, 00642, 01074, 00642,
00642, 01474, 00332, 00410, 00642, 00347, 01204, 01564,
01357, 01102, 00232, 01074, 00272, 00732, 00732, 00212,
00732, 00732, 00256, 00620, 01254, 00100, 00064, 00021,
01556, 00114, 00064, 00111, 01074, 00620, 00620, 01152,
00467, 01160, 00372, 00070, 00372, 00132, 01442, 00205,
00720, 00720, 01354, 00126, 00747, 01160, 00232, 00070,
00232, 01532, 00144, 00747, 01074, 01442, 00205, 01174,
01442, 00205, 01674, 01442, 00205, 00274, 01442, 00205,
01574, 01442, 00205, 00474, 01442, 00205, 01274, 01442,
00205, 01074, 01146, 01542, 00135, 00624, 00765, 00230,
00604, 00567, 01574, 00132, 00507, 00102, 01442, 00212,
00102, 00543, 00102, 00620, 01442, 00220, 00720, 00543,
00102, 01442, 00225, 00102, 01073, 00752, 00620, 00620,
00254, 00225, 00752, 00752, 00752, 01410, 01252, 00272,
00510, 00372, 00064, 00021, 01034, 00262, 00232, 00474,
00706, 00706, 00706, 00232, 00224, 00262, 00204, 00124,
00262, 00432, 00216, 01550, 00064, 00317, 01565, 01424,
01422, 00564, 00071, 01413, 01565, 01424, 00052, 01262,
00664, 00745, 00564, 00175, 00324, 00765, 01513, 01565,
01424, 00056, 01403, 01565, 01424, 00017, 00664, 00145,
01413, 01641, 01360, 00510, 00064, 00357, 01641, 01134,
00332, 01310, 00232, 00064, 00417, 00216, 00256, 01474,
00742, 01623, 01564, 01357, 01230, 01404, 01416, 00362,
00332, 00410, 01074, 00402, 01160, 00070, 00132, 00232,
01410, 01414, 01020, 00432, 01550, 00077, 01400, 01414,
01104, 00064, 00527, 00324, 01256, 00064, 00463, 00000,
01747, 00107, 00123, 00307, 00173, 00323, 00363, 00407,
00333, 00343, 00427, 00423, 00433, 00353, 00463, 00664,
01553, 00564, 01171, 00133, 00664, 00451, 00064, 00417,
00610, 00710, 00422, 00133, 01464, 01733, 00564, 01433,
00163, 00473, 01173, 01203, 01213, 01237, 00143, 00403,
01223, 01273, 01253, 01247, 01257, 01313, 00443, 00064,
00363, 00664, 01265, 00133, 00564, 00357, 00764, 00347,
01064, 01653, 01264, 00323, 01010, 01310, 00232, 01204,
00604, 01004, 01064, 00223, 01204, 00604, 01264, 00347,
00372, 01404, 00064, 00133, 01664, 01337, 00664, 00017,
00677, 00653, 00763, 00707, 00663, 01017, 01013, 00747,
00720, 00720, 00720, 01057, 00404, 00603, 00404, 01504,
00432, 01160, 01770, 00434, 00550, 00232, 00564, 01227,
01371, 00633, 01210, 01072, 01372, 00566, 00717, 01210,
01072, 01572, 00566, 00064, 00111, 00314, 00510, 00064,
00357, 01210, 01504, 00773, 01210, 00232, 01262, 00664,
00745, 01017, 01262, 01566, 00610, 01524, 00566, 00717,
01362, 00566, 00717, 01670, 00272, 00344, 00624, 00744,
00624, 00030, 00720, 01360, 01502, 00566, 00717, 01766,
01766, 01601, 01471, 00232, 01764, 00313, 00564, 01063,
00564, 00633, 00564, 01467, 01004, 00764, 00633, 00564,
00353, 01204, 00604, 01504, 01164, 00013, 01345, 00406,
00216, 00133, 01345, 00016, 00664, 01165, 01156, 00226,
00133, 01664, 00173, 00432, 01160, 01770, 00274, 00620,
01766, 01354, 00677, 01352, 00706, 00432, 01224, 00773,
00624, 00627, 01766, 01565, 00464, 01547, 00314, 01366,
00731, 01410, 01166, 00724, 00726, 00420, 00742, 01473,
00304, 01020, 01356, 00743, 01156, 01356, 00744, 01156,
01356, 00745, 01737, 01766, 01766, 01474, 01020, 01766,
01565, 01074, 01730, 01531, 01156, 00334, 00073, 01330,
01474, 01471, 01156, 00334, 00073, 00510, 00372, 00264,
01757, 00064, 00233, 01362, 00747, 01551, 01772, 01772,
01772, 00372, 00064, 00021, 00464, 01711, 00520, 00520,
00520, 00372, 01410, 00464, 01213, 01305, 00230, 00230,
00137, 01305, 00430, 00133, 01305, 00030, 00030, 01650,
00064, 00463, 00064, 00413, 00364, 00023, 00625, 00272,
01352, 01044, 00756, 01020, 00756, 01356, 01054, 01156,
00726, 00620, 01526, 01045, 01020, 01200, 00064, 00527,
01227, 01747, 01247, 00107, 00067, 00163, 00123, 00553,
00563, 00613, 01513, 01617, 00513, 00517, 01717, 00533,
00643, 01763, 01773, 00657, 00673, 00267, 00703, 01737,
00753, 01027, 01017, 01043, 01067, 01057, 00503, 01457,
00264, 01767, 01004, 00625, 00664, 01617, 01564, 01355,
01464, 01537, 00625, 00573, 00625, 01262, 01010, 00664,
00745, 01753, 00664, 00135, 01753, 00610, 00710, 01020,
00372, 00664, 01633, 00731, 00710, 01753, 00764, 01753,
00432, 01160, 01770, 00372, 01750, 00153, 01134, 01171,
01310, 01020, 00731, 01264, 00215, 00572, 00572, 01772,
00766, 00416, 01753, 00004, 01033, 00014, 01614, 01457,
00014, 01604, 01457, 00064, 00013, 00410, 00432, 01074,
00402, 01160, 00372, 00070, 00232, 00332, 00330, 01160,
00070, 00232, 01360, 00332, 01160, 00232, 01360, 00332,
00742, 01077, 00410, 00064, 00357, 01010, 01310, 00232,
01753, 00072, 01114, 00160, 01434, 00373, 00060, 00064,
00373, 00372, 01764, 01431, 01670, 01674, 01020, 00372,
01074, 00330, 01160, 01570, 00124, 01300, 00234, 00363,
00422, 01772, 01772, 01772, 01572, 01310, 00064, 00307,
01360, 00124, 01306, 00064, 00363, 01410, 00332, 00664,
00461, 01753, 00625, 00232, 01264, 00171, 00756, 00756,
00664, 00511, 00022, 00410, 01264, 00215, 00664, 00355,
00664, 00165, 01753, 00625, 00032, 00226, 00372, 01264,
00215, 00372, 00756, 00756, 00664, 00551, 00022, 00410,
01264, 00171, 01573, 01564, 01355, 01464, 01513, 01110,
01110, 01110, 00064, 00417, 00364, 00003, 00264, 01763,
01431, 01674, 01542, 01405, 00404, 00474, 01342, 01411,
00704, 01374, 01020, 00642, 00077, 01564, 01357, 00141,
00030, 00127, 00672, 00141, 00130, 01650, 00064, 00363,
01431, 01670, 00774, 00716, 00716, 00720, 00652, 00167,
01020, 00716, 00652, 00220, 00372, 01262, 00064, 00417,
01664, 01467, 01557, 01757, 01637, 01457, 00243, 00133,
01402, 01413, 01431, 01670, 01374, 00530, 01374, 00732,
01142, 00337, 00202, 01650, 00064, 00463, 00624, 01460,
01402, 01441, 01424, 01506, 01245, 00437, 00001, 00424,
01566, 01362, 01643, 00734, 01516, 00742, 00674, 01162,
00716, 00716, 01542, 01532, 01512, 01535, 00766, 00724,
01542, 00633, 00724, 01546, 00623, 00734, 01545, 00742,
01574, 00627, 01574, 00130, 00274, 00742, 01750, 01746,
00762, 00574, 01162, 00720, 00706, 01562, 01552, 01352,
01563, 01152, 00657, 00106, 01770, 00763, 01074, 00216,
00706, 01474, 00242, 00216, 01750, 00256, 00274, 01772,
00620, 01354, 01577, 01410, 01326, 01643, 01112, 00156,
01352, 01615, 00412, 01216, 01156, 01512, 01620, 01113,
00012, 01216, 00516, 00232, 01512, 01637, 01352, 01637,
00432, 01312, 01645, 00372, 01414, 00060, 01217, 01312,
01642, 01216, 00356, 00064, 00523, 01172, 00412, 00362,
01157, 01404, 01134, 01656, 00332, 01310, 01104, 01431,
01670, 01474, 00130, 01500, 00324, 01671, 00224, 01673,
01353, 01400, 01650, 00432, 00314, 00372, 00432, 00752,
01230, 01674, 00230, 00230, 01374, 01020, 01074, 00330,
01160, 01770, 01020, 01434, 01721, 01431, 00674, 01542,
01727, 01245, 00372, 00774, 00130, 00372, 01162, 01674,
00030, 00030, 01603, 01424, 01742, 01245, 00474, 00742,
01750, 01217, 01431, 00474, 01342, 01737, 01603, 01410,
01434, 01444, 00001, 00424, 01763, 00372, 01366, 01761,
01262, 00372, 01217, 00574, 01152, 01352, 01771, 00130,
00763, 00330, 00763, 00332, 01310, 01114, 00064, 00373
};
